@@ -25,32 +25,35 @@ class Context(ABC):
     Context that providing API that can be
     used inside `tile` and `execute`.
     """
+
     prev = None
     current = None
 
-    def __init__(self,
-                 session_id: str = None,
-                 supervisor_address: str = None,
-                 worker_address: str = None,
-                 current_address: str = None,
-                 band: BandType = None):
+    def __init__(
+        self,
+        session_id: str = None,
+        supervisor_address: str = None,
+        worker_address: str = None,
+        local_address: str = None,
+        band: BandType = None,
+    ):
         if session_id is None:
             # try to get session id from environment
-            session_id = os.environ.get('MARS_SESSION_ID')
+            session_id = os.environ.get("MARS_SESSION_ID")
             if session_id is None:
-                raise ValueError('session_id should be provided '
-                                 'to create a context')
+                raise ValueError("session_id should be provided " "to create a context")
         if supervisor_address is None:
             # try to get supervisor address from environment
-            supervisor_address = os.environ.get('MARS_SUPERVISOR_ADDRESS')
+            supervisor_address = os.environ.get("MARS_SUPERVISOR_ADDRESS")
             if supervisor_address is None:
-                raise ValueError('supervisor_address should be provided '
-                                 'to create a context')
+                raise ValueError(
+                    "supervisor_address should be provided " "to create a context"
+                )
 
         self.session_id = session_id
         self.supervisor_address = supervisor_address
         self.worker_address = worker_address
-        self.current_address = current_address
+        self.local_address = local_address
         self.band = band
 
     @abstractmethod
@@ -63,6 +66,16 @@ class Context(ABC):
         session
         """
 
+    @abstractmethod
+    def get_local_host_ip(self) -> str:
+        """
+        Get local worker's host ip
+
+        Returns
+        -------
+        host_ip : str
+        """
+
     @abstractmethod
     def get_supervisor_addresses(self) -> List[str]:
         """
@@ -94,8 +107,17 @@ class Context(ABC):
         """
 
     @abstractmethod
-    def get_chunks_result(self,
-                          data_keys: List[str]) -> List:
+    def get_slots(self) -> int:
+        """
+        Get num of slots of current band
+
+        Returns
+        -------
+        number_of_bands: int
+        """
+
+    @abstractmethod
+    def get_chunks_result(self, data_keys: List[str]) -> List:
         """
         Get result of chunks.
 
@@ -111,10 +133,9 @@ class Context(ABC):
         """
 
     @abstractmethod
-    def get_chunks_meta(self,
-                        data_keys: List[str],
-                        fields: List[str] = None,
-                        error='raise') -> List[Dict]:
+    def get_chunks_meta(
+        self, data_keys: List[str], fields: List[str] = None, error="raise"
+    ) -> List[Dict]:
         """
         Get meta of chunks.
 
@@ -153,9 +174,7 @@ class Context(ABC):
         """
 
     @abstractmethod
-    def create_remote_object(self,
-                             name: str,
-                             object_cls, *args, **kwargs):
+    def create_remote_object(self, name: str, object_cls, *args, **kwargs):
         """
         Create remote object.
 
@@ -189,8 +208,7 @@ class Context(ABC):
         """
 
     @abstractmethod
-    def destroy_remote_object(self,
-                              name: str):
+    def destroy_remote_object(self, name: str):
         """
         Destroy remote object.
 
@@ -201,12 +219,14 @@ class Context(ABC):
         """
 
     @abstractmethod
-    def register_custom_log_path(self,
-                                 session_id: str,
-                                 tileable_op_key: str,
-                                 chunk_op_key: str,
-                                 worker_address: str,
-                                 log_path: str):
+    def register_custom_log_path(
+        self,
+        session_id: str,
+        tileable_op_key: str,
+        chunk_op_key: str,
+        worker_address: str,
+        log_path: str,
+    ):
         """
         Register custom log path.
 
