@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@ from .core import DataFrameBinopUfunc
 class DataFrameAnd(DataFrameBinopUfunc):
     _op_type_ = OperandDef.AND
 
-    _func_name = '__and__'
-    _rfunc_name = '__rand__'
+    _bit_func_name = "__and__"
+    _bit_rfunc_name = "__rand__"
 
     @classproperty
     def _operator(self):
@@ -32,14 +32,15 @@ class DataFrameAnd(DataFrameBinopUfunc):
     @classproperty
     def tensor_op_type(self):
         from ...tensor.arithmetic import TensorBitand
+
         return TensorBitand
 
 
-def bitand(df, other, axis='columns', level=None, fill_value=None):
+def bitand(df, other, axis="columns", level=None, fill_value=None):
     op = DataFrameAnd(axis=axis, level=level, fill_value=fill_value, lhs=df, rhs=other)
     return op(df, other)
 
 
-def rbitand(df, other, axis='columns', level=None, fill_value=None):
+def rbitand(df, other, axis="columns", level=None, fill_value=None):
     op = DataFrameAnd(axis=axis, level=level, fill_value=fill_value, lhs=other, rhs=df)
     return op.rcall(df, other)
