@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,20 +15,26 @@
 
 from ... import opcodes as OperandDef
 from ...utils import classproperty
-from .core import DataFrameBinOpMixin, DataFrameBinOp
+from .core import DataFrameBinopUfunc
 from .docstring import bin_compare_doc
 
 
-class DataFrameLess(DataFrameBinOp, DataFrameBinOpMixin):
+class DataFrameLess(DataFrameBinopUfunc):
     _op_type_ = OperandDef.LT
 
-    _func_name = 'lt'
-    _rfunc_name = 'gt'
+    _func_name = "lt"
+    _rfunc_name = "gt"
 
     @classproperty
     def _operator(self):
         return lambda lhs, rhs: lhs.lt(rhs)
 
+    @classproperty
+    def tensor_op_type(self):
+        from ...tensor.arithmetic import TensorLessThan
+
+        return TensorLessThan
+
 
 _lt_example = """
 >>> a.lt(b, fill_value=0).execute()
@@ -42,7 +48,7 @@ dtype: bool
 """
 
 
-@bin_compare_doc('Less than', equiv='<', series_example=_lt_example)
-def lt(df, other, axis='columns', level=None):
+@bin_compare_doc("Less than", equiv="<", series_example=_lt_example)
+def lt(df, other, axis="columns", level=None):
     op = DataFrameLess(axis=axis, level=level, lhs=df, rhs=other)
     return op(df, other)
