@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +19,10 @@ from .core import DataFrameUnaryUfunc
 
 class DataFrameLog2(DataFrameUnaryUfunc):
     _op_type_ = OperandDef.LOG2
-    _func_name = 'log2'
+    _func_name = "log2"
 
     @classproperty
     def tensor_op_type(self):
         from ...tensor.arithmetic import TensorLog2
+
         return TensorLog2
