@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,20 +16,26 @@ import operator
 
 from ... import opcodes as OperandDef
 from ...utils import classproperty
-from .core import DataFrameBinOpMixin, DataFrameBinOp
+from .core import DataFrameBinopUfunc
 from .docstring import bin_arithmetic_doc
 
 
-class DataFramePower(DataFrameBinOp, DataFrameBinOpMixin):
+class DataFramePower(DataFrameBinopUfunc):
     _op_type_ = OperandDef.POW
 
-    _func_name = 'pow'
-    _rfunc_name = 'rpow'
+    _func_name = "pow"
+    _rfunc_name = "rpow"
 
     @classproperty
     def _operator(self):
         return operator.pow
 
+    @classproperty
+    def tensor_op_type(self):
+        from ...tensor.arithmetic import TensorPower
+
+        return TensorPower
+
 
 _pow_example = """
 >>> a.pow(b, fill_value=0).execute()
@@ -42,13 +48,21 @@ dtype: float64
 """
 
 
-@bin_arithmetic_doc('Exponential power', op_name='pow', equiv='**', series_example=_pow_example)
-def power(df, other, axis='columns', level=None, fill_value=None):
-    op = DataFramePower(axis=axis, level=level, fill_value=fill_value, lhs=df, rhs=other)
+@bin_arithmetic_doc(
+    "Exponential power", op_name="pow", equiv="**", series_example=_pow_example
+)
+def power(df, other, axis="columns", level=None, fill_value=None):
+    op = DataFramePower(
+        axis=axis, level=level, fill_value=fill_value, lhs=df, rhs=other
+    )
     return op(df, other)
 
 
-@bin_arithmetic_doc('Exponential power', op_name='rpow', equiv='**', series_example=_pow_example)
-def rpower(df, other, axis='columns', level=None, fill_value=None):
-    op = DataFramePower(axis=axis, level=level, fill_value=fill_value, lhs=other, rhs=df)
+@bin_arithmetic_doc(
+    "Exponential power", op_name="rpow", equiv="**", series_example=_pow_example
+)
+def rpower(df, other, axis="columns", level=None, fill_value=None):
+    op = DataFramePower(
+        axis=axis, level=level, fill_value=fill_value, lhs=other, rhs=df
+    )
     return op.rcall(df, other)
