@@ -28,12 +28,13 @@ class DataFrameCheckMonotonic(DataFrameOperand, DataFrameOperandMixin):
     _op_code_ = opcodes.CHECK_MONOTONIC
 
     # 0 - increasing, 1 - decreasing
-    _decreasing = BoolField('decreasing')
-    _strict = BoolField('strict')
+    _decreasing = BoolField("decreasing")
+    _strict = BoolField("strict")
 
     def __init__(self, decreasing=None, strict=None, output_types=None, **kw):
-        super().__init__(_decreasing=decreasing, _strict=strict,
-                         _output_types=output_types, **kw)
+        super().__init__(
+            _decreasing=decreasing, _strict=strict, _output_types=output_types, **kw
+        )
 
     @property
     def decreasing(self):
@@ -48,36 +49,52 @@ class DataFrameCheckMonotonic(DataFrameOperand, DataFrameOperandMixin):
         return self.new_tileable([df_obj], shape=(), dtype=np.dtype(bool))
 
     @classmethod
-    def tile(cls, op: 'DataFrameCheckMonotonic'):
+    def tile(cls, op: "DataFrameCheckMonotonic"):
         map_chunks = []
         for c in op.inputs[0].chunks:
             new_op = DataFrameCheckMonotonic(
-                decreasing=op.decreasing, strict=op.strict, stage=OperandStage.map,
-                output_types=[OutputType.series], order=TensorOrder.C_ORDER)
+                decreasing=op.decreasing,
+                strict=op.strict,
+                stage=OperandStage.map,
+                output_types=[OutputType.series],
+                order=TensorOrder.C_ORDER,
+            )
             map_chunks.append(new_op.new_chunk([c], shape=(2,), dtype=np.dtype(bool)))
 
         concat_op = TensorConcatenate(axis=0, dtype=np.dtype(bool))
         concat_r_chunk = concat_op.new_chunk(
-            map_chunks, shape=(len(map_chunks),), index=(0, 0), order=TensorOrder.C_ORDER)
+            map_chunks,
+            shape=(len(map_chunks),),
+            index=(0, 0),
+            order=TensorOrder.C_ORDER,
+        )
 
         new_op = DataFrameCheckMonotonic(
-            decreasing=op.decreasing, strict=op.strict, stage=OperandStage.reduce,
-            output_types=[OutputType.scalar], order=TensorOrder.C_ORDER)
+            decreasing=op.decreasing,
+            strict=op.strict,
+            stage=OperandStage.reduce,
+            output_types=[OutputType.scalar],
+            order=TensorOrder.C_ORDER,
+        )
         r_chunk = new_op.new_chunk(
-            [concat_r_chunk], shape=(), order=TensorOrder.C_ORDER, dtype=np.dtype(bool))
+            [concat_r_chunk], shape=(), order=TensorOrder.C_ORDER, dtype=np.dtype(bool)
+        )
 
         new_op = op.copy().reset_key()
         params = op.outputs[0].params
-        params['chunks'] = [r_chunk]
-        params['nsplits'] = ()
+        params["chunks"] = [r_chunk]
+        params["nsplits"] = ()
         return new_op.new_tileables(op.inputs, **params)
 
     @classmethod
-    def execute(cls, ctx, op: 'DataFrameCheckMonotonic'):
+    def execute(cls, ctx, op: "DataFrameCheckMonotonic"):
         in_data = ctx[op.inputs[0].key]
         if op.stage == OperandStage.map:
-            is_mono = in_data.is_monotonic_increasing \
-                if not op.decreasing else in_data.is_monotonic_decreasing
+            is_mono = (
+                in_data.is_monotonic_increasing
+                if not op.decreasing
+                else in_data.is_monotonic_decreasing
+            )
             if op.strict and is_mono:
                 is_mono = in_data.is_unique
 
@@ -87,12 +104,16 @@ class DataFrameCheckMonotonic(DataFrameOperand, DataFrameOperandMixin):
                 edge_array = np.array([in_data.iloc[0], in_data.iloc[-1]])
 
             ctx[op.outputs[0].key] = (
-                np.array([is_mono]), edge_array,
+                np.array([is_mono]),
+                edge_array,
             )
         else:
             in_series = pd.Series(in_data[1])
-            is_edge_mono = in_series.is_monotonic_increasing \
-                if not op.decreasing else in_series.is_monotonic_decreasing
+            is_edge_mono = (
+                in_series.is_monotonic_increasing
+                if not op.decreasing
+                else in_series.is_monotonic_decreasing
+            )
             if op.strict and is_edge_mono:
                 is_edge_mono = in_series.is_unique
             ctx[op.outputs[0].key] = in_data[0].all() and is_edge_mono
