@@ -27,21 +27,27 @@ from ..operands import DataFrameOperand, DataFrameOperandMixin
 from ..utils import parse_index, build_empty_df
 
 
-cudf = lazy_import('cudf')
+cudf = lazy_import("cudf")
 
 
 class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = OperandDef.DESCRIBE
 
-    _input = KeyField('input')
-    _percentiles = ListField('percentiles', FieldTypes.float64)
-    _include = AnyField('include')
-    _exclude = AnyField('exclude')
+    _input = KeyField("input")
+    _percentiles = ListField("percentiles", FieldTypes.float64)
+    _include = AnyField("include")
+    _exclude = AnyField("exclude")
 
-    def __init__(self, percentiles=None, include=None, exclude=None,
-                 output_types=None, **kw):
-        super().__init__(_percentiles=percentiles, _include=include,
-                         _exclude=exclude, _output_types=output_types, **kw)
+    def __init__(
+        self, percentiles=None, include=None, exclude=None, output_types=None, **kw
+    ):
+        super().__init__(
+            _percentiles=percentiles,
+            _include=include,
+            _exclude=exclude,
+            _output_types=output_types,
+            **kw
+        )
 
     @property
     def input(self):
@@ -67,28 +73,43 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
     def __call__(self, df_or_series):
         if isinstance(df_or_series, SERIES_TYPE):
             if not np.issubdtype(df_or_series.dtype, np.number):
-                raise NotImplementedError('non-numeric type is not supported for now')
+                raise NotImplementedError("non-numeric type is not supported for now")
             test_series = pd.Series([], dtype=df_or_series.dtype).describe(
-                percentiles=self._percentiles, include=self._include, exclude=self._exclude)
-            return self.new_series([df_or_series], shape=(len(test_series),),
-                                   dtype=test_series.dtype,
-                                   index_value=parse_index(test_series.index, store_data=True))
+                percentiles=self._percentiles,
+                include=self._include,
+                exclude=self._exclude,
+            )
+            return self.new_series(
+                [df_or_series],
+                shape=(len(test_series),),
+                dtype=test_series.dtype,
+                index_value=parse_index(test_series.index, store_data=True),
+            )
         else:
             test_inp_df = build_empty_df(df_or_series.dtypes)
             test_df = test_inp_df.describe(
-                percentiles=self._percentiles, include=self._include, exclude=self._exclude)
+                percentiles=self._percentiles,
+                include=self._include,
+                exclude=self._exclude,
+            )
             if len(self.percentiles) == 0:
                 # specify percentiles=False
                 # Note: unlike pandas that False is illegal value for percentiles,
                 # Mars DataFrame allows user to specify percentiles=False
                 # to skip computation about percentiles
-                test_df.drop(['50%'], axis=0, inplace=True)
+                test_df.drop(["50%"], axis=0, inplace=True)
             for dtype in test_df.dtypes:
                 if not np.issubdtype(dtype, np.number):
-                    raise NotImplementedError('non-numeric type is not supported for now')
-            return self.new_dataframe([df_or_series], shape=test_df.shape, dtypes=test_df.dtypes,
-                                      index_value=parse_index(test_df.index, store_data=True),
-                                      columns_value=parse_index(test_df.columns, store_data=True))
+                    raise NotImplementedError(
+                        "non-numeric type is not supported for now"
+                    )
+            return self.new_dataframe(
+                [df_or_series],
+                shape=test_df.shape,
+                dtypes=test_df.dtypes,
+                index_value=parse_index(test_df.index, store_data=True),
+                columns_value=parse_index(test_df.columns, store_data=True),
+            )
 
     @classmethod
     def tile(cls, op):
@@ -109,13 +130,13 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
 
         chunk_op = op.copy().reset_key()
         chunk_params = out.params.copy()
-        chunk_params['index'] = (0,) * out.ndim
+        chunk_params["index"] = (0,) * out.ndim
         out_chunk = chunk_op.new_chunk([op.input.chunks[0]], kws=[chunk_params])
 
         new_op = op.copy()
         params = out.params.copy()
-        params['chunks'] = [out_chunk]
-        params['nsplits'] = tuple((s,) for s in out.shape)
+        params["chunks"] = [out_chunk]
+        params["nsplits"] = tuple((s,) for s in out.shape)
         return new_op.new_tileables(op.inputs, kws=[params])
 
     @classmethod
@@ -154,18 +175,20 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
 
         # perform aggregation together
         aggregation = yield from recursive_tile(
-            df.agg(['count', 'mean', 'std', 'min', 'max']))
+            df.agg(["count", "mean", "std", "min", "max"])
+        )
         # calculate percentiles
         percentiles = None
         if len(op.percentiles) > 0:
-            percentiles = yield from recursive_tile(
-                df.quantile(op.percentiles))
+            percentiles = yield from recursive_tile(df.quantile(op.percentiles))
 
-        chunk_op = DataFrameDescribe(output_types=op.output_types,
-                                     stage=OperandStage.agg,
-                                     percentiles=op.percentiles)
+        chunk_op = DataFrameDescribe(
+            output_types=op.output_types,
+            stage=OperandStage.agg,
+            percentiles=op.percentiles,
+        )
         chunk_params = out.params.copy()
-        chunk_params['index'] = (0, 0)
+        chunk_params["index"] = (0, 0)
         in_chunks = aggregation.chunks
         if percentiles is not None:
             in_chunks += percentiles.chunks
@@ -173,8 +196,8 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
 
         new_op = op.copy()
         params = out.params.copy()
-        params['chunks'] = [out_chunk]
-        params['nsplits'] = tuple((s,) for s in out.shape)
+        params["chunks"] = [out_chunk]
+        params["nsplits"] = tuple((s,) for s in out.shape)
         return new_op.new_tileables(op.inputs, kws=[params])
 
     @classmethod
@@ -184,13 +207,18 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
             df_or_series = ctx[op.input.key]
 
             ctx[out.key] = df_or_series.describe(
-                percentiles=op.percentiles, include=op.include, exclude=op.exclude)
+                percentiles=op.percentiles, include=op.include, exclude=op.exclude
+            )
         else:
             assert op.stage == OperandStage.agg
 
             inputs = [ctx[inp.key] for inp in op.inputs]
-            xdf = pd if isinstance(inputs[0], (pd.DataFrame, pd.Series, pd.Index)) \
-                or cudf is None else cudf
+            xdf = (
+                pd
+                if isinstance(inputs[0], (pd.DataFrame, pd.Series, pd.Index))
+                or cudf is None
+                else cudf
+            )
 
             if len(inputs) == 1:
                 df = inputs[0]
@@ -198,8 +226,10 @@ class DataFrameDescribe(DataFrameOperand, DataFrameOperandMixin):
                 assert len(inputs) > 1
                 aggregations = inputs[0]
                 percentiles = xdf.concat(inputs[1:], axis=0)
-                df = xdf.concat([aggregations.iloc[:-1], percentiles,
-                                 aggregations.iloc[-1:]], axis=0)
+                df = xdf.concat(
+                    [aggregations.iloc[:-1], percentiles, aggregations.iloc[-1:]],
+                    axis=0,
+                )
             # ['count', 'mean', 'std', 'min', {percentiles}, 'max']
             df.index = out.index_value.to_pandas()
             ctx[out.key] = df
@@ -215,8 +245,10 @@ def describe(df_or_series, percentiles=None, include=None, exclude=None):
         if percentiles is not None:
             for p in percentiles:
                 if p < 0 or p > 1:
-                    raise ValueError('percentiles should all be in the interval [0, 1]. '
-                                     'Try [{0:.3f}] instead.'.format(p / 100))
+                    raise ValueError(
+                        "percentiles should all be in the interval [0, 1]. "
+                        "Try [{0:.3f}] instead.".format(p / 100)
+                    )
         # median should always be included
         if 0.5 not in percentiles:
             percentiles.append(0.5)
