@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,11 +19,10 @@ import numpy as np
 import pandas as pd
 
 from ... import opcodes as OperandDef
-from ...core import OutputType
-from ...custom_log import redirect_custom_log
-from ...serialize import KeyField, AnyField, StringField
-from ...tiles import TilesError
-from ...utils import check_chunks_unknown_shape, enter_current_session, quiet_stdio
+from ...core import OutputType, recursive_tile
+from ...core.custom_log import redirect_custom_log
+from ...serialization.serializables import KeyField, AnyField, StringField
+from ...utils import has_unknown_shape, enter_current_session, quiet_stdio
 from ..core import SERIES_TYPE
 from ..operands import DataFrameOperand, DataFrameOperandMixin
 from ..utils import build_series
@@ -32,17 +31,20 @@ from ..utils import build_series
 class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = OperandDef.MAP
 
-    _input = KeyField('input')
-    _arg = AnyField('arg')
-    _na_action = StringField('na_action')
-    # for chunk
-    _tileable_op_key = StringField('tileable_op_key')
+    _input = KeyField("input")
+    _arg = AnyField("arg")
+    _na_action = StringField("na_action")
 
-    def __init__(self, arg=None, na_action=None, output_types=None,
-                 tileable_op_key=None, memory_scale=None, **kw):
+    def __init__(
+        self, arg=None, na_action=None, output_types=None, memory_scale=None, **kw
+    ):
         super().__init__(
-            _arg=arg, _na_action=na_action, _output_types=output_types,
-            _tileable_op_key=tileable_op_key, _memory_scale=memory_scale, **kw)
+            _arg=arg,
+            _na_action=na_action,
+            _output_types=output_types,
+            _memory_scale=memory_scale,
+            **kw
+        )
         if not self.output_types:
             self.output_types = [OutputType.series]
 
@@ -58,10 +60,6 @@ class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
     def na_action(self):
         return self._na_action
 
-    @property
-    def tileable_op_key(self):
-        return self._tileable_op_key
-
     def _set_inputs(self, inputs):
         super()._set_inputs(inputs)
         self._input = self._inputs[0]
@@ -81,8 +79,11 @@ class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
                     try:
                         with quiet_stdio():
                             # try to infer dtype by calling the function
-                            inferred_dtype = build_series(series).map(
-                                self._arg, na_action=self._na_action).dtype
+                            inferred_dtype = (
+                                build_series(series)
+                                .map(self._arg, na_action=self._na_action)
+                                .dtype
+                            )
                     except:  # noqa: E722  # nosec
                         pass
             else:
@@ -101,8 +102,9 @@ class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
                 dtype = inferred_dtype
 
         if dtype is None:
-            raise ValueError('cannot infer dtype, '
-                             'it needs to be specified manually for `map`')
+            raise ValueError(
+                "cannot infer dtype, " "it needs to be specified manually for `map`"
+            )
         else:
             dtype = np.int64 if dtype is int else dtype
             dtype = np.dtype(dtype)
@@ -112,11 +114,21 @@ class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
             inputs.append(self._arg)
 
         if isinstance(series, SERIES_TYPE):
-            return self.new_series(inputs, shape=series.shape, dtype=dtype,
-                                   index_value=series.index_value, name=series.name)
+            return self.new_series(
+                inputs,
+                shape=series.shape,
+                dtype=dtype,
+                index_value=series.index_value,
+                name=series.name,
+            )
         else:
-            return self.new_index(inputs, shape=series.shape, dtype=dtype,
-                                  index_value=series.index_value, name=series.name)
+            return self.new_index(
+                inputs,
+                shape=series.shape,
+                dtype=dtype,
+                index_value=series.index_value,
+                name=series.name,
+            )
 
     @classmethod
     def tile(cls, op):
@@ -126,27 +138,31 @@ class DataFrameMap(DataFrameOperand, DataFrameOperandMixin):
         arg = op.arg
         if len(op.inputs) == 2:
             # make sure arg has known shape when it's a md.Series
-            check_chunks_unknown_shape([op.arg], TilesError)
-            arg = op.arg.rechunk(op.arg.shape)._inplace_tile()
+            if has_unknown_shape(op.arg):
+                yield
+            arg = yield from recursive_tile(op.arg.rechunk(op.arg.shape))
 
         out_chunks = []
         for chunk in in_series.chunks:
             chunk_op = op.copy().reset_key()
-            chunk_op._tileable_op_key = op.key
+            chunk_op.tileable_op_key = op.key
             chunk_inputs = [chunk]
             if len(op.inputs) == 2:
                 chunk_inputs.append(arg.chunks[0])
-            out_chunk = chunk_op.new_chunk(chunk_inputs, shape=chunk.shape,
-                                           dtype=out_series.dtype,
-                                           index_value=chunk.index_value,
-                                           name=out_series.name,
-                                           index=chunk.index)
+            out_chunk = chunk_op.new_chunk(
+                chunk_inputs,
+                shape=chunk.shape,
+                dtype=out_series.dtype,
+                index_value=chunk.index_value,
+                name=out_series.name,
+                index=chunk.index,
+            )
             out_chunks.append(out_chunk)
 
         new_op = op.copy()
         params = out_series.params
-        params['chunks'] = out_chunks
-        params['nsplits'] = in_series.nsplits
+        params["chunks"] = out_chunks
+        params["nsplits"] = in_series.nsplits
         return new_op.new_tileables(op.inputs, kws=[params])
 
     @classmethod
