@@ -19,32 +19,56 @@ from ... import opcodes
 from ...config import options
 from ...core import OutputType, recursive_tile
 from ...core.custom_log import redirect_custom_log
-from ...lib.version import parse as parse_version
-from ...serialization.serializables import AnyField, BoolField, \
-    TupleField, DictField
-from ...utils import enter_current_session, quiet_stdio
+from ...serialization.serializables import AnyField, BoolField, TupleField, DictField
+from ...utils import enter_current_session, quiet_stdio, pd_release_version
 from ..core import DATAFRAME_CHUNK_TYPE, DATAFRAME_TYPE
 from ..operands import DataFrameOperandMixin, DataFrameOperand
-from ..utils import build_df, build_series, validate_axis, \
-    parse_index, filter_dtypes_by_index, make_dtypes
+from ..utils import (
+    build_df,
+    build_series,
+    validate_axis,
+    parse_index,
+    filter_dtypes_by_index,
+    make_dtypes,
+)
+
+_with_convert_dtype = pd_release_version < (1, 2, 0)
 
 
 class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = opcodes.TRANSFORM
 
-    _func = AnyField('func')
-    _axis = AnyField('axis')
-    _convert_dtype = BoolField('convert_dtype')
-    _args = TupleField('args')
-    _kwds = DictField('kwds')
+    _func = AnyField("func")
+    _axis = AnyField("axis")
+    _convert_dtype = BoolField("convert_dtype")
+    _args = TupleField("args")
+    _kwds = DictField("kwds")
 
-    _call_agg = BoolField('call_agg')
+    _call_agg = BoolField("call_agg")
 
-    def __init__(self, func=None, axis=None, convert_dtype=None, args=None, kwds=None,
-                 call_agg=None, output_types=None, memory_scale=None, **kw):
-        super().__init__(_func=func, _axis=axis, _convert_dtype=convert_dtype, _args=args,
-                         _kwds=kwds, _call_agg=call_agg, _output_types=output_types,
-                         _memory_scale=memory_scale, **kw)
+    def __init__(
+        self,
+        func=None,
+        axis=None,
+        convert_dtype=None,
+        args=None,
+        kwds=None,
+        call_agg=None,
+        output_types=None,
+        memory_scale=None,
+        **kw
+    ):
+        super().__init__(
+            _func=func,
+            _axis=axis,
+            _convert_dtype=convert_dtype,
+            _args=args,
+            _kwds=kwds,
+            _call_agg=call_agg,
+            _output_types=output_types,
+            _memory_scale=memory_scale,
+            **kw
+        )
 
     @property
     def func(self):
@@ -60,11 +84,11 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
 
     @property
     def args(self):
-        return getattr(self, '_args', None) or ()
+        return getattr(self, "_args", None) or ()
 
     @property
     def kwds(self):
-        return getattr(self, '_kwds', None) or dict()
+        return getattr(self, "_kwds", None) or dict()
 
     @property
     def call_agg(self):
@@ -94,13 +118,16 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
 
         if isinstance(in_df, DATAFRAME_TYPE):
             if in_df.chunk_shape[axis] > 1:
-                chunk_size = (in_df.shape[axis],
-                              max(1, options.chunk_store_limit // in_df.shape[axis]))
+                chunk_size = (
+                    in_df.shape[axis],
+                    max(1, options.chunk_store_limit // in_df.shape[axis]),
+                )
                 if axis == 1:
                     chunk_size = chunk_size[::-1]
                 in_df = yield from recursive_tile(in_df.rechunk(chunk_size))
-        elif isinstance(op.func, str) or \
-                (isinstance(op.func, list) and any(isinstance(e, str) for e in op.func)):
+        elif isinstance(op.func, str) or (
+            isinstance(op.func, list) and any(isinstance(e, str) for e in op.func)
+        ):
             # builtin cols handles whole columns, thus merge is needed
             if in_df.chunk_shape[0] > 1:
                 in_df = yield from recursive_tile(in_df.rechunk((in_df.shape[axis],)))
@@ -127,18 +154,23 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
                     try:
                         new_index[1 - op.axis] = axis_index_map[c.index[1 - op.axis]]
                     except KeyError:
-                        new_index[1 - op.axis] = axis_index_map[c.index[1 - op.axis]] = len(axis_index_map)
+                        new_index[1 - op.axis] = axis_index_map[
+                            c.index[1 - op.axis]
+                        ] = len(axis_index_map)
 
                     if isinstance(op.func, dict):
-                        new_op._func = dict((k, v) for k, v in op.func.items() if k in new_dtypes)
+                        new_op._func = dict(
+                            (k, v) for k, v in op.func.items() if k in new_dtypes
+                        )
 
                     new_shape = list(c.shape)
                     new_shape[1] = len(new_dtypes)
 
                     if op.call_agg:
                         new_shape[op.axis] = np.nan
-                        params['index_value'] = parse_index(
-                            None, c.key, c.index_value.key)
+                        params["index_value"] = parse_index(
+                            None, c.key, c.index_value.key
+                        )
                     new_columns_value = parse_index(new_dtypes.index)
                 else:
                     new_dtypes = out_df.dtypes
@@ -149,15 +181,21 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
                     if c.index[0] == 0:
                         col_sizes.append(len(new_dtypes))
                     new_columns_value = out_df.columns_value
-                params.update(dict(dtypes=new_dtypes, shape=tuple(new_shape), index=tuple(new_index),
-                                   columns_value=new_columns_value))
+                params.update(
+                    dict(
+                        dtypes=new_dtypes,
+                        shape=tuple(new_shape),
+                        index=tuple(new_index),
+                        columns_value=new_columns_value,
+                    )
+                )
             else:
-                params['dtype'] = out_df.dtype
+                params["dtype"] = out_df.dtype
                 if isinstance(in_df, DATAFRAME_TYPE):
-                    params.pop('columns_value', None)
-                    params['index_value'] = out_df.index_value
-                    params['shape'] = (c.shape[1 - op.axis],)
-                    params['index'] = (c.index[1 - op.axis],)
+                    params.pop("columns_value", None)
+                    params["index_value"] = out_df.index_value
+                    params["shape"] = (c.shape[1 - op.axis],)
+                    params["index"] = (c.index[1 - op.axis],)
             chunks.append(new_op.new_chunk([c], **params))
 
         if out_df.ndim == 2:
@@ -181,30 +219,42 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
         if self.output_types[0] == OutputType.dataframe:
             test_df = build_df(df, fill_value=1, size=2)
             try:
-                with np.errstate(all='ignore'), quiet_stdio():
+                with np.errstate(all="ignore"), quiet_stdio():
                     if self.call_agg:
-                        infer_df = test_df.agg(self._func, axis=self._axis, *self.args, **self.kwds)
+                        infer_df = test_df.agg(
+                            self._func, axis=self._axis, *self.args, **self.kwds
+                        )
                     else:
-                        infer_df = test_df.transform(self._func, axis=self._axis, *self.args, **self.kwds)
+                        infer_df = test_df.transform(
+                            self._func, axis=self._axis, *self.args, **self.kwds
+                        )
             except:  # noqa: E722
                 infer_df = None
         else:
             test_df = build_series(df, size=2, name=df.name)
             try:
-                with np.errstate(all='ignore'), quiet_stdio():
+                with np.errstate(all="ignore"), quiet_stdio():
                     if self.call_agg:
                         infer_df = test_df.agg(self._func, args=self.args, **self.kwds)
                     else:
-                        if parse_version(pd.__version__) >= parse_version('1.2.0'):
-                            infer_df = test_df.transform(self._func, *self.args, **self.kwds)
+                        if not _with_convert_dtype:
+                            infer_df = test_df.transform(
+                                self._func, *self.args, **self.kwds
+                            )
                         else:  # pragma: no cover
-                            infer_df = test_df.transform(self._func, convert_dtype=self.convert_dtype,
-                                                         args=self.args, **self.kwds)
+                            infer_df = test_df.transform(
+                                self._func,
+                                convert_dtype=self.convert_dtype,
+                                args=self.args,
+                                **self.kwds
+                            )
             except:  # noqa: E722
                 infer_df = None
 
         if infer_df is None and dtypes is None:
-            raise TypeError('Failed to infer dtype, please specify dtypes as arguments.')
+            raise TypeError(
+                "Failed to infer dtype, please specify dtypes as arguments."
+            )
 
         if infer_df is None:
             is_df = self.output_types[0] == OutputType.dataframe
@@ -215,13 +265,15 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
             new_dtypes = make_dtypes(dtypes) if dtypes is not None else infer_df.dtypes
             self.output_types = [OutputType.dataframe]
         else:
-            new_dtypes = dtypes if dtypes is not None else (infer_df.name, infer_df.dtype)
+            new_dtypes = (
+                dtypes if dtypes is not None else (infer_df.name, infer_df.dtype)
+            )
             self.output_types = [OutputType.series]
 
         return new_dtypes
 
     def __call__(self, df, dtypes=None, index=None):
-        axis = getattr(self, 'axis', None) or 0
+        axis = getattr(self, "axis", None) or 0
         self._axis = validate_axis(axis, df)
 
         dtypes = self._infer_df_func_returns(df, dtypes)
@@ -237,8 +289,13 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
             if self.call_agg:
                 new_shape[self.axis] = np.nan
                 new_index_value = parse_index(None, (df.key, df.index_value.key))
-            return self.new_dataframe([df], shape=tuple(new_shape), dtypes=dtypes, index_value=new_index_value,
-                                      columns_value=parse_index(dtypes.index, store_data=True))
+            return self.new_dataframe(
+                [df],
+                shape=tuple(new_shape),
+                dtypes=dtypes,
+                index_value=new_index_value,
+                columns_value=parse_index(dtypes.index, store_data=True),
+            )
         else:
             name, dtype = dtypes
 
@@ -249,7 +306,13 @@ class TransformOperand(DataFrameOperand, DataFrameOperandMixin):
                 new_shape = (np.nan,) if self.call_agg else df.shape
                 new_index_value = df.index_value
 
-            return self.new_series([df], shape=new_shape, name=name, dtype=dtype, index_value=new_index_value)
+            return self.new_series(
+                [df],
+                shape=new_shape,
+                name=name,
+                dtype=dtype,
+                index_value=new_index_value,
+            )
 
 
 def df_transform(df, func, axis=0, *args, dtypes=None, **kwargs):
@@ -334,12 +397,20 @@ def df_transform(df, func, axis=0, *args, dtypes=None, **kwargs):
     1  1.000000   2.718282
     2  1.414214   7.389056
     """
-    op = TransformOperand(func=func, axis=axis, args=args, kwds=kwargs, output_types=[OutputType.dataframe],
-                          call_agg=kwargs.pop('_call_agg', False))
+    op = TransformOperand(
+        func=func,
+        axis=axis,
+        args=args,
+        kwds=kwargs,
+        output_types=[OutputType.dataframe],
+        call_agg=kwargs.pop("_call_agg", False),
+    )
     return op(df, dtypes=dtypes)
 
 
-def series_transform(series, func, convert_dtype=True, axis=0, *args, dtype=None, **kwargs):
+def series_transform(
+    series, func, convert_dtype=True, axis=0, *args, dtype=None, **kwargs
+):
     """
     Call ``func`` on self producing a Series with transformed values.
 
@@ -419,8 +490,15 @@ def series_transform(series, func, convert_dtype=True, axis=0, *args, dtype=None
     0  0.000000   1.000000
     1  1.000000   2.718282
     2  1.414214   7.389056
-   """
-    op = TransformOperand(func=func, axis=axis, convert_dtype=convert_dtype, args=args, kwds=kwargs,
-                          output_types=[OutputType.series], call_agg=kwargs.pop('_call_agg', False))
+    """
+    op = TransformOperand(
+        func=func,
+        axis=axis,
+        convert_dtype=convert_dtype,
+        args=args,
+        kwds=kwargs,
+        output_types=[OutputType.series],
+        call_agg=kwargs.pop("_call_agg", False),
+    )
     dtypes = (series.name, dtype) if dtype is not None else None
     return op(series, dtypes=dtypes)
