@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
 from datetime import datetime, date, time
 
 import numpy as np
@@ -25,109 +26,92 @@ from ...config import options
 from ...core import OutputType
 from ...serialization.serializables import AnyField, Int64Field, BoolField, StringField
 from ...tensor.utils import decide_chunk_sizes
+from ...utils import pd_release_version, NoDefault
 from ..operands import DataFrameOperand, DataFrameOperandMixin
 from ..utils import parse_index
 
 try:
     from pandas._libs.tslib import normalize_date
 except ImportError:  # pragma: no cover
+
     def normalize_date(dt):  # from pandas/_libs/tslibs/conversion.pyx
         if isinstance(dt, datetime):
             if isinstance(dt, pd.Timestamp):
-                return dt.replace(hour=0, minute=0, second=0, microsecond=0,
-                                  nanosecond=0)
+                return dt.replace(
+                    hour=0, minute=0, second=0, microsecond=0, nanosecond=0
+                )
             else:
                 return dt.replace(hour=0, minute=0, second=0, microsecond=0)
         elif isinstance(dt, date):
             return datetime(dt.year, dt.month, dt.day)
         else:
-            raise TypeError(f'Unrecognized type: {type(dt)}')
+            raise TypeError(f"Unrecognized type: {type(dt)}")
+
+
+_date_range_use_inclusive = pd_release_version[:2] >= (1, 4)
 
 
 class DataFrameDateRange(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = OperandDef.DATE_RANGE
 
-    _start = AnyField('start')
-    _end = AnyField('end')
-    _periods = Int64Field('periods')
-    _freq = AnyField('freq')
-    _tz = AnyField('tz')
-    _normalize = BoolField('normalize')
-    _name = StringField('name')
-    _closed = StringField('closed')
+    start = AnyField("start")
+    end = AnyField("end")
+    periods = Int64Field("periods")
+    freq = AnyField("freq")
+    tz = AnyField("tz")
+    normalize = BoolField("normalize")
+    name = StringField("name")
+    inclusive = StringField("closed")
 
-    def __init__(self, start=None, end=None, periods=None,
-                 freq=None, tz=None, normalize=None, name=None,
-                 closed=None, output_types=None, **kw):
-        super().__init__(_start=start, _end=end, _periods=periods,
-                         _freq=freq, _tz=tz, _normalize=normalize,
-                         _name=name, _closed=closed,
-                         _output_types=output_types, **kw)
+    def __init__(
+        self,
+        output_types=None,
+        **kw,
+    ):
+        super().__init__(_output_types=output_types, **kw)
         if self.output_types is None:
             self.output_types = [OutputType.index]
-
-    @property
-    def start(self):
-        return self._start
-
-    @property
-    def end(self):
-        return self._end
-
-    @property
-    def periods(self):
-        return self._periods
-
-    @property
-    def freq(self):
-        return self._freq
-
-    @property
-    def tz(self):
-        return self._tz
-
-    @property
-    def normalize(self):
-        return self._normalize
-
-    @property
-    def name(self):
-        return self._name
-
-    @property
-    def closed(self):
-        return self._closed
+        if getattr(self, "inclusive", None) is None:
+            self.inclusive = "both"
 
     def __call__(self, shape, chunk_size=None):
-        dtype = pd.Index([self._start]).dtype
-        index_value = parse_index(pd.Index([], dtype=dtype),
-                                  self._start, self._end, self._periods,
-                                  self._tz)
+        dtype = pd.Index([self.start]).dtype
+        index_value = parse_index(
+            pd.Index([], dtype=dtype), self.start, self.end, self.periods, self.tz
+        )
         # gen index value info
-        index_value.value._min_val = self._start
+        index_value.value._min_val = self.start
         index_value.value._min_val_close = True
-        index_value.value._max_val = self._end
+        index_value.value._max_val = self.end
         index_value.value._max_val_close = True
         index_value.value._is_unique = True
         index_value.value._is_monotonic_increasing = True
-        index_value.value._freq = self._freq
-        return self.new_index(None, shape=shape, dtype=dtype,
-                              index_value=index_value, name=self._name,
-                              raw_chunk_size=chunk_size, freq=self._freq)
+        index_value.value._freq = self.freq
+        return self.new_index(
+            None,
+            shape=shape,
+            dtype=dtype,
+            index_value=index_value,
+            name=self.name,
+            raw_chunk_size=chunk_size,
+            freq=self.freq,
+        )
 
     @classmethod
-    def tile(cls, op):
+    def tile(cls, op: "DataFrameDateRange"):
         out = op.outputs[0]
         start = op.start
         end = op.end
         freq = op.freq
         periods = op.periods
-        closed = op.closed
+        inclusive = op.inclusive
 
         chunk_length = out.extra_params.raw_chunk_size or options.chunk_size
-        chunk_length = decide_chunk_sizes(out.shape, chunk_length, out.dtype.itemsize)[0]
+        chunk_length = decide_chunk_sizes(out.shape, chunk_length, out.dtype.itemsize)[
+            0
+        ]
 
-        if closed == 'right':
+        if inclusive in ("neither", "right"):
             # if left not close, add one more for the first chunk
             chunk_length = (chunk_length[0] + 1,) + chunk_length[1:]
 
@@ -141,15 +125,20 @@ class DataFrameDateRange(DataFrameOperand, DataFrameOperandMixin):
         cum_nsplit = [0] + np.cumsum(chunk_length).tolist()
         for i, chunk_size in enumerate(chunk_length):
             chunk_op = op.copy().reset_key()
-            chunk_op._periods = chunk_size
-            if closed != 'right' or i > 0:
-                chunk_op._closed = None
+            chunk_op.periods = chunk_size
+
+            if i > 0 or inclusive not in ("neither", "right"):
+                # for chunks in the middle, all sides are inclusive
+                chunk_op.inclusive = "both"
+            elif 0 == i and inclusive == "neither":
+                chunk_op.inclusive = "right"
+
             chunk_i_start = cum_nsplit[i]
             if chunk_i_start > 0:
-                chunk_start = chunk_op._start = start + freq * chunk_i_start
+                chunk_start = chunk_op.start = start + freq * chunk_i_start
             else:
-                chunk_start = chunk_op._start = start
-            chunk_end = chunk_op._end = chunk_start + (chunk_size - 1) * freq
+                chunk_start = chunk_op.start = start
+            chunk_end = chunk_op.end = chunk_start + (chunk_size - 1) * freq
 
             # gen chunk index_value
             chunk_index_value = parse_index(out.index_value.to_pandas(), i, out)
@@ -160,29 +149,48 @@ class DataFrameDateRange(DataFrameOperand, DataFrameOperandMixin):
             chunk_index_value.value._is_unique = True
             chunk_index_value.value._is_monotonic_increasing = True
 
-            size = chunk_size - 1 if i == 0 and closed == 'right' else chunk_size
-            out_chunk = chunk_op.new_chunk(None, shape=(size,),
-                                           index=(i,), dtype=out.dtype,
-                                           index_value=chunk_index_value,
-                                           name=out.name)
+            size = (
+                chunk_size - 1
+                if i == 0 and inclusive in ("neither", "right")
+                else chunk_size
+            )
+            out_chunk = chunk_op.new_chunk(
+                None,
+                shape=(size,),
+                index=(i,),
+                dtype=out.dtype,
+                index_value=chunk_index_value,
+                name=out.name,
+            )
             out_chunks.append(out_chunk)
 
         new_op = op.copy()
         params = out.params
-        params['chunks'] = out_chunks
-        params['nsplits'] = (tuple(c.shape[0] for c in out_chunks),)
+        params["chunks"] = out_chunks
+        params["nsplits"] = (tuple(c.shape[0] for c in out_chunks),)
         return new_op.new_indexes(None, kws=[params])
 
     @classmethod
-    def execute(cls, ctx, op):
+    def execute(cls, ctx, op: "DataFrameDateRange"):
         start, end, periods = op.start, op.end, op.periods
         freq = op.freq
         if freq is not None:
             end = None
-        ctx[op.outputs[0].key] = pd.date_range(
-            start=start, end=end, periods=periods, freq=freq,
-            tz=op.tz, normalize=op.normalize, name=op.name,
-            closed=op.closed)
+        kw = dict(
+            start=start,
+            end=end,
+            periods=periods,
+            freq=freq,
+            tz=op.tz,
+            normalize=op.normalize,
+            name=op.name,
+            inclusive=op.inclusive,
+        )
+        if not _date_range_use_inclusive:
+            closed = kw.pop("inclusive")
+            assert closed != "neither"
+            kw["closed"] = None if closed == "both" else closed
+        ctx[op.outputs[0].key] = pd.date_range(**kw)
 
 
 _midnight = time(0, 0)
@@ -249,7 +257,9 @@ def _infer_tz_from_endpoints(start, end, tz):  # pragma: no cover
     return tz
 
 
-def _maybe_localize_point(ts, is_none, is_not_none, freq, tz, ambiguous, nonexistent):  # pragma: no cover
+def _maybe_localize_point(
+    ts, is_none, is_not_none, freq, tz, ambiguous, nonexistent
+):  # pragma: no cover
     """
     Localize a start or end Timestamp to the timezone of the corresponding
     start or end Timestamp
@@ -282,8 +292,19 @@ def _maybe_localize_point(ts, is_none, is_not_none, freq, tz, ambiguous, nonexis
     return ts
 
 
-def date_range(start=None, end=None, periods=None, freq=None, tz=None,
-               normalize=False, name=None, closed=None, chunk_size=None, **kwargs):
+def date_range(
+    start=None,
+    end=None,
+    periods=None,
+    freq=None,
+    tz=None,
+    normalize=False,
+    name=None,
+    closed=NoDefault.no_default,
+    inclusive=None,
+    chunk_size=None,
+    **kwargs,
+):
     """
     Return a fixed frequency DatetimeIndex.
 
@@ -307,9 +328,8 @@ def date_range(start=None, end=None, periods=None, freq=None, tz=None,
         Normalize start/end dates to midnight before generating date range.
     name : str, default None
         Name of the resulting DatetimeIndex.
-    closed : {None, 'left', 'right'}, optional
-        Make the interval closed with respect to the given frequency to
-        the 'left', 'right', or both sides (None, the default).
+    inclusive : {“both”, “neither”, “left”, “right”}, default “both”
+        Include boundaries; Whether to set each bound as closed or open.
     **kwargs
         For compatibility. Has no effect on the result.
 
@@ -402,38 +422,55 @@ def date_range(start=None, end=None, periods=None, freq=None, tz=None,
                    '2018-01-05 00:00:00+09:00'],
                   dtype='datetime64[ns, Asia/Tokyo]', freq='D')
 
-    `closed` controls whether to include `start` and `end` that are on the
-    boundary. The default includes boundary points on either end.
+    `inclusive` controls whether to include `start` and `end` that are on the
+    boundary. The default, "both", includes boundary points on either end.
 
-    >>> md.date_range(start='2017-01-01', end='2017-01-04', closed=None).execute()
+    >>> md.date_range(start='2017-01-01', end='2017-01-04', inclusive='both').execute()
     DatetimeIndex(['2017-01-01', '2017-01-02', '2017-01-03', '2017-01-04'],
                   dtype='datetime64[ns]', freq='D')
 
-    Use ``closed='left'`` to exclude `end` if it falls on the boundary.
+    Use ``inclusive='left'`` to exclude `end` if it falls on the boundary.
 
     >>> md.date_range(start='2017-01-01', end='2017-01-04', closed='left').execute()
     DatetimeIndex(['2017-01-01', '2017-01-02', '2017-01-03'],
                   dtype='datetime64[ns]', freq='D')
 
-    Use ``closed='right'`` to exclude `start` if it falls on the boundary.
+    Use ``inclusive='right'`` to exclude `start` if it falls on the boundary,
+    and similarly inclusive='neither' will exclude both `start` and `end`.
 
     >>> md.date_range(start='2017-01-01', end='2017-01-04', closed='right').execute()
     DatetimeIndex(['2017-01-02', '2017-01-03', '2017-01-04'],
                   dtype='datetime64[ns]', freq='D')
+
+    .. note::
+        Pandas 1.4.0 or later is required to use ``inclusive='neither'``.
+        Otherwise an error may be raised.
     """
     # validate periods
     if isinstance(periods, (float, np.floating)):
         periods = int(periods)
     if periods is not None and not isinstance(periods, (int, np.integer)):
-        raise TypeError(f'periods must be a number, got {periods}')
+        raise TypeError(f"periods must be a number, got {periods}")
 
     if freq is None and any(arg is None for arg in [periods, start, end]):
-        freq = 'D'
+        freq = "D"
     if sum(arg is not None for arg in [start, end, periods, freq]) != 3:
-        raise ValueError('Of the four parameters: start, end, periods, '
-                         'and freq, exactly three must be specified')
+        raise ValueError(
+            "Of the four parameters: start, end, periods, "
+            "and freq, exactly three must be specified"
+        )
     freq = to_offset(freq)
 
+    if _date_range_use_inclusive and closed is not NoDefault.no_default:
+        warnings.warn(
+            "Argument `closed` is deprecated in favor of `inclusive`.", FutureWarning
+        )
+    elif closed is NoDefault.no_default:
+        closed = None
+
+    if inclusive is None and closed is not NoDefault.no_default:
+        inclusive = closed
+
     if start is not None:
         start = pd.Timestamp(start)
 
@@ -441,7 +478,7 @@ def date_range(start=None, end=None, periods=None, freq=None, tz=None,
         end = pd.Timestamp(end)
 
     if start is pd.NaT or end is pd.NaT:
-        raise ValueError('Neither `start` nor `end` can be NaT')
+        raise ValueError("Neither `start` nor `end` can be NaT")
 
     start, end, _ = _maybe_normalize_endpoints(start, end, normalize)
     tz = _infer_tz_from_endpoints(start, end, tz)
@@ -450,36 +487,48 @@ def date_range(start=None, end=None, periods=None, freq=None, tz=None,
         # start is None and end is not None
         # adjust end first
         end = pd.date_range(end=end, periods=1, freq=freq)[0]
+        if inclusive == "neither":
+            end -= freq
         size = periods
         start = end - (periods - 1) * freq
-        if closed == 'left':
+        if inclusive in ("neither", "left"):
             size -= 1
-        elif closed == 'right':
+        elif inclusive == "right":
             # when start is None, closed == 'left' would not take effect
             # thus just ignore
-            closed = None
+            inclusive = "both"
     elif end is None:
         # end is None
         # adjust start first
         start = pd.date_range(start=start, periods=1, freq=freq)[0]
         size = periods
         end = start + (periods - 1) * freq
-        if closed == 'right':
+        if inclusive in ("neither", "right"):
             size -= 1
-        elif closed == 'left':
+        elif inclusive == "left":
             # when end is None, closed == 'left' would not take effect
             # thus just ignore
-            closed = None
+            inclusive = "both"
     else:
         if periods is None:
             periods = size = int((end - start) / freq + 1)
         else:
             size = periods
-        if closed is not None:
+        if inclusive in ("left", "right"):
             size -= 1
+        elif inclusive == "neither":
+            size -= 2
 
     shape = (size,)
-    op = DataFrameDateRange(start=start, end=end, periods=periods,
-                            freq=freq, tz=tz, normalize=normalize,
-                            closed=closed, name=name, **kwargs)
+    op = DataFrameDateRange(
+        start=start,
+        end=end,
+        periods=periods,
+        freq=freq,
+        tz=tz,
+        normalize=normalize,
+        name=name,
+        inclusive=inclusive,
+        **kwargs,
+    )
     return op(shape, chunk_size=chunk_size)
