@@ -17,33 +17,68 @@ import cloudpickle
 
 from ... import opcodes
 from ...core import recursive_tile
-from ...serialization.serializables import StringField, AnyField, BoolField, \
-    Int64Field, BytesField
+from ...serialization.serializables import (
+    StringField,
+    AnyField,
+    BoolField,
+    Int64Field,
+    BytesField,
+)
 from ..core import DATAFRAME_TYPE
 from ..operands import DataFrameOperand, DataFrameOperandMixin
-from ..utils import parse_index, build_empty_df, build_empty_series, create_sa_connection
+from ..utils import (
+    parse_index,
+    build_empty_df,
+    build_empty_series,
+    create_sa_connection,
+)
 
 
 class DataFrameToSQLTable(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = opcodes.TO_SQL
 
-    _table_name = StringField('table_name')
-    _con = AnyField('con')
-    _schema = StringField('schema')
-    _if_exists = StringField('if_exists')
-    _index = BoolField('index')
-    _index_label = AnyField('index_label')
-    _chunksize = Int64Field('chunksize')
-    _dtype = AnyField('dtype')
-    _method = AnyField('method')
-    _engine_kwargs = BytesField('engine_kwargs', on_serialize=cloudpickle.dumps,
-                                on_deserialize=cloudpickle.loads)
+    _table_name = StringField("table_name")
+    _con = AnyField("con")
+    _schema = StringField("schema")
+    _if_exists = StringField("if_exists")
+    _index = BoolField("index")
+    _index_label = AnyField("index_label")
+    _chunksize = Int64Field("chunksize")
+    _dtype = AnyField("dtype")
+    _method = AnyField("method")
+    _engine_kwargs = BytesField(
+        "engine_kwargs",
+        on_serialize=cloudpickle.dumps,
+        on_deserialize=cloudpickle.loads,
+    )
 
-    def __init__(self, table_name=None, con=None, schema=None, if_exists=None, index=None,
-                 index_label=None, chunksize=None, dtype=None, method=None, engine_kwargs=None, **kw):
-        super().__init__(_table_name=table_name, _con=con, _schema=schema, _if_exists=if_exists,
-                         _index=index, _index_label=index_label, _chunksize=chunksize,
-                         _dtype=dtype, _method=method, _engine_kwargs=engine_kwargs, **kw)
+    def __init__(
+        self,
+        table_name=None,
+        con=None,
+        schema=None,
+        if_exists=None,
+        index=None,
+        index_label=None,
+        chunksize=None,
+        dtype=None,
+        method=None,
+        engine_kwargs=None,
+        **kw
+    ):
+        super().__init__(
+            _table_name=table_name,
+            _con=con,
+            _schema=schema,
+            _if_exists=if_exists,
+            _index=index,
+            _index_label=index_label,
+            _chunksize=chunksize,
+            _dtype=dtype,
+            _method=method,
+            _engine_kwargs=engine_kwargs,
+            **kw
+        )
 
     @property
     def table_name(self):
@@ -92,63 +127,111 @@ class DataFrameToSQLTable(DataFrameOperand, DataFrameOperandMixin):
             if isinstance(df_or_series, DATAFRAME_TYPE):
                 empty_obj = build_empty_df(df_or_series.dtypes, index=empty_index)
             else:
-                empty_obj = build_empty_series(df_or_series.dtype, index=empty_index, name=df_or_series.name)
+                empty_obj = build_empty_series(
+                    df_or_series.dtype, index=empty_index, name=df_or_series.name
+                )
 
-            empty_obj.to_sql(self.table_name, con=con, schema=self.schema, if_exists=self.if_exists,
-                             index=self.index, index_label=self.index_label, dtype=self.dtype)
+            empty_obj.to_sql(
+                self.table_name,
+                con=con,
+                schema=self.schema,
+                if_exists=self.if_exists,
+                index=self.index,
+                index_label=self.index_label,
+                dtype=self.dtype,
+            )
 
-            index_value = parse_index(df_or_series.index_value.to_pandas()[:0], df_or_series.key, 'index')
+            index_value = parse_index(
+                df_or_series.index_value.to_pandas()[:0], df_or_series.key, "index"
+            )
             if isinstance(df_or_series, DATAFRAME_TYPE):
-                columns_value = parse_index(df_or_series.columns_value.to_pandas()[:0],
-                                            df_or_series.key, 'columns', store_data=True)
-                return self.new_dataframe([df_or_series], shape=(0, 0), dtypes=df_or_series.dtypes[:0],
-                                          index_value=index_value, columns_value=columns_value)
+                columns_value = parse_index(
+                    df_or_series.columns_value.to_pandas()[:0],
+                    df_or_series.key,
+                    "columns",
+                    store_data=True,
+                )
+                return self.new_dataframe(
+                    [df_or_series],
+                    shape=(0, 0),
+                    dtypes=df_or_series.dtypes[:0],
+                    index_value=index_value,
+                    columns_value=columns_value,
+                )
             else:
-                return self.new_series([df_or_series], shape=(0,), dtype=df_or_series.dtype,
-                                       index_value=index_value)
+                return self.new_series(
+                    [df_or_series],
+                    shape=(0,),
+                    dtype=df_or_series.dtype,
+                    index_value=index_value,
+                )
 
     @classmethod
-    def tile(cls, op: 'DataFrameToSQLTable'):
+    def tile(cls, op: "DataFrameToSQLTable"):
         inp = op.inputs[0]
         out = op.outputs[0]
         if inp.ndim == 2:
-            inp = yield from recursive_tile(
-                inp.rechunk({1: (inp.shape[1],)}))
+            inp = yield from recursive_tile(inp.rechunk({1: (inp.shape[1],)}))
 
         chunks = []
         for c in inp.chunks:
             new_op = op.copy().reset_key()
-            new_op._if_exists = 'append'
+            new_op._if_exists = "append"
 
             index_value = parse_index(c.index_value.to_pandas()[:0], c)
             if c.ndim == 2:
-                columns_value = parse_index(c.columns_value.to_pandas()[:0], store_data=True)
-                chunks.append(new_op.new_chunk([c], shape=(0, 0), index=c.index, dtypes=out.dtypes,
-                                               index_value=index_value, columns_value=columns_value))
+                columns_value = parse_index(
+                    c.columns_value.to_pandas()[:0], store_data=True
+                )
+                chunks.append(
+                    new_op.new_chunk(
+                        [c],
+                        shape=(0, 0),
+                        index=c.index,
+                        dtypes=out.dtypes,
+                        index_value=index_value,
+                        columns_value=columns_value,
+                    )
+                )
             else:
-                chunks.append(new_op.new_chunk([c], shape=(0,), index=c.index, dtype=out.dtype,
-                                               index_value=index_value))
+                chunks.append(
+                    new_op.new_chunk(
+                        [c],
+                        shape=(0,),
+                        index=c.index,
+                        dtype=out.dtype,
+                        index_value=index_value,
+                    )
+                )
 
         new_op = op.copy().reset_key()
         params = out.params.copy()
-        params['nsplits'] = tuple((0,) * len(sp) for sp in inp.nsplits)
+        params["nsplits"] = tuple((0,) * len(sp) for sp in inp.nsplits)
         return new_op.new_tileables([inp], chunks=chunks, **params)
 
     @classmethod
-    def execute(cls, ctx, op: 'DataFrameToSQLTable'):
+    def execute(cls, ctx, op: "DataFrameToSQLTable"):
         in_df = op.inputs[0]
         out_df = op.outputs[0]
         in_data = ctx[in_df.key]
 
         import sqlalchemy as sa
+
         engine = sa.create_engine(op.con, **(op.engine_kwargs or dict()))
 
         try:
             with engine.connect() as connection:
                 with connection.begin():
-                    in_data.to_sql(op.table_name, con=connection, if_exists=op.if_exists, index=op.index,
-                                   index_label=op.index_label, chunksize=op.chunksize, dtype=op.dtype,
-                                   method=op.method)
+                    in_data.to_sql(
+                        op.table_name,
+                        con=connection,
+                        if_exists=op.if_exists,
+                        index=op.index,
+                        index_label=op.index_label,
+                        chunksize=op.chunksize,
+                        dtype=op.dtype,
+                        method=op.method,
+                    )
         finally:
             engine.dispose()
 
@@ -158,8 +241,18 @@ class DataFrameToSQLTable(DataFrameOperand, DataFrameOperandMixin):
             ctx[out_df.key] = pd.Series([], dtype=in_data.dtype)
 
 
-def to_sql(df, name: str, con, schema=None, if_exists: str = 'fail', index: bool = True, index_label=None,
-           chunksize=None, dtype=None, method=None):
+def to_sql(
+    df,
+    name: str,
+    con,
+    schema=None,
+    if_exists: str = "fail",
+    index: bool = True,
+    index_label=None,
+    chunksize=None,
+    dtype=None,
+    method=None,
+):
     """
     Write records stored in a DataFrame to a SQL database.
 
@@ -291,6 +384,15 @@ def to_sql(df, name: str, con, schema=None, if_exists: str = 'fail', index: bool
     >>> engine.execute("SELECT * FROM integers").fetchall()
     [(1,), (None,), (2,)]
     """
-    op = DataFrameToSQLTable(table_name=name, con=con, schema=schema, if_exists=if_exists, index=index,
-                             index_label=index_label, chunksize=chunksize, dtype=dtype, method=method)
+    op = DataFrameToSQLTable(
+        table_name=name,
+        con=con,
+        schema=schema,
+        if_exists=if_exists,
+        index=index,
+        index_label=index_label,
+        chunksize=chunksize,
+        dtype=dtype,
+        method=method,
+    )
     return op(df)
