@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,28 +17,32 @@ import pandas as pd
 
 from ... import opcodes
 from ...core import OutputType
-from ...custom_log import redirect_custom_log
-from ...serialize import TupleField, DictField, FunctionField, StringField
+from ...core.custom_log import redirect_custom_log
+from ...serialization.serializables import TupleField, DictField, FunctionField
 from ...utils import enter_current_session, quiet_stdio
 from ..operands import DataFrameOperandMixin, DataFrameOperand
-from ..utils import build_empty_df, build_empty_series, parse_index, \
-    validate_output_types, make_dtypes, make_dtype
+from ..utils import (
+    build_empty_df,
+    build_empty_series,
+    parse_index,
+    validate_output_types,
+    make_dtypes,
+    make_dtype,
+)
 
 
 class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = opcodes.APPLY
-    _op_module_ = 'dataframe.groupby'
+    _op_module_ = "dataframe.groupby"
 
-    _func = FunctionField('func')
-    _args = TupleField('args')
-    _kwds = DictField('kwds')
-    # for chunk
-    _tileable_op_key = StringField('tileable_op_key')
+    _func = FunctionField("func")
+    _args = TupleField("args")
+    _kwds = DictField("kwds")
 
-    def __init__(self, func=None, args=None, kwds=None, output_types=None,
-                 tileable_op_key=None, **kw):
-        super().__init__(_func=func, _args=args, _kwds=kwds, _output_types=output_types,
-                         _tileable_op_key=tileable_op_key, **kw)
+    def __init__(self, func=None, args=None, kwds=None, output_types=None, **kw):
+        super().__init__(
+            _func=func, _args=args, _kwds=kwds, _output_types=output_types, **kw
+        )
 
     @property
     def func(self):
@@ -46,15 +50,11 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
 
     @property
     def args(self):
-        return getattr(self, '_args', None) or ()
+        return getattr(self, "_args", None) or ()
 
     @property
     def kwds(self):
-        return getattr(self, '_kwds', None) or dict()
-
-    @property
-    def tileable_op_key(self):
-        return self._tileable_op_key
+        return getattr(self, "_kwds", None) or dict()
 
     @classmethod
     @redirect_custom_log
@@ -67,7 +67,8 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
                 ctx[op.outputs[0].key] = build_empty_df(op.outputs[0].dtypes)
             else:
                 ctx[op.outputs[0].key] = build_empty_series(
-                    op.outputs[0].dtype, name=out.name)
+                    op.outputs[0].dtype, name=out.name
+                )
             return
 
         applied = in_data.apply(op.func, *op.args, **op.kwds)
@@ -78,10 +79,15 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
             if op.output_types[0] == OutputType.series:
                 assert len(applied.index) == 1
                 applied_idx = pd.MultiIndex.from_arrays(
-                    [[applied.index[0]] * len(applied.columns), applied.columns.tolist()])
+                    [
+                        [applied.index[0]] * len(applied.columns),
+                        applied.columns.tolist(),
+                    ]
+                )
                 applied_idx.names = [applied.index.name, None]
-                applied = pd.Series(np.array(applied.iloc[0]), applied_idx,
-                                    name=applied.columns.name)
+                applied = pd.Series(
+                    np.array(applied.iloc[0]), applied_idx, name=applied.columns.name
+                )
             else:
                 applied.columns.name = None
         else:
@@ -98,31 +104,53 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
             inp_chunks = [c]
 
             new_op = op.copy().reset_key()
-            new_op._tileable_op_key = op.key
+            new_op.tileable_op_key = op.key
             if op.output_types[0] == OutputType.dataframe:
-                chunks.append(new_op.new_chunk(
-                    inp_chunks, index=c.index, shape=(np.nan, len(out_df.dtypes)), dtypes=out_df.dtypes,
-                    columns_value=out_df.columns_value, index_value=out_df.index_value))
+                chunks.append(
+                    new_op.new_chunk(
+                        inp_chunks,
+                        index=c.index,
+                        shape=(np.nan, len(out_df.dtypes)),
+                        dtypes=out_df.dtypes,
+                        columns_value=out_df.columns_value,
+                        index_value=out_df.index_value,
+                    )
+                )
             else:
-                chunks.append(new_op.new_chunk(
-                    inp_chunks, name=out_df.name, index=(c.index[0],), shape=(np.nan,), dtype=out_df.dtype,
-                    index_value=out_df.index_value))
+                chunks.append(
+                    new_op.new_chunk(
+                        inp_chunks,
+                        name=out_df.name,
+                        index=(c.index[0],),
+                        shape=(np.nan,),
+                        dtype=out_df.dtype,
+                        index_value=out_df.index_value,
+                    )
+                )
 
         new_op = op.copy()
         kw = out_df.params.copy()
-        kw['chunks'] = chunks
+        kw["chunks"] = chunks
         if op.output_types[0] == OutputType.dataframe:
-            kw['nsplits'] = ((np.nan,) * len(chunks), (out_df.shape[1],))
+            kw["nsplits"] = ((np.nan,) * len(chunks), (out_df.shape[1],))
         else:
-            kw['nsplits'] = ((np.nan,) * len(chunks),)
+            kw["nsplits"] = ((np.nan,) * len(chunks),)
         return new_op.new_tileables([in_groupby], **kw)
 
-    def _infer_df_func_returns(self, in_groupby, in_df, dtypes, dtype=None,
-                               name=None, index=None):
+    def _infer_df_func_returns(
+        self, in_groupby, in_df, dtypes=None, dtype=None, name=None, index=None
+    ):
         index_value, output_type, new_dtypes = None, None, None
 
+        if self.output_types is not None and (dtypes is not None or dtype is not None):
+            ret_dtypes = dtypes if dtypes is not None else (dtype, name)
+            ret_index_value = parse_index(index) if index is not None else None
+            return ret_dtypes, ret_index_value
+
         try:
-            infer_df = in_groupby.op.build_mock_groupby().apply(self.func, *self.args, **self.kwds)
+            infer_df = in_groupby.op.build_mock_groupby().apply(
+                self.func, *self.args, **self.kwds
+            )
 
             # todo return proper index when sort=True is implemented
             index_value = parse_index(infer_df.index[:0], in_df.key, self.func)
@@ -134,14 +162,19 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
                 new_dtypes = new_dtypes or infer_df.dtypes
             elif isinstance(infer_df, pd.Series):
                 output_type = output_type or OutputType.series
-                new_dtypes = new_dtypes or (name or infer_df.name, dtype or infer_df.dtype)
+                new_dtypes = new_dtypes or (
+                    name or infer_df.name,
+                    dtype or infer_df.dtype,
+                )
             else:
                 output_type = OutputType.series
                 new_dtypes = (name, dtype or pd.Series(infer_df).dtype)
         except:  # noqa: E722  # nosec
             pass
 
-        self.output_types = [output_type] if not self.output_types else self.output_types
+        self.output_types = (
+            [output_type] if not self.output_types else self.output_types
+        )
         dtypes = new_dtypes if dtypes is None else dtypes
         index_value = index_value if index is None else parse_index(index)
         return dtypes, index_value
@@ -153,28 +186,50 @@ class GroupByApply(DataFrameOperand, DataFrameOperandMixin):
 
         with quiet_stdio():
             dtypes, index_value = self._infer_df_func_returns(
-                groupby, in_df, dtypes, dtype=dtype, name=name, index=index)
+                groupby, in_df, dtypes, dtype=dtype, name=name, index=index
+            )
         if index_value is None:
             index_value = parse_index(None, (in_df.key, in_df.index_value.key))
-        for arg, desc in zip((self.output_types, dtypes), ('output_types', 'dtypes')):
+        for arg, desc in zip((self.output_types, dtypes), ("output_types", "dtypes")):
             if arg is None:
-                raise TypeError(f'Cannot determine {desc} by calculating with enumerate data, '
-                                'please specify it as arguments')
+                raise TypeError(
+                    f"Cannot determine {desc} by calculating with enumerate data, "
+                    "please specify it as arguments"
+                )
 
         if self.output_types[0] == OutputType.dataframe:
             new_shape = (np.nan, len(dtypes))
-            return self.new_dataframe([groupby], shape=new_shape, dtypes=dtypes, index_value=index_value,
-                                      columns_value=parse_index(dtypes.index, store_data=True))
+            return self.new_dataframe(
+                [groupby],
+                shape=new_shape,
+                dtypes=dtypes,
+                index_value=index_value,
+                columns_value=parse_index(dtypes.index, store_data=True),
+            )
         else:
             name = name or dtypes[0]
             dtype = dtype or dtypes[1]
             new_shape = (np.nan,)
-            return self.new_series([groupby], name=name, shape=new_shape, dtype=dtype,
-                                   index_value=index_value)
+            return self.new_series(
+                [groupby],
+                name=name,
+                shape=new_shape,
+                dtype=dtype,
+                index_value=index_value,
+            )
 
 
-def groupby_apply(groupby, func, *args, output_type=None, dtypes=None, dtype=None,
-                  name=None, index=None, **kwargs):
+def groupby_apply(
+    groupby,
+    func,
+    *args,
+    output_type=None,
+    dtypes=None,
+    dtype=None,
+    name=None,
+    index=None,
+    **kwargs,
+):
     """
     Apply function `func` group-wise and combine the results together.
 
@@ -241,10 +296,11 @@ def groupby_apply(groupby, func, *args, output_type=None, dtypes=None, dtype=Non
     * For Series output, you need to specify ``dtype`` and ``name`` of
       output Series.
     """
-    output_types = kwargs.pop('output_types', None)
-    object_type = kwargs.pop('object_type', None)
+    output_types = kwargs.pop("output_types", None)
+    object_type = kwargs.pop("object_type", None)
     output_types = validate_output_types(
-        output_types=output_types, output_type=output_type, object_type=object_type)
+        output_types=output_types, output_type=output_type, object_type=object_type
+    )
 
     dtypes = make_dtypes(dtypes)
     dtype = make_dtype(dtype)
