@@ -23,8 +23,16 @@ import pandas as pd
 from ... import opcodes
 from ...core import ENTITY_TYPE, OutputType, get_output_types, recursive_tile
 from ...core.operand import OperandStage, MapReduceOperand
-from ...serialization.serializables import BoolField, DictField, Float32Field, KeyField, \
-    Int32Field, Int64Field, NDArrayField, StringField
+from ...serialization.serializables import (
+    BoolField,
+    DictField,
+    Float32Field,
+    KeyField,
+    Int32Field,
+    Int64Field,
+    NDArrayField,
+    StringField,
+)
 from ...tensor.operands import TensorShuffleProxy
 from ...tensor.random import RandomStateField
 from ...tensor.utils import gen_random_seeds
@@ -33,13 +41,14 @@ from ..initializer import Series as asseries
 from ..operands import DataFrameOperandMixin, DataFrameOperand
 from ..utils import parse_index
 
-_ILOC_COL_HEADER = '_gsamp_iloc_col_'
-_WEIGHT_COL_HEADER = '_gsamp_weight_col_'
+_ILOC_COL_HEADER = "_gsamp_iloc_col_"
+_WEIGHT_COL_HEADER = "_gsamp_weight_col_"
 
 
 # code adapted from pandas.core.groupby.groupby.DataFrameGroupBy.sample
-def _sample_groupby_iter(groupby, obj_index, n, frac, replace, weights,
-                         random_state=None, errors='ignore'):
+def _sample_groupby_iter(
+    groupby, obj_index, n, frac, replace, weights, random_state=None, errors="ignore"
+):
     if weights is None:
         ws = [None] * groupby.ngroups
     elif not isinstance(weights, Iterable) or isinstance(weights, str):
@@ -49,7 +58,7 @@ def _sample_groupby_iter(groupby, obj_index, n, frac, replace, weights,
         ws = [weights.iloc[idx] for idx in groupby.indices.values()]
 
     group_iterator = groupby.grouper.get_iterator(groupby._selected_obj)
-    if not replace and errors == 'ignore':
+    if not replace and errors == "ignore":
         for (_, obj), w in zip(group_iterator, ws):
             yield obj.sample(
                 n=n, frac=frac, replace=replace, weights=w, random_state=random_state
@@ -63,31 +72,50 @@ def _sample_groupby_iter(groupby, obj_index, n, frac, replace, weights,
 
 class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
     _op_code_ = opcodes.GROUPBY_SAMPLE_ILOC
-    _op_module_ = 'dataframe.groupby'
+    _op_module_ = "dataframe.groupby"
 
-    _groupby_params = DictField('groupby_params')
-    _size = Int64Field('size')
-    _frac = Float32Field('frac')
-    _replace = BoolField('replace')
-    _weights = KeyField('weights')
-    _seed = Int32Field('seed')
-    _random_state = RandomStateField('random_state')
-    _errors = StringField('errors')
+    _groupby_params = DictField("groupby_params")
+    _size = Int64Field("size")
+    _frac = Float32Field("frac")
+    _replace = BoolField("replace")
+    _weights = KeyField("weights")
+    _seed = Int32Field("seed")
+    _random_state = RandomStateField("random_state")
+    _errors = StringField("errors")
 
-    _random_col_id = Int32Field('random_col_id')
+    _random_col_id = Int32Field("random_col_id")
 
     # for chunks
     # num of instances for chunks
-    _left_iloc_bound = Int64Field('left_iloc_bound')
+    _left_iloc_bound = Int64Field("left_iloc_bound")
 
-    def __init__(self, groupby_params=None, size=None, frac=None, replace=None,
-                 weights=None, random_state=None, seed=None, errors=None,
-                 left_iloc_bound=None, random_col_id=None, **kw):
-        super().__init__(_groupby_params=groupby_params, _size=size, _frac=frac,
-                         _seed=seed, _replace=replace, _weights=weights,
-                         _random_state=random_state, _errors=errors,
-                         _left_iloc_bound=left_iloc_bound,
-                         _random_col_id=random_col_id, **kw)
+    def __init__(
+        self,
+        groupby_params=None,
+        size=None,
+        frac=None,
+        replace=None,
+        weights=None,
+        random_state=None,
+        seed=None,
+        errors=None,
+        left_iloc_bound=None,
+        random_col_id=None,
+        **kw
+    ):
+        super().__init__(
+            _groupby_params=groupby_params,
+            _size=size,
+            _frac=frac,
+            _seed=seed,
+            _replace=replace,
+            _weights=weights,
+            _random_state=random_state,
+            _errors=errors,
+            _left_iloc_bound=left_iloc_bound,
+            _random_col_id=random_col_id,
+            **kw
+        )
         if self._random_col_id is None:
             self._random_col_id = random.randint(10000, 99999)
 
@@ -145,11 +173,12 @@ class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
         inp_tileables = [df]
         if self.weights is not None:
             inp_tileables.append(self.weights)
-        return self.new_tileable(inp_tileables, dtype=np.dtype(np.int_),
-                                 shape=(np.nan,))
+        return self.new_tileable(
+            inp_tileables, dtype=np.dtype(np.int_), shape=(np.nan,)
+        )
 
     @classmethod
-    def tile(cls, op: 'GroupBySampleILoc'):
+    def tile(cls, op: "GroupBySampleILoc"):
         in_df = op.inputs[0]
         out_tensor = op.outputs[0]
         iloc_col_header = _ILOC_COL_HEADER + str(op.random_col_id)
@@ -163,8 +192,8 @@ class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
         else:
             weights_iter = iter(op.weights.chunks)
 
-        if isinstance(op.groupby_params['by'], list):
-            map_cols = list(op.groupby_params['by'])
+        if isinstance(op.groupby_params["by"], list):
+            map_cols = list(op.groupby_params["by"])
         else:  # pragma: no cover
             map_cols = []
 
@@ -190,28 +219,33 @@ class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
             if weight_chunk is not None:
                 inp_chunks.append(weight_chunk)
             params = inp_chunk.params
-            params.update(dict(
-                dtypes=new_dtypes, columns_value=new_columns_value,
-                shape=(inp_chunk.shape[0], len(new_dtypes)),
-                index=inp_chunk.index,
-            ))
+            params.update(
+                dict(
+                    dtypes=new_dtypes,
+                    columns_value=new_columns_value,
+                    shape=(inp_chunk.shape[0], len(new_dtypes)),
+                    index=inp_chunk.index,
+                )
+            )
             map_chunks.append(new_op.new_chunk(inp_chunks, **params))
 
         new_op = op.copy().reset_key()
         new_op._output_types = [OutputType.dataframe]
         params = in_df.params
-        params.update(dict(
-            chunks=map_chunks,
-            nsplits=(in_df.nsplits[0], (len(new_dtypes),)),
-            dtypes=new_dtypes, columns_value=new_columns_value,
-            shape=(in_df.shape[0], len(new_dtypes)),
-        ))
+        params.update(
+            dict(
+                chunks=map_chunks,
+                nsplits=(in_df.nsplits[0], (len(new_dtypes),)),
+                dtypes=new_dtypes,
+                columns_value=new_columns_value,
+                shape=(in_df.shape[0], len(new_dtypes)),
+            )
+        )
         map_df = new_op.new_tileable(op.inputs, **params)
 
         groupby_params = op.groupby_params.copy()
-        groupby_params.pop('selection', None)
-        grouped = yield from recursive_tile(
-            map_df.groupby(**groupby_params))
+        groupby_params.pop("selection", None)
+        grouped = yield from recursive_tile(map_df.groupby(**groupby_params))
 
         result_chunks = []
         seeds = gen_random_seeds(len(grouped.chunks), op.random_state)
@@ -222,36 +256,50 @@ class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
             new_op._random_state = None
             new_op._seed = seed
 
-            result_chunks.append(new_op.new_chunk(
-                [group_chunk], shape=(np.nan,), index=(group_chunk.index[0],),
-                dtype=out_tensor.dtype
-            ))
+            result_chunks.append(
+                new_op.new_chunk(
+                    [group_chunk],
+                    shape=(np.nan,),
+                    index=(group_chunk.index[0],),
+                    dtype=out_tensor.dtype,
+                )
+            )
 
         new_op = op.copy().reset_key()
         params = out_tensor.params
-        params.update(dict(
-            chunks=result_chunks, nsplits=((np.nan,) * len(result_chunks),)
-        ))
+        params.update(
+            dict(chunks=result_chunks, nsplits=((np.nan,) * len(result_chunks),))
+        )
         return new_op.new_tileables(op.inputs, **params)
 
     @classmethod
-    def execute(cls, ctx, op: 'GroupBySampleILoc'):
+    def execute(cls, ctx, op: "GroupBySampleILoc"):
         in_data = ctx[op.inputs[0].key]
         iloc_col = _ILOC_COL_HEADER + str(op.random_col_id)
         weight_col = _WEIGHT_COL_HEADER + str(op.random_col_id)
         if op.stage == OperandStage.map:
             if op.weights is not None:
-                ret = pd.DataFrame({
-                    iloc_col: np.arange(op.left_iloc_bound, op.left_iloc_bound + len(in_data)),
-                    weight_col: ctx[op.weights.key],
-                }, index=in_data.index)
+                ret = pd.DataFrame(
+                    {
+                        iloc_col: np.arange(
+                            op.left_iloc_bound, op.left_iloc_bound + len(in_data)
+                        ),
+                        weight_col: ctx[op.weights.key],
+                    },
+                    index=in_data.index,
+                )
             else:
-                ret = pd.DataFrame({
-                    iloc_col: np.arange(op.left_iloc_bound, op.left_iloc_bound + len(in_data)),
-                }, index=in_data.index)
+                ret = pd.DataFrame(
+                    {
+                        iloc_col: np.arange(
+                            op.left_iloc_bound, op.left_iloc_bound + len(in_data)
+                        ),
+                    },
+                    index=in_data.index,
+                )
 
-            if isinstance(op.groupby_params['by'], list):
-                ret = pd.concat([in_data[op.groupby_params['by']], ret], axis=1)
+            if isinstance(op.groupby_params["by"], list):
+                ret = pd.concat([in_data[op.groupby_params["by"]], ret], axis=1)
 
             ctx[op.outputs[0].key] = ret
         else:
@@ -261,39 +309,65 @@ class GroupBySampleILoc(DataFrameOperand, DataFrameOperandMixin):
             if len(in_data.obj) == 0 or in_data.ngroups == 0:
                 ctx[op.outputs[0].key] = np.array([], dtype=np.int_)
             else:
-                ctx[op.outputs[0].key] = np.concatenate([
-                    sample_pd[iloc_col].to_numpy()
-                    for sample_pd in _sample_groupby_iter(
-                        in_data, in_data.obj.index, n=op.size, frac=op.frac, replace=op.replace,
-                        weights=weight_col, random_state=op.random_state, errors=op.errors
-                    )
-                ])
+                ctx[op.outputs[0].key] = np.concatenate(
+                    [
+                        sample_pd[iloc_col].to_numpy()
+                        for sample_pd in _sample_groupby_iter(
+                            in_data,
+                            in_data.obj.index,
+                            n=op.size,
+                            frac=op.frac,
+                            replace=op.replace,
+                            weights=weight_col,
+                            random_state=op.random_state,
+                            errors=op.errors,
+                        )
+                    ]
+                )
 
 
 class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
     _op_code_ = opcodes.RAND_SAMPLE
-    _op_module_ = 'dataframe.groupby'
+    _op_module_ = "dataframe.groupby"
 
-    _groupby_params = DictField('groupby_params')
-    _size = Int64Field('size')
-    _frac = Float32Field('frac')
-    _replace = BoolField('replace')
-    _weights = KeyField('weights')
-    _seed = Int32Field('seed')
-    _random_state = RandomStateField('random_state')
-    _errors = StringField('errors')
+    _groupby_params = DictField("groupby_params")
+    _size = Int64Field("size")
+    _frac = Float32Field("frac")
+    _replace = BoolField("replace")
+    _weights = KeyField("weights")
+    _seed = Int32Field("seed")
+    _random_state = RandomStateField("random_state")
+    _errors = StringField("errors")
 
     # for chunks
     # num of instances for chunks
-    _input_nsplits = NDArrayField('input_nsplits')
+    _input_nsplits = NDArrayField("input_nsplits")
 
-    def __init__(self, groupby_params=None, size=None, frac=None, replace=None,
-                 weights=None, random_state=None, seed=None,
-                 errors=None, input_nsplits=None, **kw):
-        super().__init__(_groupby_params=groupby_params, _size=size, _frac=frac,
-                         _seed=seed, _replace=replace, _weights=weights,
-                         _random_state=random_state, _errors=errors,
-                         _input_nsplits=input_nsplits, **kw)
+    def __init__(
+        self,
+        groupby_params=None,
+        size=None,
+        frac=None,
+        replace=None,
+        weights=None,
+        random_state=None,
+        seed=None,
+        errors=None,
+        input_nsplits=None,
+        **kw
+    ):
+        super().__init__(
+            _groupby_params=groupby_params,
+            _size=size,
+            _frac=frac,
+            _seed=seed,
+            _replace=replace,
+            _weights=weights,
+            _random_state=random_state,
+            _errors=errors,
+            _input_nsplits=input_nsplits,
+            **kw
+        )
 
     @property
     def groupby_params(self):
@@ -343,7 +417,7 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
         while df.op.output_types[0] not in (OutputType.dataframe, OutputType.series):
             df = df.inputs[0]
 
-        selection = groupby.op.groupby_params.pop('selection', None)
+        selection = groupby.op.groupby_params.pop("selection", None)
         if df.ndim > 1 and selection:
             if isinstance(selection, tuple) and selection not in df.dtypes:
                 selection = list(selection)
@@ -352,8 +426,10 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             result_df = df
 
         params = result_df.params
-        params['shape'] = (np.nan,) if result_df.ndim == 1 else (np.nan, result_df.shape[-1])
-        params['index_value'] = parse_index(result_df.index_value.to_pandas()[:0])
+        params["shape"] = (
+            (np.nan,) if result_df.ndim == 1 else (np.nan, result_df.shape[-1])
+        )
+        params["index_value"] = parse_index(result_df.index_value.to_pandas()[:0])
 
         input_dfs = [df]
         if isinstance(self.weights, ENTITY_TYPE):
@@ -374,12 +450,13 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
         chunk_op = op.copy().reset_key()
         if isinstance(weights, ENTITY_TYPE):
             chunk_op._weights = weights
-        params['index'] = (0,) * out.ndim
+        params["index"] = (0,) * out.ndim
         chunk = chunk_op.new_chunk([c.chunks[0] for c in input_dfs], **params)
 
         df_op = op.copy().reset_key()
         return df_op.new_tileables(
-            input_dfs, chunks=[chunk], nsplits=((s,) for s in out.shape), **params)
+            input_dfs, chunks=[chunk], nsplits=((s,) for s in out.shape), **params
+        )
 
     @classmethod
     def _tile_distributed(cls, op: "GroupBySample", in_df, weights):
@@ -388,9 +465,15 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             yield
 
         sample_iloc_op = GroupBySampleILoc(
-            groupby_params=op.groupby_params, size=op.size, frac=op.frac, replace=op.replace,
-            weights=weights, random_state=op.random_state, errors=op.errors, seed=None,
-            left_iloc_bound=None
+            groupby_params=op.groupby_params,
+            size=op.size,
+            frac=op.frac,
+            replace=op.replace,
+            weights=weights,
+            random_state=op.random_state,
+            errors=op.errors,
+            seed=None,
+            left_iloc_bound=None,
         )
         sampled_iloc = yield from recursive_tile(sample_iloc_op(in_df))
 
@@ -402,11 +485,15 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             new_op._output_types = [OutputType.tensor]
             new_op._input_nsplits = np.array(in_df.nsplits[0])
 
-            map_chunks.append(new_op.new_chunk(
-                [c], dtype=sampled_iloc.dtype, shape=(np.nan,), index=c.index))
+            map_chunks.append(
+                new_op.new_chunk(
+                    [c], dtype=sampled_iloc.dtype, shape=(np.nan,), index=c.index
+                )
+            )
 
         proxy_chunk = TensorShuffleProxy(dtype=sampled_iloc.dtype).new_chunk(
-            map_chunks, shape=())
+            map_chunks, shape=()
+        )
 
         reduce_chunks = []
         for src_chunk in in_df.chunks:
@@ -417,8 +504,14 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             new_op.reducer_index = (src_chunk.index[0],)
             new_op._input_nsplits = np.array(in_df.nsplits[0])
 
-            reduce_chunks.append(new_op.new_chunk(
-                [proxy_chunk], index=src_chunk.index, dtype=sampled_iloc.dtype, shape=(np.nan,)))
+            reduce_chunks.append(
+                new_op.new_chunk(
+                    [proxy_chunk],
+                    index=src_chunk.index,
+                    dtype=sampled_iloc.dtype,
+                    shape=(np.nan,),
+                )
+            )
 
         combine_chunks = []
         for src_chunk, reduce_chunk in zip(in_df.chunks, reduce_chunks):
@@ -428,16 +521,23 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
 
             params = out_df.params
             if out_df.ndim == 2:
-                params.update(dict(
-                    index=src_chunk.index, dtypes=out_df.dtypes,
-                    shape=(np.nan, out_df.shape[1]),
-                    columns_value=out_df.columns_value,
-                ))
+                params.update(
+                    dict(
+                        index=src_chunk.index,
+                        dtypes=out_df.dtypes,
+                        shape=(np.nan, out_df.shape[1]),
+                        columns_value=out_df.columns_value,
+                    )
+                )
             else:
-                params.update(dict(
-                    index=(src_chunk.index[0],), dtype=out_df.dtype,
-                    shape=(np.nan,), name=out_df.name,
-                ))
+                params.update(
+                    dict(
+                        index=(src_chunk.index[0],),
+                        dtype=out_df.dtype,
+                        shape=(np.nan,),
+                        name=out_df.name,
+                    )
+                )
             combine_chunks.append(new_op.new_chunk([src_chunk, reduce_chunk], **params))
 
         new_op = op.copy().reset_key()
@@ -445,27 +545,26 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             new_nsplits = ((np.nan,) * in_df.chunk_shape[0], (out_df.shape[1],))
         else:
             new_nsplits = ((np.nan,) * in_df.chunk_shape[0],)
-        return new_op.new_tileables(out_df.inputs, chunks=combine_chunks, nsplits=new_nsplits,
-                                    **out_df.params)
+        return new_op.new_tileables(
+            out_df.inputs, chunks=combine_chunks, nsplits=new_nsplits, **out_df.params
+        )
 
     @classmethod
-    def tile(cls, op: 'GroupBySample'):
+    def tile(cls, op: "GroupBySample"):
         in_df = op.inputs[0]
         if in_df.ndim == 2:
-            in_df = yield from recursive_tile(
-                in_df.rechunk({1: (in_df.shape[1],)}))
+            in_df = yield from recursive_tile(in_df.rechunk({1: (in_df.shape[1],)}))
 
         weights = op.weights
         if isinstance(weights, ENTITY_TYPE):
-            weights = yield from recursive_tile(
-                weights.rechunk({0: in_df.nsplits[0]}))
+            weights = yield from recursive_tile(weights.rechunk({0: in_df.nsplits[0]}))
 
         if len(in_df.chunks) == 1:
             return cls._tile_one_chunk(op, in_df, weights)
         return (yield from cls._tile_distributed(op, in_df, weights))
 
     @classmethod
-    def execute(cls, ctx, op: 'GroupBySample'):
+    def execute(cls, ctx, op: "GroupBySample"):
         out_df = op.outputs[0]
 
         if op.stage == OperandStage.map:
@@ -486,7 +585,7 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
         elif op.stage == OperandStage.combine:
             in_data = ctx[op.inputs[0].key]
             idx = ctx[op.inputs[1].key]
-            selection = op.groupby_params.get('selection')
+            selection = op.groupby_params.get("selection")
             if selection:
                 in_data = in_data[selection]
             ctx[op.outputs[0].key] = in_data.iloc[idx]
@@ -496,23 +595,39 @@ class GroupBySample(MapReduceOperand, DataFrameOperandMixin):
             if isinstance(weights, ENTITY_TYPE):
                 weights = ctx[weights.key]
             params = op.groupby_params.copy()
-            selection = params.pop('selection', None)
+            selection = params.pop("selection", None)
 
             grouped = in_data.groupby(**params)
             if selection is not None:
                 grouped = grouped[selection]
 
-            result = pd.concat([
-                sample_df for sample_df in _sample_groupby_iter(
-                    grouped, in_data.index, n=op.size, frac=op.frac, replace=op.replace,
-                    weights=weights, random_state=op.random_state, errors=op.errors,
-                )
-            ])
+            result = pd.concat(
+                [
+                    sample_df
+                    for sample_df in _sample_groupby_iter(
+                        grouped,
+                        in_data.index,
+                        n=op.size,
+                        frac=op.frac,
+                        replace=op.replace,
+                        weights=weights,
+                        random_state=op.random_state,
+                        errors=op.errors,
+                    )
+                ]
+            )
             ctx[out_df.key] = result
 
 
-def groupby_sample(groupby, n=None, frac=None, replace=False, weights=None,
-                   random_state=None, errors='ignore'):
+def groupby_sample(
+    groupby,
+    n=None,
+    frac=None,
+    replace=False,
+    weights=None,
+    random_state=None,
+    errors="ignore",
+):
     """
     Return a random sample of items from each group.
 
@@ -600,15 +715,22 @@ def groupby_sample(groupby, n=None, frac=None, replace=False, weights=None,
     0    red  0
     """
     groupby_params = groupby.op.groupby_params.copy()
-    groupby_params.pop('as_index', None)
+    groupby_params.pop("as_index", None)
 
     if weights is not None and not isinstance(weights, ENTITY_TYPE):
         weights = asseries(weights)
 
     n = 1 if n is None and frac is None else n
     rs = copy.deepcopy(
-        random_state.to_numpy() if hasattr(random_state, 'to_numpy') else random_state)
-    op = GroupBySample(size=n, frac=frac, replace=replace, weights=weights,
-                       random_state=rs, groupby_params=groupby_params,
-                       errors=errors)
+        random_state.to_numpy() if hasattr(random_state, "to_numpy") else random_state
+    )
+    op = GroupBySample(
+        size=n,
+        frac=frac,
+        replace=replace,
+        weights=weights,
+        random_state=rs,
+        groupby_params=groupby_params,
+        errors=errors,
+    )
     return op(groupby)
