@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@ import pandas as pd
 
 from ... import opcodes
 from ...core import OutputType
-from ...custom_log import redirect_custom_log
-from ...serialize import BoolField, TupleField, DictField, AnyField, StringField
+from ...core.custom_log import redirect_custom_log
+from ...serialization.serializables import BoolField, TupleField, DictField, AnyField
 from ...utils import enter_current_session, quiet_stdio
 from ..operands import DataFrameOperandMixin, DataFrameOperand
 from ..utils import build_empty_df, build_empty_series, parse_index
@@ -26,21 +26,25 @@ from ..utils import build_empty_df, build_empty_series, parse_index
 
 class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = opcodes.TRANSFORM
-    _op_module_ = 'dataframe.groupby'
+    _op_module_ = "dataframe.groupby"
 
-    _func = AnyField('func')
-    _args = TupleField('args')
-    _kwds = DictField('kwds')
+    _func = AnyField("func")
+    _args = TupleField("args")
+    _kwds = DictField("kwds")
 
-    _call_agg = BoolField('call_agg')
+    _call_agg = BoolField("call_agg")
 
-    # for chunk
-    _tileable_op_key = StringField('tileable_op_key')
-
-    def __init__(self, func=None, args=None, kwds=None, call_agg=None, output_types=None,
-                 tileable_op_key=None, **kw):
-        super().__init__(_func=func, _args=args, _kwds=kwds, _call_agg=call_agg,
-                         _output_types=output_types, _tileable_op_key=tileable_op_key, **kw)
+    def __init__(
+        self, func=None, args=None, kwds=None, call_agg=None, output_types=None, **kw
+    ):
+        super().__init__(
+            _func=func,
+            _args=args,
+            _kwds=kwds,
+            _call_agg=call_agg,
+            _output_types=output_types,
+            **kw,
+        )
 
     @property
     def func(self):
@@ -48,33 +52,34 @@ class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
 
     @property
     def args(self):
-        return getattr(self, '_args', None) or ()
+        return getattr(self, "_args", None) or ()
 
     @property
     def kwds(self):
-        return getattr(self, '_kwds', None) or dict()
+        return getattr(self, "_kwds", None) or dict()
 
     @property
     def call_agg(self):
         return self._call_agg
 
-    @property
-    def tileable_op_key(self):
-        return self._tileable_op_key
-
     def _infer_df_func_returns(self, in_groupby, dtypes, index):
         index_value, output_types, new_dtypes = None, None, None
 
-        output_types = [OutputType.dataframe] \
-            if in_groupby.op.output_types[0] == OutputType.dataframe_groupby else [OutputType.series]
+        output_types = (
+            [OutputType.dataframe]
+            if in_groupby.op.output_types[0] == OutputType.dataframe_groupby
+            else [OutputType.series]
+        )
 
         try:
             mock_groupby = in_groupby.op.build_mock_groupby()
-            with np.errstate(all='ignore'), quiet_stdio():
+            with np.errstate(all="ignore"), quiet_stdio():
                 if self.call_agg:
                     infer_df = mock_groupby.agg(self.func, *self.args, **self.kwds)
                 else:
-                    infer_df = mock_groupby.transform(self.func, *self.args, **self.kwds)
+                    infer_df = mock_groupby.transform(
+                        self.func, *self.args, **self.kwds
+                    )
 
             # todo return proper index when sort=True is implemented
             index_value = parse_index(None, in_groupby.key, self.func)
@@ -101,20 +106,32 @@ class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
         dtypes, index_value = self._infer_df_func_returns(groupby, dtypes, index)
         if index_value is None:
             index_value = parse_index(None, (in_df.key, in_df.index_value.key))
-        for arg, desc in zip((self.output_types, dtypes), ('output_types', 'dtypes')):
+        for arg, desc in zip((self.output_types, dtypes), ("output_types", "dtypes")):
             if arg is None:
-                raise TypeError(f'Cannot determine {desc} by calculating with enumerate data, '
-                                'please specify it as arguments')
+                raise TypeError(
+                    f"Cannot determine {desc} by calculating with enumerate data, "
+                    "please specify it as arguments"
+                )
 
         if self.output_types[0] == OutputType.dataframe:
             new_shape = (np.nan if self.call_agg else in_df.shape[0], len(dtypes))
-            return self.new_dataframe([groupby], shape=new_shape, dtypes=dtypes, index_value=index_value,
-                                      columns_value=parse_index(dtypes.index, store_data=True))
+            return self.new_dataframe(
+                [groupby],
+                shape=new_shape,
+                dtypes=dtypes,
+                index_value=index_value,
+                columns_value=parse_index(dtypes.index, store_data=True),
+            )
         else:
             name, dtype = dtypes
             new_shape = (np.nan,) if self.call_agg else groupby.shape
-            return self.new_series([groupby], name=name, shape=new_shape, dtype=dtype,
-                                   index_value=index_value)
+            return self.new_series(
+                [groupby],
+                name=name,
+                shape=new_shape,
+                dtype=dtype,
+                index_value=index_value,
+            )
 
     @classmethod
     def tile(cls, op):
@@ -126,24 +143,38 @@ class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
             inp_chunks = [c]
 
             new_op = op.copy().reset_key()
-            new_op._tileable_op_key = op.key
+            new_op.tileable_op_key = op.key
             if op.output_types[0] == OutputType.dataframe:
                 new_index = c.index if c.ndim == 2 else c.index + (0,)
-                chunks.append(new_op.new_chunk(
-                    inp_chunks, index=new_index, shape=(np.nan, len(out_df.dtypes)), dtypes=out_df.dtypes,
-                    columns_value=out_df.columns_value, index_value=out_df.index_value))
+                chunks.append(
+                    new_op.new_chunk(
+                        inp_chunks,
+                        index=new_index,
+                        shape=(np.nan, len(out_df.dtypes)),
+                        dtypes=out_df.dtypes,
+                        columns_value=out_df.columns_value,
+                        index_value=out_df.index_value,
+                    )
+                )
             else:
-                chunks.append(new_op.new_chunk(
-                    inp_chunks, name=out_df.name, index=(c.index[0],), shape=(np.nan,), dtype=out_df.dtype,
-                    index_value=out_df.index_value))
+                chunks.append(
+                    new_op.new_chunk(
+                        inp_chunks,
+                        name=out_df.name,
+                        index=(c.index[0],),
+                        shape=(np.nan,),
+                        dtype=out_df.dtype,
+                        index_value=out_df.index_value,
+                    )
+                )
 
         new_op = op.copy()
         kw = out_df.params.copy()
-        kw['chunks'] = chunks
+        kw["chunks"] = chunks
         if op.output_types[0] == OutputType.dataframe:
-            kw['nsplits'] = ((np.nan,) * len(chunks), (len(out_df.dtypes),))
+            kw["nsplits"] = ((np.nan,) * len(chunks), (len(out_df.dtypes),))
         else:
-            kw['nsplits'] = ((np.nan,) * len(chunks),)
+            kw["nsplits"] = ((np.nan,) * len(chunks),)
         return new_op.new_tileables([in_groupby], **kw)
 
     @classmethod
@@ -153,12 +184,17 @@ class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
         in_data = ctx[op.inputs[0].key]
         out_chunk = op.outputs[0]
 
-        if not in_data:
+        if in_data is None:
             if op.output_types[0] == OutputType.dataframe:
-                ctx[op.outputs[0].key] = build_empty_df(out_chunk.dtypes)
+                ctx[op.outputs[0].key] = build_empty_df(
+                    out_chunk.dtypes, index=out_chunk.index_value.to_pandas()
+                )
             else:
                 ctx[op.outputs[0].key] = build_empty_series(
-                    out_chunk.dtype, name=out_chunk.name)
+                    out_chunk.dtype,
+                    name=out_chunk.name,
+                    index=out_chunk.index_value.to_pandas(),
+                )
             return
 
         if op.call_agg:
@@ -179,8 +215,17 @@ class GroupByTransform(DataFrameOperand, DataFrameOperandMixin):
         ctx[op.outputs[0].key] = result
 
 
-def groupby_transform(groupby, f, *args, dtypes=None, dtype=None, name=None, index=None,
-                      output_types=None, **kwargs):
+def groupby_transform(
+    groupby,
+    f,
+    *args,
+    dtypes=None,
+    dtype=None,
+    name=None,
+    index=None,
+    output_types=None,
+    **kwargs,
+):
     """
     Call function producing a like-indexed DataFrame on each group and
     return a DataFrame having the same indexes as the original object
@@ -276,10 +321,11 @@ def groupby_transform(groupby, f, *args, dtypes=None, dtype=None, name=None, ind
     4  4  6.0
     5  3  8.0
     """
-    call_agg = kwargs.pop('_call_agg', False)
+    call_agg = kwargs.pop("_call_agg", False)
     if not call_agg and isinstance(f, (dict, list)):
-        raise TypeError(f'Does not support transform with {type(f)}')
+        raise TypeError(f"Does not support transform with {type(f)}")
 
-    op = GroupByTransform(func=f, args=args, kwds=kwargs, output_types=output_types,
-                          call_agg=call_agg)
+    op = GroupByTransform(
+        func=f, args=args, kwds=kwargs, output_types=output_types, call_agg=call_agg
+    )
     return op(groupby, dtypes=dtypes, dtype=dtype, name=name, index=index)
