@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,41 +34,41 @@ def _install():
     from .add_prefix import df_add_prefix, series_add_prefix
 
     for cls in DATAFRAME_TYPE + SERIES_TYPE:
-        setattr(cls, 'iloc', cache_readonly(iloc))
-        setattr(cls, 'loc', cache_readonly(loc))
-        setattr(cls, 'iat', cache_readonly(iat))
-        setattr(cls, 'at', cache_readonly(at))
-        setattr(cls, 'head', head)
-        setattr(cls, 'reindex', reindex)
-        setattr(cls, 'reindex_like', reindex_like)
-        setattr(cls, 'rename_axis', rename_axis)
-        setattr(cls, 'tail', tail)
-        setattr(cls, 'mask', mask)
-        setattr(cls, 'where', where)
-        setattr(cls, 'sample', sample)
+        setattr(cls, "iloc", cache_readonly(iloc))
+        setattr(cls, "loc", cache_readonly(loc))
+        setattr(cls, "iat", cache_readonly(iat))
+        setattr(cls, "at", cache_readonly(at))
+        setattr(cls, "head", head)
+        setattr(cls, "reindex", reindex)
+        setattr(cls, "reindex_like", reindex_like)
+        setattr(cls, "rename_axis", rename_axis)
+        setattr(cls, "tail", tail)
+        setattr(cls, "mask", mask)
+        setattr(cls, "where", where)
+        setattr(cls, "sample", sample)
 
     for cls in DATAFRAME_TYPE:
-        setattr(cls, 'set_index', set_index)
-        setattr(cls, '__getitem__', dataframe_getitem)
-        setattr(cls, '__setitem__', dataframe_setitem)
-        setattr(cls, 'insert', df_insert)
-        setattr(cls, 'reset_index', df_reset_index)
-        setattr(cls, 'rename', df_rename)
-        setattr(cls, 'set_axis', df_set_axis)
-        setattr(cls, 'add_prefix', df_add_prefix)
+        setattr(cls, "set_index", set_index)
+        setattr(cls, "__getitem__", dataframe_getitem)
+        setattr(cls, "__setitem__", dataframe_setitem)
+        setattr(cls, "insert", df_insert)
+        setattr(cls, "reset_index", df_reset_index)
+        setattr(cls, "rename", df_rename)
+        setattr(cls, "set_axis", df_set_axis)
+        setattr(cls, "add_prefix", df_add_prefix)
 
     for cls in SERIES_TYPE:
-        setattr(cls, '__getitem__', series_getitem)
-        setattr(cls, 'reset_index', series_reset_index)
-        setattr(cls, 'rename', series_rename)
-        setattr(cls, 'set_axis', series_set_axis)
-        setattr(cls, 'add_prefix', series_add_prefix)
+        setattr(cls, "__getitem__", series_getitem)
+        setattr(cls, "reset_index", series_reset_index)
+        setattr(cls, "rename", series_rename)
+        setattr(cls, "set_axis", series_set_axis)
+        setattr(cls, "add_prefix", series_add_prefix)
 
     for cls in INDEX_TYPE:
-        setattr(cls, '__getitem__', index_getitem)
-        setattr(cls, '__setitem__', index_setitem)
-        setattr(cls, 'rename', index_rename)
-        setattr(cls, 'set_names', index_set_names)
+        setattr(cls, "__getitem__", index_getitem)
+        setattr(cls, "__setitem__", index_setitem)
+        setattr(cls, "rename", index_rename)
+        setattr(cls, "set_names", index_set_names)
 
 
 _install()
