@@ -22,7 +22,11 @@ from ...config import options
 from ...core import ENTITY_TYPE, Entity, OutputType, get_output_types
 from ...core.operand import OperandStage
 from ...serialization.serializables import StringField, AnyField, BoolField, Int64Field
-from ..align import align_dataframe_dataframe, align_dataframe_series, align_series_series
+from ..align import (
+    align_dataframe_dataframe,
+    align_dataframe_series,
+    align_series_series,
+)
 from ..core import DATAFRAME_TYPE, SERIES_TYPE
 from ..operands import DataFrameOperandMixin, DataFrameOperand
 from ..utils import validate_axis
@@ -31,21 +35,40 @@ from ..utils import validate_axis
 class FillNA(DataFrameOperand, DataFrameOperandMixin):
     _op_type_ = opcodes.FILL_NA
 
-    _value = AnyField('value', on_serialize=lambda x: x.data if isinstance(x, Entity) else x)
-    _method = StringField('method')
-    _axis = AnyField('axis')
-    _limit = Int64Field('limit')
-    _downcast = AnyField('downcast')
-    _use_inf_as_na = BoolField('use_inf_as_na')
+    _value = AnyField(
+        "value", on_serialize=lambda x: x.data if isinstance(x, Entity) else x
+    )
+    _method = StringField("method")
+    _axis = AnyField("axis")
+    _limit = Int64Field("limit")
+    _downcast = AnyField("downcast")
+    _use_inf_as_na = BoolField("use_inf_as_na")
 
-    _output_limit = Int64Field('output_limit')
+    _output_limit = Int64Field("output_limit")
 
-    def __init__(self, value=None, method=None, axis=None, limit=None, downcast=None,
-                 use_inf_as_na=None, output_types=None,
-                 output_limit=None, **kw):
-        super().__init__(_value=value, _method=method, _axis=axis, _limit=limit, _downcast=downcast,
-                         _use_inf_as_na=use_inf_as_na, _output_types=output_types,
-                         _output_limit=output_limit, **kw)
+    def __init__(
+        self,
+        value=None,
+        method=None,
+        axis=None,
+        limit=None,
+        downcast=None,
+        use_inf_as_na=None,
+        output_types=None,
+        output_limit=None,
+        **kw
+    ):
+        super().__init__(
+            _value=value,
+            _method=method,
+            _axis=axis,
+            _limit=limit,
+            _downcast=downcast,
+            _use_inf_as_na=use_inf_as_na,
+            _output_types=output_types,
+            _output_limit=output_limit,
+            **kw
+        )
 
     @property
     def value(self):
@@ -82,7 +105,7 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
 
     @staticmethod
     def _get_first_slice(op, df, end):
-        if op.method == 'bfill':
+        if op.method == "bfill":
             if op.output_types[0] == OutputType.series:
                 return df.iloc[:end]
             else:
@@ -106,7 +129,9 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
         axis = op.axis
         method = op.method
 
-        filled = input_data.fillna(method=method, axis=axis, limit=limit, downcast=op.downcast)
+        filled = input_data.fillna(
+            method=method, axis=axis, limit=limit, downcast=op.downcast
+        )
         ctx[op.outputs[0].key] = cls._get_first_slice(op, filled, 1)
         del filled
 
@@ -119,49 +144,57 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
         input_data = ctx[op.inputs[0].key]
         if limit is not None:
             n_summaries = (len(op.inputs) - 1) // 2
-            summaries = [ctx[inp.key] for inp in op.inputs[1:1 + n_summaries]]
+            summaries = [ctx[inp.key] for inp in op.inputs[1 : 1 + n_summaries]]
         else:
             summaries = [ctx[inp.key] for inp in op.inputs[1:]]
 
         if not summaries:
-            ctx[op.outputs[0].key] = input_data.fillna(method=method, axis=axis, limit=limit,
-                                                       downcast=op.downcast)
+            ctx[op.outputs[0].key] = input_data.fillna(
+                method=method, axis=axis, limit=limit, downcast=op.downcast
+            )
             return
 
         valid_summary = cls._get_first_slice(
-            op, pd.concat(summaries, axis=axis).fillna(method=method, axis=axis), 1)
+            op, pd.concat(summaries, axis=axis).fillna(method=method, axis=axis), 1
+        )
 
-        if method == 'bfill':
+        if method == "bfill":
             concat_df = pd.concat([input_data, valid_summary], axis=axis)
         else:
             concat_df = pd.concat([valid_summary, input_data], axis=axis)
 
-        concat_df.fillna(method=method, axis=axis, inplace=True, limit=limit,
-                         downcast=op.downcast)
+        concat_df.fillna(
+            method=method, axis=axis, inplace=True, limit=limit, downcast=op.downcast
+        )
         ctx[op.outputs[0].key] = cls._get_first_slice(op, concat_df, -1)
 
     @classmethod
     def execute(cls, ctx, op):
         try:
-            pd.set_option('mode.use_inf_as_na', op.use_inf_as_na)
+            pd.set_option("mode.use_inf_as_na", op.use_inf_as_na)
             if op.stage == OperandStage.map:
                 cls._execute_map(ctx, op)
             elif op.stage == OperandStage.combine:
                 cls._execute_combine(ctx, op)
             else:
                 input_data = ctx[op.inputs[0].key]
-                value = getattr(op, 'value', None)
+                value = getattr(op, "value", None)
                 if isinstance(op.value, ENTITY_TYPE):
                     value = ctx[op.value.key]
                 if not isinstance(input_data, pd.Index):
                     ctx[op.outputs[0].key] = input_data.fillna(
-                        value=value, method=op.method, axis=op.axis,
-                        limit=op.limit, downcast=op.downcast)
+                        value=value,
+                        method=op.method,
+                        axis=op.axis,
+                        limit=op.limit,
+                        downcast=op.downcast,
+                    )
                 else:
                     ctx[op.outputs[0].key] = input_data.fillna(
-                        value=value, downcast=op.downcast)
+                        value=value, downcast=op.downcast
+                    )
         finally:
-            pd.reset_option('mode.use_inf_as_na')
+            pd.reset_option("mode.use_inf_as_na")
 
     @classmethod
     def _tile_one_by_one(cls, op):
@@ -187,7 +220,9 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
 
         summaries_to_concat = []
 
-        idx_range = list(range(idx) if is_forward else range(idx + 1, len(summary_chunks)))
+        idx_range = list(
+            range(idx) if is_forward else range(idx + 1, len(summary_chunks))
+        )
         for i in idx_range:
             summaries_to_concat.append(summary_chunks[i])
 
@@ -201,13 +236,13 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
     def _tile_directional_dataframe(cls, op):
         in_df = op.inputs[0]
         df = op.outputs[0]
-        is_forward = op.method == 'ffill'
+        is_forward = op.method == "ffill"
 
         n_rows, n_cols = in_df.chunk_shape
 
         # map to get individual results and summaries
-        src_chunks = np.empty(in_df.chunk_shape, dtype=np.object)
-        summary_chunks = np.empty(in_df.chunk_shape, dtype=np.object)
+        src_chunks = np.empty(in_df.chunk_shape, dtype=object)
+        summary_chunks = np.empty(in_df.chunk_shape, dtype=object)
         for c in in_df.chunks:
             new_chunk_op = op.copy().reset_key()
             new_chunk_op.stage = OperandStage.map
@@ -217,43 +252,54 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
                 summary_shape = (1, c.shape[1])
             src_chunks[c.index] = c
             summary_chunks[c.index] = new_chunk_op.new_chunk(
-                [c], shape=summary_shape, dtypes=df.dtypes)
+                [c], shape=summary_shape, dtypes=df.dtypes
+            )
 
         # combine summaries into results
-        output_chunk_array = np.empty(in_df.chunk_shape, dtype=np.object)
+        output_chunk_array = np.empty(in_df.chunk_shape, dtype=object)
         if op.axis == 1:
             for row in range(n_rows):
                 row_src = src_chunks[row, :]
                 row_summaries = summary_chunks[row, :]
                 for col in range(n_cols):
                     output_chunk_array[row, col] = cls._build_combine(
-                        op, row_src, row_summaries, col, is_forward)
+                        op, row_src, row_summaries, col, is_forward
+                    )
         else:
             for col in range(n_cols):
                 col_src = src_chunks[:, col]
                 col_summaries = summary_chunks[:, col]
                 for row in range(n_rows):
                     output_chunk_array[row, col] = cls._build_combine(
-                        op, col_src, col_summaries, row, is_forward)
+                        op, col_src, col_summaries, row, is_forward
+                    )
 
         output_chunks = list(output_chunk_array.reshape((n_rows * n_cols,)))
         new_op = op.copy().reset_key()
-        return new_op.new_tileables(op.inputs, shape=in_df.shape, nsplits=in_df.nsplits,
-                                    chunks=output_chunks, dtypes=df.dtypes,
-                                    index_value=df.index_value, columns_value=df.columns_value)
+        return new_op.new_tileables(
+            op.inputs,
+            shape=in_df.shape,
+            nsplits=in_df.nsplits,
+            chunks=output_chunks,
+            dtypes=df.dtypes,
+            index_value=df.index_value,
+            columns_value=df.columns_value,
+        )
 
     @classmethod
     def _tile_directional_series(cls, op):
         in_series = op.inputs[0]
         series = op.outputs[0]
-        forward = op.method == 'ffill'
+        forward = op.method == "ffill"
 
         # map to get individual results and summaries
-        summary_chunks = np.empty(in_series.chunk_shape, dtype=np.object)
+        summary_chunks = np.empty(in_series.chunk_shape, dtype=object)
         for c in in_series.chunks:
             new_chunk_op = op.copy().reset_key()
             new_chunk_op.stage = OperandStage.map
-            summary_chunks[c.index] = new_chunk_op.new_chunk([c], shape=(1,), dtype=series.dtype)
+            summary_chunks[c.index] = new_chunk_op.new_chunk(
+                [c], shape=(1,), dtype=series.dtype
+            )
 
         # combine summaries into results
         output_chunks = [
@@ -261,9 +307,14 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
             for i in range(len(in_series.chunks))
         ]
         new_op = op.copy().reset_key()
-        return new_op.new_tileables(op.inputs, shape=in_series.shape, nsplits=in_series.nsplits,
-                                    chunks=output_chunks, dtype=series.dtype,
-                                    index_value=series.index_value)
+        return new_op.new_tileables(
+            op.inputs,
+            shape=in_series.shape,
+            nsplits=in_series.nsplits,
+            chunks=output_chunks,
+            dtype=series.dtype,
+            index_value=series.index_value,
+        )
 
     @classmethod
     def _tile_both_dataframes(cls, op):
@@ -271,43 +322,68 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
         in_value = op.inputs[1]
         df = op.outputs[0]
 
-        nsplits, out_shape, left_chunks, right_chunks = align_dataframe_dataframe(in_df, in_value)
+        nsplits, out_shape, left_chunks, right_chunks = align_dataframe_dataframe(
+            in_df, in_value
+        )
         out_chunk_indexes = itertools.product(*(range(s) for s in out_shape))
 
         out_chunks = []
-        for idx, left_chunk, right_chunk in zip(out_chunk_indexes, left_chunks, right_chunks):
-            out_chunk = op.copy().reset_key().new_chunk([left_chunk, right_chunk],
-                                                        shape=(np.nan, np.nan), index=idx)
+        for idx, left_chunk, right_chunk in zip(
+            out_chunk_indexes, left_chunks, right_chunks
+        ):
+            out_chunk = (
+                op.copy()
+                .reset_key()
+                .new_chunk([left_chunk, right_chunk], shape=(np.nan, np.nan), index=idx)
+            )
             out_chunks.append(out_chunk)
 
         new_op = op.copy()
-        return new_op.new_dataframes(op.inputs, df.shape,
-                                     nsplits=tuple(tuple(ns) for ns in nsplits),
-                                     chunks=out_chunks, dtypes=df.dtypes,
-                                     index_value=df.index_value, columns_value=df.columns_value)
+        return new_op.new_dataframes(
+            op.inputs,
+            df.shape,
+            nsplits=tuple(tuple(ns) for ns in nsplits),
+            chunks=out_chunks,
+            dtypes=df.dtypes,
+            index_value=df.index_value,
+            columns_value=df.columns_value,
+        )
 
     @classmethod
     def _tile_dataframe_series(cls, op):
         left, right = op.inputs[0], op.inputs[1]
         df = op.outputs[0]
 
-        nsplits, out_shape, left_chunks, right_chunks = align_dataframe_series(left, right, axis=1)
+        nsplits, out_shape, left_chunks, right_chunks = align_dataframe_series(
+            left, right, axis=1
+        )
         out_chunk_indexes = itertools.product(*(range(s) for s in out_shape))
 
         out_chunks = []
         for out_idx, df_chunk in zip(out_chunk_indexes, left_chunks):
             series_chunk = right_chunks[out_idx[1]]
-            kw = dict(shape=(nsplits[0][out_idx[0]], nsplits[1][out_idx[1]]),
-                      index_value=df_chunk.index_value,
-                      columns_value=df_chunk.columns_value)
-            out_chunk = op.copy().reset_key().new_chunk([df_chunk, series_chunk], index=out_idx, **kw)
+            kw = dict(
+                shape=(nsplits[0][out_idx[0]], nsplits[1][out_idx[1]]),
+                index_value=df_chunk.index_value,
+                columns_value=df_chunk.columns_value,
+            )
+            out_chunk = (
+                op.copy()
+                .reset_key()
+                .new_chunk([df_chunk, series_chunk], index=out_idx, **kw)
+            )
             out_chunks.append(out_chunk)
 
         new_op = op.copy().reset_key()
-        return new_op.new_dataframes(op.inputs, df.shape,
-                                     nsplits=tuple(tuple(ns) for ns in nsplits),
-                                     chunks=out_chunks, dtypes=df.dtypes,
-                                     index_value=df.index_value, columns_value=df.columns_value)
+        return new_op.new_dataframes(
+            op.inputs,
+            df.shape,
+            nsplits=tuple(tuple(ns) for ns in nsplits),
+            chunks=out_chunks,
+            dtypes=df.dtypes,
+            index_value=df.index_value,
+            columns_value=df.columns_value,
+        )
 
     @classmethod
     def _tile_both_series(cls, op):
@@ -317,23 +393,38 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
         nsplits, out_shape, left_chunks, right_chunks = align_series_series(left, right)
 
         out_chunks = []
-        for idx, left_chunk, right_chunk in zip(range(out_shape[0]), left_chunks, right_chunks):
-            out_chunk = op.copy().reset_key().new_chunk([left_chunk, right_chunk],
-                                                        index_value=left_chunk.index_value,
-                                                        shape=(np.nan,), index=(idx,))
+        for idx, left_chunk, right_chunk in zip(
+            range(out_shape[0]), left_chunks, right_chunks
+        ):
+            out_chunk = (
+                op.copy()
+                .reset_key()
+                .new_chunk(
+                    [left_chunk, right_chunk],
+                    index_value=left_chunk.index_value,
+                    shape=(np.nan,),
+                    index=(idx,),
+                )
+            )
             out_chunks.append(out_chunk)
 
         new_op = op.copy()
-        return new_op.new_seriess(op.inputs, df.shape,
-                                  nsplits=tuple(tuple(ns) for ns in nsplits),
-                                  chunks=out_chunks, dtype=df.dtype,
-                                  index_value=df.index_value, name=df.name)
+        return new_op.new_seriess(
+            op.inputs,
+            df.shape,
+            nsplits=tuple(tuple(ns) for ns in nsplits),
+            chunks=out_chunks,
+            dtype=df.dtype,
+            index_value=df.index_value,
+            name=df.name,
+        )
 
     @classmethod
     def tile(cls, op):
         in_df = op.inputs[0]
-        if len(in_df.chunks) == 1 and \
-                (not isinstance(op.value, ENTITY_TYPE) or len(op.value.chunks) == 1):
+        if len(in_df.chunks) == 1 and (
+            not isinstance(op.value, ENTITY_TYPE) or len(op.value.chunks) == 1
+        ):
             return cls._tile_one_by_one(op)
         elif op.method is not None:
             if op.output_types[0] == OutputType.dataframe:
@@ -350,30 +441,48 @@ class FillNA(DataFrameOperand, DataFrameOperandMixin):
             return cls._tile_both_series(op)
 
     def __call__(self, a, value_df=None):
-        method = getattr(self, 'method', None)
-        if method == 'backfill':
-            method = 'bfill'
-        elif method == 'pad':
-            method = 'ffill'
+        method = getattr(self, "method", None)
+        if method == "backfill":
+            method = "bfill"
+        elif method == "pad":
+            method = "ffill"
         self._method = method
-        axis = getattr(self, 'axis', None) or 0
+        axis = getattr(self, "axis", None) or 0
         self._axis = validate_axis(axis, a)
 
         inputs = [a]
         if value_df is not None:
             inputs.append(value_df)
         if isinstance(a, DATAFRAME_TYPE):
-            return self.new_dataframe(inputs, shape=a.shape, dtypes=a.dtypes, index_value=a.index_value,
-                                      columns_value=a.columns_value)
+            return self.new_dataframe(
+                inputs,
+                shape=a.shape,
+                dtypes=a.dtypes,
+                index_value=a.index_value,
+                columns_value=a.columns_value,
+            )
         elif isinstance(a, SERIES_TYPE):
-            return self.new_series(inputs, shape=a.shape, dtype=a.dtype, index_value=a.index_value,
-                                   name=a.name)
+            return self.new_series(
+                inputs,
+                shape=a.shape,
+                dtype=a.dtype,
+                index_value=a.index_value,
+                name=a.name,
+            )
         else:
-            return self.new_index(inputs, shape=a.shape, dtype=a.dtype, index_value=a.index_value,
-                                  name=a.name, names=a.names)
+            return self.new_index(
+                inputs,
+                shape=a.shape,
+                dtype=a.dtype,
+                index_value=a.index_value,
+                name=a.name,
+                names=a.names,
+            )
 
 
-def fillna(df, value=None, method=None, axis=None, inplace=False, limit=None, downcast=None):
+def fillna(
+    df, value=None, method=None, axis=None, inplace=False, limit=None, downcast=None
+):
     """
     Fill NA/NaN values using the specified method.
 
@@ -468,12 +577,18 @@ def fillna(df, value=None, method=None, axis=None, inplace=False, limit=None, do
     elif value is not None and method is not None:
         raise ValueError("Cannot specify both 'value' and 'method'.")
 
-    if isinstance(df, SERIES_TYPE) and isinstance(value, (DATAFRAME_TYPE, pd.DataFrame)):
-        raise ValueError('"value" parameter must be a scalar, dict or Series, but you passed a "%s"'
-                         % type(value).__name__)
+    if isinstance(df, SERIES_TYPE) and isinstance(
+        value, (DATAFRAME_TYPE, pd.DataFrame)
+    ):
+        raise ValueError(
+            '"value" parameter must be a scalar, dict or Series, but you passed a "%s"'
+            % type(value).__name__
+        )
 
     if downcast is not None:
-        raise NotImplementedError('Currently argument "downcast" is not implemented yet')
+        raise NotImplementedError(
+            'Currently argument "downcast" is not implemented yet'
+        )
     if limit is not None:
         raise NotImplementedError('Currently argument "limit" is not implemented yet')
 
@@ -483,8 +598,15 @@ def fillna(df, value=None, method=None, axis=None, inplace=False, limit=None, do
         value_df = None
 
     use_inf_as_na = options.dataframe.mode.use_inf_as_na
-    op = FillNA(value=value, method=method, axis=axis, limit=limit, downcast=downcast,
-                use_inf_as_na=use_inf_as_na, output_types=get_output_types(df))
+    op = FillNA(
+        value=value,
+        method=method,
+        axis=axis,
+        limit=limit,
+        downcast=downcast,
+        use_inf_as_na=use_inf_as_na,
+        output_types=get_output_types(df),
+    )
     out_df = op(df, value_df=value_df)
     if inplace:
         df.data = out_df.data
@@ -501,7 +623,9 @@ def ffill(df, axis=None, inplace=False, limit=None, downcast=None):
     {klass} or None
         Object with missing values filled or None if ``inplace=True``.
     """
-    return fillna(df, method='ffill', axis=axis, inplace=inplace, limit=limit, downcast=downcast)
+    return fillna(
+        df, method="ffill", axis=axis, inplace=inplace, limit=limit, downcast=downcast
+    )
 
 
 def bfill(df, axis=None, inplace=False, limit=None, downcast=None):
@@ -513,7 +637,9 @@ def bfill(df, axis=None, inplace=False, limit=None, downcast=None):
     {klass} or None
         Object with missing values filled or None if ``inplace=True``.
     """
-    return fillna(df, method='bfill', axis=axis, inplace=inplace, limit=limit, downcast=downcast)
+    return fillna(
+        df, method="bfill", axis=axis, inplace=inplace, limit=limit, downcast=downcast
+    )
 
 
 def index_fillna(index, value=None, downcast=None):
@@ -543,6 +669,10 @@ def index_fillna(index, value=None, downcast=None):
         raise ValueError("'value' must be a scalar, passed: %s" % type(value))
 
     use_inf_as_na = options.dataframe.mode.use_inf_as_na
-    op = FillNA(value=value, downcast=downcast, use_inf_as_na=use_inf_as_na,
-                output_types=get_output_types(index))
+    op = FillNA(
+        value=value,
+        downcast=downcast,
+        use_inf_as_na=use_inf_as_na,
+        output_types=get_output_types(index),
+    )
     return op(index)
