@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ from .core import DataFrameReductionOperand, DataFrameReductionMixin
 
 class DataFrameCount(DataFrameReductionOperand, DataFrameReductionMixin):
     _op_type_ = OperandDef.COUNT
-    _func_name = 'count'
+    _func_name = "count"
 
     @property
     def is_atomic(self):
@@ -39,14 +39,30 @@ class DataFrameCount(DataFrameReductionOperand, DataFrameReductionMixin):
 
 
 def count_series(series, level=None, combine_size=None, **kw):
-    use_inf_as_na = kw.pop('_use_inf_as_na', options.dataframe.mode.use_inf_as_na)
-    op = DataFrameCount(level=level, combine_size=combine_size, output_types=[OutputType.scalar],
-                        use_inf_as_na=use_inf_as_na)
+    use_inf_as_na = kw.pop("_use_inf_as_na", options.dataframe.mode.use_inf_as_na)
+    method = kw.pop("method", None)
+    op = DataFrameCount(
+        level=level,
+        combine_size=combine_size,
+        output_types=[OutputType.scalar],
+        use_inf_as_na=use_inf_as_na,
+        method=method,
+    )
     return op(series)
 
 
-def count_dataframe(df, axis=0, level=None, numeric_only=False, combine_size=None, **kw):
-    use_inf_as_na = kw.pop('_use_inf_as_na', options.dataframe.mode.use_inf_as_na)
-    op = DataFrameCount(axis=axis, level=level, numeric_only=numeric_only, combine_size=combine_size,
-                        output_types=[OutputType.series], use_inf_as_na=use_inf_as_na)
+def count_dataframe(
+    df, axis=0, level=None, numeric_only=False, combine_size=None, **kw
+):
+    use_inf_as_na = kw.pop("_use_inf_as_na", options.dataframe.mode.use_inf_as_na)
+    method = kw.pop("method", None)
+    op = DataFrameCount(
+        axis=axis,
+        level=level,
+        numeric_only=numeric_only,
+        combine_size=combine_size,
+        output_types=[OutputType.series],
+        use_inf_as_na=use_inf_as_na,
+        method=method,
+    )
     return op(df)
