@@ -21,16 +21,34 @@ from .... import opcodes
 from ....serialization.serializables import BoolField, Float64Field
 from ..aggregation import BaseDataFrameExpandingAgg
 
-_stage_info = namedtuple('_stage_info', ('map_groups', 'map_sources', 'combine_sources',
-                                         'combine_columns', 'combine_funcs', 'key_to_funcs',
-                                         'valid_columns', 'min_periods_func_name'))
+_stage_info = namedtuple(
+    "_stage_info",
+    (
+        "map_groups",
+        "map_sources",
+        "combine_sources",
+        "combine_columns",
+        "combine_funcs",
+        "key_to_funcs",
+        "valid_columns",
+        "min_periods_func_name",
+    ),
+)
 
-_cum_alpha_coeff_func = '_cum_alpha_coeff'
-_cum_square_alpha_coeff_func = '_cum_square_alpha_coeff'
+_cum_alpha_coeff_func = "_cum_alpha_coeff"
+_cum_square_alpha_coeff_func = "_cum_square_alpha_coeff"
 
 
-def _add_pred_results(pred_results, local_results, axis=0, alpha=None, order=1,
-                      alpha_ignore_na=False, pred_exponent=None, alpha_data=None):
+def _add_pred_results(
+    pred_results,
+    local_results,
+    axis=0,
+    alpha=None,
+    order=1,
+    alpha_ignore_na=False,
+    pred_exponent=None,
+    alpha_data=None,
+):
     if pred_results[0].ndim == 1:
         df_filler = 0
     else:
@@ -40,7 +58,7 @@ def _add_pred_results(pred_results, local_results, axis=0, alpha=None, order=1,
     new_locals = []
     combine_axis = pred_results[0].ndim - axis - 1
     weight = (1 - alpha) ** order
-    pred_coeff = weight ** pred_exponent
+    pred_coeff = weight**pred_exponent
     for idx, (pred_result, local_result) in enumerate(zip(pred_results, local_results)):
         local_result.fillna(df_filler, inplace=True)
         pred_result = pred_result.mul(pred_coeff).sum(axis=axis)
@@ -51,23 +69,35 @@ def _add_pred_results(pred_results, local_results, axis=0, alpha=None, order=1,
             weights = np.arange(1, len(local_result) + 1)
             if local_result.ndim == 2:
                 weights_df = pd.DataFrame(
-                    np.repeat(weights.reshape((len(local_result), 1)), len(local_result.columns), axis=1),
-                    columns=local_result.columns, index=local_result.index)
+                    np.repeat(
+                        weights.reshape((len(local_result), 1)),
+                        len(local_result.columns),
+                        axis=1,
+                    ),
+                    columns=local_result.columns,
+                    index=local_result.index,
+                )
             else:
                 weights_df = pd.Series(weights, index=local_result.index)
             weights_df[alpha_data.isna()] = np.nan
             weights_df.ffill(inplace=True)
             weights_df.fillna(0, inplace=True)
 
-            weights_df = weight ** weights_df
+            weights_df = weight**weights_df
             pred_df = weights_df.mul(pred_result, axis=combine_axis)
 
         new_locals.append(local_result.add(pred_df, axis=combine_axis))
     return new_locals
 
 
-def _combine_mean(pred_results, local_results, axis=0, alpha=None, alpha_ignore_na=False,
-                  pred_exponent=None):
+def _combine_mean(
+    pred_results,
+    local_results,
+    axis=0,
+    alpha=None,
+    alpha_ignore_na=False,
+    pred_exponent=None,
+):
     if pred_results is None:
         return (local_results[0] / local_results[1]).ffill()
 
@@ -79,14 +109,25 @@ def _combine_mean(pred_results, local_results, axis=0, alpha=None, alpha_ignore_
 
     if pred_results is not None:
         local_sum_data, local_count_data = _add_pred_results(
-            pred_results, local_results, axis=axis, alpha=alpha, alpha_ignore_na=alpha_ignore_na,
-            pred_exponent=pred_exponent, alpha_data=alpha_data
+            pred_results,
+            local_results,
+            axis=axis,
+            alpha=alpha,
+            alpha_ignore_na=alpha_ignore_na,
+            pred_exponent=pred_exponent,
+            alpha_data=alpha_data,
         )
     return local_sum_data / local_count_data
 
 
-def _combine_var(pred_results, local_results, axis=0, alpha=None, alpha_ignore_na=False,
-                 pred_exponent=None):
+def _combine_var(
+    pred_results,
+    local_results,
+    axis=0,
+    alpha=None,
+    alpha_ignore_na=False,
+    pred_exponent=None,
+):
     local_results[0] = local_results[0].ffill()
     alpha_data = local_results[1]
     local_results[1] = alpha_data.ffill()
@@ -95,56 +136,94 @@ def _combine_var(pred_results, local_results, axis=0, alpha=None, alpha_ignore_n
     alpha2_data = local_results[3]
     local_results[3] = alpha2_data.ffill()
 
-    local_sum_data, local_count_data, local_sum_square, local_count2_data = local_results
+    (
+        local_sum_data,
+        local_count_data,
+        local_sum_square,
+        local_count2_data,
+    ) = local_results
     if pred_results is None:
-        return (local_sum_square - local_sum_data ** 2 / local_count_data) \
-               / (local_count_data - local_count2_data / local_count_data)
+        return (local_sum_square - local_sum_data**2 / local_count_data) / (
+            local_count_data - local_count2_data / local_count_data
+        )
 
     pred_sum_data, pred_count_data, pred_sum_square, pred_count2_data = pred_results
 
-    local_count2_data, = _add_pred_results(
-        [pred_count2_data], [local_count2_data], axis=axis, alpha=alpha, order=2,
-        alpha_ignore_na=alpha_ignore_na, pred_exponent=pred_exponent, alpha_data=alpha_data)
+    (local_count2_data,) = _add_pred_results(
+        [pred_count2_data],
+        [local_count2_data],
+        axis=axis,
+        alpha=alpha,
+        order=2,
+        alpha_ignore_na=alpha_ignore_na,
+        pred_exponent=pred_exponent,
+        alpha_data=alpha_data,
+    )
 
-    local_sum_square, local_sum_data, local_count_data = \
-        _add_pred_results(
-            [pred_sum_square, pred_sum_data, pred_count_data],
-            [local_sum_square, local_sum_data, local_count_data],
-            axis=axis, alpha=alpha, alpha_ignore_na=alpha_ignore_na,
-            pred_exponent=pred_exponent, alpha_data=alpha_data
+    local_sum_square, local_sum_data, local_count_data = _add_pred_results(
+        [pred_sum_square, pred_sum_data, pred_count_data],
+        [local_sum_square, local_sum_data, local_count_data],
+        axis=axis,
+        alpha=alpha,
+        alpha_ignore_na=alpha_ignore_na,
+        pred_exponent=pred_exponent,
+        alpha_data=alpha_data,
+    )
+
+    return (local_sum_square - local_sum_data**2 / local_count_data) / (
+        local_count_data - local_count2_data / local_count_data
+    )
+
+
+def _combine_std(
+    pred_results,
+    local_results,
+    axis=0,
+    alpha=None,
+    alpha_ignore_na=False,
+    pred_exponent=None,
+):
+    return np.sqrt(
+        _combine_var(
+            pred_results,
+            local_results,
+            axis=axis,
+            alpha=alpha,
+            alpha_ignore_na=alpha_ignore_na,
+            pred_exponent=pred_exponent,
         )
-
-    return (local_sum_square - local_sum_data ** 2 / local_count_data) \
-        / (local_count_data - local_count2_data / local_count_data)
-
-
-def _combine_std(pred_results, local_results, axis=0, alpha=None, alpha_ignore_na=False,
-                 pred_exponent=None):
-    return np.sqrt(_combine_var(
-        pred_results, local_results, axis=axis, alpha=alpha, alpha_ignore_na=alpha_ignore_na,
-        pred_exponent=pred_exponent))
+    )
 
 
 def _combine_data_count(pred_results, local_results, axis=0, **__):
     if pred_results is None:
         return local_results[0]
-    return local_results[0].add(pred_results[0].sum(), axis=pred_results[0].ndim - axis - 1)
+    return local_results[0].add(
+        pred_results[0].sum(), axis=pred_results[0].ndim - axis - 1
+    )
 
 
 class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
     _op_type_ = opcodes.EWM_AGG
 
-    _alpha = Float64Field('alpha')
-    _adjust = BoolField('adjust')
-    _alpha_ignore_na = BoolField('alpha_ignore_na')
+    _alpha = Float64Field("alpha")
+    _adjust = BoolField("adjust")
+    _alpha_ignore_na = BoolField("alpha_ignore_na")
 
-    _validate_columns = BoolField('_validate_columns')
+    _validate_columns = BoolField("_validate_columns")
 
     _exec_cache = dict()
 
-    def __init__(self, alpha=None, adjust=None, alpha_ignore_na=None, validate_columns=None, **kw):
-        super().__init__(_alpha=alpha, _adjust=adjust, _alpha_ignore_na=alpha_ignore_na,
-                         _validate_columns=validate_columns, **kw)
+    def __init__(
+        self, alpha=None, adjust=None, alpha_ignore_na=None, validate_columns=None, **kw
+    ):
+        super().__init__(
+            _alpha=alpha,
+            _adjust=adjust,
+            _alpha_ignore_na=alpha_ignore_na,
+            _validate_columns=validate_columns,
+            **kw
+        )
 
     @property
     def alpha(self) -> float:
@@ -164,20 +243,27 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
 
     @classmethod
     def _get_stage_functions(cls, op: "DataFrameEwmAgg", func):
-        if func == '_data_count':
-            return ['_data_count'], _combine_data_count
-        elif func == 'mean':
-            return ['cumsum', _cum_alpha_coeff_func], _combine_mean
-        elif func in {'var', 'std'}:
-            return ['cumsum', _cum_alpha_coeff_func, 'cumsum2', _cum_square_alpha_coeff_func], \
-                   _combine_var if func == 'var' else _combine_std
+        if func == "_data_count":
+            return ["_data_count"], _combine_data_count
+        elif func == "mean":
+            return ["cumsum", _cum_alpha_coeff_func], _combine_mean
+        elif func in {"var", "std"}:
+            return (
+                [
+                    "cumsum",
+                    _cum_alpha_coeff_func,
+                    "cumsum2",
+                    _cum_square_alpha_coeff_func,
+                ],
+                _combine_var if func == "var" else _combine_std,
+            )
         else:  # pragma: no cover
             raise NotImplementedError
 
     @classmethod
     def _calc_data_alphas(cls, op: "DataFrameEwmAgg", in_data, order):
         exec_cache = cls._exec_cache[op.key]
-        cache_key = ('_calc_data_alphas', order, id(in_data))
+        cache_key = ("_calc_data_alphas", order, id(in_data))
         try:
             return exec_cache[cache_key]
         except KeyError:
@@ -195,9 +281,11 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
         return result
 
     @classmethod
-    def _execute_cum_alpha_coeff(cls, op: "DataFrameEwmAgg", in_data, order, final=True):
+    def _execute_cum_alpha_coeff(
+        cls, op: "DataFrameEwmAgg", in_data, order, final=True
+    ):
         exec_cache = cls._exec_cache[op.key]
-        cache_key = ('cum_alpha_coeff', order, id(in_data))
+        cache_key = ("cum_alpha_coeff", order, id(in_data))
         summary = None
 
         try:
@@ -215,7 +303,7 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
     @classmethod
     def _execute_cumsum(cls, op: "DataFrameEwmAgg", in_data):
         exec_cache = cls._exec_cache[op.key]
-        cache_key = ('cumsum', id(in_data))
+        cache_key = ("cumsum", id(in_data))
         summary = None
 
         try:
@@ -224,12 +312,20 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
             min_periods = 1 if op.min_periods > 0 else 0
 
             try:
-                data = in_data.ewm(alpha=op.alpha, ignore_na=op.alpha_ignore_na, adjust=op.adjust,
-                                   min_periods=min_periods).mean()
+                data = in_data.ewm(
+                    alpha=op.alpha,
+                    ignore_na=op.alpha_ignore_na,
+                    adjust=op.adjust,
+                    min_periods=min_periods,
+                ).mean()
             except ValueError:
                 in_data = in_data.copy()
-                data = in_data.ewm(alpha=op.alpha, ignore_na=op.alpha_ignore_na, adjust=op.adjust,
-                                   min_periods=min_periods).mean()
+                data = in_data.ewm(
+                    alpha=op.alpha,
+                    ignore_na=op.alpha_ignore_na,
+                    adjust=op.adjust,
+                    min_periods=min_periods,
+                ).mean()
 
             alpha_sum, _ = op._execute_cum_alpha_coeff(op, in_data, 1, final=False)
             result = exec_cache[cache_key] = data * alpha_sum
@@ -244,16 +340,24 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
         min_periods = 1 if op.min_periods > 0 else 0
 
         try:
-            data = in_data.ewm(alpha=op.alpha, ignore_na=op.alpha_ignore_na, adjust=op.adjust,
-                               min_periods=min_periods).var(bias=True)
+            data = in_data.ewm(
+                alpha=op.alpha,
+                ignore_na=op.alpha_ignore_na,
+                adjust=op.adjust,
+                min_periods=min_periods,
+            ).var(bias=True)
         except ValueError:
             in_data = in_data.copy()
-            data = in_data.ewm(alpha=op.alpha, ignore_na=op.alpha_ignore_na, adjust=op.adjust,
-                               min_periods=min_periods).var(bias=True)
+            data = in_data.ewm(
+                alpha=op.alpha,
+                ignore_na=op.alpha_ignore_na,
+                adjust=op.adjust,
+                min_periods=min_periods,
+            ).var(bias=True)
 
         alpha_sum, _ = op._execute_cum_alpha_coeff(op, in_data, 1)
         cumsum, _ = op._execute_cumsum(op, in_data)
-        result = alpha_sum * data + cumsum ** 2 / alpha_sum
+        result = alpha_sum * data + cumsum**2 / alpha_sum
 
         if op.output_agg:
             summary = result.ffill()[-1:]
@@ -266,17 +370,17 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
 
         summary = None
         min_periods = 1 if op.min_periods > 0 else 0
-        if func == '_data_count':
+        if func == "_data_count":
             result = in_data.expanding(min_periods=min_periods).count()
         elif func in (_cum_alpha_coeff_func, _cum_square_alpha_coeff_func):
             order = 1 if func == _cum_alpha_coeff_func else 2
             result, summary = cls._execute_cum_alpha_coeff(op, in_data, order)
-        elif func == 'cumsum':
+        elif func == "cumsum":
             result, summary = cls._execute_cumsum(op, in_data)
-        elif func == 'cumsum2':
+        elif func == "cumsum2":
             result, summary = cls._execute_cumsum2(op, in_data)
         else:  # pragma: no cover
-            raise ValueError('Map function %s not supported')
+            raise ValueError("Map function %s not supported")
 
         if op.output_agg:
             summary = summary if summary is not None else result.iloc[-1:]
@@ -306,7 +410,11 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
                     remain_counts = in_data.notna()[::-1].to_numpy().argmax(axis=0)
                     if in_data.ndim > 1:
                         remain_counts = remain_counts.reshape((1, len(in_data.columns)))
-                        summary = pd.DataFrame(remain_counts, columns=in_data.columns, index=summaries[-1].index)
+                        summary = pd.DataFrame(
+                            remain_counts,
+                            columns=in_data.columns,
+                            index=summaries[-1].index,
+                        )
                     else:
                         summary = pd.Series(remain_counts, index=summaries[-1].index)
                 summaries.insert(-1, summary)
@@ -316,14 +424,23 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
             cls._exec_cache.pop(op.key, None)
 
     @classmethod
-    def _execute_combine_function(cls, op: "DataFrameEwmAgg", func, prev_inputs, local_inputs,
-                                  func_cols):
+    def _execute_combine_function(
+        cls, op: "DataFrameEwmAgg", func, prev_inputs, local_inputs, func_cols
+    ):
         exec_cache = cls._exec_cache[op.key]
-        pred_exponent = exec_cache.get('pred_exponent')
+        pred_exponent = exec_cache.get("pred_exponent")
         if func_cols and pred_exponent is not None:
-            pred_exponent = pred_exponent[func_cols] if pred_exponent is not None else None
-        return func(prev_inputs, local_inputs, axis=op.axis, alpha=op.alpha,
-                    alpha_ignore_na=op.alpha_ignore_na, pred_exponent=pred_exponent)
+            pred_exponent = (
+                pred_exponent[func_cols] if pred_exponent is not None else None
+            )
+        return func(
+            prev_inputs,
+            local_inputs,
+            axis=op.axis,
+            alpha=op.alpha,
+            alpha_ignore_na=op.alpha_ignore_na,
+            pred_exponent=pred_exponent,
+        )
 
     @classmethod
     def _execute_combine(cls, ctx, op: "DataFrameEwmAgg"):
@@ -334,13 +451,17 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
                 pred_data = ctx[op.inputs[1].key]
 
                 if op.alpha_ignore_na:
-                    pred_exponent = pred_data[-2].shift(-1)[::-1].cumsum()[::-1].fillna(0)
+                    pred_exponent = (
+                        pred_data[-2].shift(-1)[::-1].cumsum()[::-1].fillna(0)
+                    )
                 else:
                     succ_counts = pred_data[-1].shift(-1)
                     succ_counts.iloc[-1] = 0
-                    pred_exponent = pred_data[-2].add(succ_counts[::-1].cumsum()[::-1], axis=op.axis)
+                    pred_exponent = pred_data[-2].add(
+                        succ_counts[::-1].cumsum()[::-1], axis=op.axis
+                    )
 
-                cls._exec_cache[op.key]['pred_exponent'] = pred_exponent
+                cls._exec_cache[op.key]["pred_exponent"] = pred_exponent
 
             super()._execute_combine(ctx, op)
         finally:
@@ -349,13 +470,20 @@ class DataFrameEwmAgg(BaseDataFrameExpandingAgg):
     @classmethod
     def _execute_raw_function(cls, op: "DataFrameEwmAgg", in_data):
         for _ in range(2):
-            ewm = in_data.ewm(alpha=op.alpha, min_periods=op.min_periods, adjust=op.adjust,
-                              ignore_na=op.alpha_ignore_na)
+            ewm = in_data.ewm(
+                alpha=op.alpha,
+                min_periods=op.min_periods,
+                adjust=op.adjust,
+                ignore_na=op.alpha_ignore_na,
+            )
             try:
                 val = ewm.agg(op.func)
-                if in_data.ndim == 2 and op.validate_columns \
-                        and len(val.columns) != len(op.outputs[0].columns_value.to_pandas()):
-                    raise ValueError('Columns not consistent')
+                if (
+                    in_data.ndim == 2
+                    and op.validate_columns
+                    and len(val.columns) != len(op.outputs[0].columns_value.to_pandas())
+                ):
+                    raise ValueError("Columns not consistent")
                 return val
             except ValueError:
                 in_data = in_data.copy()
