@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,12 +19,16 @@ from .predict import predict
 
 def register_op():
     from .start_tracker import StartTracker
+
     del StartTracker
 
 
 from ..utils import config_mod_getattr as _config_mod_getattr
 
-_config_mod_getattr({
-    'XGBClassifier': '.classifier.XGBClassifier',
-    'XGBRegressor': '.regressor.XGBRegressor',
-}, globals())
+_config_mod_getattr(
+    {
+        "XGBClassifier": ".classifier.XGBClassifier",
+        "XGBRegressor": ".regressor.XGBRegressor",
+    },
+    globals(),
+)
