@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,10 @@ import numpy as np
 
 from ... import opcodes as OperandDef
 from ... import tensor as mt
-from ...core import Base, Entity, ExecutableTuple
-from ...context import get_context
-from ...serialize import AnyField, KeyField
-from ...tiles import TilesError
+from ...core import ENTITY_TYPE, ExecutableTuple, recursive_tile
+from ...core.context import get_context
+from ...serialization.serializables import AnyField, KeyField
 from ...tensor.core import TENSOR_TYPE, TensorOrder
-from ...utils import recursive_tile
 from ..operands import LearnOperand, LearnOperandMixin, OutputType
 from ..utils.multiclass import type_of_target
 from ..utils import check_consistent_length, column_or_1d
@@ -30,14 +28,19 @@ from ..utils import check_consistent_length, column_or_1d
 class CheckTargets(LearnOperand, LearnOperandMixin):
     _op_type_ = OperandDef.CHECK_TARGETS
 
-    _y_true = AnyField('y_true')
-    _y_pred = AnyField('y_pred')
-    _type_true = KeyField('type_true')
-    _type_pred = KeyField('type_pred')
+    _y_true = AnyField("y_true")
+    _y_pred = AnyField("y_pred")
+    _type_true = KeyField("type_true")
+    _type_pred = KeyField("type_pred")
 
     def __init__(self, y_true=None, y_pred=None, type_true=None, type_pred=None, **kw):
-        super().__init__(_y_true=y_true, _y_pred=y_pred,
-                         _type_true=type_true, _type_pred=type_pred, **kw)
+        super().__init__(
+            _y_true=y_true,
+            _y_pred=y_pred,
+            _type_true=type_true,
+            _type_pred=type_pred,
+            **kw,
+        )
         # scalar(y_type), y_true, y_pred
         self.output_types = [OutputType.tensor] * 3
 
@@ -64,9 +67,9 @@ class CheckTargets(LearnOperand, LearnOperandMixin):
     def _set_inputs(self, inputs):
         super()._set_inputs(inputs)
         inputs_iter = iter(self._inputs)
-        if isinstance(self._y_true, (Base, Entity)):
+        if isinstance(self._y_true, ENTITY_TYPE):
             self._y_true = next(inputs_iter)
-        if isinstance(self._y_pred, (Base, Entity)):
+        if isinstance(self._y_pred, ENTITY_TYPE):
             self._y_pred = next(inputs_iter)
         if self._type_true is not None:
             self._type_true = next(inputs_iter)
@@ -75,57 +78,57 @@ class CheckTargets(LearnOperand, LearnOperandMixin):
 
     def __call__(self, y_true, y_pred):
         inputs = []
-        if isinstance(y_true, (Base, Entity)):
+        if isinstance(y_true, ENTITY_TYPE):
             inputs.append(y_true)
-        if isinstance(y_pred, (Base, Entity)):
+        if isinstance(y_pred, ENTITY_TYPE):
             inputs.append(y_pred)
         self._type_true = type_of_target(y_true)
         self._type_pred = type_of_target(y_pred)
         inputs.extend([self._type_true, self._type_pred])
 
         kws = list()
-        kws.append({
-            'shape': (),
-            'dtype': np.dtype(object),
-            'order': TensorOrder.C_ORDER
-        })
-        kws.extend([y.params for y in (mt.tensor(y_true),
-                                       mt.tensor(y_pred))])
-        kws[1]['shape'] = kws[2]['shape'] = (np.nan,)
+        kws.append(
+            {"shape": (), "dtype": np.dtype(object), "order": TensorOrder.C_ORDER}
+        )
+        kws.extend([y.params for y in (mt.tensor(y_true), mt.tensor(y_pred))])
+        kws[1]["shape"] = kws[2]["shape"] = (np.nan,)
         return ExecutableTuple(self.new_tileables(inputs, kws=kws))
 
     @classmethod
     def tile(cls, op):
         y_true, y_pred = op.y_true, op.y_pred
         for y in (op.y_true, op.y_pred):
-            if isinstance(y, (Base, Entity)):
+            if isinstance(y, ENTITY_TYPE):
                 if np.isnan(y.size):  # pragma: no cover
-                    raise TilesError('input has unknown shape')
+                    yield
 
         check_consistent_length(y_true, y_pred)
 
+        # make sure type_true and type_pred executed first
+        chunks = [op.type_true.chunks[0], op.type_pred.chunks[0]]
+        yield chunks
+
         ctx = get_context()
-        try:
-            type_true, type_pred = ctx.get_chunk_results(
-                [op.type_true.chunks[0].key,
-                 op.type_pred.chunks[0].key])
-        except (KeyError, AttributeError):
-            raise TilesError('type_true and type_pred '
-                             'needs to be executed first')
+        type_true, type_pred = [
+            d.item() if hasattr(d, "item") else d
+            for d in ctx.get_chunks_result([c.key for c in chunks])
+        ]
 
         y_type = {type_true, type_pred}
         if y_type == {"binary", "multiclass"}:
             y_type = {"multiclass"}
 
         if len(y_type) > 1:
-            raise ValueError(f"Classification metrics can't handle a mix of {type_true} "
-                             f"and {type_pred} targets")
+            raise ValueError(
+                f"Classification metrics can't handle a mix of {type_true} "
+                f"and {type_pred} targets"
+            )
 
         # We can't have more than one value on y_type => The set is no more needed
         y_type = y_type.pop()
 
         # No metrics support "multiclass-multioutput" format
-        if (y_type not in ["binary", "multiclass", "multilabel-indicator"]):
+        if y_type not in ["binary", "multiclass", "multilabel-indicator"]:
             raise ValueError(f"{y_type} is not supported")
 
         if y_type in ["binary", "multiclass"]:
@@ -133,31 +136,42 @@ class CheckTargets(LearnOperand, LearnOperandMixin):
             y_pred = column_or_1d(y_pred)
             if y_type == "binary":
                 unique_values = mt.union1d(y_true, y_pred)
-                y_type = mt.where(mt.count_nonzero(unique_values) > 2,
-                                  'multiclass', y_type)
-        elif y_type.startswith('multilabel'):
+                y_type = mt.where(
+                    mt.count_nonzero(unique_values) > 2, "multiclass", y_type
+                )
+        elif y_type.startswith("multilabel"):
             y_true = mt.tensor(y_true).tosparse()
             y_pred = mt.tensor(y_pred).tosparse()
-            y_type = 'multilabel-indicator'
+            y_type = "multilabel-indicator"
 
-        if not isinstance(y_true, (Base, Entity)):
+        if not isinstance(y_true, ENTITY_TYPE):
             y_true = mt.tensor(y_true)
-        if not isinstance(y_pred, (Base, Entity)):
+        if not isinstance(y_pred, ENTITY_TYPE):
             y_pred = mt.tensor(y_pred)
 
         if not isinstance(y_type, TENSOR_TYPE):
             y_type = mt.tensor(y_type, dtype=object)
 
-        y_type = recursive_tile(y_type)
-        y_true = recursive_tile(y_true)
-        y_pred = recursive_tile(y_pred)
+        y_type = yield from recursive_tile(y_type)
+        y_true = yield from recursive_tile(y_true)
+        y_pred = yield from recursive_tile(y_pred)
 
         kws = [out.params for out in op.outputs]
         kws[0].update(dict(nsplits=(), chunks=[y_type.chunks[0]]))
-        kws[1].update(dict(nsplits=y_true.nsplits, chunks=y_true.chunks,
-                           shape=tuple(sum(sp) for sp in y_true.nsplits)))
-        kws[2].update(dict(nsplits=y_pred.nsplits, chunks=y_pred.chunks,
-                           shape=tuple(sum(sp) for sp in y_pred.nsplits)))
+        kws[1].update(
+            dict(
+                nsplits=y_true.nsplits,
+                chunks=y_true.chunks,
+                shape=tuple(sum(sp) for sp in y_true.nsplits),
+            )
+        )
+        kws[2].update(
+            dict(
+                nsplits=y_pred.nsplits,
+                chunks=y_pred.chunks,
+                shape=tuple(sum(sp) for sp in y_pred.nsplits),
+            )
+        )
         new_op = op.copy()
         return new_op.new_tileables(op.inputs, kws=kws)
 
