@@ -104,13 +104,13 @@ def train_test_split(*arrays, **options):
     n_arrays = len(arrays)
     if n_arrays == 0:
         raise ValueError("At least one array required as input")
-    test_size = options.pop('test_size', None)
-    train_size = options.pop('train_size', None)
-    random_state = options.pop('random_state', None)
-    stratify = options.pop('stratify', None)
-    shuffle = options.pop('shuffle', True)
-    session = options.pop('session', None)
-    run_kwargs = options.pop('run_kwargs', None)
+    test_size = options.pop("test_size", None)
+    train_size = options.pop("train_size", None)
+    random_state = options.pop("random_state", None)
+    stratify = options.pop("stratify", None)
+    shuffle = options.pop("shuffle", True)
+    session = options.pop("session", None)
+    run_kwargs = options.pop("run_kwargs", None)
 
     if options:
         raise TypeError(f"Invalid parameters passed: {options}")
@@ -118,34 +118,36 @@ def train_test_split(*arrays, **options):
     arrays = indexable(*arrays, session=session, run_kwargs=run_kwargs)
 
     n_samples = _num_samples(arrays[0])
-    n_train, n_test = _validate_shuffle_split(n_samples, test_size, train_size,
-                                              default_test_size=0.25)
+    n_train, n_test = _validate_shuffle_split(
+        n_samples, test_size, train_size, default_test_size=0.25
+    )
 
     if shuffle is False:
         if stratify is not None:  # pragma: no cover
             raise ValueError(
-                "Stratified train/test split is not implemented for "
-                "shuffle=False")
+                "Stratified train/test split is not implemented for " "shuffle=False"
+            )
 
-        iterables = ((a[:n_train], a[n_train: n_train + n_test])
-                     for a in arrays)
+        iterables = ((a[:n_train], a[n_train : n_train + n_test]) for a in arrays)
     else:
         if stratify is not None:  # pragma: no cover
-            raise NotImplementedError('stratify is not implemented yet')
+            raise NotImplementedError("stratify is not implemented yet")
         else:
-            shuffled_arrays = shuffle_arrays(
-                *arrays, random_state=random_state)
+            shuffled_arrays = shuffle_arrays(*arrays, random_state=random_state)
             if not isinstance(shuffled_arrays, tuple):
                 shuffled_arrays = (shuffled_arrays,)
-            iterables = ((a[:n_train], a[n_train: n_train + n_test])
-                         for a in shuffled_arrays)
+            iterables = (
+                (a[:n_train], a[n_train : n_train + n_test]) for a in shuffled_arrays
+            )
 
-    return list(ExecutableTuple(chain.from_iterable(iterables)).execute(
-        session=session, **(run_kwargs or dict())))
+    return list(
+        ExecutableTuple(chain.from_iterable(iterables)).execute(
+            session=session, **(run_kwargs or dict())
+        )
+    )
 
 
-def _validate_shuffle_split(n_samples, test_size, train_size,
-                            default_test_size=None):
+def _validate_shuffle_split(n_samples, test_size, train_size, default_test_size=None):
     """
     Validation helper to check if the test/test sizes are meaningful wrt to the
     size of the data (n_samples)
@@ -156,37 +158,49 @@ def _validate_shuffle_split(n_samples, test_size, train_size,
     test_size_type = np.asarray(test_size).dtype.kind
     train_size_type = np.asarray(train_size).dtype.kind
 
-    if (test_size_type == 'i' and (test_size >= n_samples or test_size <= 0)
-            or test_size_type == 'f' and (test_size <= 0 or test_size >= 1)):
-        raise ValueError(f'test_size={test_size} should be either positive and smaller'
-                         f' than the number of samples {n_samples} or a float in the '
-                         '(0, 1) range')
+    if (
+        test_size_type == "i"
+        and (test_size >= n_samples or test_size <= 0)
+        or test_size_type == "f"
+        and (test_size <= 0 or test_size >= 1)
+    ):
+        raise ValueError(
+            f"test_size={test_size} should be either positive and smaller"
+            f" than the number of samples {n_samples} or a float in the "
+            "(0, 1) range"
+        )
 
-    if (train_size_type == 'i' and (train_size >= n_samples or train_size <= 0)
-            or train_size_type == 'f' and (train_size <= 0 or train_size >= 1)):
-        raise ValueError(f'train_size={train_size} should be either positive and smaller'
-                         f' than the number of samples {n_samples} or a float in the '
-                         '(0, 1) range')
+    if (
+        train_size_type == "i"
+        and (train_size >= n_samples or train_size <= 0)
+        or train_size_type == "f"
+        and (train_size <= 0 or train_size >= 1)
+    ):
+        raise ValueError(
+            f"train_size={train_size} should be either positive and smaller"
+            f" than the number of samples {n_samples} or a float in the "
+            "(0, 1) range"
+        )
 
-    if train_size is not None and train_size_type not in ('i', 'f'):  # pragma: no cover
+    if train_size is not None and train_size_type not in ("i", "f"):  # pragma: no cover
         raise ValueError(f"Invalid value for train_size: {train_size}")
-    if test_size is not None and test_size_type not in ('i', 'f'):
+    if test_size is not None and test_size_type not in ("i", "f"):
         raise ValueError(f"Invalid value for test_size: {test_size}")
 
-    if (train_size_type == 'f' and test_size_type == 'f' and
-            train_size + test_size > 1):
+    if train_size_type == "f" and test_size_type == "f" and train_size + test_size > 1:
         raise ValueError(
-            f'The sum of test_size and train_size = {train_size + test_size}, '
-            'should be in the (0, 1) range. Reduce test_size and/or train_size.')
+            f"The sum of test_size and train_size = {train_size + test_size}, "
+            "should be in the (0, 1) range. Reduce test_size and/or train_size."
+        )
 
-    if test_size_type == 'f':
+    if test_size_type == "f":
         n_test = ceil(test_size * n_samples)
-    elif test_size_type == 'i':
+    elif test_size_type == "i":
         n_test = float(test_size)
 
-    if train_size_type == 'f':
+    if train_size_type == "f":
         n_train = floor(train_size * n_samples)
-    elif train_size_type == 'i':  # pragma: no cover
+    elif train_size_type == "i":  # pragma: no cover
         n_train = float(train_size)
 
     if train_size is None:
@@ -195,17 +209,19 @@ def _validate_shuffle_split(n_samples, test_size, train_size,
         n_test = n_samples - n_train
 
     if n_train + n_test > n_samples:  # pragma: no cover
-        raise ValueError(f'The sum of train_size and test_size = {n_train + n_test}, '
-                         f'should be smaller than the number of samples {n_samples}. '
-                         'Reduce test_size and/or train_size.')
+        raise ValueError(
+            f"The sum of train_size and test_size = {n_train + n_test}, "
+            f"should be smaller than the number of samples {n_samples}. "
+            "Reduce test_size and/or train_size."
+        )
 
     n_train, n_test = int(n_train), int(n_test)
 
     if n_train == 0:  # pragma: no cover
         raise ValueError(
-            f'With n_samples={n_samples}, test_size={test_size} and '
-            f'train_size={train_size}, the resulting train set will '
-            f'be empty. Adjust any of the aforementioned parameters.'
+            f"With n_samples={n_samples}, test_size={test_size} and "
+            f"train_size={train_size}, the resulting train set will "
+            f"be empty. Adjust any of the aforementioned parameters."
         )
 
     return n_train, n_test
@@ -216,6 +232,7 @@ class BaseCrossValidator(metaclass=ABCMeta):
 
     Implementations must define `_iter_test_masks` or `_iter_test_indices`.
     """
+
     def split(self, X, y=None, groups=None):  # pragma: no cover
         """Generate indices to split data into training and test set.
 
@@ -274,26 +291,27 @@ class _BaseKFold(BaseCrossValidator, metaclass=ABCMeta):
     @abstractmethod
     def __init__(self, n_splits, *, shuffle, random_state):
         if not isinstance(n_splits, numbers.Integral):
-            raise ValueError('The number of folds must be of Integral type. '
-                             '%s of type %s was passed.'
-                             % (n_splits, type(n_splits)))
+            raise ValueError(
+                "The number of folds must be of Integral type. "
+                "%s of type %s was passed." % (n_splits, type(n_splits))
+            )
         n_splits = int(n_splits)
 
         if n_splits <= 1:
             raise ValueError(
                 "k-fold cross-validation requires at least one"
                 " train/test split by setting n_splits=2 or more,"
-                " got n_splits={0}.".format(n_splits))
+                " got n_splits={0}.".format(n_splits)
+            )
 
         if not isinstance(shuffle, bool):
-            raise TypeError("shuffle must be True or False;"
-                            " got {0}".format(shuffle))
+            raise TypeError("shuffle must be True or False;" " got {0}".format(shuffle))
 
         if not shuffle and random_state is not None:  # None is the default
             raise ValueError(
-                'Setting a random_state has no effect since shuffle is '
-                'False. You should leave '
-                'random_state to its default (None), or set shuffle=True.',
+                "Setting a random_state has no effect since shuffle is "
+                "False. You should leave "
+                "random_state to its default (None), or set shuffle=True.",
             )
 
         self.n_splits = n_splits
@@ -388,10 +406,9 @@ class KFold(_BaseKFold):
 
     RepeatedKFold : Repeats K-Fold n times.
     """
-    def __init__(self, n_splits=5, *, shuffle=False,
-                 random_state=None):
-        super().__init__(n_splits=n_splits, shuffle=shuffle,
-                         random_state=random_state)
+
+    def __init__(self, n_splits=5, *, shuffle=False, random_state=None):
+        super().__init__(n_splits=n_splits, shuffle=shuffle, random_state=random_state)
 
     def split(self, X, y=None, groups=None):
         """Generate indices to split data into training and test set.
@@ -421,9 +438,11 @@ class KFold(_BaseKFold):
         n_samples = _num_samples(X)
         if self.n_splits > n_samples:
             raise ValueError(
-                ("Cannot have number of splits n_splits={0} greater"
-                 " than the number of samples: n_samples={1}.")
-                .format(self.n_splits, n_samples))
+                (
+                    "Cannot have number of splits n_splits={0} greater"
+                    " than the number of samples: n_samples={1}."
+                ).format(self.n_splits, n_samples)
+            )
 
         indices = mt.arange(n_samples)
         if self.shuffle:
@@ -431,7 +450,7 @@ class KFold(_BaseKFold):
 
         n_splits = self.n_splits
         fold_sizes = np.full(n_splits, n_samples // n_splits, dtype=int)
-        fold_sizes[:n_samples % n_splits] += 1
+        fold_sizes[: n_samples % n_splits] += 1
         current = 0
         for fold_size in fold_sizes:
             start, stop = current, current + fold_size
