@@ -16,8 +16,17 @@
 from sklearn.utils import gen_batches
 
 from .collect_ports import collect_ports
-from .core import convert_to_tensor_or_dataframe, \
-    concat_chunks, copy_learned_attributes
-from .validation import check_array, assert_all_finite, \
-    check_consistent_length, column_or_1d, check_X_y
+from .core import (
+    convert_to_tensor_or_dataframe,
+    concat_chunks,
+    copy_learned_attributes,
+    get_chunk_n_rows,
+)
+from .validation import (
+    check_array,
+    assert_all_finite,
+    check_consistent_length,
+    column_or_1d,
+    check_X_y,
+)
 from .shuffle import shuffle
