@@ -19,16 +19,20 @@ from urllib.parse import urlparse
 from typing import List, Dict, Union, Tuple, Iterator, BinaryIO, TextIO
 
 import pyarrow as pa
-from pyarrow.fs import FileSystem as ArrowFileSystem, \
-    LocalFileSystem as ArrowLocalFileSystem, \
-    HadoopFileSystem as ArrowHadoopFileSystem, \
-    FileSelector, FileInfo, FileType
+from pyarrow.fs import (
+    FileSystem as ArrowFileSystem,
+    LocalFileSystem as ArrowLocalFileSystem,
+    HadoopFileSystem as ArrowHadoopFileSystem,
+    FileSelector,
+    FileInfo,
+    FileType,
+)
 
 from ...utils import implements, stringify_path
 from .core import FileSystem, path_type
 
 
-__all__ = ('ArrowBasedLocalFileSystem', 'HadoopFileSystem')
+__all__ = ("ArrowBasedLocalFileSystem", "HadoopFileSystem")
 
 
 # When pyarrow.fs.FileSystem gc collected,
@@ -73,9 +77,7 @@ class ArrowBasedFileSystem(FileSystem):
         return file_info
 
     @implements(FileSystem.delete)
-    def delete(self,
-               path: path_type,
-               recursive: bool = False):
+    def delete(self, path: path_type, recursive: bool = False):
         path = self._process_path(path)
         info = self._get_file_info(path)
         if info.is_file:
@@ -85,13 +87,10 @@ class ArrowBasedFileSystem(FileSystem):
                 raise OSError(f"[Errno 66] Directory not empty: '{path}'")
             self._arrow_fs.delete_dir(path)
         else:  # pragma: no cover
-            raise TypeError(f'path({path}) to delete '
-                            f'must be a file or directory')
+            raise TypeError(f"path({path}) to delete " f"must be a file or directory")
 
     @implements(FileSystem.rename)
-    def rename(self,
-               path: path_type,
-               new_path: path_type):
+    def rename(self, path: path_type, new_path: path_type):
         path = self._process_path(path)
         new_path = self._process_path(new_path)
         self._arrow_fs.move(path, new_path)
@@ -102,17 +101,15 @@ class ArrowBasedFileSystem(FileSystem):
         info = self._get_file_info(path)
         stat = dict(name=path, size=info.size, modified_time=info.mtime_ns / 1e9)
         if info.type == FileType.File:
-            stat['type'] = 'file'
+            stat["type"] = "file"
         elif info.type == FileType.Directory:
-            stat['type'] = 'directory'
+            stat["type"] = "directory"
         else:  # pragma: no cover
-            stat['type'] = 'other'
+            stat["type"] = "other"
         return stat
 
     @implements(FileSystem.mkdir)
-    def mkdir(self,
-              path: path_type,
-              create_parents: bool = True):
+    def mkdir(self, path: path_type, create_parents: bool = True):
         path = self._process_path(path)
         self._arrow_fs.create_dir(path, recursive=create_parents)
 
@@ -139,27 +136,28 @@ class ArrowBasedFileSystem(FileSystem):
         return info.type != FileType.NotFound
 
     @implements(FileSystem.open)
-    def open(self,
-             path: path_type,
-             mode: str = 'rb') -> Union[BinaryIO, TextIO]:
+    def open(self, path: path_type, mode: str = "rb") -> Union[BinaryIO, TextIO]:
         path = self._process_path(path)
-        is_binary = mode.endswith('b')
+        is_binary = mode.endswith("b")
         if not is_binary:  # pragma: no cover
-            raise ValueError(f'mode can only be binary for '
-                             f'arrow based filesystem, got {mode}')
-        mode = mode.rstrip('b')
-        if mode == 'w':
+            raise ValueError(
+                f"mode can only be binary for " f"arrow based filesystem, got {mode}"
+            )
+        mode = mode.rstrip("b")
+        if mode == "w":
             file = self._arrow_fs.open_output_stream(path)
-        elif mode == 'r':
+        elif mode == "r":
             if self._sequential_read:  # pragma: no cover
                 file = self._arrow_fs.open_input_stream(path)
             else:
                 file = self._arrow_fs.open_input_file(path)
-        elif mode == 'a':
+        elif mode == "a":
             file = self._arrow_fs.open_append_stream(path)
         else:  # pragma: no cover
-            raise ValueError(f'mode can only be "wb", "rb" and "ab" for '
-                             f'arrow based filesystem, got {mode}')
+            raise ValueError(
+                f'mode can only be "wb", "rb" and "ab" for '
+                f"arrow based filesystem, got {mode}"
+            )
 
         _file_to_filesystems[file] = self._arrow_fs
         return file
@@ -183,9 +181,7 @@ class ArrowBasedFileSystem(FileSystem):
             yield curr, dirs, files
 
     @implements(FileSystem.glob)
-    def glob(self,
-             path: path_type,
-             recursive: bool = False) -> List[path_type]:
+    def glob(self, path: path_type, recursive: bool = False) -> List[path_type]:
         from ._glob import FileSystemGlob
 
         path = self._process_path(path)
@@ -206,18 +202,29 @@ class ArrowBasedLocalFileSystem(ArrowBasedFileSystem):
 
 
 class HadoopFileSystem(ArrowBasedFileSystem):
-    def __init__(self, host="default", port=0, user=None, kerb_ticket=None,
-                 driver='libhdfs', extra_conf=None):
-        assert driver == 'libhdfs'
-        if 'HADOOP_HOME' in os.environ and 'CLASSPATH' not in os.environ:
+    def __init__(
+        self,
+        host="default",
+        port=0,
+        user=None,
+        kerb_ticket=None,
+        driver="libhdfs",
+        extra_conf=None,
+    ):
+        assert driver == "libhdfs"
+        if "HADOOP_HOME" in os.environ and "CLASSPATH" not in os.environ:
             classpath_proc = subprocess.run(
-                [os.environ['HADOOP_HOME'] + '/bin/hdfs', 'classpath', '--glob'],
-                stdout=subprocess.PIPE
+                [os.environ["HADOOP_HOME"] + "/bin/hdfs", "classpath", "--glob"],
+                stdout=subprocess.PIPE,
             )
-            os.environ['CLASSPATH'] = classpath_proc.stdout.decode().strip()
-        arrow_fs = ArrowHadoopFileSystem(host=host, port=port, user=user,
-                                         kerb_ticket=kerb_ticket,
-                                         extra_conf=extra_conf)
+            os.environ["CLASSPATH"] = classpath_proc.stdout.decode().strip()
+        arrow_fs = ArrowHadoopFileSystem(
+            host=host,
+            port=port,
+            user=user,
+            kerb_ticket=kerb_ticket,
+            extra_conf=extra_conf,
+        )
         super().__init__(arrow_fs)
 
     @staticmethod
@@ -227,7 +234,7 @@ class HadoopFileSystem(ArrowBasedFileSystem):
         # hdfs://localhost:8020/tmp/test/simple_test.csv,
         # due to the reason that pa.fs.HadoopFileSystem cannot accept
         # path with hdfs:// prefix
-        if path.startswith('hdfs://'):
+        if path.startswith("hdfs://"):
             return urlparse(path).path
         else:
             return path
