@@ -23,38 +23,36 @@ from .local import LocalFileSystem
 from .oss import OSSFileSystem
 
 
-_filesystems = {
-    'file': LocalFileSystem,
-    'oss': OSSFileSystem
-}
+_filesystems = {"file": LocalFileSystem, "oss": OSSFileSystem}
 
 
 def register_filesystem(name: str, fs):
     _filesystems[name] = fs
 
 
-def get_fs(path: path_type,
-           storage_options: Dict = None) -> FileSystem:
+def get_fs(path: path_type, storage_options: Dict = None) -> FileSystem:
     if storage_options is None:
         storage_options = dict()
 
     # detect scheme
     if os.path.exists(path) or glob_.glob(path):
-        scheme = 'file'
+        scheme = "file"
     else:
         scheme = urlparse(path).scheme
-    if scheme == '' or len(scheme) == 1:  # len == 1 for windows
-        scheme = 'file'
+    if scheme == "" or len(scheme) == 1:  # len == 1 for windows
+        scheme = "file"
 
     try:
         file_system_type = _filesystems[scheme]
     except KeyError:  # pragma: no cover
-        if scheme == 'hdfs':
-            raise ImportError('Need to install `pyarrow` to connect to HDFS.')
-        raise ValueError(f'Unknown file system type: {scheme}, '
-                         f'available include: {", ".join(_filesystems)}')
+        if scheme == "hdfs":
+            raise ImportError("Need to install `pyarrow` to connect to HDFS.")
+        raise ValueError(
+            f"Unknown file system type: {scheme}, "
+            f'available include: {", ".join(_filesystems)}'
+        )
 
-    if scheme == 'file' or scheme == 'oss':
+    if scheme == "file" or scheme == "oss":
         # local file system use an singleton.
         return file_system_type.get_instance()
     else:
@@ -63,25 +61,25 @@ def get_fs(path: path_type,
         return file_system_type(**storage_options)
 
 
-def glob(path: path_type,
-         storage_options: Dict = None) -> List[path_type]:
-    if '*' in path:
+def glob(path: path_type, storage_options: Dict = None) -> List[path_type]:
+    if "*" in path:
         fs = get_fs(path, storage_options)
         return fs.glob(path)
     else:
         return [path]
 
 
-def file_size(path: path_type,
-              storage_options: Dict = None) -> int:
+def file_size(path: path_type, storage_options: Dict = None) -> int:
     fs = get_fs(path, storage_options)
-    return fs.stat(path)['size']
+    return fs.stat(path)["size"]
 
 
-def open_file(path: path_type,
-              mode: str = 'rb',
-              compression: str = None,
-              storage_options: Dict = None):
+def open_file(
+    path: path_type,
+    mode: str = "rb",
+    compression: str = None,
+    storage_options: Dict = None,
+):
     fs = get_fs(path, storage_options)
     file = fs.open(path, mode=mode)
 
