@@ -305,6 +305,7 @@ NORMALIZE = 442
 TOPK = 443
 TRAPZ = 444
 GET_SHAPE = 445
+BINCOUNT = 446
 # fancy index, distributed phase is a shuffle operation that
 # the fancy indexes will be distributed to the left chunks
 # the concat phase will concat back the indexed left chunks and index
@@ -367,7 +368,7 @@ DROP_NA = 720
 NUNIQUE = 721
 CUT = 722
 SHIFT = 723
-DATAFRAME_DIFF = 724
+DIFF = 724
 VALUE_COUNTS = 725
 TO_DATETIME = 726
 DATAFRAME_DROP = 727
@@ -447,6 +448,8 @@ READ_PARQUET = 2103
 TO_PARQUET = 2104
 READ_SQL = 2105
 TO_SQL = 2108
+READ_RAYDATASET = 2109
+READ_MLDATASET = 2106
 
 TO_CSV_STAT = 2102
 
@@ -480,7 +483,7 @@ PROXIMA_SIMPLE_BUILDER = 2238
 PROXIMA_SIMPLE_SEARCHER = 2239
 KNEIGHBORS_GRAPH = 2237
 
-# CLUSTER
+# cluster
 KMEANS_PLUS_PLUS_INIT = 2250
 KMEANS_SCALABLE_PLUS_PLUS_INIT = 2251
 KMEANS_ELKAN_INIT_BOUNDS = 2252
@@ -528,11 +531,16 @@ ACCURACY_SCORE = 3305
 COLLECT_PORTS = 3306
 # unique labels
 UNIQUE_LABELS = 3307
-# PREPROCESSING
+# preprocessing
 LABEL_BINARIZE = 3308
-# ensemble
+# ensemble: blockwise
 BLOCKWISE_ENSEMBLE_FIT = 3309
 BLOCKWISE_ENSEMBLE_PREDICT = 3310
+# ensemble: bagging
+BAGGING_SHUFFLE_SAMPLE = 3400
+BAGGING_SHUFFLE_REINDEX = 3401
+BAGGING_FIT = 3402
+BAGGING_PREDICTION = 3403
 
 # Remote Functions and class
 REMOTE_FUNCATION = 5001
@@ -560,7 +568,9 @@ for _var_name, _var_val in globals().copy().items():
     if not isinstance(_var_val, int):
         continue
     if _var_val in _val_to_dict:  # pragma: no cover
-        raise ImportError(f'Cannot import opcode: {_var_name} and '
-                          f'{_val_to_dict[_var_val]} collides with value {_var_val}')
+        raise ImportError(
+            f"Cannot import opcode: {_var_name} and "
+            f"{_val_to_dict[_var_val]} collides with value {_var_val}"
+        )
     _val_to_dict[_var_val] = _var_name
 del _val_to_dict, _var_name, _var_val
