@@ -18,6 +18,7 @@ import itertools
 import logging
 from abc import ABC
 from collections import namedtuple
+from dataclasses import dataclass
 from typing import Any, Callable, Coroutine, Dict, Type
 from urllib.parse import urlparse
 
@@ -33,11 +34,41 @@ from ..communication.errors import ChannelClosed
 ray = lazy_import("ray")
 logger = logging.getLogger(__name__)
 
-ChannelID = namedtuple("ChannelID", ["local_address", "client_id", "channel_index", "dest_address"])
+ChannelID = namedtuple(
+    "ChannelID", ["local_address", "client_id", "channel_index", "dest_address"]
+)
+
+
+def _argwrapper_unpickler(serialized_message):
+    return _ArgWrapper(deserialize(*serialized_message))
+
+
+@dataclass
+class _ArgWrapper:
+    message: Any = None
+
+    def __init__(self, message):
+        self.message = message
+
+    def __reduce__(self):
+        return _argwrapper_unpickler, (serialize(self.message),)
+
+
+if ray:
+    _ray_serialize = ray.serialization.SerializationContext.serialize
+    _ray_deserialize_object = ray.serialization.SerializationContext._deserialize_object
+
+    def _serialize(self, value):
+        return _ray_serialize(self, value)
+
+    def _deserialize_object(self, data, metadata, object_ref):
+        return _ray_deserialize_object(self, data, metadata, object_ref)
+
+    ray.serialization.SerializationContext.serialize = _serialize
+    ray.serialization.SerializationContext._deserialize_object = _deserialize_object
 
 
 class RayChannelException(Exception):
-
     def __init__(self, exc_type, exc_value: BaseException, exc_traceback):
         self.exc_type = exc_type
         self.exc_value = exc_value
@@ -48,23 +79,29 @@ class RayChannelBase(Channel, ABC):
     """
     Channel for communications between ray processes.
     """
-    __slots__ = '_channel_index', '_channel_id', '_in_queue', '_closed'
 
-    name = 'ray'
+    __slots__ = "_channel_index", "_channel_id", "_in_queue", "_closed"
+
+    name = "ray"
     _channel_index_gen = itertools.count()
 
-    def __init__(self,
-                 local_address: str = None,
-                 dest_address: str = None,
-                 channel_index: int = None,
-                 channel_id: ChannelID = None,
-                 compression=None):
-        super().__init__(local_address=local_address,
-                         dest_address=dest_address,
-                         compression=compression)
+    def __init__(
+        self,
+        local_address: str = None,
+        dest_address: str = None,
+        channel_index: int = None,
+        channel_id: ChannelID = None,
+        compression=None,
+    ):
+        super().__init__(
+            local_address=local_address,
+            dest_address=dest_address,
+            compression=compression,
+        )
         self._channel_index = channel_index or next(self._channel_index_gen)
         self._channel_id = channel_id or ChannelID(
-            local_address, _gen_client_id(), self._channel_index, dest_address)
+            local_address, _gen_client_id(), self._channel_index, dest_address
+        )
         self._in_queue = asyncio.Queue()
         self._closed = asyncio.Event()
 
@@ -91,41 +128,52 @@ class RayClientChannel(RayChannelBase):
     """
     A channel from ray driver/actor to ray actor. Use ray call reply for client channel recv.
     """
-    __slots__ = '_peer_actor',
 
-    def __init__(self,
-                 dest_address: str = None,
-                 channel_index: int = None,
-                 channel_id: ChannelID = None,
-                 compression=None):
+    __slots__ = ("_peer_actor",)
+
+    def __init__(
+        self,
+        dest_address: str = None,
+        channel_index: int = None,
+        channel_id: ChannelID = None,
+        compression=None,
+    ):
         super().__init__(None, dest_address, channel_index, channel_id, compression)
         # ray actor should be created with the address as the name.
-        self._peer_actor: 'ray.actor.ActorHandle' = ray.get_actor(dest_address)
+        self._peer_actor: "ray.actor.ActorHandle" = ray.get_actor(dest_address)
 
     @implements(Channel.send)
     async def send(self, message: Any):
         if self._closed.is_set():  # pragma: no cover
-            raise ChannelClosed('Channel already closed, cannot send message')
+            raise ChannelClosed("Channel already closed, cannot send message")
         # Put ray object ref to queue
-        await self._in_queue.put((message, self._peer_actor.__on_ray_recv__.remote(
-            self.channel_id, serialize(message))))
+        self._in_queue.put_nowait(
+            (
+                message,
+                self._peer_actor.__on_ray_recv__.remote(
+                    self.channel_id, _ArgWrapper(message)
+                ),
+            )
+        )
 
     @implements(Channel.recv)
     async def recv(self):
         if self._closed.is_set():  # pragma: no cover
-            raise ChannelClosed('Channel already closed, cannot recv message')
+            raise ChannelClosed("Channel already closed, cannot recv message")
         try:
             # Wait on ray object ref
             message, object_ref = await self._in_queue.get()
-            with debug_async_timeout('ray_object_retrieval_timeout', 'Client sent message is %s', message):
+            with debug_async_timeout(
+                "ray_object_retrieval_timeout", "Client sent message is %s", message
+            ):
                 result = await object_ref
             if isinstance(result, RayChannelException):
                 raise result.exc_value.with_traceback(result.exc_traceback)
-            return deserialize(*result)
+            return result.message
         except ray.exceptions.RayActorError:
             if not self._closed.is_set():
                 # raise a EOFError as the SocketChannel does
-                raise EOFError('Server may be closed')
+                raise EOFError("Server may be closed")
         except (RuntimeError, ServerClosed) as e:  # pragma: no cover
             if not self._closed.is_set():
                 raise e
@@ -138,13 +186,16 @@ class RayServerChannel(RayChannelBase):
     channel message sends for one received message, or else it will be taken as next
     message's reply.
     """
-    __slots__ = '_out_queue', '_msg_recv_counter', '_msg_sent_counter'
 
-    def __init__(self,
-                 local_address: str = None,
-                 channel_index: int = None,
-                 channel_id: ChannelID = None,
-                 compression=None):
+    __slots__ = "_out_queue", "_msg_recv_counter", "_msg_sent_counter"
+
+    def __init__(
+        self,
+        local_address: str = None,
+        channel_index: int = None,
+        channel_id: ChannelID = None,
+        compression=None,
+    ):
         super().__init__(local_address, None, channel_index, channel_id, compression)
         self._out_queue = asyncio.Queue()
         self._msg_recv_counter = 0
@@ -153,43 +204,46 @@ class RayServerChannel(RayChannelBase):
     @implements(Channel.send)
     async def send(self, message: Any):
         if self._closed.is_set():  # pragma: no cover
-            raise ChannelClosed('Channel already closed, cannot send message')
+            raise ChannelClosed("Channel already closed, cannot send message")
         # Current process is ray actor, we use ray call reply to send message to ray driver/actor.
         # Not that we can only send once for every read message in channel, otherwise
         # it will be taken as other message's reply.
-        await self._out_queue.put(serialize(message))
+        await self._out_queue.put(message)
         self._msg_sent_counter += 1
-        assert self._msg_sent_counter <= self._msg_recv_counter, \
-            "RayServerChannel channel doesn't support send multiple replies for one message."
+        assert (
+            self._msg_sent_counter <= self._msg_recv_counter
+        ), "RayServerChannel channel doesn't support send multiple replies for one message."
 
     @implements(Channel.recv)
     async def recv(self):
         if self._closed.is_set():  # pragma: no cover
-            raise ChannelClosed('Channel already closed, cannot write message')
+            raise ChannelClosed("Channel already closed, cannot write message")
         try:
-            return deserialize(*(await self._in_queue.get()))
+            return await self._in_queue.get()
         except RuntimeError:  # pragma: no cover
             if not self._closed.is_set():
                 raise
 
-    async def __on_ray_recv__(self, message):
+    async def __on_ray_recv__(self, message_wrapper):
         """This method will be invoked when current process is a ray actor rather than a ray driver"""
         self._msg_recv_counter += 1
-        await self._in_queue.put(message)
-        # Avoid hang when channel is closed after `self._out_queue.get()` is awaited.
-        done, _ = await asyncio.wait([self._out_queue.get(), self._closed.wait()],
-                                     return_when=asyncio.FIRST_COMPLETED)
+        await self._in_queue.put(message_wrapper.message)
+        result_message = await self._out_queue.get()
         if self._closed.is_set():  # pragma: no cover
-            raise ChannelClosed('Channel already closed')
-        if done:
-            return await done.pop()
+            raise ChannelClosed("Channel already closed")
+        return _ArgWrapper(result_message)
+
+    @implements(Channel.close)
+    async def close(self):
+        await super().close()
+        self._out_queue.put_nowait(None)
 
 
 @register_server
 class RayServer(Server):
-    __slots__ = '_closed', '_channels', '_tasks'
+    __slots__ = "_closed", "_channels", "_tasks"
 
-    scheme = 'ray'
+    scheme = "ray"
     _server_instance = None
     _ray_actor_started = False
 
@@ -221,19 +275,24 @@ class RayServer(Server):
     @implements(Server.create)
     async def create(config: Dict) -> "RayServer":
         if not RayServer.is_ray_actor_started():
-            logger.warning('Current process is not a ray actor, the ray server '
-                           'will not receive messages from clients.')
+            logger.warning(
+                "Current process is not a ray actor, the ray server "
+                "will not receive messages from clients."
+            )
         assert RayServer._server_instance is None
         config = config.copy()
-        address = config.pop('address')
-        handle_channel = config.pop('handle_channel')
+        address = config.pop("address")
+        handle_channel = config.pop("handle_channel")
         if urlparse(address).scheme != RayServer.scheme:  # pragma: no cover
-            raise ValueError(f'Address for RayServer '
-                             f'should be starts with "ray://", '
-                             f'got {address}')
+            raise ValueError(
+                f"Address for RayServer "
+                f'should be starts with "ray://", '
+                f"got {address}"
+            )
         if config:  # pragma: no cover
-            raise TypeError(f'Creating RayServer got unexpected '
-                            f'arguments: {",".join(config)}')
+            raise TypeError(
+                f"Creating RayServer got unexpected " f'arguments: {",".join(config)}'
+            )
         server = RayServer(address, handle_channel)
         RayServer._server_instance = server
         return server
@@ -265,8 +324,10 @@ class RayServer(Server):
         channel = args[0]
         assert isinstance(channel, RayServerChannel)
         if kwargs:  # pragma: no cover
-            raise TypeError(f'{type(self).__name__} got unexpected '
-                            f'arguments: {",".join(kwargs)}')
+            raise TypeError(
+                f"{type(self).__name__} got unexpected "
+                f'arguments: {",".join(kwargs)}'
+            )
         await self.channel_handler(channel)
 
     @implements(Server.stop)
@@ -287,12 +348,16 @@ class RayServer(Server):
 
     async def __on_ray_recv__(self, channel_id: ChannelID, message):
         if self.stopped:
-            raise ServerClosed(f'Remote server {self.address} closed, but got message {deserialize(*message)} '
-                               f'from channel {channel_id}')
+            raise ServerClosed(
+                f"Remote server {self.address} closed, but got message {message} "
+                f"from channel {channel_id}"
+            )
         channel = self._channels.get(channel_id)
         if not channel:
             _, _, peer_channel_index, peer_dest_address = channel_id
-            channel = RayServerChannel(peer_dest_address, peer_channel_index, channel_id)
+            channel = RayServerChannel(
+                peer_dest_address, peer_channel_index, channel_id
+            )
             self._channels[channel_id] = channel
             self._tasks[channel_id] = asyncio.create_task(self.on_connected(channel))
         return await channel.__on_ray_recv__(message)
@@ -304,22 +369,19 @@ class RayClient(Client):
 
     scheme = RayServer.scheme
 
-    def __init__(self,
-                 local_address: str,
-                 dest_address: str,
-                 channel: Channel):
-        super().__init__(local_address,
-                         dest_address,
-                         channel)
+    def __init__(self, local_address: str, dest_address: str, channel: Channel):
+        super().__init__(local_address, dest_address, channel)
 
     @staticmethod
     @implements(Client.connect)
-    async def connect(dest_address: str,
-                      local_address: str = None,
-                      **kwargs) -> "Client":
+    async def connect(
+        dest_address: str, local_address: str = None, **kwargs
+    ) -> "Client":
         if urlparse(dest_address).scheme != RayServer.scheme:  # pragma: no cover
-            raise ValueError(f'Destination address should start with "ray://" '
-                             f'for RayClient, got {dest_address}')
+            raise ValueError(
+                f'Destination address should start with "ray://" '
+                f"for RayClient, got {dest_address}"
+            )
         client_channel = RayClientChannel(dest_address)
         client = RayClient(local_address, dest_address, client_channel)
         return client
@@ -331,4 +393,5 @@ class RayClient(Client):
 
 def _gen_client_id():
     import uuid
+
     return uuid.uuid4().hex
