@@ -17,30 +17,42 @@
 from ..core.base import MarsError
 
 
+class ReconstructWorkerError(MarsError):
+    pass
+
+
 class ActorPoolNotStarted(MarsError):
     pass
 
 
-class ActorNotExist(Exception):
+class ActorNotExist(MarsError):
     pass
 
 
-class ActorAlreadyExist(Exception):
+class ActorAlreadyExist(MarsError):
     pass
 
 
-class NoIdleSlot(Exception):
+class NoIdleSlot(MarsError):
     pass
 
 
-class ServerClosed(Exception):
+class NoFreeSlot(MarsError):
     pass
 
 
-class CannotCancelTask(Exception):
+class SlotStateError(MarsError):
     pass
 
 
-class Return(Exception):
+class ServerClosed(MarsError):
+    pass
+
+
+class CannotCancelTask(MarsError):
+    pass
+
+
+class Return(MarsError):
     def __init__(self, value):
         self.value = value
