@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,73 +15,56 @@
 from collections.abc import Iterable
 from functools import partial
 
-import numpy as np
-
 from .. import opcodes
-from ..core import Entity, Base, ChunkData
-from ..custom_log import redirect_custom_log
+from ..core import ENTITY_TYPE, TILEABLE_TYPE, ChunkData
+from ..core.custom_log import redirect_custom_log
+from ..core.operand import ObjectOperand
 from ..dataframe.core import DATAFRAME_TYPE, SERIES_TYPE, INDEX_TYPE
-from ..serialize import FunctionField, ListField, DictField, \
-    BoolField, Int32Field, StringField
-from ..operands import ObjectOperand
+from ..serialization.serializables import (
+    FunctionField,
+    ListField,
+    DictField,
+    BoolField,
+    Int32Field,
+)
 from ..tensor.core import TENSOR_TYPE
-from ..utils import build_fetch_tileable, calc_nsplits, \
-    enter_current_session, find_objects, replace_objects
+from ..utils import (
+    build_fetch_tileable,
+    enter_current_session,
+    find_objects,
+    replace_objects,
+    get_params_fields,
+)
 from .operands import RemoteOperandMixin
 
 
-class _TileablePlaceholder:
-    def __init__(self, tileable):
-        self.tileable = build_fetch_tileable(tileable)
-
-    def __getstate__(self):
-        fetch_op = self.tileable.op
-        fetch_tileable = self.tileable
-        chunk_infos = [(type(c.op), c.op.output_types, c.key, c.id, c.params)
-                       for c in fetch_tileable.chunks]
-        return type(fetch_op), fetch_op.id, fetch_op.output_types, \
-               fetch_tileable.params, fetch_tileable.nsplits, chunk_infos
-
-    def __setstate__(self, state):
-        fetch_op_type, fetch_op_id, output_types, params, nsplits, chunk_infos = state
-        params['nsplits'] = nsplits
-        chunks = []
-        for ci in chunk_infos:
-            chunk_op_type, chunk_op_output_types, chunk_key, chunk_id, chunk_params = ci
-            chunk = chunk_op_type(output_types=chunk_op_output_types).new_chunk(
-                None, _key=chunk_key, _id=chunk_id, kws=[chunk_params])
-            chunks.append(chunk)
-        params['chunks'] = chunks
-        self.tileable = fetch_op_type(
-            _id=fetch_op_id, output_types=output_types).new_tileable(None, kws=[params])
-
-    def __mars_tokenize__(self):
-        return self.__getstate__()
-
-    def __call__(self):  # pragma: no cover
-        # make itself serializable
-        pass
-
-
 class RemoteFunction(RemoteOperandMixin, ObjectOperand):
     _op_type_ = opcodes.REMOTE_FUNCATION
-    _op_module_ = 'remote'
+    _op_module_ = "remote"
 
-    _function = FunctionField('function')
-    _function_args = ListField('function_args')
-    _function_kwargs = DictField('function_kwargs')
-    _retry_when_fail = BoolField('retry_when_fail')
-    _n_output = Int32Field('n_output')
-    # for chunk
-    _tileable_op_key = StringField('tileable_op_key')
+    _function = FunctionField("function")
+    _function_args = ListField("function_args")
+    _function_kwargs = DictField("function_kwargs")
+    _retry_when_fail = BoolField("retry_when_fail")
+    _n_output = Int32Field("n_output")
 
-    def __init__(self, function=None, function_args=None,
-                 function_kwargs=None, retry_when_fail=None,
-                 n_output=None, tileable_op_key=None, **kw):
-        super().__init__(_function=function, _function_args=function_args,
-                         _function_kwargs=function_kwargs,
-                         _retry_when_fail=retry_when_fail,
-                         _n_output=n_output, _tileable_op_key=tileable_op_key, **kw)
+    def __init__(
+        self,
+        function=None,
+        function_args=None,
+        function_kwargs=None,
+        retry_when_fail=None,
+        n_output=None,
+        **kw,
+    ):
+        super().__init__(
+            _function=function,
+            _function_args=function_args,
+            _function_kwargs=function_kwargs,
+            _retry_when_fail=retry_when_fail,
+            _n_output=n_output,
+            **kw,
+        )
 
     @property
     def function(self):
@@ -103,10 +86,6 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
     def n_output(self):
         return self._n_output
 
-    @property
-    def tileable_op_key(self):
-        return self._tileable_op_key
-
     @property
     def output_limit(self):
         return self._n_output or 1
@@ -117,11 +96,12 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
 
     @classmethod
     def _no_prepare(cls, tileable):
-        return isinstance(tileable, (TENSOR_TYPE, DATAFRAME_TYPE,
-                                     SERIES_TYPE, INDEX_TYPE))
+        return isinstance(
+            tileable, (TENSOR_TYPE, DATAFRAME_TYPE, SERIES_TYPE, INDEX_TYPE)
+        )
 
     def _set_inputs(self, inputs):
-        raw_inputs = getattr(self, '_inputs', None)
+        raw_inputs = getattr(self, "_inputs", None)
         super()._set_inputs(inputs)
 
         function_inputs = iter(inp for inp in self._inputs)
@@ -134,20 +114,21 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
                         mapping[raw_inp] = next(function_inputs)
                     else:
                         # in tile, set_inputs from chunk
-                        mapping[raw_inp] = _TileablePlaceholder(raw_inp)
+                        mapping[raw_inp] = build_fetch_tileable(raw_inp)
                 else:
                     mapping[raw_inp] = next(function_inputs)
         self._function_args = replace_objects(self._function_args, mapping)
         self._function_kwargs = replace_objects(self._function_kwargs, mapping)
 
     def __call__(self):
-        find_inputs = partial(find_objects, types=(Entity, Base))
+        find_inputs = partial(find_objects, types=ENTITY_TYPE)
         inputs = find_inputs(self._function_args) + find_inputs(self._function_kwargs)
         if self.n_output is None:
             return self.new_tileable(inputs)
         else:
             return self.new_tileables(
-                inputs, kws=[dict(i=i) for i in range(self.n_output)])
+                inputs, kws=[dict(i=i) for i in range(self.n_output)]
+            )
 
     @classmethod
     def tile(cls, op):
@@ -156,8 +137,14 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
 
         chunk_inputs = []
         pure_depends = []
+        executed = False
         for inp in op.inputs:
             if cls._no_prepare(inp):  # pragma: no cover
+                if not executed:
+                    # trigger execution
+                    yield
+                else:
+                    executed = True
                 # if input is tensor, DataFrame etc,
                 # do not prepare data, because the data may be to huge,
                 # and users can choose to fetch slice of the data themselves
@@ -167,14 +154,14 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
             chunk_inputs.extend(inp.chunks)
         chunk_op._pure_depends = pure_depends
         # record tileable op key for chunk op
-        chunk_op._tileable_op_key = op.key
+        chunk_op.tileable_op_key = op.key
 
         out_chunks = [list() for _ in range(len(outs))]
         chunk_kws = []
         for i, out in enumerate(outs):
             chunk_params = out.params
-            chunk_params['index'] = ()
-            chunk_params['i'] = i
+            chunk_params["index"] = ()
+            chunk_params["i"] = i
             chunk_kws.append(chunk_params)
         chunks = chunk_op.new_chunks(chunk_inputs, kws=chunk_kws)
         for i, c in enumerate(chunks):
@@ -183,8 +170,8 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
         kws = []
         for i, out in enumerate(outs):
             params = out.params
-            params['chunks'] = out_chunks[i]
-            params['nsplits'] = ()
+            params["chunks"] = out_chunks[i]
+            params["nsplits"] = ()
             kws.append(params)
         new_op = op.copy()
         return new_op.new_tileables(op.inputs, kws=kws)
@@ -193,23 +180,22 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
     @redirect_custom_log
     @enter_current_session
     def execute(cls, ctx, op: "RemoteFunction"):
-        mapping = {inp: ctx[inp.key] for inp, is_pure_dep
-                   in zip(op.inputs, op.pure_depends) if not is_pure_dep}
+        mapping = {
+            inp: ctx[inp.key]
+            for inp, is_pure_dep in zip(op.inputs, op.pure_depends)
+            if not is_pure_dep
+        }
         for to_search in [op.function_args, op.function_kwargs]:
-            tileable_placeholders = find_objects(to_search, _TileablePlaceholder)
-            for ph in tileable_placeholders:
-                tileable = ph.tileable
-                chunk_index_to_shape = dict()
-                for chunk in tileable.chunks:
-                    if any(np.isnan(s) for s in chunk.shape):
-                        shape = ctx.get_chunk_metas([chunk.key], filter_fields=['chunk_shape'])[0][0]
-                        chunk._shape = shape
-                    chunk_index_to_shape[chunk.index] = chunk.shape
-                if any(any(np.isnan(s) for s in ns) for ns in tileable._nsplits):
-                    nsplits = calc_nsplits(chunk_index_to_shape)
-                    tileable._nsplits = nsplits
-                    tileable._shape = tuple(sum(ns) for ns in nsplits)
-                mapping[ph] = tileable
+            tileables = find_objects(to_search, TILEABLE_TYPE)
+            for tileable in tileables:
+                chunks = tileable.chunks
+                fields = get_params_fields(chunks[0])
+                metas = ctx.get_chunks_meta(
+                    [chunk.key for chunk in chunks], fields=fields
+                )
+                for chunk, meta in zip(chunks, metas):
+                    chunk.params = {field: meta[field] for field in fields}
+                tileable.refresh_params()
 
         function = op.function
         function_args = replace_objects(op.function_args, mapping)
@@ -221,12 +207,16 @@ class RemoteFunction(RemoteOperandMixin, ObjectOperand):
             ctx[op.outputs[0].key] = result
         else:
             if not isinstance(result, Iterable):
-                raise TypeError(f'Specifying n_output={op.n_output}, '
-                                f'but result is not iterable, got {result}')
+                raise TypeError(
+                    f"Specifying n_output={op.n_output}, "
+                    f"but result is not iterable, got {result}"
+                )
             result = list(result)
             if len(result) != op.n_output:
-                raise ValueError(f'Length of return value should be {op.n_output}, '
-                                 f'got {len(result)}')
+                raise ValueError(
+                    f"Length of return value should be {op.n_output}, "
+                    f"got {len(result)}"
+                )
             for out, r in zip(op.outputs, result):
                 ctx[out.key] = r
 
@@ -330,10 +320,13 @@ def spawn(func, args=(), kwargs=None, retry_when_fail=False, n_output=None):
     if kwargs is None:
         kwargs = dict()
     if not isinstance(kwargs, dict):
-        raise TypeError('kwargs has to be a dict')
+        raise TypeError("kwargs has to be a dict")
 
-    op = RemoteFunction(function=func, function_args=args,
-                        function_kwargs=kwargs,
-                        retry_when_fail=retry_when_fail,
-                        n_output=n_output)
+    op = RemoteFunction(
+        function=func,
+        function_args=args,
+        function_kwargs=kwargs,
+        retry_when_fail=retry_when_fail,
+        n_output=n_output,
+    )
     return op()
