@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # limitations under the License.
 
 from ..core import FuseChunkData, FuseChunk
-from ..operands import Fuse, FuseChunkMixin, ObjectOperandMixin
+from ..core.operand import Fuse, FuseChunkMixin, ObjectOperandMixin
 
 
 class RemoteFuseChunkMixin(ObjectOperandMixin, FuseChunkMixin):
