@@ -22,8 +22,13 @@ from .. import opcodes
 from ..core import OutputType, TILEABLE_TYPE
 from ..core.context import Context
 from ..core.operand import MergeDictOperand
-from ..serialization.serializables import BytesField, ListField, \
-    Int32Field, DictField, BoolField
+from ..serialization.serializables import (
+    BytesField,
+    ListField,
+    Int32Field,
+    DictField,
+    BoolField,
+)
 from ..typing import TileableType, SessionType
 from ..utils import to_binary, build_fetch_tileable
 
@@ -31,18 +36,32 @@ from ..utils import to_binary, build_fetch_tileable
 class RunScript(MergeDictOperand):
     _op_type_ = opcodes.RUN_SCRIPT
 
-    _code: bytes = BytesField('code')
-    _data: Dict[str, TileableType] = DictField('data')
-    _retry_when_fail: bool = BoolField('retry_when_fail')
-    _command_args: List[str] = ListField('command_args')
-    _world_size: int = Int32Field('world_size')
-    _rank: int = Int32Field('rank')
+    _code: bytes = BytesField("code")
+    _data: Dict[str, TileableType] = DictField("data")
+    _retry_when_fail: bool = BoolField("retry_when_fail")
+    _command_args: List[str] = ListField("command_args")
+    _world_size: int = Int32Field("world_size")
+    _rank: int = Int32Field("rank")
 
-    def __init__(self, code=None, data=None, world_size=None, rank=None,
-                 retry_when_fail=None, command_args=None, **kw):
-        super().__init__(_code=code, _data=data, _world_size=world_size, _rank=rank,
-                         _retry_when_fail=retry_when_fail, _command_args=command_args,
-                         **kw)
+    def __init__(
+        self,
+        code=None,
+        data=None,
+        world_size=None,
+        rank=None,
+        retry_when_fail=None,
+        command_args=None,
+        **kw
+    ):
+        super().__init__(
+            _code=code,
+            _data=data,
+            _world_size=world_size,
+            _rank=rank,
+            _retry_when_fail=retry_when_fail,
+            _command_args=command_args,
+            **kw
+        )
         if self.output_types is None:
             self.output_types = [OutputType.object]
 
@@ -105,22 +124,24 @@ class RunScript(MergeDictOperand):
             out_chunks.append(chunk_op.new_chunk(input_chunks, index=(i,)))
 
         new_op = op.copy()
-        return new_op.new_tileables(op.inputs, chunks=out_chunks,
-                                    nsplits=(tuple(np.nan for _ in range(len(out_chunks))),))
+        return new_op.new_tileables(
+            op.inputs,
+            chunks=out_chunks,
+            nsplits=(tuple(np.nan for _ in range(len(out_chunks))),),
+        )
 
     @classmethod
     def _build_envs(cls, ctx, op):
         # set mars envs
         envs = dict()
-        envs['RANK'] = str(op.rank)
-        envs['WORLD_SIZE'] = str(op.world_size)
+        envs["RANK"] = str(op.rank)
+        envs["WORLD_SIZE"] = str(op.world_size)
         return envs
 
     @classmethod
     def _build_locals(cls, ctx: Union[Context, dict], op: "RunScript"):
         sess = ctx.get_current_session().as_default()
-        local = {'session': sess,
-                 '__name__': '__main__'}
+        local = {"session": sess, "__name__": "__main__"}
         if op.data is not None:
             local.update(op.data)
         return local
@@ -136,13 +157,13 @@ class RunScript(MergeDictOperand):
 
         try:
             os.environ.update(envs)
-            sys.argv = ['script']
+            sys.argv = ["script"]
             sys.argv.extend(op.command_args)
 
             exec(op.code, cls._build_locals(ctx, op))
 
             if op.rank == 0:
-                ctx[op.outputs[0].key] = {'status': 'ok'}
+                ctx[op.outputs[0].key] = {"status": "ok"}
             else:
                 ctx[op.outputs[0].key] = {}
         finally:
@@ -153,8 +174,9 @@ class RunScript(MergeDictOperand):
 
 def _extract_inputs(data: Dict[str, TileableType] = None) -> List[TileableType]:
     if data is not None and not isinstance(data, dict):
-        raise TypeError('`data` must be a dict whose key is '
-                        'variable name and value is data')
+        raise TypeError(
+            "`data` must be a dict whose key is " "variable name and value is data"
+        )
 
     inputs = []
     if data is not None:
@@ -165,13 +187,15 @@ def _extract_inputs(data: Dict[str, TileableType] = None) -> List[TileableType]:
     return inputs
 
 
-def run_script(script: Union[bytes, str, BinaryIO, TextIO],
-               data: Dict[str, TileableType] = None,
-               n_workers: int = 1,
-               command_argv: List[str] = None,
-               session: SessionType = None,
-               retry_when_fail: bool = False,
-               run_kwargs: Dict[str, Any] = None):
+def run_script(
+    script: Union[bytes, str, BinaryIO, TextIO],
+    data: Dict[str, TileableType] = None,
+    n_workers: int = 1,
+    command_argv: List[str] = None,
+    session: SessionType = None,
+    retry_when_fail: bool = False,
+    run_kwargs: Dict[str, Any] = None,
+):
     """
     Run script in Mars cluster.
 
@@ -199,13 +223,18 @@ def run_script(script: Union[bytes, str, BinaryIO, TextIO],
 
     """
 
-    if hasattr(script, 'read'):
+    if hasattr(script, "read"):
         code = script.read()
     else:
-        with open(os.path.abspath(script), 'rb') as f:
+        with open(os.path.abspath(script), "rb") as f:
             code = f.read()
 
     inputs = _extract_inputs(data)
-    op = RunScript(data=data, code=to_binary(code), world_size=n_workers,
-                   retry_when_fail=retry_when_fail, command_args=command_argv)
+    op = RunScript(
+        data=data,
+        code=to_binary(code),
+        world_size=n_workers,
+        retry_when_fail=retry_when_fail,
+        command_args=command_argv,
+    )
     return op(inputs).execute(session=session, **(run_kwargs or {}))
