@@ -20,11 +20,17 @@ from .... import oscar as mo
 from ....lib.aio import alru_cache
 from ....typing import BandType
 from ...core import NodeRole
-from ..core import watch_method, NodeStatus, WorkerSlotInfo, QuotaInfo, \
-    DiskInfo, StorageInfo
+from ..core import (
+    watch_method,
+    NodeStatus,
+    WorkerSlotInfo,
+    QuotaInfo,
+    DiskInfo,
+    StorageInfo,
+)
 from .core import AbstractClusterAPI
 
-APIType = TypeVar('APIType', bound='ClusterAPI')
+APIType = TypeVar("APIType", bound="ClusterAPI")
 logger = logging.getLogger(__name__)
 
 
@@ -33,16 +39,17 @@ class ClusterAPI(AbstractClusterAPI):
         self._address = address
         self._locator_ref = None
         self._uploader_ref = None
-        self._node_info_ref = None
 
     async def _init(self):
         from ..locator import SupervisorLocatorActor
         from ..uploader import NodeInfoUploaderActor
 
-        self._locator_ref = await mo.actor_ref(SupervisorLocatorActor.default_uid(),
-                                               address=self._address)
-        self._uploader_ref = await mo.actor_ref(NodeInfoUploaderActor.default_uid(),
-                                                address=self._address)
+        self._locator_ref = await mo.actor_ref(
+            SupervisorLocatorActor.default_uid(), address=self._address
+        )
+        self._uploader_ref = await mo.actor_ref(
+            NodeInfoUploaderActor.default_uid(), address=self._address
+        )
 
     @classmethod
     @alru_cache(cache_exceptions=False)
@@ -54,16 +61,17 @@ class ClusterAPI(AbstractClusterAPI):
     @alru_cache(cache_exceptions=False)
     async def _get_node_info_ref(self):
         from ..supervisor.node_info import NodeInfoCollectorActor
+
         [node_info_ref] = await self.get_supervisor_refs(
-            [NodeInfoCollectorActor.default_uid()])
+            [NodeInfoCollectorActor.default_uid()]
+        )
         return node_info_ref
 
     async def get_supervisors(self, filter_ready: bool = True) -> List[str]:
         return await self._locator_ref.get_supervisors(filter_ready=filter_ready)
 
     @watch_method
-    async def watch_supervisors(self,
-                                version: Optional[int] = None):
+    async def watch_supervisors(self, version: Optional[int] = None):
         return await self._locator_ref.watch_supervisors(version=version)
 
     async def get_supervisors_by_keys(self, keys: List[str]) -> List[str]:
@@ -74,8 +82,6 @@ class ClusterAPI(AbstractClusterAPI):
         ----------
         keys
             key for a supervisor address
-        watch
-            if True, will watch changes of supervisor changes
 
         Returns
         -------
@@ -83,13 +89,12 @@ class ClusterAPI(AbstractClusterAPI):
             addresses of the supervisor
         """
         get_supervisor = self._locator_ref.get_supervisor
-        return await get_supervisor.batch(
-            *(get_supervisor.delay(k) for k in keys)
-        )
+        return await get_supervisor.batch(*(get_supervisor.delay(k) for k in keys))
 
     @watch_method
-    async def watch_supervisors_by_keys(self, keys: List[str],
-                                        version: Optional[int] = None):
+    async def watch_supervisors_by_keys(
+        self, keys: List[str], version: Optional[int] = None
+    ):
         return await self._locator_ref.watch_supervisors_by_keys(keys, version=version)
 
     async def get_supervisor_refs(self, uids: List[str]) -> List[mo.ActorRef]:
@@ -109,37 +114,58 @@ class ClusterAPI(AbstractClusterAPI):
             references of the actors
         """
         addrs = await self.get_supervisors_by_keys(uids)
-        return await asyncio.gather(*[
-            mo.actor_ref(uid, address=addr) for addr, uid in zip(addrs, uids)
-        ])
+        return await asyncio.gather(
+            *[mo.actor_ref(uid, address=addr) for addr, uid in zip(addrs, uids)]
+        )
 
     async def watch_supervisor_refs(self, uids: List[str]):
         async for addrs in self.watch_supervisors_by_keys(uids):
-            yield await asyncio.gather(*[
-                mo.actor_ref(uid, address=addr) for addr, uid in zip(addrs, uids)
-            ])
+            yield await asyncio.gather(
+                *[mo.actor_ref(uid, address=addr) for addr, uid in zip(addrs, uids)]
+            )
 
     @watch_method
-    async def watch_nodes(self, role: NodeRole, env: bool = False,
-                          resource: bool = False, detail: bool = False,
-                          version: Optional[int] = None,
-                          statuses: Set[NodeStatus] = None,
-                          exclude_statuses: Set[NodeStatus] = None) -> List[Dict[str, Dict]]:
+    async def watch_nodes(
+        self,
+        role: NodeRole,
+        env: bool = False,
+        resource: bool = False,
+        detail: bool = False,
+        version: Optional[int] = None,
+        statuses: Set[NodeStatus] = None,
+        exclude_statuses: Set[NodeStatus] = None,
+    ) -> List[Dict[str, Dict]]:
         statuses = self._calc_statuses(statuses, exclude_statuses)
         node_info_ref = await self._get_node_info_ref()
         return await node_info_ref.watch_nodes(
-            role, env=env, resource=resource, detail=detail,
-            statuses=statuses, version=version)
+            role,
+            env=env,
+            resource=resource,
+            detail=detail,
+            statuses=statuses,
+            version=version,
+        )
 
-    async def get_nodes_info(self, nodes: List[str] = None, role: NodeRole = None,
-                             env: bool = False, resource: bool = False, detail: bool = False,
-                             statuses: Set[NodeStatus] = None,
-                             exclude_statuses: Set[NodeStatus] = None):
+    async def get_nodes_info(
+        self,
+        nodes: List[str] = None,
+        role: NodeRole = None,
+        env: bool = False,
+        resource: bool = False,
+        detail: bool = False,
+        statuses: Set[NodeStatus] = None,
+        exclude_statuses: Set[NodeStatus] = None,
+    ):
         statuses = self._calc_statuses(statuses, exclude_statuses)
         node_info_ref = await self._get_node_info_ref()
         return await node_info_ref.get_nodes_info(
-            nodes=nodes, role=role, env=env, resource=resource,
-            detail=detail, statuses=statuses)
+            nodes=nodes,
+            role=role,
+            env=env,
+            resource=resource,
+            detail=detail,
+            statuses=statuses,
+        )
 
     async def set_node_status(self, node: str, role: NodeRole, status: NodeStatus):
         """
@@ -157,22 +183,29 @@ class ClusterAPI(AbstractClusterAPI):
         node_info_ref = await self._get_node_info_ref()
         await node_info_ref.update_node_info(node, role, status=status)
 
-    async def get_all_bands(self, role: NodeRole = None,
-                            statuses: Set[NodeStatus] = None,
-                            exclude_statuses: Set[NodeStatus] = None) -> Dict[BandType, int]:
+    async def get_all_bands(
+        self,
+        role: NodeRole = None,
+        statuses: Set[NodeStatus] = None,
+        exclude_statuses: Set[NodeStatus] = None,
+    ) -> Dict[BandType, int]:
         statuses = self._calc_statuses(statuses, exclude_statuses)
         node_info_ref = await self._get_node_info_ref()
         return await node_info_ref.get_all_bands(role, statuses=statuses)
 
     @watch_method
-    async def watch_all_bands(self, role: NodeRole = None,
-                              version: Optional[int] = None,
-                              statuses: Set[NodeStatus] = None,
-                              exclude_statuses: Set[NodeStatus] = None):
+    async def watch_all_bands(
+        self,
+        role: NodeRole = None,
+        version: Optional[int] = None,
+        statuses: Set[NodeStatus] = None,
+        exclude_statuses: Set[NodeStatus] = None,
+    ):
         statuses = self._calc_statuses(statuses, exclude_statuses)
         node_info_ref = await self._get_node_info_ref()
         return await node_info_ref.watch_all_bands(
-            role, statuses=statuses, version=version)
+            role, statuses=statuses, version=version
+        )
 
     async def get_mars_versions(self) -> List[str]:
         node_info_ref = await self._get_node_info_ref()
@@ -207,12 +240,12 @@ class ClusterAPI(AbstractClusterAPI):
         """
         await self._locator_ref.wait_all_supervisors_ready()
 
-    async def set_band_slot_infos(self, band_name: str,
-                                  slot_infos: List[WorkerSlotInfo]):
+    async def set_band_slot_infos(
+        self, band_name: str, slot_infos: List[WorkerSlotInfo]
+    ):
         await self._uploader_ref.set_band_slot_infos.tell(band_name, slot_infos)
 
-    async def set_band_quota_info(self, band_name: str,
-                                  quota_info: QuotaInfo):
+    async def set_band_quota_info(self, band_name: str, quota_info: QuotaInfo):
         await self._uploader_ref.set_band_quota_info.tell(band_name, quota_info)
 
     async def set_node_disk_info(self, disk_info: List[DiskInfo]):
@@ -222,28 +255,77 @@ class ClusterAPI(AbstractClusterAPI):
     async def set_band_storage_info(self, band_name: str, storage_info: StorageInfo):
         await self._uploader_ref.set_band_storage_info(band_name, storage_info)
 
+    async def request_worker(
+        self, worker_cpu: int = None, worker_mem: int = None, timeout: int = None
+    ) -> str:
+        node_allocator_ref = await self._get_node_allocator_ref()
+        address = await node_allocator_ref.request_worker(
+            worker_cpu, worker_mem, timeout
+        )
+        return address
+
+    async def release_worker(self, address: str):
+        node_allocator_ref = await self._get_node_allocator_ref()
+        await node_allocator_ref.release_worker(address)
+        node_info_ref = await self._get_node_info_ref()
+        await node_info_ref.update_node_info(
+            address, NodeRole.WORKER, status=NodeStatus.STOPPED
+        )
+
+    async def reconstruct_worker(self, address: str):
+        node_allocator_ref = await self._get_node_allocator_ref()
+        await node_allocator_ref.reconstruct_worker(address)
+
+    @alru_cache(cache_exceptions=False)
+    async def _get_node_allocator_ref(self):
+        from ..supervisor.node_allocator import NodeAllocatorActor
+
+        [node_allocator_ref] = await self.get_supervisor_refs(
+            [NodeAllocatorActor.default_uid()]
+        )
+        return node_allocator_ref
+
 
 class MockClusterAPI(ClusterAPI):
     @classmethod
     async def create(cls: Type[APIType], address: str, **kw) -> APIType:
         from ..supervisor.locator import SupervisorPeerLocatorActor
         from ..uploader import NodeInfoUploaderActor
+        from ..supervisor.node_allocator import NodeAllocatorActor
         from ..supervisor.node_info import NodeInfoCollectorActor
 
-        dones, _ = await asyncio.wait([
-            mo.create_actor(SupervisorPeerLocatorActor, 'fixed', address,
-                            uid=SupervisorPeerLocatorActor.default_uid(),
-                            address=address),
-            mo.create_actor(NodeInfoCollectorActor,
-                            uid=NodeInfoCollectorActor.default_uid(),
-                            address=address),
-            mo.create_actor(NodeInfoUploaderActor, NodeRole.WORKER,
-                            interval=kw.get('upload_interval'),
-                            band_to_slots=kw.get('band_to_slots'),
-                            use_gpu=kw.get('use_gpu', False),
-                            uid=NodeInfoUploaderActor.default_uid(),
-                            address=address),
-        ])
+        dones, _ = await asyncio.wait(
+            [
+                mo.create_actor(
+                    SupervisorPeerLocatorActor,
+                    "fixed",
+                    address,
+                    uid=SupervisorPeerLocatorActor.default_uid(),
+                    address=address,
+                ),
+                mo.create_actor(
+                    NodeInfoCollectorActor,
+                    uid=NodeInfoCollectorActor.default_uid(),
+                    address=address,
+                ),
+                mo.create_actor(
+                    NodeAllocatorActor,
+                    "fixed",
+                    address,
+                    uid=NodeAllocatorActor.default_uid(),
+                    address=address,
+                ),
+                mo.create_actor(
+                    NodeInfoUploaderActor,
+                    NodeRole.WORKER,
+                    interval=kw.get("upload_interval"),
+                    band_to_slots=kw.get("band_to_slots"),
+                    use_gpu=kw.get("use_gpu", False),
+                    uid=NodeInfoUploaderActor.default_uid(),
+                    address=address,
+                ),
+            ]
+        )
 
         for task in dones:
             try:
@@ -261,14 +343,22 @@ class MockClusterAPI(ClusterAPI):
         from ..uploader import NodeInfoUploaderActor
         from ..supervisor.node_info import NodeInfoCollectorActor
 
-        await asyncio.wait([
-            mo.destroy_actor(mo.create_actor_ref(
-                uid=SupervisorPeerLocatorActor.default_uid(),
-                address=address)),
-            mo.destroy_actor(mo.create_actor_ref(
-                uid=NodeInfoCollectorActor.default_uid(),
-                address=address)),
-            mo.destroy_actor(mo.create_actor_ref(
-                uid=NodeInfoUploaderActor.default_uid(),
-                address=address)),
-        ])
+        await asyncio.wait(
+            [
+                mo.destroy_actor(
+                    mo.create_actor_ref(
+                        uid=SupervisorPeerLocatorActor.default_uid(), address=address
+                    )
+                ),
+                mo.destroy_actor(
+                    mo.create_actor_ref(
+                        uid=NodeInfoCollectorActor.default_uid(), address=address
+                    )
+                ),
+                mo.destroy_actor(
+                    mo.create_actor_ref(
+                        uid=NodeInfoUploaderActor.default_uid(), address=address
+                    )
+                ),
+            ]
+        )
