@@ -12,6 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .api import LifecycleAPI, MockLifecycleAPI, \
-    AbstractLifecycleAPI, WebLifecycleAPI
+from .api import LifecycleAPI, MockLifecycleAPI, AbstractLifecycleAPI, WebLifecycleAPI
 from .errors import TileableNotTracked
