@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import asyncio
+import copy
 import heapq
 import logging
 from collections import defaultdict
@@ -48,12 +49,14 @@ class SubtaskQueueingActor(mo.Actor):
 
     @classmethod
     def gen_uid(cls, session_id: str):
-        return f'{session_id}_subtask_queueing'
+        return f"{session_id}_subtask_queueing"
 
     def __init__(self, session_id: str, submit_period: Union[float, int] = None):
         self._session_id = session_id
         self._stid_to_bands = defaultdict(list)
         self._stid_to_items = dict()
+        # Note that we need to ensure top item in every band heap queue is valid,
+        # so that we can ensure band queue is busy if the band queue is not empty.
         self._band_queues = defaultdict(list)
 
         self._cluster_api = None
@@ -69,27 +72,57 @@ class SubtaskQueueingActor(mo.Actor):
 
     async def __post_create__(self):
         from ...cluster import ClusterAPI
+
         self._cluster_api = await ClusterAPI.create(self.address)
         self._band_slot_nums = {}
 
         async def watch_bands():
             async for bands in self._cluster_api.watch_all_bands():
-                self._band_slot_nums = bands
+                # confirm ready bands indeed changed
+                if bands != self._band_slot_nums:
+                    old_band_slot_nums = self._band_slot_nums
+                    self._band_slot_nums = copy.deepcopy(bands)
+                    if self._band_queues:
+                        await self.balance_queued_subtasks()
+                        # Refresh global slot manager to get latest bands,
+                        # so that subtasks reassigned to the new bands can be
+                        # ensured to get submitted as least one subtask every band
+                        # successfully.
+                        await self._slots_ref.refresh_bands()
+                        all_bands = {*bands.keys(), *old_band_slot_nums.keys()}
+                        bands_delta = {}
+                        for b in all_bands:
+                            delta = bands.get(b, 0) - old_band_slot_nums.get(b, 0)
+                            if delta != 0:
+                                bands_delta[b] = delta
+                        # Submit tasks on new bands manually, otherwise some subtasks
+                        # will never got submitted. Note that we must ensure every new
+                        # band will get at least one subtask submitted successfully.
+                        # Later subtasks submit on the band will be triggered by the
+                        # success of previous subtasks on the same band.
+                        logger.info(
+                            "Bands changed with delta %s, submit all bands.",
+                            bands_delta,
+                        )
+                        await self.ref().submit_subtasks()
 
         self._band_watch_task = asyncio.create_task(watch_bands())
 
         from .globalslot import GlobalSlotManagerActor
+
         [self._slots_ref] = await self._cluster_api.get_supervisor_refs(
             [GlobalSlotManagerActor.default_uid()]
         )
         from .assigner import AssignerActor
+
         self._assigner_ref = await mo.actor_ref(
             AssignerActor.gen_uid(self._session_id), address=self.address
         )
 
         if self._submit_period > 0:
-            self._periodical_submit_task = \
-                self.ref().periodical_submit.tell_delay(delay=self._submit_period)
+            self._periodical_submit_task = self.ref().periodical_submit.tell_delay(
+                delay=self._submit_period
+            )
 
     async def __pre_destroy__(self):
         self._band_watch_task.cancel()
@@ -98,8 +131,9 @@ class SubtaskQueueingActor(mo.Actor):
 
     async def periodical_submit(self):
         await self.ref().submit_subtasks.tell()
-        self._periodical_submit_task = \
-            self.ref().periodical_submit.tell_delay(delay=self._submit_period)
+        self._periodical_submit_task = self.ref().periodical_submit.tell_delay(
+            delay=self._submit_period
+        )
 
     @alru_cache
     async def _get_task_api(self):
@@ -108,6 +142,7 @@ class SubtaskQueueingActor(mo.Actor):
     @alru_cache(cache_exceptions=False)
     async def _get_manager_ref(self):
         from .manager import SubtaskManagerActor
+
         return await mo.actor_ref(
             SubtaskManagerActor.gen_uid(self._session_id), address=self.address
         )
@@ -117,14 +152,15 @@ class SubtaskQueueingActor(mo.Actor):
         for subtask, band, priority in zip(subtasks, bands, priorities):
             assert band is not None
             self._stid_to_bands[subtask.subtask_id].append(band)
-            heap_item = self._stid_to_items[subtask.subtask_id] = \
-                HeapItem(subtask, priority + (self._max_enqueue_id,))
+            heap_item = self._stid_to_items[subtask.subtask_id] = HeapItem(
+                subtask, priority + (self._max_enqueue_id,)
+            )
             self._max_enqueue_id += 1
             heapq.heappush(self._band_queues[band], heap_item)
-        logger.debug('%d subtasks enqueued', len(subtasks))
+        logger.debug("%d subtasks enqueued", len(subtasks))
 
     async def submit_subtasks(self, band: Tuple = None, limit: Optional[int] = None):
-        logger.debug('Submitting subtasks with limit %s', limit)
+        logger.debug("Submitting subtasks with limit %s", limit)
 
         if not limit and band not in self._band_slot_nums:
             self._band_slot_nums = await self._cluster_api.get_all_bands()
@@ -133,40 +169,74 @@ class SubtaskQueueingActor(mo.Actor):
         submit_aio_tasks = []
         manager_ref = await self._get_manager_ref()
 
+        apply_delays = []
+        submit_items_list = []
+        submitted_bands = []
+
         for band in bands:
             band_limit = limit or self._band_slot_nums[band]
             task_queue = self._band_queues[band]
             submit_items = dict()
             while task_queue and len(submit_items) < band_limit:
+                self._ensure_top_item_valid(task_queue)
                 item = heapq.heappop(task_queue)
-                # skip removed items (as they may still in the queue)
-                if item.subtask.subtask_id not in self._stid_to_items:
-                    continue
                 submit_items[item.subtask.subtask_id] = item
 
             subtask_ids = list(submit_items)
             if not subtask_ids:
                 continue
+
+            submitted_bands.append(band)
+            submit_items_list.append(submit_items)
+
             # todo it is possible to provide slot data with more accuracy
             subtask_slots = [1] * len(subtask_ids)
 
-            async with redirect_subtask_errors(self, [item.subtask for item in submit_items.values()]):
-                submitted_ids = set(await self._slots_ref.apply_subtask_slots(
+            apply_delays.append(
+                self._slots_ref.apply_subtask_slots.delay(
                     band, self._session_id, subtask_ids, subtask_slots
-                ))
+                )
+            )
+
+        async with redirect_subtask_errors(
+            self,
+            [
+                item.subtask
+                for submit_items in submit_items_list
+                for item in submit_items.values()
+            ],
+        ):
+            submitted_ids_list = await self._slots_ref.apply_subtask_slots.batch(
+                *apply_delays
+            )
+
+        for band, submit_items, submitted_ids in zip(
+            submitted_bands, submit_items_list, submitted_ids_list
+        ):
+            subtask_ids = list(submit_items)
+            task_queue = self._band_queues[band]
+
+            async with redirect_subtask_errors(
+                self, [item.subtask for item in submit_items.values()]
+            ):
                 non_submitted_ids = [k for k in submit_items if k not in submitted_ids]
                 if submitted_ids:
                     for stid in subtask_ids:
                         if stid not in submitted_ids:
                             continue
                         item = submit_items[stid]
-                        logger.debug('Submit subtask %s to band %r', item.subtask.subtask_id, band)
-                        submit_aio_tasks.append(asyncio.create_task(
-                            manager_ref.submit_subtask_to_band.tell(item.subtask.subtask_id, band)))
+                        logger.debug("Submit subtask %r to band %r", item.subtask, band)
+                        submit_aio_tasks.append(
+                            asyncio.create_task(
+                                manager_ref.submit_subtask_to_band.tell(
+                                    item.subtask.subtask_id, band
+                                )
+                            )
+                        )
                         await asyncio.sleep(0)
                         self.remove_queued_subtasks([item.subtask.subtask_id])
                 else:
-                    logger.debug('No slots available')
+                    logger.debug("No slots available")
 
             for stid in non_submitted_ids:
                 heapq.heappush(task_queue, submit_items[stid])
@@ -174,6 +244,14 @@ class SubtaskQueueingActor(mo.Actor):
         if submit_aio_tasks:
             yield asyncio.gather(*submit_aio_tasks)
 
+    def _ensure_top_item_valid(self, task_queue):
+        """Clean invalid subtask item from queue to ensure that"""
+        while (
+            task_queue and task_queue[0].subtask.subtask_id not in self._stid_to_items
+        ):
+            #  skip removed items (as they may be re-pushed into the queue)
+            heapq.heappop(task_queue)
+
     @mo.extensible
     def update_subtask_priority(self, subtask_id: str, priority: Tuple):
         if subtask_id not in self._stid_to_bands:
@@ -185,5 +263,41 @@ class SubtaskQueueingActor(mo.Actor):
 
     def remove_queued_subtasks(self, subtask_ids: List[str]):
         for stid in subtask_ids:
-            self._stid_to_bands.pop(stid, None)
+            bands = self._stid_to_bands.pop(stid, [])
             self._stid_to_items.pop(stid, None)
+            for band in bands:
+                band_queue = self._band_queues.get(band)
+                self._ensure_top_item_valid(band_queue)
+
+    async def all_bands_busy(self) -> bool:
+        """Return True if all bands queue has tasks waiting to be submitted."""
+        bands = set(self._band_slot_nums.keys())
+        if set(self._band_queues.keys()).issuperset(bands):
+            return all(len(self._band_queues[band]) > 0 for band in bands)
+        return False
+
+    async def balance_queued_subtasks(self):
+        # record length of band queues
+        band_num_queued_subtasks = {
+            band: len(queue) for band, queue in self._band_queues.items()
+        }
+        move_queued_subtasks = await self._assigner_ref.reassign_subtasks(
+            band_num_queued_subtasks
+        )
+        items = []
+        # rewrite band queues according to feedbacks from assigner
+        for band, move in move_queued_subtasks.items():
+            task_queue = self._band_queues[band]
+            assert move + len(task_queue) >= 0
+            for _ in range(abs(move)):
+                if move < 0:
+                    # TODO: pop item of low priority
+                    item = heapq.heappop(task_queue)
+                    self._stid_to_bands[item.subtask.subtask_id].remove(band)
+                    items.append(item)
+                elif move > 0:
+                    item = items.pop()
+                    self._stid_to_bands[item.subtask.subtask_id].append(band)
+                    heapq.heappush(task_queue, item)
+            if len(task_queue) == 0:
+                self._band_queues.pop(band)
