@@ -16,11 +16,12 @@ import asyncio
 import logging
 import os
 import time
-from typing import Dict, List, NamedTuple, Optional, Set, Tuple
+from typing import Dict, List, NamedTuple, Set, Tuple
 
 import psutil
 
 from .... import oscar as mo
+from ....oscar.errors import NoFreeSlot, SlotStateError
 from ....oscar.backends.allocate_strategy import IdleLabel
 from ....typing import BandType
 from ...cluster import WorkerSlotInfo, ClusterAPI
@@ -48,13 +49,18 @@ class WorkerSlotManagerActor(mo.Actor):
         band_to_slots = await self._cluster_api.get_bands()
         for band, n_slot in band_to_slots.items():
             self._band_slot_managers[band] = await mo.create_actor(
-                BandSlotManagerActor, band, n_slot, self._global_slots_ref,
+                BandSlotManagerActor,
+                band,
+                n_slot,
+                self._global_slots_ref,
                 uid=BandSlotManagerActor.gen_uid(band[1]),
-                address=self.address)
+                address=self.address,
+            )
 
     async def __pre_destroy__(self):
-        await asyncio.gather(*[mo.destroy_actor(ref)
-                               for ref in self._band_slot_managers.values()])
+        await asyncio.gather(
+            *[mo.destroy_actor(ref) for ref in self._band_slot_managers.values()]
+        )
 
 
 class BandSlotManagerActor(mo.Actor):
@@ -63,10 +69,11 @@ class BandSlotManagerActor(mo.Actor):
 
     @classmethod
     def gen_uid(cls, band_name: str):
-        return f'{band_name}_band_slot_manager'
+        return f"{band_name}_band_slot_manager"
 
-    def __init__(self, band: BandType, n_slots: int,
-                 global_slots_ref: mo.ActorRef = None):
+    def __init__(
+        self, band: BandType, n_slots: int, global_slots_ref: mo.ActorRef = None
+    ):
         super().__init__()
         self._cluster_api = None
 
@@ -97,18 +104,22 @@ class BandSlotManagerActor(mo.Actor):
         except mo.ActorNotExist:
             pass
 
-        strategy = IdleLabel(self._band_name, f'worker_slot_control')
+        strategy = IdleLabel(self._band_name, f"worker_slot_control")
         for slot_id in range(self._n_slots):
             self._slot_control_refs[slot_id] = await mo.create_actor(
                 BandSlotControlActor,
-                self.ref(), self._band_name, slot_id,
+                self.ref(),
+                self._band_name,
+                slot_id,
                 uid=BandSlotControlActor.gen_uid(self._band_name, slot_id),
                 address=self.address,
-                allocate_strategy=strategy)
+                allocate_strategy=strategy,
+            )
             self._fresh_slots.add(slot_id)
 
         self._usage_upload_task = self.ref().upload_slot_usages.tell_delay(
-            periodical=True, delay=1)
+            periodical=True, delay=1
+        )
 
     async def __pre_destroy__(self):
         self._usage_upload_task.cancel()
@@ -118,11 +129,21 @@ class BandSlotManagerActor(mo.Actor):
             return self._global_slots_ref
 
         from ..supervisor import GlobalSlotManagerActor
-        [self._global_slots_ref] = await self._cluster_api.get_supervisor_refs([
-            GlobalSlotManagerActor.default_uid()])
+
+        [self._global_slots_ref] = await self._cluster_api.get_supervisor_refs(
+            [GlobalSlotManagerActor.default_uid()]
+        )
         return self._global_slots_ref
 
-    async def acquire_free_slot(self, session_stid: Tuple[str, str]):
+    def get_slot_address(self, slot_id: int):
+        return self._slot_control_refs[slot_id].address
+
+    def get_subtask_slot(self, session_stid: Tuple[str, str]):
+        return self._session_stid_to_slot.get(session_stid)
+
+    async def acquire_free_slot(self, session_stid: Tuple[str, str], block=True):
+        if not block and self._semaphore.locked():
+            raise NoFreeSlot(f"No free slot for {session_stid}")
         yield self._semaphore.acquire()
         if self._restarting:
             yield self._restart_done_event.wait()
@@ -131,41 +152,71 @@ class BandSlotManagerActor(mo.Actor):
         self._fresh_slots.difference_update([slot_id])
         self._slot_to_session_stid[slot_id] = session_stid
         self._session_stid_to_slot[session_stid] = slot_id
-        logger.debug('Slot %d acquired for subtask %r', slot_id, session_stid)
+        logger.debug("Slot %d acquired for subtask %r", slot_id, session_stid)
         raise mo.Return(slot_id)
 
-    def get_slot_address(self, slot_id: int):
-        return self._slot_control_refs[slot_id].address
+    def release_free_slot(self, slot_id: int, session_stid: Tuple[str, str]):
+        acquired_session_stid = self._slot_to_session_stid.pop(slot_id, None)
+        if acquired_session_stid is None:
+            raise SlotStateError(f"Slot {slot_id} is not acquired.")
+        if acquired_session_stid != session_stid:
+            raise SlotStateError(
+                f"Slot {slot_id} releasing state incorrect, "
+                f"the acquired session_stid: {acquired_session_stid}, "
+                f"the releasing session_stid: {session_stid}"
+            )
+        acquired_slot_id = self._session_stid_to_slot.pop(acquired_session_stid)
+        assert (
+            acquired_slot_id == slot_id
+        ), f"{acquired_session_stid}: acquired_slot_id {acquired_slot_id} != slot_id {slot_id}"
 
-    def get_subtask_slot(self, session_stid: Tuple[str, str]):
-        return self._session_stid_to_slot.get(session_stid)
-
-    def release_free_slot(self, slot_id: int, pid: Optional[int] = None):
-        if pid is not None:
-            self._slot_to_proc[slot_id] = proc = psutil.Process(pid)
-            self._fresh_slots.add(slot_id)
-            # collect initial stats for the process
-            proc.cpu_percent(interval=None)
-
-        if slot_id in self._slot_kill_events:
-            event = self._slot_kill_events.pop(slot_id)
-            event.set()
-
-        session_stid = self._slot_to_session_stid.pop(slot_id, None)
-        self._session_stid_to_slot.pop(session_stid, None)
-        logger.debug('Slot %d released', slot_id)
+        logger.debug("Slot %d released", slot_id)
 
         if slot_id not in self._free_slots:
             self._free_slots.add(slot_id)
             self._semaphore.release()
 
+    def register_slot(self, slot_id: int, pid: int):
+        try:
+            self._fresh_slots.add(slot_id)
+            if slot_id in self._slot_kill_events:
+                event = self._slot_kill_events.pop(slot_id)
+                event.set()
+            if slot_id in self._slot_to_session_stid:
+                # We should release the slot by one role, if the slot is
+                # acquired by the SubtaskExecutionActor, then the slot
+                # should be released by it, too.
+                session_stid = self._slot_to_session_stid[slot_id]
+                logger.info(
+                    "Slot %s registered by pid %s, current acquired session_stid is %s",
+                    slot_id,
+                    pid,
+                    session_stid,
+                )
+            else:
+                if slot_id not in self._free_slots:
+                    self._free_slots.add(slot_id)
+                    self._semaphore.release()
+        finally:
+            # psutil may raises exceptions, but currently we can't handle the register exception,
+            # so put it to the finally.
+            # TODO(fyrestone): handle register_slot failure.
+            self._slot_to_proc[slot_id] = proc = psutil.Process(pid)
+            # collect initial stats for the process
+            proc.cpu_percent(interval=None)
+
     async def _kill_slot(self, slot_id: int):
         if slot_id in self._slot_kill_events:
             await self._slot_kill_events[slot_id].wait()
             return
 
         event = self._slot_kill_events[slot_id] = asyncio.Event()
-        await mo.kill_actor(self._slot_control_refs[slot_id])
+        # TODO(fyrestone): Make it more reliable. e.g. kill_actor
+        # success but the actor does not restart.
+        try:
+            await mo.kill_actor(self._slot_control_refs[slot_id])
+        except ConnectionError:
+            pass
         await event.wait()
 
     async def kill_slot(self, slot_id: int):
@@ -179,11 +230,12 @@ class BandSlotManagerActor(mo.Actor):
 
         self._restart_done_event = asyncio.Event()
         self._restarting = True
-        slot_ids = [slot_id for slot_id in self._free_slots
-                    if slot_id not in self._fresh_slots]
+        slot_ids = [
+            slot_id for slot_id in self._free_slots if slot_id not in self._fresh_slots
+        ]
         if slot_ids:
             yield asyncio.gather(*[self._kill_slot(slot_id) for slot_id in slot_ids])
-            logger.info('%d idle slots restarted', len(slot_ids))
+            logger.info("%d idle slots restarted", len(slot_ids))
 
         self._restarting = False
         self._restart_done_event.set()
@@ -202,17 +254,22 @@ class BandSlotManagerActor(mo.Actor):
             except psutil.NoSuchProcess:  # pragma: no cover
                 continue
 
-            slot_infos.append(WorkerSlotInfo(
-                slot_id=slot_id,
-                session_id=session_id,
-                subtask_id=subtask_id,
-                processor_usage=usage
-            ))
+            slot_infos.append(
+                WorkerSlotInfo(
+                    slot_id=slot_id,
+                    session_id=session_id,
+                    subtask_id=subtask_id,
+                    processor_usage=usage,
+                )
+            )
 
             if global_slots_ref is not None:  # pragma: no branch
                 # FIXME fix band slot mistake
-                delays.append(global_slots_ref.update_subtask_slots.delay(
-                    self._band[1], session_id, subtask_id, max(1.0, usage)))
+                delays.append(
+                    global_slots_ref.update_subtask_slots.delay(
+                        self._band[1], session_id, subtask_id, max(1.0, usage)
+                    )
+                )
 
         if delays:  # pragma: no branch
             yield global_slots_ref.update_subtask_slots.batch(*delays)
@@ -221,7 +278,8 @@ class BandSlotManagerActor(mo.Actor):
 
         if periodical:
             self._usage_upload_task = self.ref().upload_slot_usages.tell_delay(
-                periodical=True, delay=1)
+                periodical=True, delay=1
+            )
 
     def dump_data(self):
         """
@@ -233,7 +291,7 @@ class BandSlotManagerActor(mo.Actor):
 class BandSlotControlActor(mo.Actor):
     @classmethod
     def gen_uid(cls, band_name: str, slot_id: int):
-        return f'{band_name}_{slot_id}_band_slot_control'
+        return f"{band_name}_{slot_id}_band_slot_control"
 
     def __init__(self, manager_ref, band_name, slot_id: int):
         self._manager_ref = manager_ref
@@ -246,6 +304,7 @@ class BandSlotControlActor(mo.Actor):
 
     async def _report_slot_ready(self):
         from ...cluster.api import ClusterAPI
+
         try:
             self._cluster_api = await ClusterAPI.create(self.address)
             await self._cluster_api.wait_node_ready()
@@ -253,4 +312,4 @@ class BandSlotControlActor(mo.Actor):
             pass
 
         await mo.wait_actor_pool_recovered(self.address)
-        await self._manager_ref.release_free_slot.tell(self._slot_id, os.getpid())
+        await self._manager_ref.register_slot.tell(self._slot_id, os.getpid())
