@@ -30,11 +30,13 @@ logger = logging.getLogger(__name__)
 
 
 class GraphAnalyzer:
-    def __init__(self,
-                 chunk_graph: ChunkGraph,
-                 band_slots: Dict[BandType, int],
-                 task: Task,
-                 graph_assigner_cls: Type[AbstractGraphAssigner] = None):
+    def __init__(
+        self,
+        chunk_graph: ChunkGraph,
+        band_slots: Dict[BandType, int],
+        task: Task,
+        graph_assigner_cls: Type[AbstractGraphAssigner] = None,
+    ):
         self._chunk_graph = chunk_graph
         self._band_slots = band_slots
         self._task = task
@@ -56,26 +58,33 @@ class GraphAnalyzer:
             chunk = stack.popleft()
             if chunk not in visited:
                 inp_chunks = chunk_graph.predecessors(chunk)
-                if not inp_chunks or \
-                        all(inp_chunk in visited for inp_chunk in inp_chunks):
+                if not inp_chunks or all(
+                    inp_chunk in visited for inp_chunk in inp_chunks
+                ):
                     if len(inp_chunks) == 0:
                         op_key = chunk.op.key
                         if op_key not in op_keys:
                             op_keys.add(op_key)
                             yield chunk.op
                     visited.add(chunk)
-                    stack.extend(c for c in chunk_graph[chunk]
-                                 if c not in visited)
+                    stack.extend(c for c in chunk_graph[chunk] if c not in visited)
                 else:
                     stack.appendleft(chunk)
                     stack.extendleft(
-                        reversed([c for c in chunk_graph.predecessors(chunk)
-                                  if c not in visited]))
+                        reversed(
+                            [
+                                c
+                                for c in chunk_graph.predecessors(chunk)
+                                if c not in visited
+                            ]
+                        )
+                    )
             if not stack and start_chunks:
                 stack.appendleft(start_chunks.popleft())
 
-    def _fuse(self, chunk_to_bands: Dict[ChunkType, BandType]) \
-            -> Dict[ChunkType, BandType]:
+    def _fuse(
+        self, chunk_to_bands: Dict[ChunkType, BandType]
+    ) -> Dict[ChunkType, BandType]:
         fusion = Fusion(self._chunk_graph)
         to_fuse_nodes_list, fused_nodes = fusion.fuse()
         assert len(to_fuse_nodes_list) == len(fused_nodes)
@@ -99,10 +108,11 @@ class GraphAnalyzer:
         return new_chunk_to_bands
 
     @classmethod
-    def _gen_input_chunks(cls,
-                          inp_chunks: List[ChunkType],
-                          chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]) \
-            -> List[ChunkType]:
+    def _gen_input_chunks(
+        cls,
+        inp_chunks: List[ChunkType],
+        chunk_to_fetch_chunk: Dict[ChunkType, ChunkType],
+    ) -> List[ChunkType]:
         # gen fetch chunks for input chunks
         inp_fetch_chunks = []
         for inp_chunk in inp_chunks:
@@ -118,14 +128,12 @@ class GraphAnalyzer:
 
         return inp_fetch_chunks
 
-    def _build_subtask_chunk_graph(self,
-                                   chunk: ChunkType,
-                                   chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]) \
-            -> ChunkGraph:
+    def _build_subtask_chunk_graph(
+        self, chunk: ChunkType, chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]
+    ) -> ChunkGraph:
         virtual = isinstance(chunk.op, VirtualOperand)
         inp_chunks = chunk.inputs
-        assert all(inp_chunk in self._chunk_graph
-                   for inp_chunk in inp_chunks)
+        assert all(inp_chunk in self._chunk_graph for inp_chunk in inp_chunks)
         inp_fetch_chunks = self._gen_input_chunks(inp_chunks, chunk_to_fetch_chunk)
 
         # gen chunk graph for each subtask
@@ -135,8 +143,9 @@ class GraphAnalyzer:
         out_params = [out.params for out in outs]
         copied_op = chunk.op.copy()
         copied_op._key = chunk.op.key
-        copied_chunks = [c.data for c in
-                         copied_op.new_chunks(inp_fetch_chunks, kws=out_params)]
+        copied_chunks = [
+            c.data for c in copied_op.new_chunks(inp_fetch_chunks, kws=out_params)
+        ]
         for out, copied_chunk in zip(outs, copied_chunks):
             copied_chunk._key = out.key
             result_chunks.append(copied_chunk)
@@ -149,10 +158,9 @@ class GraphAnalyzer:
             self._chunk_to_copied[out] = copied_chunk
         return subtask_chunk_graph
 
-    def _build_fuse_subtask_chunk_graph(self,
-                                        chunk: ChunkType,
-                                        chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]) \
-            -> ChunkGraph:
+    def _build_fuse_subtask_chunk_graph(
+        self, chunk: ChunkType, chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]
+    ) -> ChunkGraph:
         # gen chunk graph for each subtask
         result_chunks = []
         subtask_chunk_graph = ChunkGraph(result_chunks)
@@ -165,20 +173,22 @@ class GraphAnalyzer:
                 # the first chunk
                 inp_chunks = chunk.inputs
                 inp_fetch_chunks = self._gen_input_chunks(
-                    inp_chunks, chunk_to_fetch_chunk)
+                    inp_chunks, chunk_to_fetch_chunk
+                )
                 copied_fuse_chunk = copied_op.new_chunk(
-                    inp_fetch_chunks, kws=[fuse_chunk.params.copy()]).data
+                    inp_fetch_chunks, kws=[fuse_chunk.params.copy()]
+                ).data
                 copied_fuse_chunk._key = fuse_chunk.key
                 subtask_chunk_graph.add_node(copied_fuse_chunk)
                 for inp_fetch_chunk in inp_fetch_chunks:
                     subtask_chunk_graph.add_node(inp_fetch_chunk)
-                    subtask_chunk_graph.add_edge(
-                        inp_fetch_chunk, copied_fuse_chunk)
+                    subtask_chunk_graph.add_edge(inp_fetch_chunk, copied_fuse_chunk)
             else:
                 inp_chunk = fuse_to_copied[fused_chunks[i - 1]]
                 copied_fuse_chunk = copied_op.new_chunks(
                     [inp_chunk] * len(fuse_chunk.inputs),
-                    kws=[fuse_chunk.params.copy()])[0].data
+                    kws=[out.params.copy() for out in fuse_chunk.op.outputs],
+                )[fuse_chunk.extra_params["_i"]].data
                 copied_fuse_chunk._key = fuse_chunk.key
                 subtask_chunk_graph.add_node(copied_fuse_chunk)
                 subtask_chunk_graph.add_edge(inp_chunk, copied_fuse_chunk)
@@ -186,22 +196,29 @@ class GraphAnalyzer:
                     # the last chunk
                     result_chunks.append(copied_fuse_chunk)
             fuse_to_copied[fuse_chunk] = copied_fuse_chunk
-        self._chunk_to_copied[chunk.chunk] = self._chunk_to_copied[chunk] = \
-            fuse_to_copied[chunk.chunk]
+        self._chunk_to_copied[chunk.chunk] = self._chunk_to_copied[
+            chunk
+        ] = fuse_to_copied[chunk.chunk]
         return subtask_chunk_graph
 
-    def _gen_subtask(self,
-                     chunk: ChunkType,
-                     chunk_to_priorities: Dict[ChunkType, Tuple[int, ...]],
-                     chunk_to_bands: Dict[ChunkType, BandType],
-                     chunk_to_fetch_chunk: Dict[ChunkType, ChunkType]) -> Subtask:
+    def _gen_subtask(
+        self,
+        chunk: ChunkType,
+        chunk_to_priorities: Dict[ChunkType, Tuple[int, ...]],
+        chunk_to_bands: Dict[ChunkType, BandType],
+        chunk_to_fetch_chunk: Dict[ChunkType, ChunkType],
+    ) -> Subtask:
         virtual = isinstance(chunk.op, VirtualOperand)
-        inp_chunks = [inp_chunk for inp_chunk in self._chunk_graph.predecessors(chunk)
-                      if not isinstance(inp_chunk.op, Fetch)]
+        inp_chunks = [
+            inp_chunk
+            for inp_chunk in self._chunk_graph.predecessors(chunk)
+            if not isinstance(inp_chunk.op, Fetch)
+        ]
         # calculate priority
         if inp_chunks:
-            depth = max(chunk_to_priorities[inp_chunk][0]
-                        for inp_chunk in inp_chunks) + 1
+            depth = (
+                max(chunk_to_priorities[inp_chunk][0] for inp_chunk in inp_chunks) + 1
+            )
         else:
             depth = 0
         priority = (depth, chunk.op.priority or 0)
@@ -211,10 +228,12 @@ class GraphAnalyzer:
         band = chunk_to_bands.get(chunk)
         if not isinstance(chunk.op, Fuse):
             subtask_chunk_graph = self._build_subtask_chunk_graph(
-                chunk, chunk_to_fetch_chunk)
+                chunk, chunk_to_fetch_chunk
+            )
         else:
             subtask_chunk_graph = self._build_fuse_subtask_chunk_graph(
-                chunk, chunk_to_fetch_chunk)
+                chunk, chunk_to_fetch_chunk
+            )
 
         subtask = Subtask(
             subtask_id=new_task_id(),
@@ -224,7 +243,11 @@ class GraphAnalyzer:
             expect_bands=[band] if band is not None else None,
             virtual=virtual,
             priority=priority,
-            extra_config=self._extra_config)
+            retryable=all(
+                getattr(chunk.op, "retryable", True) for chunk in subtask_chunk_graph
+            ),
+            extra_config=self._extra_config,
+        )
         return subtask
 
     @staticmethod
@@ -233,7 +256,7 @@ class GraphAnalyzer:
             # band already
             return band_or_worker
         else:
-            return band_or_worker, 'numa-0'
+            return band_or_worker, "numa-0"
 
     @enter_mode(build=True)
     def gen_subtask_graph(self) -> SubtaskGraph:
@@ -253,27 +276,44 @@ class GraphAnalyzer:
             elif chunk.op.reassign_worker:
                 reassign_worker_ops.append(chunk.op)
 
-        start_ops = list(self._iter_start_ops(fetch_removed_chunk_graph)) \
-            if len(fetch_removed_chunk_graph) > 0 else []
+        start_ops = (
+            list(self._iter_start_ops(fetch_removed_chunk_graph))
+            if len(fetch_removed_chunk_graph) > 0
+            else []
+        )
 
         # assign start chunks
         to_assign_ops = start_ops + reassign_worker_ops
         assigner = self._graph_assigner_cls(
-            fetch_removed_chunk_graph, to_assign_ops, self._band_slots)
+            fetch_removed_chunk_graph, to_assign_ops, self._band_slots
+        )
         # assign expect workers
-        cur_assigns = {op.key: self._to_band(op.expect_worker)
-                       for op in start_ops if op.expect_worker is not None}
-        logger.debug('Start to assign %s start chunks for task %s',
-                     len(start_ops), self._task.task_id)
+        cur_assigns = {
+            op.key: self._to_band(op.expect_worker)
+            for op in start_ops
+            if op.expect_worker is not None
+        }
+        logger.debug(
+            "Start to assign %s start chunks for task %s",
+            len(start_ops),
+            self._task.task_id,
+        )
         chunk_to_bands = assigner.assign(cur_assigns=cur_assigns)
-        logger.debug('Assigned %s start chunks for task %s',
-                     len(start_ops), self._task.task_id)
+        logger.debug(
+            "Assigned %s start chunks for task %s", len(start_ops), self._task.task_id
+        )
+
+        # assign expect workers for those specified with `expect_worker`
+        # skip `start_ops`, which have been assigned before
+        for chunk in self._chunk_graph:
+            if chunk not in start_ops and chunk.op.expect_worker is not None:
+                chunk_to_bands[chunk] = self._to_band(chunk.op.expect_worker)
 
         # fuse node
         if self._fuse_enabled:
-            logger.debug('Start to fuse chunks for task %s', self._task.task_id)
+            logger.debug("Start to fuse chunks for task %s", self._task.task_id)
             chunk_to_bands = self._fuse(chunk_to_bands)
-            logger.debug('Chunks fused for task %s', self._task.task_id)
+            logger.debug("Chunks fused for task %s", self._task.task_id)
 
         subtask_graph = SubtaskGraph()
         chunk_to_priorities = dict()
@@ -288,17 +328,18 @@ class GraphAnalyzer:
 
             # gen subtask
             subtask = self._gen_subtask(
-                chunk, chunk_to_priorities,
-                chunk_to_bands, chunk_to_fetch_chunk)
+                chunk, chunk_to_priorities, chunk_to_bands, chunk_to_fetch_chunk
+            )
 
             for out in chunk.op.outputs:
                 chunk_to_subtask[out] = subtask
                 visited.add(out)
             subtask_graph.add_node(subtask)
-            inp_subtasks = \
-                [chunk_to_subtask[inp_chunk] for inp_chunk
-                 in self._chunk_graph.predecessors(chunk)
-                 if not isinstance(inp_chunk.op, Fetch)]
+            inp_subtasks = [
+                chunk_to_subtask[inp_chunk]
+                for inp_chunk in self._chunk_graph.predecessors(chunk)
+                if not isinstance(inp_chunk.op, Fetch)
+            ]
             for inp_subtask in inp_subtasks:
                 subtask_graph.add_edge(inp_subtask, subtask)
 
