@@ -37,17 +37,19 @@ from .processor import TaskProcessorActor
 
 
 class TaskConfigurationActor(mo.Actor):
-    def __init__(self,
-                 task_conf: Dict[str, Any],
-                 task_preprocessor_cls: Type[TaskPreprocessor] = None):
+    def __init__(
+        self,
+        task_conf: Dict[str, Any],
+        task_preprocessor_cls: Type[TaskPreprocessor] = None,
+    ):
         for name, value in task_conf.items():
             setattr(task_options, name, value)
         self._task_preprocessor_cls = task_preprocessor_cls
 
     def get_config(self):
         return {
-            'task_options': task_options,
-            'task_preprocessor_cls': self._task_preprocessor_cls
+            "task_options": task_options,
+            "task_preprocessor_cls": self._task_preprocessor_cls,
         }
 
 
@@ -88,18 +90,21 @@ class TaskManagerActor(mo.Actor):
 
     async def __post_create__(self):
         self._cluster_api = await ClusterAPI.create(self.address)
-        self._scheduling_api = await SchedulingAPI.create(self._session_id, self.address)
+        self._scheduling_api = await SchedulingAPI.create(
+            self._session_id, self.address
+        )
         self._meta_api = await MetaAPI.create(self._session_id, self.address)
-        self._lifecycle_api = await LifecycleAPI.create(
-            self._session_id, self.address)
+        self._lifecycle_api = await LifecycleAPI.create(self._session_id, self.address)
 
         # get config
         configuration_ref = await mo.actor_ref(
-            TaskConfigurationActor.default_uid(),
-            address=self.address)
+            TaskConfigurationActor.default_uid(), address=self.address
+        )
         task_conf = await configuration_ref.get_config()
-        self._config, self._task_preprocessor_cls = \
-            task_conf['task_options'], task_conf['task_preprocessor_cls']
+        self._config, self._task_preprocessor_cls = (
+            task_conf["task_options"],
+            task_conf["task_preprocessor_cls"],
+        )
         self._task_preprocessor_cls = self._get_task_preprocessor_cls()
 
         # init context
@@ -112,20 +117,23 @@ class TaskManagerActor(mo.Actor):
     async def _init_context(self):
         loop = asyncio.get_running_loop()
         context = ThreadedServiceContext(
-            self._session_id, self.address, self.address, self.address, loop=loop)
+            self._session_id, self.address, self.address, self.address, loop=loop
+        )
         await context.init()
         set_context(context)
 
     @staticmethod
     def gen_uid(session_id):
-        return f'{session_id}_task_manager'
+        return f"{session_id}_task_manager"
 
     @enter_mode(kernel=True)
-    async def submit_tileable_graph(self,
-                                    graph: TileableGraph,
-                                    task_name: str = None,
-                                    fuse_enabled: bool = None,
-                                    extra_config: dict = None) -> str:
+    async def submit_tileable_graph(
+        self,
+        graph: TileableGraph,
+        task_name: str = None,
+        fuse_enabled: bool = None,
+        extra_config: dict = None,
+    ) -> str:
         self._last_idle_time = None
         if task_name is None:
             # new task without task name
@@ -144,8 +152,13 @@ class TaskManagerActor(mo.Actor):
         if task_name not in self._task_name_to_parent_task_id:
             # gen main task which mean each submission from user
             processor_ref = await mo.create_actor(
-                TaskProcessorActor, self._session_id, parent_task_id,
-                task_name=task_name, address=self.address, uid=uid)
+                TaskProcessorActor,
+                self._session_id,
+                parent_task_id,
+                task_name=task_name,
+                address=self.address,
+                uid=uid,
+            )
             self._task_name_to_parent_task_id[task_name] = parent_task_id
         else:
             processor_ref = await mo.actor_ref(mo.ActorRef(self.address, uid))
@@ -155,19 +168,23 @@ class TaskManagerActor(mo.Actor):
         if fuse_enabled is None:
             fuse_enabled = self._config.fuse_enabled
         # gen task
-        task = Task(task_id, self._session_id,
-                    graph, task_name,
-                    parent_task_id=parent_task_id,
-                    fuse_enabled=fuse_enabled,
-                    extra_config=extra_config)
+        task = Task(
+            task_id,
+            self._session_id,
+            graph,
+            task_name,
+            parent_task_id=parent_task_id,
+            fuse_enabled=fuse_enabled,
+            extra_config=extra_config,
+        )
         # gen task processor
         tiled_context = await self._gen_tiled_context(graph)
         await processor_ref.add_task(
-            task, tiled_context, self._config, self._task_preprocessor_cls)
+            task, tiled_context, self._config, self._task_preprocessor_cls
+        )
 
         for tileable in graph.result_tileables:
-            info = ResultTileableInfo(tileable=tileable,
-                                      processor_ref=processor_ref)
+            info = ResultTileableInfo(tileable=tileable, processor_ref=processor_ref)
             self._tileable_key_to_info[tileable.key].append(info)
 
         return task_id
@@ -176,7 +193,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         res = await processor_ref.get_tileable_graph_as_dict()
         return res
@@ -185,7 +202,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return await processor_ref.get_tileable_details()
 
@@ -193,36 +210,36 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return await processor_ref.get_tileable_subtasks(tileable_id, with_input_output)
 
-    async def _gen_tiled_context(self, graph: TileableGraph) -> \
-            Dict[TileableType, TileableType]:
+    async def _gen_tiled_context(
+        self, graph: TileableGraph
+    ) -> Dict[TileableType, TileableType]:
         # process graph, add fetch node to tiled context
         tiled_context = dict()
         for tileable in graph:
             if isinstance(tileable.op, Fetch) and tileable.is_coarse():
                 info = self._tileable_key_to_info[tileable.key][-1]
-                tiled_context[tileable] = \
-                    await info.processor_ref.get_result_tileable(tileable.key)
+                tiled_context[tileable] = await info.processor_ref.get_result_tileable(
+                    tileable.key
+                )
         return tiled_context
 
     def _get_task_preprocessor_cls(self):
         if self._task_preprocessor_cls is not None:
             assert isinstance(self._task_preprocessor_cls, str)
-            module, name = self._task_preprocessor_cls.rsplit('.', 1)
+            module, name = self._task_preprocessor_cls.rsplit(".", 1)
             return getattr(importlib.import_module(module), name)
         else:
             return TaskPreprocessor
 
-    async def wait_task(self,
-                        task_id: str,
-                        timeout: int = None):
+    async def wait_task(self, task_id: str, timeout: int = None):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return processor_ref.wait(timeout)
 
@@ -230,7 +247,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         yield processor_ref.cancel()
 
@@ -238,9 +255,9 @@ class TaskManagerActor(mo.Actor):
         if not self._task_id_to_processor_ref:
             raise mo.Return([])
 
-        results = yield asyncio.gather(*[
-            ref.result() for ref in self._task_id_to_processor_ref.values()
-        ])
+        results = yield asyncio.gather(
+            *[ref.result() for ref in self._task_id_to_processor_ref.values()]
+        )
 
         if progress:
             task_to_result = {res.task_id: res for res in results}
@@ -252,10 +269,12 @@ class TaskManagerActor(mo.Actor):
                 else:
                     res.progress = 1.0
 
-            progresses = yield asyncio.gather(*[
-                self._task_id_to_processor_ref[task_id].progress()
-                for task_id in progress_task_ids
-            ])
+            progresses = yield asyncio.gather(
+                *[
+                    self._task_id_to_processor_ref[task_id].progress()
+                    for task_id in progress_task_ids
+                ]
+            )
             for task_id, progress in zip(progress_task_ids, progresses):
                 task_to_result[task_id].progress = progress
 
@@ -265,7 +284,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return await processor_ref.result()
 
@@ -273,7 +292,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return await processor_ref.get_result_tileables()
 
@@ -282,7 +301,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         yield processor_ref.set_subtask_result(subtask_result)
 
@@ -291,7 +310,7 @@ class TaskManagerActor(mo.Actor):
         try:
             processor_ref = self._task_id_to_processor_ref[task_id]
         except KeyError:  # pragma: no cover
-            raise TaskNotExist(f'Task {task_id} does not exist')
+            raise TaskNotExist(f"Task {task_id} does not exist")
 
         return await processor_ref.progress()
 
