@@ -34,31 +34,37 @@ logger = logging.getLogger(__name__)
 
 
 class CancellableTiler(Tiler):
-    def __init__(self,
-                 tileable_graph: TileableGraph,
-                 tile_context: Dict[TileableType, TileableType],
-                 processed_chunks: Set[ChunkType],
-                 add_nodes: Callable,
-                 cancelled: asyncio.Event = None):
-        super().__init__(tileable_graph, tile_context,
-                         processed_chunks, add_nodes)
+    def __init__(
+        self,
+        tileable_graph: TileableGraph,
+        tile_context: Dict[TileableType, TileableType],
+        processed_chunks: Set[ChunkType],
+        add_nodes: Callable,
+        cancelled: asyncio.Event = None,
+    ):
+        super().__init__(tileable_graph, tile_context, processed_chunks, add_nodes)
         self._cancelled = cancelled
 
     @property
     def cancelled(self):
         return self._cancelled.is_set()
 
-    def _gen_tileable_handlers(self,
-                               next_tileable_handlers: List[Tuple[TileableType, tile_gen_type]]):
-        for tileable, tile_handler in super()._gen_tileable_handlers(next_tileable_handlers):
+    def _gen_tileable_handlers(
+        self, next_tileable_handlers: List[Tuple[TileableType, tile_gen_type]]
+    ):
+        for tileable, tile_handler in super()._gen_tileable_handlers(
+            next_tileable_handlers
+        ):
             if not self.cancelled:
                 yield tileable, tile_handler
             else:
                 break
 
-    def _gen_result_chunks(self,
-                           chunk_graph: ChunkGraph,
-                           next_tileable_handlers: List[Tuple[TileableType, tile_gen_type]]):
+    def _gen_result_chunks(
+        self,
+        chunk_graph: ChunkGraph,
+        next_tileable_handlers: List[Tuple[TileableType, tile_gen_type]],
+    ):
         if not self.cancelled:
             return super()._gen_result_chunks(chunk_graph, next_tileable_handlers)
         else:
@@ -77,17 +83,25 @@ class CancellableTiler(Tiler):
 
 
 class TaskPreprocessor:
-    __slots__ = '_task', 'tileable_graph', 'tile_context', \
-                '_config', 'tileable_optimization_records', \
-                'chunk_optimization_records_list', \
-                '_cancelled', '_done'
+    __slots__ = (
+        "_task",
+        "tileable_graph",
+        "tile_context",
+        "_config",
+        "tileable_optimization_records",
+        "chunk_optimization_records_list",
+        "_cancelled",
+        "_done",
+    )
 
     tile_context: Dict[TileableType, TileableType]
 
-    def __init__(self,
-                 task: Task,
-                 tiled_context: Dict[TileableType, TileableType] = None,
-                 config: Config = None):
+    def __init__(
+        self,
+        task: Task,
+        tiled_context: Dict[TileableType, TileableType] = None,
+        config: Config = None,
+    ):
         self._task = task
         self.tileable_graph = task.tileable_graph
         self._config = config
@@ -110,8 +124,9 @@ class TaskPreprocessor:
         """
         if self._config.optimize_tileable_graph:
             # enable optimization
-            self.tileable_optimization_records = \
-                optimize_tileable_graph(self.tileable_graph)
+            self.tileable_optimization_records = optimize_tileable_graph(
+                self.tileable_graph
+            )
         return self.tileable_graph
 
     def _fill_fetch_tileable_with_chunks(self, tileable_graph: TileableGraph):
@@ -133,29 +148,35 @@ class TaskPreprocessor:
         self._fill_fetch_tileable_with_chunks(tileable_graph)
         # iterative chunk graph builder
         chunk_graph_builder = ChunkGraphBuilder(
-            tileable_graph, fuse_enabled=self._task.fuse_enabled,
+            tileable_graph,
+            fuse_enabled=self._task.fuse_enabled,
             tile_context=self.tile_context,
-            tiler_cls=partial(CancellableTiler, cancelled=self._cancelled))
+            tiler_cls=partial(CancellableTiler, cancelled=self._cancelled),
+        )
         optimize = self._config.optimize_chunk_graph
         meta_updated = set()
         for chunk_graph in chunk_graph_builder.build():
             # optimize chunk graph
             if optimize:
                 self.chunk_optimization_records_list.append(
-                    optimize_chunk_graph(chunk_graph))
+                    optimize_chunk_graph(chunk_graph)
+                )
             yield chunk_graph
             # update tileables' meta
             self._update_tileables_params(tileable_graph, meta_updated)
 
-    def analyze(self,
-                chunk_graph: ChunkGraph,
-                available_bands: Dict[BandType, int]) -> SubtaskGraph:
-        logger.debug('Start to gen subtask graph for task %s', self._task.task_id)
+    def analyze(
+        self, chunk_graph: ChunkGraph, available_bands: Dict[BandType, int]
+    ) -> SubtaskGraph:
+        logger.debug("Start to gen subtask graph for task %s", self._task.task_id)
         task = self._task
         analyzer = GraphAnalyzer(chunk_graph, available_bands, task)
         graph = analyzer.gen_subtask_graph()
-        logger.debug('Generated subtask graph of %s subtasks for task %s',
-                     len(graph), self._task.task_id)
+        logger.debug(
+            "Generated subtask graph of %s subtasks for task %s",
+            len(graph),
+            self._task.task_id,
+        )
         return graph
 
     def _get_done(self):
@@ -173,18 +194,18 @@ class TaskPreprocessor:
         self._cancelled.set()
 
     def get_tiled(self, tileable: TileableType):
-        tileable = tileable.data if hasattr(tileable, 'data') else tileable
+        tileable = tileable.data if hasattr(tileable, "data") else tileable
         return self.tile_context[tileable]
 
-    def _update_tileable_params(self,  # pylint: disable=no-self-use
-                                tileable: TileableType,
-                                tiled: TileableType):
+    def _update_tileable_params(
+        self, tileable: TileableType, tiled: TileableType  # pylint: disable=no-self-use
+    ):
         tiled.refresh_params()
         tileable.params = tiled.params
 
-    def _update_tileables_params(self,
-                                 tileable_graph: TileableGraph,
-                                 updated: Set[TileableType]):
+    def _update_tileables_params(
+        self, tileable_graph: TileableGraph, updated: Set[TileableType]
+    ):
         for tileable in tileable_graph:
             if tileable in updated:
                 continue
