@@ -16,18 +16,24 @@ import asyncio
 import itertools
 import logging
 import operator
+import os
 import sys
+import tempfile
 import time
 from collections import defaultdict
 from functools import reduce, wraps
-from typing import Callable, Coroutine, Dict, Iterator, \
-    List, Optional, Set, Type, Union
+from typing import Callable, Coroutine, Dict, Iterator, List, Optional, Set, Type, Union
 
 from .... import oscar as mo
 from ....config import Config
 from ....core import ChunkGraph, TileableGraph
-from ....core.operand import Fetch, FetchShuffle, MapReduceOperand, \
-    ShuffleProxy, OperandStage
+from ....core.operand import (
+    Fetch,
+    FetchShuffle,
+    MapReduceOperand,
+    ShuffleProxy,
+    OperandStage,
+)
 from ....optimization.logical import OptimizationRecords
 from ....typing import TileableType, BandType
 from ....utils import build_fetch
@@ -42,8 +48,10 @@ from .stage import TaskStageProcessor
 
 logger = logging.getLogger(__name__)
 
+MARS_ENABLE_DUMPING_SUBTASK_GRAPH = int(os.environ.get("MARS_DUMP_SUBTASK_GRAPH", 0))
 
-def _record_error(func: Union[Callable, Coroutine]=None, log_when_error=True):
+
+def _record_error(func: Union[Callable, Coroutine] = None, log_when_error=True):
     assert asyncio.iscoroutinefunction(func)
 
     @wraps(func)
@@ -52,7 +60,7 @@ def _record_error(func: Union[Callable, Coroutine]=None, log_when_error=True):
             return await func(processor, *args, **kwargs)
         except:  # noqa: E722  # nosec  # pylint: disable=bare-except  # pragma: no cover
             if log_when_error:
-                logger.exception('Unexpected error happens in %s', func)
+                logger.exception("Unexpected error happens in %s", func)
             processor._err_infos.append(sys.exc_info())
             raise
 
@@ -63,14 +71,16 @@ class TaskProcessor:
     stage_processors: List[TaskStageProcessor]
     cur_stage_processor: Optional[TaskStageProcessor]
 
-    def __init__(self,
-                 task: Task,
-                 preprocessor: TaskPreprocessor,
-                 # APIs
-                 cluster_api: ClusterAPI,
-                 lifecycle_api: LifecycleAPI,
-                 scheduling_api: SchedulingAPI,
-                 meta_api: MetaAPI):
+    def __init__(
+        self,
+        task: Task,
+        preprocessor: TaskPreprocessor,
+        # APIs
+        cluster_api: ClusterAPI,
+        lifecycle_api: LifecycleAPI,
+        scheduling_api: SchedulingAPI,
+        meta_api: MetaAPI,
+    ):
         self._task = task
         self._preprocessor = preprocessor
 
@@ -80,9 +90,18 @@ class TaskProcessor:
         self._scheduling_api = scheduling_api
         self._meta_api = meta_api
 
+        self._dump_subtask_graph = False
+        if MARS_ENABLE_DUMPING_SUBTASK_GRAPH or (
+            task.extra_config and task.extra_config.get("dump_subtask_graph")
+        ):
+            self._dump_subtask_graph = True
+
         self.result = TaskResult(
-            task_id=task.task_id, session_id=task.session_id, start_time=time.time(),
-            status=TaskStatus.pending)
+            task_id=task.task_id,
+            session_id=task.session_id,
+            start_time=time.time(),
+            status=TaskStatus.pending,
+        )
         self.done = asyncio.Event()
         self.stage_processors = []
         self.cur_stage_processor = None
@@ -92,6 +111,10 @@ class TaskProcessor:
         self._raw_tile_context = preprocessor.tile_context.copy()
         self._lifecycle_processed_tileables = set()
 
+    @property
+    def task_id(self):
+        return self._task.task_id
+
     @property
     def preprocessor(self):
         return self._preprocessor
@@ -117,15 +140,19 @@ class TaskProcessor:
     async def incref_fetch_tileables(self):
         # incref fetch tileables in tileable graph to prevent them from deleting
         to_incref_tileable_keys = [
-            tileable.op.source_key for tileable in self.tileable_graph
-            if isinstance(tileable.op, Fetch) and tileable in self._raw_tile_context]
+            tileable.op.source_key
+            for tileable in self.tileable_graph
+            if isinstance(tileable.op, Fetch) and tileable in self._raw_tile_context
+        ]
         await self._lifecycle_api.incref_tileables(to_incref_tileable_keys)
 
     @_record_error
     async def decref_fetch_tileables(self):
         fetch_tileable_keys = [
-            tileable.op.source_key for tileable in self.tileable_graph
-            if isinstance(tileable.op, Fetch) and tileable in self._raw_tile_context]
+            tileable.op.source_key
+            for tileable in self.tileable_graph
+            if isinstance(tileable.op, Fetch) and tileable in self._raw_tile_context
+        ]
         await self._lifecycle_api.decref_tileables(fetch_tileable_keys)
 
     @_record_error
@@ -139,8 +166,11 @@ class TaskProcessor:
             try:
                 tiled_tileable = self._preprocessor.get_tiled(result_tileable)
                 tracks[0].append(result_tileable.key)
-                tracks[1].append(self._lifecycle_api.track.delay(
-                    result_tileable.key, [c.key for c in tiled_tileable.chunks]))
+                tracks[1].append(
+                    self._lifecycle_api.track.delay(
+                        result_tileable.key, [c.key for c in tiled_tileable.chunks]
+                    )
+                )
                 processed.add(result_tileable)
             except KeyError:
                 # not tiled, skip
@@ -152,7 +182,8 @@ class TaskProcessor:
     @_record_error
     async def decref_result_tileables(self):
         await self._lifecycle_api.decref_tileables(
-            [t.key for t in self._lifecycle_processed_tileables])
+            [t.key for t in self._lifecycle_processed_tileables]
+        )
 
     @_record_error
     async def incref_stage(self, stage_processor: "TaskStageProcessor"):
@@ -166,8 +197,10 @@ class TaskProcessor:
             # process reducer, since mapper will generate sub keys
             # we incref (main_key, sub_key) for reducer
             for chunk in subtask.chunk_graph:
-                if isinstance(chunk.op, MapReduceOperand) and \
-                        chunk.op.stage == OperandStage.reduce:
+                if (
+                    isinstance(chunk.op, MapReduceOperand)
+                    and chunk.op.stage == OperandStage.reduce
+                ):
                     # reducer
                     data_keys = chunk.op.get_dependent_data_keys()
                     incref_chunk_keys.extend(data_keys)
@@ -175,11 +208,13 @@ class TaskProcessor:
                     incref_chunk_keys.extend([key[0] for key in data_keys])
         result_chunks = stage_processor.chunk_graph.result_chunks
         incref_chunk_keys.extend([c.key for c in result_chunks])
+        logger.debug("Incref chunks %s for stage", incref_chunk_keys)
         await self._lifecycle_api.incref_chunks(incref_chunk_keys)
 
     @classmethod
-    def _get_decref_stage_chunk_keys(cls,
-                                     stage_processor: "TaskStageProcessor") -> List[str]:
+    def _get_decref_stage_chunk_keys(
+        cls, stage_processor: "TaskStageProcessor"
+    ) -> List[str]:
         decref_chunk_keys = []
         error_or_cancelled = stage_processor.error_or_cancelled()
         if stage_processor.subtask_graph:
@@ -187,8 +222,9 @@ class TaskProcessor:
             if error_or_cancelled:
                 # error or cancel, rollback incref for subtask results
                 for subtask in subtask_graph:
-                    if stage_processor.subtask_results.get(subtask):
+                    if subtask.subtask_id in stage_processor.decref_subtask:
                         continue
+                    stage_processor.decref_subtask.add(subtask.subtask_id)
                     # if subtask not executed, rollback incref of predecessors
                     for inp_subtask in subtask_graph.predecessors(subtask):
                         for result_chunk in inp_subtask.chunk_graph.results:
@@ -199,18 +235,26 @@ class TaskProcessor:
                                         data_keys = chunk.op.get_dependent_data_keys()
                                         decref_chunk_keys.extend(data_keys)
                                         decref_chunk_keys.extend(
-                                            [key[0] for key in data_keys])
+                                            [key[0] for key in data_keys]
+                                        )
                         decref_chunk_keys.extend(
-                            [c.key for c in inp_subtask.chunk_graph.results])
+                            [c.key for c in inp_subtask.chunk_graph.results]
+                        )
             # decref result of chunk graphs
             decref_chunk_keys.extend(
-                [c.key for c in stage_processor.chunk_graph.results])
+                [c.key for c in stage_processor.chunk_graph.results]
+            )
         return decref_chunk_keys
 
     @mo.extensible
     @_record_error
     async def decref_stage(self, stage_processor: "TaskStageProcessor"):
         decref_chunk_keys = self._get_decref_stage_chunk_keys(stage_processor)
+        logger.debug(
+            "Decref chunks %s when stage %s finish",
+            decref_chunk_keys,
+            stage_processor.stage_id,
+        )
         await self._lifecycle_api.decref_chunks(decref_chunk_keys)
 
     @decref_stage.batch
@@ -218,13 +262,13 @@ class TaskProcessor:
     async def decref_stage(self, args_list, kwargs_list):
         decref_chunk_keys = []
         for args, kwargs in zip(args_list, kwargs_list):
-            decref_chunk_keys.extend(
-                self._get_decref_stage_chunk_keys(*args, **kwargs))
+            decref_chunk_keys.extend(self._get_decref_stage_chunk_keys(*args, **kwargs))
+        logger.debug("Decref chunks %s when stage finish", decref_chunk_keys)
         await self._lifecycle_api.decref_chunks(decref_chunk_keys)
 
-    async def _get_next_chunk_graph(self,
-                                    chunk_graph_iter: Iterator[ChunkGraph]) \
-            -> Optional[ChunkGraph]:
+    async def _get_next_chunk_graph(
+        self, chunk_graph_iter: Iterator[ChunkGraph]
+    ) -> Optional[ChunkGraph]:
         def next_chunk_graph():
             try:
                 return next(chunk_graph_iter)
@@ -257,8 +301,9 @@ class TaskProcessor:
 
         return tileable_id_to_tileable
 
-    def _get_tileable_to_subtasks(self, subtask_graph: SubtaskGraph) \
-            -> Dict[TileableType, List[Subtask]]:
+    def _get_tileable_to_subtasks(
+        self, subtask_graph: SubtaskGraph
+    ) -> Dict[TileableType, List[Subtask]]:
         tileable_to_chunks = defaultdict(set)
         chunk_to_subtasks = dict()
 
@@ -277,23 +322,26 @@ class TaskProcessor:
             for chunk in subtask.chunk_graph:
                 # for every non-fuse chunks (including fused),
                 # register subtasks if needed
-                if isinstance(chunk.op, (FetchShuffle, Fetch)) or \
-                        chunk.key not in chunk_to_subtasks:
+                if (
+                    isinstance(chunk.op, (FetchShuffle, Fetch))
+                    or chunk.key not in chunk_to_subtasks
+                ):
                     continue
                 chunk_to_subtasks[chunk.key].add(subtask)
 
         tileable_to_subtasks = dict()
         # collect subtasks for tileables
         for tileable, chunk_keys in tileable_to_chunks.items():
-            tileable_to_subtasks[tileable] = list(reduce(
-                operator.or_,
-                [chunk_to_subtasks[chunk_key] for chunk_key in chunk_keys]
-            ))
+            tileable_to_subtasks[tileable] = list(
+                reduce(
+                    operator.or_,
+                    [chunk_to_subtasks[chunk_key] for chunk_key in chunk_keys],
+                )
+            )
         return tileable_to_subtasks
 
     @_record_error
-    async def get_next_stage_processor(self) \
-            -> Optional[TaskStageProcessor]:
+    async def get_next_stage_processor(self) -> Optional[TaskStageProcessor]:
         tileable_graph = self._preprocessor.tileable_graph
         self._init_chunk_graph_iter(tileable_graph)
 
@@ -306,18 +354,26 @@ class TaskProcessor:
         # gen subtask graph
         available_bands = await self._get_available_band_slots()
         subtask_graph = await asyncio.to_thread(
-            self._preprocessor.analyze, chunk_graph, available_bands)
+            self._preprocessor.analyze, chunk_graph, available_bands
+        )
         tileable_to_subtasks = await asyncio.to_thread(
-            self._get_tileable_to_subtasks, subtask_graph)
+            self._get_tileable_to_subtasks, subtask_graph
+        )
         tileable_id_to_tileable = await asyncio.to_thread(
             self._get_tileable_id_to_tileable
         )
         stage_processor = TaskStageProcessor(
-            new_task_id(), self._task, chunk_graph, subtask_graph,
-            list(available_bands), tileable_to_subtasks,
+            new_task_id(),
+            self._task,
+            chunk_graph,
+            subtask_graph,
+            list(available_bands),
+            tileable_to_subtasks,
             tileable_id_to_tileable,
             self._get_chunk_optimization_records(),
-            self._scheduling_api, self._meta_api)
+            self._scheduling_api,
+            self._meta_api,
+        )
         return stage_processor
 
     @_record_error
@@ -338,8 +394,31 @@ class TaskProcessor:
             self.result.error = err
             self.result.traceback = tb
 
+    def dump_subtask_graph(self):
+        from .graph_visualizer import GraphVisualizer
+
+        try:  # pragma: no cover
+            import graphviz
+        except ImportError:
+            graphviz = None
+
+        dot = GraphVisualizer(self).to_dot()
+        directory = tempfile.gettempdir()
+        file_name = f"mars-{self.task_id}"
+        logger.debug(
+            "subtask graph is stored in %s", os.path.join(directory, file_name)
+        )
+        if graphviz is not None:  # pragma: no cover
+            g = graphviz.Source(dot)
+            g.view(file_name, directory=directory)
+        else:
+            with open(os.path.join(directory, file_name), "w") as f:
+                f.write(dot)
+
     def finish(self):
         self.done.set()
+        if self._dump_subtask_graph:
+            self.dump_subtask_graph()
 
     def is_done(self) -> bool:
         return self.done.is_set()
@@ -350,10 +429,7 @@ class TaskProcessorActor(mo.Actor):
     _processed_task_ids: Set[str]
     _cur_processor: Optional[TaskProcessor]
 
-    def __init__(self,
-                 session_id: str,
-                 task_id: str,
-                 task_name: str = None):
+    def __init__(self, session_id: str, task_id: str, task_name: str = None):
         self.session_id = session_id
         self.task_id = task_id
         self.task_name = task_name
@@ -371,23 +447,30 @@ class TaskProcessorActor(mo.Actor):
         self._cluster_api = await ClusterAPI.create(self.address)
         self._scheduling_api = await SchedulingAPI.create(self.session_id, self.address)
         self._meta_api = await MetaAPI.create(self.session_id, self.address)
-        self._lifecycle_api = await LifecycleAPI.create(
-            self.session_id, self.address)
+        self._lifecycle_api = await LifecycleAPI.create(self.session_id, self.address)
 
     @classmethod
     def gen_uid(cls, session_id: str, task_id: str):
-        return f'task_processor_{session_id}_{task_id}'
+        return f"task_processor_{session_id}_{task_id}"
 
-    async def add_task(self,
-                       task: Task,
-                       tiled_context: Dict[TileableType, TileableType],
-                       config: Config,
-                       task_preprocessor_cls: Type[TaskPreprocessor]):
+    async def add_task(
+        self,
+        task: Task,
+        tiled_context: Dict[TileableType, TileableType],
+        config: Config,
+        task_preprocessor_cls: Type[TaskPreprocessor],
+    ):
         task_preprocessor = task_preprocessor_cls(
-            task, tiled_context=tiled_context, config=config)
-        processor = TaskProcessor(task, task_preprocessor,
-                                  self._cluster_api, self._lifecycle_api,
-                                  self._scheduling_api, self._meta_api)
+            task, tiled_context=tiled_context, config=config
+        )
+        processor = TaskProcessor(
+            task,
+            task_preprocessor,
+            self._cluster_api,
+            self._lifecycle_api,
+            self._scheduling_api,
+            self._meta_api,
+        )
         self._task_id_to_processor[task.task_id] = processor
 
         # tell self to start running
@@ -454,12 +537,15 @@ class TaskProcessorActor(mo.Actor):
                 self._cur_processor = None
 
     async def wait(self, timeout: int = None):
-        fs = [processor.done.wait() for processor
-              in self._task_id_to_processor.values()]
+        fs = [
+            processor.done.wait() for processor in self._task_id_to_processor.values()
+        ]
 
         _, pending = yield asyncio.wait(fs, timeout=timeout)
         if not pending:
             raise mo.Return(self.result())
+        else:
+            [fut.cancel() for fut in pending]
 
     async def cancel(self):
         if self._cur_processor:
@@ -494,8 +580,11 @@ class TaskProcessorActor(mo.Actor):
         subtask_progress = 0.0
         n_stage = 0
         stage_processors = itertools.chain(
-            *(processor.stage_processors for processor
-              in self._task_id_to_processor.values()))
+            *(
+                processor.stage_processors
+                for processor in self._task_id_to_processor.values()
+            )
+        )
         for stage_processor in stage_processors:
             if stage_processor.subtask_graph is None:  # pragma: no cover
                 # generating subtask
@@ -503,11 +592,14 @@ class TaskProcessorActor(mo.Actor):
             n_subtask = len(stage_processor.subtask_graph)
             if n_subtask == 0:  # pragma: no cover
                 continue
-            progress = sum(result.progress for result
-                           in stage_processor.subtask_results.values())
-            progress += sum(result.progress for subtask_key, result
-                            in stage_processor.subtask_snapshots.items()
-                            if subtask_key not in stage_processor.subtask_results)
+            progress = sum(
+                result.progress for result in stage_processor.subtask_results.values()
+            )
+            progress += sum(
+                result.progress
+                for subtask_key, result in stage_processor.subtask_snapshots.items()
+                if subtask_key not in stage_processor.subtask_results
+            )
             subtask_progress += progress / n_subtask
             n_stage += 1
         if n_stage > 0:
@@ -540,23 +632,19 @@ class TaskProcessorActor(mo.Actor):
 
             node_name = str(chunk.op)
 
-            node_list.append({
-                'tileableId': chunk.key,
-                'tileableName': node_name
-            })
+            node_list.append({"tileableId": chunk.key, "tileableName": node_name})
             for inp, is_pure_dep in zip(chunk.inputs, chunk.op.pure_depends):
                 if inp not in tileable_graph:  # pragma: no cover
                     continue
-                edge_list.append({
-                    'fromTileableId': inp.key,
-                    'toTileableId': chunk.key,
-                    'linkType': 1 if is_pure_dep else 0,
-                })
+                edge_list.append(
+                    {
+                        "fromTileableId": inp.key,
+                        "toTileableId": chunk.key,
+                        "linkType": 1 if is_pure_dep else 0,
+                    }
+                )
 
-        graph_dict = {
-            'tileables': node_list,
-            'dependencies': edge_list
-        }
+        graph_dict = {"tileables": node_list, "dependencies": edge_list}
         return graph_dict
 
     def get_tileable_details(self):
@@ -577,14 +665,18 @@ class TaskProcessorActor(mo.Actor):
 
         tileable_infos = dict()
         for tileable, subtasks in tileable_to_subtasks.items():
-            results = [subtask_results.get(subtask.subtask_id, default_result)
-                       for subtask in subtasks]
+            results = [
+                subtask_results.get(subtask.subtask_id, default_result)
+                for subtask in subtasks
+            ]
 
             # calc progress
             if not results:  # pragma: no cover
                 progress = 1.0
             else:
-                progress = 1.0 * sum(result.progress for result in results) / len(results)
+                progress = (
+                    1.0 * sum(result.progress for result in results) / len(results)
+                )
 
             # calc status
             statuses = set(result.status for result in results)
@@ -599,15 +691,17 @@ class TaskProcessorActor(mo.Actor):
             else:
                 status = SubtaskStatus.running
 
-            props = {slot: getattr(tileable, slot, None) for slot in tileable.__slots__}
-            props = {k: v for k, v in props.get('_FIELD_VALUES').items()
-                     if k != 'key' and isinstance(v, (int, float, str))}
+            props = {
+                k: v
+                for k, v in getattr(tileable.op, "_FIELD_VALUES").items()
+                if k != "key" and isinstance(v, (int, float, str))
+            }
 
             tileable_infos[tileable.key] = {
-                'progress': progress,
-                'subtaskCount': len(results),
-                'status': status.value,
-                'properties': props,
+                "progress": progress,
+                "subtaskCount": len(results),
+                "status": status.value,
+                "properties": props,
             }
 
         return tileable_infos
@@ -644,22 +738,22 @@ class TaskProcessorActor(mo.Actor):
                     if pred.subtask_id in returned_subtasks:  # pragma: no cover
                         continue
                     returned_subtasks[pred.subtask_id] = pred
-                    subtask_id_to_types[pred.subtask_id] = 'Input'
+                    subtask_id_to_types[pred.subtask_id] = "Input"
                 for succ in subtask_graph.iter_successors(subtask):
                     if succ.subtask_id in returned_subtasks:  # pragma: no cover
                         continue
                     returned_subtasks[succ.subtask_id] = succ
-                    subtask_id_to_types[succ.subtask_id] = 'Output'
+                    subtask_id_to_types[succ.subtask_id] = "Output"
 
         for subtask in returned_subtasks.values():
             subtask_result = subtask_results.get(
                 subtask, subtask_snapshots.get(subtask, default_result)
             )
             subtask_details[subtask.subtask_id] = {
-                'name': subtask.subtask_name,
-                'status': subtask_result.status.value,
-                'progress': subtask_result.progress,
-                'nodeType': subtask_id_to_types.get(subtask.subtask_id, 'Calculation'),
+                "name": subtask.subtask_name,
+                "status": subtask_result.status.value,
+                "progress": subtask_result.progress,
+                "nodeType": subtask_id_to_types.get(subtask.subtask_id, "Calculation"),
             }
 
         for subtask in returned_subtasks.values():
@@ -667,7 +761,7 @@ class TaskProcessorActor(mo.Actor):
             for pred in subtask_graph.iter_predecessors(subtask):
                 if pred.subtask_id in returned_subtasks:
                     pred_ids.append(pred.subtask_id)
-            subtask_details[subtask.subtask_id]['fromSubtaskIds'] = pred_ids
+            subtask_details[subtask.subtask_id]["fromSubtaskIds"] = pred_ids
         return subtask_details
 
     def get_result_tileable(self, tileable_key: str):
@@ -677,11 +771,11 @@ class TaskProcessorActor(mo.Actor):
             if result_tileable.key == tileable_key:
                 tiled = processor.get_tiled(result_tileable)
                 return build_fetch(tiled)
-        raise KeyError(f'Tileable {tileable_key} does not exist')  # pragma: no cover
+        raise KeyError(f"Tileable {tileable_key} does not exist")  # pragma: no cover
 
-    async def _decref_input_subtasks(self,
-                                     subtask: Subtask,
-                                     subtask_graph: SubtaskGraph):
+    async def _decref_input_subtasks(
+        self, subtask: Subtask, subtask_graph: SubtaskGraph
+    ):
         # make sure subtasks are decreffed only once
         if subtask.subtask_id not in self._subtask_decref_events:
             self._subtask_decref_events[subtask.subtask_id] = asyncio.Event()
@@ -695,15 +789,29 @@ class TaskProcessorActor(mo.Actor):
                 # for reducer chunk, decref mapper chunks
                 if isinstance(result_chunk.op, ShuffleProxy):
                     for chunk in subtask.chunk_graph:
-                        if isinstance(chunk.op, MapReduceOperand) and \
-                                chunk.op.stage == OperandStage.reduce:
+                        if (
+                            isinstance(chunk.op, MapReduceOperand)
+                            and chunk.op.stage == OperandStage.reduce
+                        ):
                             data_keys = chunk.op.get_dependent_data_keys()
                             decref_chunk_keys.extend(data_keys)
                             # decref main key as well
                             decref_chunk_keys.extend([key[0] for key in data_keys])
                 decref_chunk_keys.append(result_chunk.key)
+        logger.debug(
+            "Decref chunks %s when subtask %s finish",
+            decref_chunk_keys,
+            subtask.subtask_id,
+        )
         await self._lifecycle_api.decref_chunks(decref_chunk_keys)
-        self._subtask_decref_events.pop(subtask.subtask_id).set()
+
+        # `set_subtask_result` will be called when subtask finished
+        # but report progress will call set_subtask_result too,
+        # so it have risk to duplicate decrease some subtask input object reference,
+        # it will cause object reference count lower zero
+        # TODO(Catch-Bull): Pop asyncio.Event when current subtask `set_subtask_result`
+        # will never be called
+        self._subtask_decref_events[subtask.subtask_id].set()
 
     async def set_subtask_result(self, subtask_result: SubtaskResult):
         stage_processor = self._cur_processor.cur_stage_processor
@@ -714,18 +822,31 @@ class TaskProcessorActor(mo.Actor):
             # set before
             return
 
-        stage_processor.subtask_snapshots[subtask] = subtask_result.merge_bands(
+        stage_processor.subtask_snapshots[subtask] = subtask_result.update(
             stage_processor.subtask_snapshots.get(subtask)
         )
         if subtask_result.status.is_done:
+            # update stage_processor.subtask_results to avoid concurrent set_subtask_result
+            # since we release lock when `_decref_input_subtasks`.
+            stage_processor.subtask_results[subtask] = subtask_result.update(
+                stage_processor.subtask_results.get(subtask)
+            )
             try:
                 # Since every worker will call supervisor to set subtask result,
                 # we need to release actor lock to make `decref_chunks` parallel to avoid blocking
                 # other `set_subtask_result` calls.
-                yield self._decref_input_subtasks(subtask, stage_processor.subtask_graph)
+                if subtask.subtask_id not in stage_processor.decref_subtask:
+                    stage_processor.decref_subtask.add(subtask.subtask_id)
+                    yield self._decref_input_subtasks(
+                        subtask, stage_processor.subtask_graph
+                    )
+
             except:  # noqa: E722  # nosec  # pylint: disable=bare-except  # pragma: no cover
                 _, err, tb = sys.exc_info()
-                if subtask_result.status not in (SubtaskStatus.errored, SubtaskStatus.cancelled):
+                if subtask_result.status not in (
+                    SubtaskStatus.errored,
+                    SubtaskStatus.cancelled,
+                ):
                     subtask_result.status = SubtaskStatus.errored
                     subtask_result.error = err
                     subtask_result.traceback = tb
