@@ -20,19 +20,20 @@ import re
 import sys
 import urllib.parse
 from collections import defaultdict
-from typing import Callable, Dict, List, NamedTuple, Optional, Union
+from typing import Callable, Dict, List, NamedTuple, Optional, Type, Union
 
 from tornado import httpclient, web
-from tornado.simple_httpclient import HTTPTimeoutError
+from tornado.simple_httpclient import HTTPRequest, HTTPTimeoutError
 
+from ...lib.aio import alru_cache
 from ...utils import serialize_serializable, deserialize_serializable
 
 if sys.version_info[:2] == (3, 6):
     # make sure typing works
-    re.Pattern = type(re.compile(r'.*'))
+    re.Pattern = type(re.compile(r".*"))
 
 logger = logging.getLogger(__name__)
-_ROOT_PLACEHOLDER = 'ROOT_PLACEHOLDER'
+_ROOT_PLACEHOLDER = "ROOT_PLACEHOLDER"
 
 
 class MarsRequestHandler(web.RequestHandler):  # pragma: no cover
@@ -47,10 +48,11 @@ class _WebApiDef(NamedTuple):
     arg_filter: Optional[Dict] = None
 
 
-def web_api(sub_pattern: str, method: Union[str, List[str]],
-            arg_filter: Optional[Dict] = None):
-    if not sub_pattern.endswith('$'):  # pragma: no branch
-        sub_pattern += '$'
+def web_api(
+    sub_pattern: str, method: Union[str, List[str]], arg_filter: Optional[Dict] = None
+):
+    if not sub_pattern.endswith("$"):  # pragma: no branch
+        sub_pattern += "$"
     methods = method if isinstance(method, list) else [method]
 
     def wrapper(func):
@@ -63,8 +65,10 @@ def web_api(sub_pattern: str, method: Union[str, List[str]],
                 return res
             except:  # noqa: E722  # nosec  # pylint: disable=bare-except
                 exc_type, exc, tb = sys.exc_info()
-                err_msg = f'{exc_type.__name__} when handling request with ' \
-                          f'{type(self).__name__}.{func.__name__}'
+                err_msg = (
+                    f"{exc_type.__name__} when handling request with "
+                    f"{type(self).__name__}.{func.__name__}"
+                )
                 logger.exception(err_msg)
                 self.write(serialize_serializable((exc, tb)))
                 self.set_status(500, err_msg)
@@ -78,6 +82,25 @@ def web_api(sub_pattern: str, method: Union[str, List[str]],
     return wrapper
 
 
+@alru_cache(cache_exceptions=False)
+async def _get_cluster_api(address: str):
+    from ..cluster import ClusterAPI
+
+    return await ClusterAPI.create(address)
+
+
+@alru_cache(cache_exceptions=False)
+async def _get_api_by_key(
+    api_cls: Type, session_id: str, address: str, with_key_arg: bool = True
+):
+    cluster_api = await _get_cluster_api(address)
+    [address] = await cluster_api.get_supervisors_by_keys([session_id])
+    if with_key_arg:
+        return await api_cls.create(session_id, address)
+    else:
+        return await api_cls.create(address)
+
+
 class MarsServiceWebAPIHandler(MarsRequestHandler):
     _root_pattern = None
     _method_to_handlers = None
@@ -86,6 +109,16 @@ class MarsServiceWebAPIHandler(MarsRequestHandler):
         self._collect_services()
         super().__init__(*args, **kwargs)
 
+    def _get_api_by_key(
+        self, api_cls: Type, session_id: str, with_key_arg: bool = True
+    ):
+        return _get_api_by_key(
+            api_cls,
+            session_id,
+            address=self._supervisor_addr,
+            with_key_arg=with_key_arg,
+        )
+
     @classmethod
     def _collect_services(cls):
         if cls._method_to_handlers is not None:
@@ -94,26 +127,35 @@ class MarsServiceWebAPIHandler(MarsRequestHandler):
         cls._method_to_handlers = defaultdict(dict)
         for attr in dir(cls):
             handle_func = getattr(cls, attr, None)
-            if not hasattr(handle_func, '_web_api_defs'):
+            if not hasattr(handle_func, "_web_api_defs"):
                 continue
-            web_api_defs = getattr(handle_func, '_web_api_defs')  # type: List[_WebApiDef]
+            web_api_defs = getattr(
+                handle_func, "_web_api_defs"
+            )  # type: List[_WebApiDef]
             for api_def in web_api_defs:
                 cls._method_to_handlers[api_def.method.lower()][handle_func] = api_def
 
+    def prepare(self):
+        self.set_header("Content-Type", "application/octet-stream")
+
     @classmethod
     def get_root_pattern(cls):
-        return cls._root_pattern + '(?:/(?P<sub_path>.*)$|$)'
+        return cls._root_pattern + "(?:/(?P<sub_path>.*)$|$)"
 
     @functools.lru_cache(100)
     def _route_sub_path(self, http_method: str, sub_path: str):
-        handlers = self._method_to_handlers[http_method.lower()]  # type: Dict[Callable, _WebApiDef]
+        handlers = self._method_to_handlers[
+            http_method.lower()
+        ]  # type: Dict[Callable, _WebApiDef]
         method, kwargs = None, None
         for handler_method, web_api_def in handlers.items():
             match = web_api_def.sub_pattern_compiled.match(sub_path)
             if match is not None:
                 if web_api_def.arg_filter is not None:
-                    if not all(self.get_argument(k, None) == v
-                               for k, v in web_api_def.arg_filter.items()):
+                    if not all(
+                        self.get_argument(k, None) == v
+                        for k, v in web_api_def.arg_filter.items()
+                    ):
                         continue
                     method, kwargs = handler_method, dict(match.groupdict())
                 elif method is None:
@@ -122,15 +164,18 @@ class MarsServiceWebAPIHandler(MarsRequestHandler):
         if method is not None:
             return method, kwargs
         else:
-            raise web.HTTPError(404, f'{sub_path} does not match any defined APIs '
-                                f'with method {http_method.upper()}')
+            raise web.HTTPError(
+                404,
+                f"{sub_path} does not match any defined APIs "
+                f"with method {http_method.upper()}",
+            )
 
     def _make_handle_http_method(http_method: str):
         async def _handle_http_method(self: "MarsServiceWebAPIHandler", **kwargs):
             # make sure results from APIs is not stored
-            self.add_header('Cache-Control', 'no-store')
+            self.add_header("Cache-Control", "no-store")
 
-            sub_path = kwargs.pop('sub_path', None) or ''
+            sub_path = kwargs.pop("sub_path", None) or ""
             method, kw = self._route_sub_path(http_method, sub_path)
             kw.update(kwargs)
             res = method(self, **kw)
@@ -140,11 +185,11 @@ class MarsServiceWebAPIHandler(MarsRequestHandler):
         _handle_http_method.__name__ = http_method.lower()
         return _handle_http_method
 
-    get = _make_handle_http_method('get')
-    put = _make_handle_http_method('put')
-    post = _make_handle_http_method('post')
-    patch = _make_handle_http_method('patch')
-    delete = _make_handle_http_method('delete')
+    get = _make_handle_http_method("get")
+    put = _make_handle_http_method("put")
+    post = _make_handle_http_method("post")
+    patch = _make_handle_http_method("patch")
+    delete = _make_handle_http_method("delete")
 
     del _make_handle_http_method
 
@@ -158,28 +203,38 @@ class MarsWebAPIClientMixin:
             self._client_obj = httpclient.AsyncHTTPClient()
             return self._client_obj
 
+    @property
+    def request_rewriter(self) -> Callable:
+        return getattr(self, "_request_rewriter", None)
+
+    @request_rewriter.setter
+    def request_rewriter(self, value: Callable):
+        self._request_rewriter = value
+
     def __del__(self):
-        if hasattr(self, '_client_obj'):
+        if hasattr(self, "_client_obj"):
             self._client_obj.close()
 
     async def _request_url(self, method, path, **kwargs):
         self._running_loop = asyncio.get_running_loop()
 
-        if 'data' in kwargs:
-            kwargs['body'] = kwargs.pop('data')
+        if "data" in kwargs:
+            kwargs["body"] = kwargs.pop("data")
 
-        if 'params' in kwargs:
-            params = kwargs.pop('params')
+        if "params" in kwargs:
+            params = kwargs.pop("params")
             for k, v in params.items():
                 if isinstance(v, (list, tuple, set)):
-                    params[k] = ','.join(str(i) for i in v)
+                    params[k] = ",".join(str(i) for i in v)
             url_params = urllib.parse.urlencode(params)
-            path_connector = '?' if '?' not in path else '&'
+            path_connector = "?" if "?" not in path else "&"
             path += path_connector + url_params
 
         try:
-            res = await self._client.fetch(
-                path, method=method, raise_error=False, **kwargs)
+            request = HTTPRequest(path, method=method, **kwargs)
+            if self.request_rewriter:
+                request = self.request_rewriter(request)
+            res = await self._client.fetch(request, raise_error=False)
         except HTTPTimeoutError as ex:
             raise TimeoutError(str(ex)) from None
 
