@@ -22,10 +22,10 @@ from .core import TensorBinOp
 from .utils import arithmetic_operand
 
 
-@arithmetic_operand(sparse_mode='binary_or')
+@arithmetic_operand(sparse_mode="binary_or")
 class TensorBitand(TensorBinOp):
     _op_type_ = OperandDef.BITAND
-    _func_name = 'bitwise_and'
+    _func_name = "bitwise_and"
 
 
 @infer_dtype(np.bitwise_and)
