@@ -14,17 +14,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import numpy as np
+
 from ... import opcodes as OperandDef
+from ..utils import infer_dtype
 from .core import TensorUnaryOp
 from .utils import arithmetic_operand
 
 
-@arithmetic_operand(sparse_mode='unary')
+@arithmetic_operand(sparse_mode="unary")
 class TensorFabs(TensorUnaryOp):
     _op_type_ = OperandDef.FABS
-    _func_name = 'fabs'
+    _func_name = "fabs"
 
 
+@infer_dtype(np.fabs)
 def fabs(x, out=None, where=None, **kwargs):
     """
     Compute the absolute values element-wise.
