@@ -22,10 +22,10 @@ from .core import TensorUnaryOp
 from .utils import arithmetic_operand
 
 
-@arithmetic_operand(sparse_mode='unary')
+@arithmetic_operand(sparse_mode="unary")
 class TensorInvert(TensorUnaryOp):
     _op_type_ = OperandDef.INVERT
-    _func_name = 'invert'
+    _func_name = "invert"
 
 
 @infer_dtype(np.invert)
