@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,10 +22,10 @@ from .core import TensorBinOp
 from .utils import arithmetic_operand
 
 
-@arithmetic_operand(sparse_mode='always_false')
+@arithmetic_operand(sparse_mode="always_false")
 class TensorLogAddExp(TensorBinOp):
     _op_type_ = OperandDef.LOGADDEXP
-    _func_name = 'logaddexp'
+    _func_name = "logaddexp"
 
 
 @infer_dtype(np.logaddexp)
