@@ -22,10 +22,10 @@ from .core import TensorUnaryOp
 from .utils import arithmetic_operand
 
 
-@arithmetic_operand(sparse_mode='unary')
+@arithmetic_operand(sparse_mode="unary")
 class TensorNegative(TensorUnaryOp):
     _op_type_ = OperandDef.NEGATIVE
-    _func_name = 'negative'
+    _func_name = "negative"
 
 
 @infer_dtype(np.negative)
