@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -84,6 +84,7 @@ def result_type(*tensors_and_dtypes):
     """
     from ..core import Tensor
 
-    arrays_and_dtypes = [a.dtype if isinstance(a, Tensor) else a
-                         for a in tensors_and_dtypes]
+    arrays_and_dtypes = [
+        a.dtype if isinstance(a, Tensor) else a for a in tensors_and_dtypes
+    ]
     return np.result_type(*arrays_and_dtypes)
