@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -104,7 +104,7 @@ def tile(A, reps):
             slc = (slice(None),) * axis + (slice(0),)
             a = a[slc]
         elif rep < 0:
-            raise ValueError('negative dimensions are not allowed')
+            raise ValueError("negative dimensions are not allowed")
         elif rep > 1:
             a = concatenate([a] * rep, axis=axis)
 
