@@ -21,7 +21,7 @@ class TensorToCPU(TensorDeviceConversionBase):
     _op_type_ = OperandDef.TO_CPU
 
     def __init__(self, dtype=None, gpu=None, sparse=None, **kw):
-        super().__init__(_dtype=dtype, _gpu=gpu, _sparse=sparse, **kw)
+        super().__init__(dtype=dtype, gpu=gpu, sparse=sparse, **kw)
         if self.gpu or self.gpu is None:
             self.gpu = False
 
