@@ -20,8 +20,15 @@ from ... import opcodes as OperandDef
 from ...config import options
 from ...core import ExecutableTuple, recursive_tile
 from ...core.operand import OperandStage
-from ...serialization.serializables import FieldTypes, KeyField, \
-    Int64Field, Int32Field, BoolField, StringField, ListField
+from ...serialization.serializables import (
+    FieldTypes,
+    KeyField,
+    Int64Field,
+    Int32Field,
+    BoolField,
+    StringField,
+    ListField,
+)
 from ...utils import ceildiv, flatten
 from ..array_utils import as_same_device, device
 from ..core import TensorOrder
@@ -34,27 +41,49 @@ from .sort import _validate_sort_psrs_kinds
 class TensorTopk(TensorOperand, TensorOperandMixin):
     _op_type_ = OperandDef.TOPK
 
-    _input = KeyField('input')
-    _k = Int64Field('k')
-    _axis = Int32Field('axis')
-    _largest = BoolField('largest')
-    _sorted = BoolField('sorted')
-    _order = ListField('order', FieldTypes.string)
-    _parallel_kind = StringField('parallel_kind')
-    _psrs_kinds = ListField('psrs_kinds', FieldTypes.string)
-    _return_value = BoolField('return_value')
-    _return_indices = BoolField('return_indices')
-    _axis_offset = Int64Field('axis_offset',
-                              on_serialize=lambda x: -1 if x is not None and np.isnan(x) else x,
-                              on_deserialize=lambda x: np.nan if x == -1 else x)
+    _input = KeyField("input")
+    _k = Int64Field("k")
+    _axis = Int32Field("axis")
+    _largest = BoolField("largest")
+    _sorted = BoolField("sorted")
+    _order = ListField("order", FieldTypes.string)
+    _parallel_kind = StringField("parallel_kind")
+    _psrs_kinds = ListField("psrs_kinds", FieldTypes.string)
+    _return_value = BoolField("return_value")
+    _return_indices = BoolField("return_indices")
+    _axis_offset = Int64Field(
+        "axis_offset",
+        on_serialize=lambda x: -1 if x is not None and np.isnan(x) else x,
+        on_deserialize=lambda x: np.nan if x == -1 else x,
+    )
 
-    def __init__(self, k=None, axis=None, largest=None, sorted=None, order=None,
-                 parallel_kind=None, psrs_kinds=None, return_value=None, return_indices=None,
-                 axis_offset=None, **kw):
-        super().__init__(_k=k, _axis=axis, _largest=largest, _sorted=sorted,
-                         _parallel_kind=parallel_kind, _psrs_kinds=psrs_kinds,
-                         _return_value=return_value, _return_indices=return_indices,
-                         _order=order, _axis_offset=axis_offset, **kw)
+    def __init__(
+        self,
+        k=None,
+        axis=None,
+        largest=None,
+        sorted=None,
+        order=None,
+        parallel_kind=None,
+        psrs_kinds=None,
+        return_value=None,
+        return_indices=None,
+        axis_offset=None,
+        **kw
+    ):
+        super().__init__(
+            _k=k,
+            _axis=axis,
+            _largest=largest,
+            _sorted=sorted,
+            _parallel_kind=parallel_kind,
+            _psrs_kinds=psrs_kinds,
+            _return_value=return_value,
+            _return_indices=return_indices,
+            _order=order,
+            _axis_offset=axis_offset,
+            **kw
+        )
 
     @property
     def input(self):
@@ -116,19 +145,23 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         shape[self._axis] = min(a.shape[self._axis], self._k)
         kws = []
         if self._return_value:
-            kws.append({
-                'shape': tuple(shape),
-                'order': a.order,
-                'dtype': a.dtype,
-                'type': 'topk'
-            })
+            kws.append(
+                {
+                    "shape": tuple(shape),
+                    "order": a.order,
+                    "dtype": a.dtype,
+                    "type": "topk",
+                }
+            )
         if self._return_indices:
-            kws.append({
-                'shape': tuple(shape),
-                'order': TensorOrder.C_ORDER,
-                'dtype': np.dtype(np.int64),
-                'type': 'argtopk'
-            })
+            kws.append(
+                {
+                    "shape": tuple(shape),
+                    "order": TensorOrder.C_ORDER,
+                    "dtype": np.dtype(np.int64),
+                    "type": "argtopk",
+                }
+            )
         ret = self.new_tensors([a], kws=kws)
         if len(kws) == 1:
             return ret[0]
@@ -141,30 +174,34 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         chunk_op = op.copy().reset_key()
         kws = []
         if return_value:
-            kws.append({
-                'shape': out.shape,
-                'order': out.order,
-                'index': (0,) * out.ndim,
-                'dtype': out.dtype,
-                'type': 'topk'
-            })
+            kws.append(
+                {
+                    "shape": out.shape,
+                    "order": out.order,
+                    "index": (0,) * out.ndim,
+                    "dtype": out.dtype,
+                    "type": "topk",
+                }
+            )
         if return_indices:
-            kws.append({
-                'shape': out.shape,
-                'order': TensorOrder.C_ORDER,
-                'index': (0,) * out.ndim,
-                'dtype': np.dtype(np.int64),
-                'type': 'argtopk'
-            })
+            kws.append(
+                {
+                    "shape": out.shape,
+                    "order": TensorOrder.C_ORDER,
+                    "index": (0,) * out.ndim,
+                    "dtype": np.dtype(np.int64),
+                    "type": "argtopk",
+                }
+            )
         chunks = chunk_op.new_chunks([op.input.chunks[0]], kws=kws)
         kws = [out.params for out in op.outputs]
         nsplits = tuple((s,) for s in out.shape)
         if return_value:
-            kws[0]['nsplits'] = nsplits
-            kws[0]['chunks'] = [chunks[0]]
+            kws[0]["nsplits"] = nsplits
+            kws[0]["chunks"] = [chunks[0]]
         if return_indices:
-            kws[-1]['nsplits'] = nsplits
-            kws[-1]['chunks'] = [chunks[1]]
+            kws[-1]["nsplits"] = nsplits
+            kws[-1]["chunks"] = [chunks[1]]
         new_op = op.copy()
         return new_op.new_tensors(op.inputs, kws=kws)
 
@@ -176,10 +213,15 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         return_indices = op.return_indices
 
         # just sort, force need_align=True
-        psrs_kinds = op.psrs_kinds or ['quicksort', 'mergesort', 'mergesort']
-        sort_op = TensorSort(axis=op.axis, order=op.order,
-                             psrs_kinds=psrs_kinds, need_align=True,
-                             return_value=return_value, return_indices=return_indices)
+        psrs_kinds = op.psrs_kinds or ["quicksort", "mergesort", "mergesort"]
+        sort_op = TensorSort(
+            axis=op.axis,
+            order=op.order,
+            psrs_kinds=psrs_kinds,
+            need_align=True,
+            return_value=return_value,
+            return_indices=return_indices,
+        )
         ret = sort_op(op.input)
 
         if not isinstance(ret, tuple):
@@ -195,16 +237,17 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         new_op = op.copy()
         kws = [o.params for o in op.outputs]
         if return_value:
-            kws[0]['nsplits'] = ret[0].nsplits
-            kws[0]['chunks'] = ret[0].chunks
+            kws[0]["nsplits"] = ret[0].nsplits
+            kws[0]["chunks"] = ret[0].chunks
         if return_indices:
-            kws[-1]['nsplits'] = ret[-1].nsplits
-            kws[-1]['chunks'] = ret[-1].chunks
+            kws[-1]["nsplits"] = ret[-1].nsplits
+            kws[-1]["chunks"] = ret[-1].chunks
         return new_op.new_tensors(op.inputs, kws=kws)
 
     @classmethod
-    def _gen_topk_chunk(cls, input_chunk, op, is_terminate_node,
-                        axis_offset=None, chunk_index=None):
+    def _gen_topk_chunk(
+        cls, input_chunk, op, is_terminate_node, axis_offset=None, chunk_index=None
+    ):
         chunk_op = op.copy().reset_key()
         if axis_offset is not None:
             chunk_op._axis_offset = axis_offset
@@ -220,28 +263,35 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
                 chunk_op.stage = OperandStage.map
             else:
                 chunk_op.stage = OperandStage.combine
-            return chunk_op.new_chunk([input_chunk], shape=tuple(shape),
-                                      order=input_chunk.order,
-                                      index=chunk_index)
+            return chunk_op.new_chunk(
+                [input_chunk],
+                shape=tuple(shape),
+                order=input_chunk.order,
+                index=chunk_index,
+            )
         else:
             chunk_op.stage = OperandStage.agg
             kws = []
             if op.return_value:
-                kws.append({
-                    'shape': tuple(shape),
-                    'order': input_chunk.order,
-                    'dtype': input_chunk.dtype,
-                    'index': chunk_index,
-                    'type': 'topk'
-                })
+                kws.append(
+                    {
+                        "shape": tuple(shape),
+                        "order": input_chunk.order,
+                        "dtype": input_chunk.dtype,
+                        "index": chunk_index,
+                        "type": "topk",
+                    }
+                )
             if op.return_indices:
-                kws.append({
-                    'shape': tuple(shape),
-                    'order': TensorOrder.C_ORDER,
-                    'dtype': np.dtype(np.int64),
-                    'index': chunk_index,
-                    'type': 'argtopk'
-                })
+                kws.append(
+                    {
+                        "shape": tuple(shape),
+                        "order": TensorOrder.C_ORDER,
+                        "dtype": np.dtype(np.int64),
+                        "index": chunk_index,
+                        "type": "argtopk",
+                    }
+                )
             return chunk_op.new_chunks([input_chunk], kws=kws)
 
     @classmethod
@@ -255,8 +305,9 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         shape[axis] = sum(c.shape[axis] for c in input_chunks)
 
         merge_op = TensorConcatenate(axis=axis, dtype=input_chunks[0].dtype)
-        return merge_op.new_chunk(input_chunks, shape=tuple(shape),
-                                  order=input_chunks[0].order)
+        return merge_op.new_chunk(
+            input_chunks, shape=tuple(shape), order=input_chunks[0].order
+        )
 
     @classmethod
     def _tile_via_tree(cls, op):
@@ -268,19 +319,25 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
 
         out_chunks, indices_chunks = [], []
         for other_idx in itertools.product(
-                *(range(s) for i, s in enumerate(a.chunk_shape) if i != axis)):
+            *(range(s) for i, s in enumerate(a.chunk_shape) if i != axis)
+        ):
             merge_chunks = []
             for j in range(a.chunk_shape[axis]):
                 idx = list(other_idx)
                 idx.insert(axis, j)
                 input_chunk = a.cix[tuple(idx)]
-                merge_chunks.append(cls._gen_topk_chunk(input_chunk, op, False,
-                                                        axis_offset=axis_offsets[j]))
+                merge_chunks.append(
+                    cls._gen_topk_chunk(
+                        input_chunk, op, False, axis_offset=axis_offsets[j]
+                    )
+                )
             while len(merge_chunks) > combine_size:
                 new_size = ceildiv(len(merge_chunks), combine_size)
                 new_merge_chunks = []
                 for i in range(new_size):
-                    to_merge_chunks = merge_chunks[i * combine_size: (i + 1) * combine_size]
+                    to_merge_chunks = merge_chunks[
+                        i * combine_size : (i + 1) * combine_size
+                    ]
                     merge_chunk = cls._merge_chunks(to_merge_chunks, axis)
                     topk_chunk = cls._gen_topk_chunk(merge_chunk, op, False)
                     new_merge_chunks.append(topk_chunk)
@@ -289,8 +346,9 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
             merge_chunk = cls._merge_chunks(merge_chunks, axis)
             chunk_index = list(other_idx)
             chunk_index.insert(axis, 0)
-            chunks = \
-                cls._gen_topk_chunk(merge_chunk, op, True, chunk_index=tuple(chunk_index))
+            chunks = cls._gen_topk_chunk(
+                merge_chunk, op, True, chunk_index=tuple(chunk_index)
+            )
             if return_value:
                 out_chunks.append(chunks[0])
             if return_indices:
@@ -301,11 +359,11 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         nsplits[axis] = (min(a.shape[axis], op.k),)
         kws = [out.params for out in op.outputs]
         if return_value:
-            kws[0]['nsplits'] = nsplits
-            kws[0]['chunks'] = out_chunks
+            kws[0]["nsplits"] = nsplits
+            kws[0]["chunks"] = out_chunks
         if return_indices:
-            kws[-1]['nsplits'] = nsplits
-            kws[-1]['chunks'] = indices_chunks
+            kws[-1]["nsplits"] = nsplits
+            kws[-1]["chunks"] = indices_chunks
         return new_op.new_tensors(op.inputs, kws=kws)
 
     @classmethod
@@ -320,34 +378,36 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
 
         parallel_kind = op.parallel_kind.lower()
 
-        if parallel_kind == 'auto':
+        if parallel_kind == "auto":
             nsplit = a.nsplits[axis]
             max_chunk_size = max(nsplit)
             if np.isnan(max_chunk_size):
                 # has unknown chunk shape and k > 100 just choose 'psrs'
-                parallel_kind = 'psrs' if k > 100 else 'tree'
+                parallel_kind = "psrs" if k > 100 else "tree"
             else:
                 if combine_size * k <= max_chunk_size:
                     # each chunk will have k elements on specified axis,
                     # if combined chunk which generated in the tree reduction
                     # is less than max chunk size, parallel kind `tree` will be adopted
-                    parallel_kind = 'tree'
+                    parallel_kind = "tree"
                 else:
-                    parallel_kind = 'psrs'
+                    parallel_kind = "psrs"
 
-        if parallel_kind == 'tree':
-            op._parallel_kind = 'tree'
+        if parallel_kind == "tree":
+            op._parallel_kind = "tree"
             return cls._tile_via_tree(op)
         else:
-            assert parallel_kind == 'psrs'
-            op._parallel_kind = 'psrs'
+            assert parallel_kind == "psrs"
+            op._parallel_kind = "psrs"
             return (yield from cls._tile_via_psrs(op))
 
     @classmethod
     def execute(cls, ctx, op):
         inputs, device_id, xp = as_same_device(
             flatten([ctx[inp.key] for inp in op.inputs]),
-            device=op.device, ret_extra=True)
+            device=op.device,
+            ret_extra=True,
+        )
         if len(inputs) == 2:
             a, indices = inputs
         else:
@@ -362,9 +422,19 @@ class TensorTopk(TensorOperand, TensorOperandMixin):
         axis_offset = op.axis_offset
 
         with device(device_id):
-            av, ap = _topk_helper(xp, a, k, axis=axis, largest=largest, sorted=to_sort,
-                                  order=op.order, indices=indices, axis_offset=axis_offset,
-                                  return_value=return_value, return_indices=return_indices)
+            av, ap = _topk_helper(
+                xp,
+                a,
+                k,
+                axis=axis,
+                largest=largest,
+                sorted=to_sort,
+                order=op.order,
+                indices=indices,
+                axis_offset=axis_offset,
+                return_value=return_value,
+                return_indices=return_indices,
+            )
             if op.stage != OperandStage.agg:
                 out = [av]
                 if op.return_indices:
@@ -383,13 +453,24 @@ def _gen_indices(shape, axis, xp):
     return xp.swapaxes(ap, -1, axis)
 
 
-def _topk_helper(xp, a, k, axis=-1, largest=True, sorted=True, order=None,
-                 indices=None, axis_offset=None, return_value=True, return_indices=False):
+def _topk_helper(
+    xp,
+    a,
+    k,
+    axis=-1,
+    largest=True,
+    sorted=True,
+    order=None,
+    indices=None,
+    axis_offset=None,
+    return_value=True,
+    return_indices=False,
+):
     size = a.shape[axis]
     base_slc = (slice(None),) * axis
     kw = {}
     if order is not None:
-        kw['order'] = order
+        kw["order"] = order
 
     ap = None
     if return_indices:
@@ -398,7 +479,8 @@ def _topk_helper(xp, a, k, axis=-1, largest=True, sorted=True, order=None,
             if k < size:
                 length = size - k
                 ap = xp.argpartition(a, length, axis=axis, **kw)[
-                    base_slc + (slice(-k, None),)]
+                    base_slc + (slice(-k, None),)
+                ]
                 av = xp.take_along_axis(a, ap, axis)
                 if indices is not None:
                     ap = xp.take_along_axis(indices, ap, axis)
@@ -411,13 +493,13 @@ def _topk_helper(xp, a, k, axis=-1, largest=True, sorted=True, order=None,
             if sorted:
                 # sort then reverse
                 ags = xp.argsort(av, axis=axis, **kw)[
-                    base_slc + (slice(None, None, -1),)]
+                    base_slc + (slice(None, None, -1),)
+                ]
                 ap = xp.take_along_axis(ap, ags, axis)
                 av = xp.take_along_axis(av, ags, axis)
         else:
             if k < size:
-                ap = xp.argpartition(a, k, axis=axis, **kw)[
-                    base_slc + (slice(k),)]
+                ap = xp.argpartition(a, k, axis=axis, **kw)[base_slc + (slice(k),)]
                 av = xp.take_along_axis(a, ap, axis)
                 if indices is not None:
                     ap = xp.take_along_axis(indices, ap, axis)
@@ -439,17 +521,16 @@ def _topk_helper(xp, a, k, axis=-1, largest=True, sorted=True, order=None,
             if k < size:
                 length = size - k
                 av = xp.partition(a, length, axis=axis, **kw)[
-                    base_slc + (slice(-k, None),)]
+                    base_slc + (slice(-k, None),)
+                ]
             else:
                 av = a
             if sorted:
                 # sort then reverse
-                av = xp.sort(av, axis=axis, **kw)[
-                    base_slc + (slice(None, None, -1),)]
+                av = xp.sort(av, axis=axis, **kw)[base_slc + (slice(None, None, -1),)]
         else:
             if k < size:
-                av = xp.partition(a, k, axis=axis, **kw)[
-                    base_slc + (slice(k),)]
+                av = xp.partition(a, k, axis=axis, **kw)[base_slc + (slice(k),)]
             else:
                 av = a
             if sorted:
@@ -458,8 +539,9 @@ def _topk_helper(xp, a, k, axis=-1, largest=True, sorted=True, order=None,
     return av, ap
 
 
-def _validate_topk_arguments(a, k, axis, largest, sorted, order,
-                             parallel_kind, psrs_kinds):
+def _validate_topk_arguments(
+    a, k, axis, largest, sorted, order, parallel_kind, psrs_kinds
+):
     a = astensor(a)
     if axis is None:
         a = a.flatten()
@@ -468,20 +550,48 @@ def _validate_topk_arguments(a, k, axis, largest, sorted, order,
         axis = validate_axis(a.ndim, axis)
     # if a is structure type and order is not None
     order = validate_order(a.dtype, order)
-    if parallel_kind.lower() not in {'auto', 'tree', 'psrs'}:
-        raise ValueError('`parallel_kind` could only be `auto`, `tree`, or `psrs`')
+    if parallel_kind.lower() not in {"auto", "tree", "psrs"}:
+        raise ValueError("`parallel_kind` could only be `auto`, `tree`, or `psrs`")
     # if psrs is chosen, sort will be used,
     # psrs_kinds will be passed into it, so use the validation logic in sort
     psrs_kinds = _validate_sort_psrs_kinds(psrs_kinds)
     return a, k, axis, largest, sorted, order, parallel_kind, psrs_kinds
 
 
-def topk(a, k, axis=-1, largest=True, sorted=True, order=None, parallel_kind='auto',
-         psrs_kinds=None, return_index=False):
-    a, k, axis, largest, sorted, order, parallel_kind, psrs_kinds = _validate_topk_arguments(
-        a, k, axis, largest, sorted, order, parallel_kind, psrs_kinds)
-    op = TensorTopk(k=k, axis=axis, largest=largest, sorted=sorted, order=order,
-                    parallel_kind=parallel_kind, psrs_kinds=psrs_kinds,
-                    dtype=a.dtype, return_value=True, return_indices=return_index,
-                    stage=OperandStage.agg)
+def topk(
+    a,
+    k,
+    axis=-1,
+    largest=True,
+    sorted=True,
+    order=None,
+    parallel_kind="auto",
+    psrs_kinds=None,
+    return_index=False,
+):
+    (
+        a,
+        k,
+        axis,
+        largest,
+        sorted,
+        order,
+        parallel_kind,
+        psrs_kinds,
+    ) = _validate_topk_arguments(
+        a, k, axis, largest, sorted, order, parallel_kind, psrs_kinds
+    )
+    op = TensorTopk(
+        k=k,
+        axis=axis,
+        largest=largest,
+        sorted=sorted,
+        order=order,
+        parallel_kind=parallel_kind,
+        psrs_kinds=psrs_kinds,
+        dtype=a.dtype,
+        return_value=True,
+        return_indices=return_index,
+        stage=OperandStage.agg,
+    )
     return op(a)
