@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,19 +15,35 @@
 # limitations under the License.
 
 import logging
-from collections import defaultdict
 from collections.abc import Iterable
-from datetime import datetime
 from enum import Enum
 from operator import attrgetter
+from typing import Any, Dict
 
 import numpy as np
 
-from ..core import Entity, HasShapeTileableEnity, ChunkData, Chunk, HasShapeTileableData, \
-    Serializable, OutputType, register_output_types, _ExecuteAndFetchMixin
-from ..serialize import ProviderType, ValueType, DataTypeField, ListField, TupleField, \
-    BoolField, StringField, AnyField
-from ..utils import log_unhandled, on_serialize_shape, on_deserialize_shape, is_build_mode
+from ..core import (
+    HasShapeTileable,
+    ChunkData,
+    Chunk,
+    HasShapeTileableData,
+    OutputType,
+    register_output_types,
+    _ExecuteAndFetchMixin,
+    is_build_mode,
+)
+from ..core.entity.utils import refresh_tileable_shape
+from ..serialization.serializables import (
+    Serializable,
+    FieldTypes,
+    DataTypeField,
+    ListField,
+    TupleField,
+    StringField,
+    AnyField,
+    ReferenceField,
+)
+from ..utils import on_serialize_shape, on_deserialize_shape
 from .utils import get_chunk_slices, fetch_corner_data
 
 logger = logging.getLogger(__name__)
@@ -35,62 +51,91 @@ logger = logging.getLogger(__name__)
 
 class TensorOrder(Enum):
     # C order
-    C_ORDER = 'C'
+    C_ORDER = "C"
     # Fortran order
-    F_ORDER = 'F'
+    F_ORDER = "F"
 
 
 class TensorChunkData(ChunkData):
     __slots__ = ()
+    type_name = "Tensor"
 
     # required fields
-    _shape = TupleField('shape', ValueType.int64,
-                        on_serialize=on_serialize_shape, on_deserialize=on_deserialize_shape)
-    _order = StringField('order', on_serialize=attrgetter('value'), on_deserialize=TensorOrder)
+    _shape = TupleField(
+        "shape",
+        FieldTypes.int64,
+        on_serialize=on_serialize_shape,
+        on_deserialize=on_deserialize_shape,
+    )
+    _order = ReferenceField("order", TensorOrder)
     # optional fields
-    _dtype = DataTypeField('dtype')
+    _dtype = DataTypeField("dtype")
 
     def __init__(self, op=None, index=None, shape=None, dtype=None, order=None, **kw):
         if isinstance(order, str):
             order = getattr(TensorOrder, order)
-        super().__init__(_op=op, _index=index, _shape=shape, _dtype=dtype, _order=order, **kw)
+        super().__init__(
+            _op=op, _index=index, _shape=shape, _dtype=dtype, _order=order, **kw
+        )
         if self.order is None and self.op is not None:
             if len(self.inputs) == 0:
                 self._order = TensorOrder.C_ORDER
-            elif all(hasattr(inp, 'order') and inp.order == TensorOrder.F_ORDER
-                     for inp in self.inputs):
+            elif all(
+                hasattr(inp, "order") and inp.order == TensorOrder.F_ORDER
+                for inp in self.inputs
+            ):
                 self._order = TensorOrder.F_ORDER
             else:
                 self._order = TensorOrder.C_ORDER
 
-    @classmethod
-    def cls(cls, provider):
-        if provider.type == ProviderType.protobuf:
-            from ..serialize.protos.tensor_pb2 import TensorChunkDef
-            return TensorChunkDef
-        return super().cls(provider)
-
     @property
-    def params(self):
+    def params(self) -> Dict[str, Any]:
         # params return the properties which useful to rebuild a new chunk
         return {
-            'shape': self.shape,
-            'dtype': self.dtype,
-            'order': self.order,
-            'index': self.index,
+            "shape": self.shape,
+            "dtype": self.dtype,
+            "order": self.order,
+            "index": self.index,
         }
 
+    @params.setter
+    def params(self, new_params: Dict[str, Any]):
+        params = new_params.copy()
+        params.pop("index", None)  # index not needed to update
+        new_shape = params.pop("shape", None)
+        if new_shape is not None:
+            self._shape = new_shape
+        dtype = params.pop("dtype", None)
+        if dtype is not None:
+            self._dtype = dtype
+        order = params.pop("order", None)
+        if order is not None:
+            self._order = order
+        if params:  # pragma: no cover
+            raise TypeError(f"Unknown params: {list(params)}")
+
+    @classmethod
+    def get_params_from_data(cls, data: np.ndarray) -> Dict[str, Any]:
+        from .array_utils import is_cupy
+
+        if not is_cupy(data):
+            data = np.asarray(data)
+        order = (
+            TensorOrder.C_ORDER if data.flags["C_CONTIGUOUS"] else TensorOrder.F_ORDER
+        )
+        return {"shape": data.shape, "dtype": data.dtype, "order": order}
+
     def __len__(self):
         try:
             return self.shape[0]
         except IndexError:
             if is_build_mode():
                 return 0
-            raise TypeError('len() of unsized object')
+            raise TypeError("len() of unsized object")
 
     @property
     def shape(self):
-        return getattr(self, '_shape', None)
+        return getattr(self, "_shape", None)
 
     @property
     def ndim(self):
@@ -102,11 +147,11 @@ class TensorChunkData(ChunkData):
 
     @property
     def dtype(self):
-        return getattr(self, '_dtype', None) or self.op.dtype
+        return getattr(self, "_dtype", None) or self.op.dtype
 
     @property
     def order(self):
-        return getattr(self, '_order', None)
+        return getattr(self, "_order", None)
 
     @property
     def nbytes(self):
@@ -116,6 +161,7 @@ class TensorChunkData(ChunkData):
 class TensorChunk(Chunk):
     __slots__ = ()
     _allow_data_type_ = (TensorChunkData,)
+    type_name = "Tensor"
 
     def __len__(self):
         return len(self._data)
@@ -123,46 +169,63 @@ class TensorChunk(Chunk):
 
 class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
     __slots__ = ()
+    type_name = "Tensor"
 
     # required fields
-    _order = StringField('order', on_serialize=attrgetter('value'), on_deserialize=TensorOrder)
+    _order = StringField(
+        "order", on_serialize=attrgetter("value"), on_deserialize=TensorOrder
+    )
     # optional fields
-    _dtype = DataTypeField('dtype')
-    _chunks = ListField('chunks', ValueType.reference(TensorChunkData),
-                        on_serialize=lambda x: [it.data for it in x] if x is not None else x,
-                        on_deserialize=lambda x: [TensorChunk(it) for it in x] if x is not None else x)
+    _dtype = DataTypeField("dtype")
+    _chunks = ListField(
+        "chunks",
+        FieldTypes.reference(TensorChunkData),
+        on_serialize=lambda x: [it.data for it in x] if x is not None else x,
+        on_deserialize=lambda x: [TensorChunk(it) for it in x] if x is not None else x,
+    )
 
-    def __init__(self, op=None, shape=None, dtype=None, order=None, nsplits=None, chunks=None, **kw):
+    def __init__(
+        self,
+        op=None,
+        shape=None,
+        dtype=None,
+        order=None,
+        nsplits=None,
+        chunks=None,
+        **kw,
+    ):
         if isinstance(order, str):
             order = getattr(TensorOrder, order)
-        super().__init__(_op=op, _shape=shape, _dtype=dtype, _order=order, _nsplits=nsplits,
-                         _chunks=chunks, **kw)
+        super().__init__(
+            _op=op,
+            _shape=shape,
+            _dtype=dtype,
+            _order=order,
+            _nsplits=nsplits,
+            _chunks=chunks,
+            **kw,
+        )
         if self.order is None and self.op is not None:
             if len(self.inputs) == 0:
                 self._order = TensorOrder.C_ORDER
-            elif all(hasattr(inp, 'order') and inp.order == TensorOrder.F_ORDER
-                     for inp in self.inputs):
+            elif all(
+                hasattr(inp, "order") and inp.order == TensorOrder.F_ORDER
+                for inp in self.inputs
+            ):
                 self._order = TensorOrder.F_ORDER
             else:
                 self._order = TensorOrder.C_ORDER
 
-    @classmethod
-    def cls(cls, provider):
-        if provider.type == ProviderType.protobuf:
-            from ..serialize.protos.tensor_pb2 import TensorDef
-            return TensorDef
-        return super().cls(provider)
-
     def _to_str(self, representation=False):
         if is_build_mode() or len(self._executed_sessions) == 0:
             # in build mode, or not executed, just return representation
             if representation:
-                return f'Tensor <op={type(self._op).__name__}, shape={self._shape}, key={self._key}>'
+                return f"Tensor <op={type(self._op).__name__}, shape={self._shape}, key={self._key}>"
             else:
-                return f'Tensor(op={type(self._op).__name__}, shape={self._shape})'
+                return f"Tensor(op={type(self._op).__name__}, shape={self._shape})"
         else:
             print_options = np.get_printoptions()
-            threshold = print_options['threshold']
+            threshold = print_options["threshold"]
 
             corner_data = fetch_corner_data(self, session=self._executed_sessions[-1])
             # if less than default threshold, just set it as default,
@@ -181,38 +244,53 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
     @property
     def params(self):
         # params return the properties which useful to rebuild a new tileable object
-        return {
-            'shape': self.shape,
-            'dtype': self.dtype,
-            'order': self.order
-        }
+        return {"shape": self.shape, "dtype": self.dtype, "order": self.order}
+
+    @params.setter
+    def params(self, new_params: Dict[str, Any]):
+        params = new_params.copy()
+        shape = params.pop("shape", None)
+        if shape is not None:
+            self._shape = shape
+        dtype = params.pop("dtype", None)
+        if dtype is not None:
+            self._dtype = dtype
+        order = params.pop("order", None)
+        if order is not None:
+            self._order = order
+        if params:  # pragma: no cover
+            raise TypeError(f"Unknown params: {list(params)}")
+
+    def refresh_params(self):
+        refresh_tileable_shape(self)
+        if self._dtype is None:
+            self._dtype = self.chunks[0].dtype
 
     @property
     def flags(self):
         c_order = True if self.ndim <= 1 else self.order == TensorOrder.C_ORDER
         f_order = True if self.ndim <= 1 else self.order == TensorOrder.F_ORDER
-        return {
-            'C_CONTIGUOUS': c_order,
-            'F_CONTIGUOUS': f_order
-        }
+        return {"C_CONTIGUOUS": c_order, "F_CONTIGUOUS": f_order}
 
     @property
     def real(self):
         from .arithmetic import real
+
         return real(self)
 
     @property
     def imag(self):
         from .arithmetic import imag
+
         return imag(self)
 
     @property
     def dtype(self):
-        return getattr(self, '_dtype', None) or self.op.dtype
+        return getattr(self, "_dtype", None) or self.op.dtype
 
     @property
     def order(self):
-        return getattr(self, '_order', None)
+        return getattr(self, "_order", None)
 
     @property
     def nbytes(self):
@@ -231,6 +309,7 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
             return self
 
         from .datasource import fromdense
+
         return fromdense(self, missing=missing)
 
     def todense(self, fill_value=None):
@@ -238,6 +317,7 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
             return self
 
         from .datasource import fromsparse
+
         return fromsparse(self, fill_value=fill_value)
 
     def transpose(self, *axes):
@@ -255,10 +335,11 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
     def reshape(self, shape, *shapes, **kw):
         from .reshape import reshape
 
-        order = kw.pop('order', 'C')
+        order = kw.pop("order", "C")
         if kw:
             raise TypeError(
-                f"'{next(iter(kw))}' is an invalid keyword argument for this function")
+                f"'{next(iter(kw))}' is an invalid keyword argument for this function"
+            )
 
         if isinstance(shape, Iterable):
             shape = tuple(shape)
@@ -276,10 +357,12 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
     @staticmethod
     def from_dataframe(in_df):
         from .datasource import from_dataframe
+
         return from_dataframe(in_df)
 
     def to_dataframe(self, *args, **kwargs):
         from ..dataframe.datasource.from_tensor import dataframe_from_tensor
+
         return dataframe_from_tensor(self, *args, **kwargs)
 
     @property
@@ -290,9 +373,10 @@ class TensorData(HasShapeTileableData, _ExecuteAndFetchMixin):
         return self._execute_and_fetch(session=session, **kw)
 
 
-class Tensor(HasShapeTileableEnity):
+class Tensor(HasShapeTileable):
     __slots__ = ()
     _allow_data_type_ = (TensorData,)
+    type_name = "Tensor"
 
     def __len__(self):
         return len(self._data)
@@ -334,7 +418,7 @@ class Tensor(HasShapeTileableEnity):
     def __array_function__(self, func, types, args, kwargs):
         from .. import tensor as module
 
-        for submodule in func.__module__.split('.')[1:]:
+        for submodule in func.__module__.split(".")[1:]:
             try:
                 module = getattr(module, submodule)
             except AttributeError:
@@ -448,7 +532,7 @@ class Tensor(HasShapeTileableEnity):
     def totiledb(self, uri, ctx=None, key=None, timestamp=None):
         return self._data.totiledb(uri, ctx=ctx, key=key, timestamp=timestamp)
 
-    def copy(self, order='C'):
+    def copy(self, order="C"):
         return super().copy().astype(self.dtype, order=order, copy=False)
 
     def sort(self, axis=-1, kind=None, parallel_kind=None, psrs_kinds=None, order=None):
@@ -510,10 +594,16 @@ class Tensor(HasShapeTileableEnity):
         """
         from .base import sort
 
-        self._data = sort(self, axis=axis, kind=kind, parallel_kind=parallel_kind,
-                          psrs_kinds=psrs_kinds, order=order).data
+        self._data = sort(
+            self,
+            axis=axis,
+            kind=kind,
+            parallel_kind=parallel_kind,
+            psrs_kinds=psrs_kinds,
+            order=order,
+        ).data
 
-    def partition(self, kth, axis=-1, kind='introselect', order=None, **kw):
+    def partition(self, kth, axis=-1, kind="introselect", order=None, **kw):
         """
         Rearranges the elements in the tensor in such a way that the value of the
         element in kth position is in the position it would be in a sorted tensor.
@@ -566,8 +656,7 @@ class Tensor(HasShapeTileableEnity):
         """
         from .base import partition
 
-        self._data = partition(self, kth, axis=axis,
-                               kind=kind, order=order, **kw).data
+        self._data = partition(self, kth, axis=axis, kind=kind, order=order, **kw).data
 
     @property
     def flat(self):
@@ -629,197 +718,7 @@ class flatiter(object):
 
 
 class Indexes(Serializable):
-    _indexes = AnyField('indexes')
-
-    def __init__(self, indexes=None, **kw):
-        self._indexes = indexes
-        super().__init__(**kw)
-
-    @property
-    def indexes(self):
-        return self._indexes
-
-
-class MutableTensorData(TensorData):
-    __slots__ = ()
-
-    # required fields
-    _name = StringField('name')
-    _compression = BoolField("compression")
-    _chunk_eps = ListField('chunk_eps')
-
-    def __init__(self, name=None, op=None, shape=None, dtype=None, key=None, chunk_eps=None,
-                 nsplits=None, chunks=None, **kw):
-        super().__init__(op=op, shape=shape, dtype=dtype, nsplits=nsplits, chunks=chunks,
-                         _name=name, _key=key, _chunk_eps=chunk_eps, **kw)
-
-    @classmethod
-    def cls(cls, provider):
-        return super().cls(provider)
-
-    def __str__(self):
-        return f'MutableTensor(op={type(self.op).__name__}, name={self.name}, shape={self.shape})'
-
-    def __repr__(self):
-        return f'MutableTensor <op={type(self.op).__name__}, name={self.name}, shape={self.shape}, key={self.key}>'
-
-    @property
-    def params(self):
-        # params return the properties which useful to rebuild a new tileable object
-        return {
-            'shape': self.shape,
-            'dtype': self.dtype,
-            'name': self.name,
-            'compression': self.compression,
-            "chunk_eps": self.chunk_eps,
-        }
-
-    @property
-    def name(self):
-        return getattr(self, '_name', None)
-
-    @property
-    def compression(self):
-        return getattr(self, '_compression', None)
-
-    @property
-    def chunk_eps(self):
-        return getattr(self, '_chunk_eps', None)
-
-
-class MutableTensor(Entity):
-    __slots__ = ("_chunk_to_endpoint", "_chunk_buffers", "_record_type", "_buffer_size")
-    _allow_data_type_ = (MutableTensorData,)
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._chunk_buffers = defaultdict(lambda: [])
-        self._record_type = np.dtype([("index", np.uint32), ("ts", np.dtype('datetime64[ns]')), ("value", self.dtype)])
-        if self.chunks:
-            self._buffer_size = np.prod(self.chunks[0].shape)
-        else:
-            # MutableTensor doesn't hold chunks in LocalSession, thus we don't care the buffer
-            self._buffer_size = 0
-
-        if self._data.chunk_eps is not None:
-            self._chunk_to_endpoint = dict((c.key, ep) for c, ep in zip(self.chunks, self._data.chunk_eps))
-        else:
-            self._chunk_to_endpoint = dict()
-
-    def __len__(self):
-        return len(self._data)
-
-    @property
-    def name(self):
-        return self._data.name
-
-    @property
-    def chunk_to_endpoint(self):
-        return self._chunk_to_endpoint
-
-    def __setitem__(self, index, value):
-        from ..session import Session
-        session = Session.default_or_local()
-        return session.write_mutable_tensor(self, index, value)
-
-    def seal(self):
-        from ..session import Session
-        session = Session.default_or_local()
-        return session.seal(self)
-
-    @log_unhandled
-    def _do_write(self, tensor_index, value):
-        ''' Notes [buffer management of mutable tensor]:
-        Write operations on a mutable tensor are buffered at client. Every chunk has a
-        corresponding buffer in the form of
-
-            {chunk_key: [(index, ts, value)]}
-
-        Every time we write to a chunk, we will append the new operation records to
-        the list
-
-        At the end of write, if the buffer size exceeds `buffer_size`, the buffer will be send
-        to the corresponding worker.
-
-        The insights for above design are:
-
-        1. `append` on (small) list is fast
-        2. We try to flush the (affected) buffer to worker at the end of every write, the buffer
-           size is guaranteed to less than 2 * chunk_size.
-        '''
-        from .indexing.core import process_index, calc_shape
-        from .indexing.getitem import TensorIndex
-        from .utils import setitem_as_records
-
-        tensor_index = process_index(self.ndim, tensor_index)
-        output_shape = calc_shape(self.shape, tensor_index)
-
-        index_tensor_op = TensorIndex(dtype=self.dtype, sparse=False, indexes=tensor_index)
-        index_tensor = index_tensor_op.new_tensor([self], tuple(output_shape))._inplace_tile()
-        output_chunks = index_tensor.chunks
-
-        is_scalar = np.isscalar(value) or isinstance(value, tuple) and self.dtype.fields
-
-        if not is_scalar:
-            value = np.broadcast_to(value, output_shape).astype(self.dtype)
-
-        nsplits_acc = [np.cumsum((0,) + tuple(c.shape[i] for c in output_chunks
-                                              if all(idx == 0 for j, idx in enumerate(c.index) if j != i)))
-                       for i in range(len(output_chunks[0].shape))]
-
-        now = np.datetime64(datetime.now())
-        affected_chunk_keys = []
-
-        for output_chunk in output_chunks:
-            records = self._chunk_buffers[output_chunk.op.input.key]
-            records += setitem_as_records(nsplits_acc, output_chunk, value, now, is_scalar=is_scalar)
-            affected_chunk_keys.append(output_chunk.op.input.key)
-
-        # Try to flush affected chunks
-        return self._do_flush(self._buffer_size, affected_chunk_keys)
-
-    @log_unhandled
-    def _do_flush(self, buffer_size_limit=1, affected_chunk_keys=None):
-        chunk_records_to_send = []
-        affected_chunk_keys = affected_chunk_keys or self._chunk_buffers.keys()
-        for chunk_key in affected_chunk_keys:
-            records = self._chunk_buffers[chunk_key]
-            if len(records) >= buffer_size_limit:
-                chunk_records_to_send.append((chunk_key, self._chunk_to_endpoint[chunk_key],
-                                              np.array(records, dtype=self._record_type)))
-                self._chunk_buffers[chunk_key] = []
-        return chunk_records_to_send
-
-
-def mutable_tensor(name, shape=None, dtype=np.float_, fill_value=None, chunk_size=None):
-    """
-    Create or get a mutable tensor using the local or default session.
-
-    When `shape` is `None`, it will try to get the mutable tensor with name `name`. Otherwise,
-    it will try to create a mutable tensor using the provided `name` and `shape`.
-
-    Parameters
-    ----------
-    name : str
-        Name of the mutable tensor.
-    shape : int or sequence of ints
-        Shape of the new mutable tensor, e.g., ``(2, 3)`` or ``2``.
-    dtype : data-type, optional
-        The desired data-type for the mutable tensor, e.g., `mt.int8`.  Default is `mt.float_`.
-    chunk_size: int or tuple of ints, optional
-        Specifies chunk size for each dimension.
-    fill_value: scalar, optional
-        The created mutable tensor will be filled by `fill_value` defaultly, if the parameter is None,
-        the newly created mutable tensor will be initialized with `np.zeros`. See also `numpy.full`.
-    """
-    from ..session import Session
-    session = Session.default_or_local()
-
-    if shape is None:
-        return session.get_mutable_tensor(name)
-    else:
-        return session.create_mutable_tensor(name, shape=shape, dtype=dtype,
-                                             fill_value=fill_value, chunk_size=chunk_size)
+    indexes = AnyField("indexes")
 
 
 TENSOR_TYPE = (Tensor, TensorData)
