@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import KeyField, StringField
+from ...serialization.serializables import KeyField, StringField
 from ...lib.sparse import SparseNDArray
 from ...lib.sparse.core import naked, get_array_module, get_sparse_module
 from ..array_utils import create_array
@@ -34,8 +34,8 @@ class TensorEmptyBase(object):
         self._gen_rand()
 
     def _gen_rand(self):
-        if getattr(self, '_rand', None) is None:
-            self._obj_set('_rand', np.random.random())
+        if getattr(self, "_rand", None) is None:
+            self._obj_set("_rand", np.random.random())
 
     def to_chunk_op(self, *args):
         op = self.copy().reset_key()
@@ -45,14 +45,14 @@ class TensorEmptyBase(object):
 
 
 class TensorEmpty(TensorEmptyBase, TensorNoInput):
-    __slots__ = '_rand',
+    __slots__ = ("_rand",)
     _op_type_ = OperandDef.TENSOR_EMPTY
 
-    _order = StringField('order')
+    _order = StringField("order")
 
-    def __init__(self, dtype=None, gpu=None, order=None, **kw):
-        dtype = np.dtype(dtype or 'f8')
-        super().__init__(_dtype=dtype, _gpu=gpu, _order=order, **kw)
+    def __init__(self, dtype=None, order=None, **kw):
+        dtype = np.dtype(dtype or "f8")
+        super().__init__(dtype=dtype, _order=order, **kw)
 
     @property
     def order(self):
@@ -61,11 +61,12 @@ class TensorEmpty(TensorEmptyBase, TensorNoInput):
     @classmethod
     def execute(cls, ctx, op):
         chunk = op.outputs[0]
-        ctx[chunk.key] = create_array(op)('empty', chunk.shape, dtype=op.dtype,
-                                          order=op.order)
+        ctx[chunk.key] = create_array(op)(
+            "empty", chunk.shape, dtype=op.dtype, order=op.order
+        )
 
 
-def empty(shape, dtype=None, chunk_size=None, gpu=False, order='C'):
+def empty(shape, dtype=None, chunk_size=None, gpu=None, order="C"):
     """
     Return a new tensor of given shape and type, without initializing entries.
 
@@ -111,22 +112,26 @@ def empty(shape, dtype=None, chunk_size=None, gpu=False, order='C'):
     array([[-1073741821, -1067949133],
            [  496041986,    19249760]])                     #random
     """
-    tensor_order = get_order(order, None, available_options='CF',
-                             err_msg="only 'C' or 'F' order is permitted")
+    tensor_order = get_order(
+        order,
+        None,
+        available_options="CF",
+        err_msg="only 'C' or 'F' order is permitted",
+    )
     op = TensorEmpty(dtype=dtype, gpu=gpu, order=order)
     return op(shape, chunk_size=chunk_size, order=tensor_order)
 
 
 class TensorEmptyLike(TensorEmptyBase, TensorLike):
-    __slots__ = '_rand',
+    __slots__ = ("_rand",)
     _op_type_ = OperandDef.TENSOR_EMPTY_LIKE
 
-    _input = KeyField('input')
-    _order = StringField('order')
+    _input = KeyField("input")
+    _order = StringField("order")
 
     def __init__(self, dtype=None, gpu=None, sparse=False, order=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else None
-        super().__init__(_dtype=dtype, _gpu=gpu, _order=order, _sparse=sparse, **kw)
+        super().__init__(dtype=dtype, gpu=gpu, _order=order, sparse=sparse, **kw)
 
     @property
     def order(self):
@@ -139,16 +144,23 @@ class TensorEmptyLike(TensorEmptyBase, TensorLike):
             in_data = naked(ctx[op.inputs[0].key])
             xps = get_sparse_module(in_data)
             xp = get_array_module(in_data)
-            ctx[chunk.key] = SparseNDArray(xps.csr_matrix(
-                (xp.empty_like(in_data.data, dtype=op.dtype),
-                 in_data.indices, in_data.indptr), shape=in_data.shape
-            ))
+            ctx[chunk.key] = SparseNDArray(
+                xps.csr_matrix(
+                    (
+                        xp.empty_like(in_data.data, dtype=op.dtype),
+                        in_data.indices,
+                        in_data.indptr,
+                    ),
+                    shape=in_data.shape,
+                )
+            )
         else:
             ctx[chunk.key] = create_array(op)(
-                'empty_like', ctx[op.inputs[0].key], dtype=op.dtype, order=op.order)
+                "empty_like", ctx[op.inputs[0].key], dtype=op.dtype, order=op.order
+            )
 
 
-def empty_like(a, dtype=None, gpu=None, order='K'):
+def empty_like(a, dtype=None, gpu=None, order="K"):
     """
     Return a new tensor with the same shape and type as a given tensor.
 
