@@ -19,7 +19,11 @@ import numpy as np
 from ... import opcodes as OperandDef
 from ...lib.sparse import SparseNDArray
 from ...lib.sparse.core import get_sparse_module, get_array_module, naked
-from ...serialization.serializables import KeyField, StringField
+from ...serialization.serializables import (
+    AnyField,
+    KeyField,
+    StringField,
+)
 from ..array_utils import create_array, convert_order
 from ..utils import get_order
 from .core import TensorNoInput, TensorLike
@@ -29,28 +33,29 @@ from .array import tensor
 class TensorOnes(TensorNoInput):
     _op_type_ = OperandDef.TENSOR_ONES
 
-    _order = StringField('order')
+    order = StringField("order")
+    shape = AnyField("shape")
+    chunk_size = AnyField("chunk_size")
 
-    def __init__(self, dtype=None, order=None, **kw):
-        dtype = np.dtype(dtype or 'f8')
-        super().__init__(dtype=dtype, _order=order, **kw)
-
-    @property
-    def order(self):
-        return self._order
+    def to_chunk_op(self, *args):
+        chunk_op = super().to_chunk_op(*args)
+        chunk_op.shape = args[0]
+        chunk_op.chunk_size = None
+        return chunk_op
 
     @classmethod
     def execute(cls, ctx, op):
         chunk = op.outputs[0]
         try:
-            ctx[chunk.key] = create_array(op)('ones', chunk.shape,
-                                              dtype=op.dtype, order=op.order)
+            ctx[chunk.key] = create_array(op)(
+                "ones", op.shape, dtype=op.dtype, order=op.order
+            )
         except TypeError:  # in case that cp.ones does not have arg ``order``
-            x = create_array(op)('ones', chunk.shape, dtype=op.dtype)
+            x = create_array(op)("ones", op.shape, dtype=op.dtype)
             ctx[chunk.key] = convert_order(x, op.order)
 
 
-def ones(shape, dtype=None, chunk_size=None, gpu=False, order='C'):
+def ones(shape, dtype=None, chunk_size=None, gpu=None, order="C"):
     """
     Return a new tensor of given shape and type, filled with ones.
 
@@ -99,16 +104,23 @@ def ones(shape, dtype=None, chunk_size=None, gpu=False, order='C'):
            [ 1.,  1.]])
 
     """
-    tensor_order = get_order(order, None, available_options='CF',
-                             err_msg="only 'C' or 'F' order is permitted")
-    op = TensorOnes(dtype=dtype, gpu=gpu, order=order)
+    tensor_order = get_order(
+        order,
+        None,
+        available_options="CF",
+        err_msg="only 'C' or 'F' order is permitted",
+    )
+    dtype = np.dtype(dtype or "f8")
+    op = TensorOnes(
+        dtype=dtype, shape=shape, chunk_size=chunk_size, gpu=gpu, order=order
+    )
     return op(shape, chunk_size=chunk_size, order=tensor_order)
 
 
 class TensorOnesLike(TensorLike):
     _op_type_ = OperandDef.TENSOR_ONES_LIKE
 
-    _input = KeyField('input')
+    _input = KeyField("input")
 
     def __init__(self, dtype=None, sparse=False, **kw):
         dtype = np.dtype(dtype) if dtype is not None else None
@@ -120,10 +132,16 @@ class TensorOnesLike(TensorLike):
         in_data = naked(ctx[op.input.key])
         xps = get_sparse_module(in_data)
         xp = get_array_module(in_data)
-        ctx[chunk.key] = SparseNDArray(xps.csr_matrix(
-            (xp.ones_like(in_data.data, dtype=chunk.op.dtype),
-             in_data.indices, in_data.indptr), shape=in_data.shape
-        ))
+        ctx[chunk.key] = SparseNDArray(
+            xps.csr_matrix(
+                (
+                    xp.ones_like(in_data.data, dtype=chunk.op.dtype),
+                    in_data.indices,
+                    in_data.indptr,
+                ),
+                shape=in_data.shape,
+            )
+        )
 
     @classmethod
     def execute(cls, ctx, op):
@@ -131,10 +149,11 @@ class TensorOnesLike(TensorLike):
             cls.execute_sparse(ctx, op)
         else:
             ctx[op.outputs[0].key] = create_array(op)(
-                'ones_like', ctx[op.inputs[0].key], dtype=op.dtype)
+                "ones_like", ctx[op.inputs[0].key], dtype=op.dtype
+            )
 
 
-def ones_like(a, dtype=None, gpu=None, order='K'):
+def ones_like(a, dtype=None, gpu=None, order="K"):
     """
     Return a tensor of ones with the same shape and type as a given tensor.
 
