@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,9 +20,8 @@ import numpy as np
 
 from ...lib import sparse
 from ... import opcodes as OperandDef
-from ...serialize import KeyField, Int32Field
-from ...utils import check_chunks_unknown_shape
-from ...tiles import TilesError
+from ...serialization.serializables import KeyField, Int32Field
+from ...utils import has_unknown_shape
 from ..array_utils import create_array
 from ..core import TensorOrder
 from .core import TensorHasInput
@@ -36,14 +35,15 @@ class TensorTri(TensorHasInput):
         return self.new_tensor([m], shape=m.shape, order=order)
 
     def to_chunk_op(self, *args):
-        k, = args
+        (k,) = args
         op = self.copy().reset_key()
         op._k = k
         return op
 
     @classmethod
     def tile(cls, op):
-        check_chunks_unknown_shape(op.inputs, TilesError)
+        if has_unknown_shape(*op.inputs):
+            yield
         tensor = op.outputs[0]
 
         m = op.input
@@ -64,44 +64,56 @@ class TensorTri(TensorHasInput):
             ru_fx = fx(*ru_pos)
 
             chunk_shape = tuple(nsplits[i][idx] for i, idx in enumerate(out_idx))
-            if (is_triu and ld_fx > 0 and ru_fx > 0) or (not is_triu and ld_fx < 0 and ru_fx < 0):
+            if (is_triu and ld_fx > 0 and ru_fx > 0) or (
+                not is_triu and ld_fx < 0 and ru_fx < 0
+            ):
                 # does not cross, fill with zeros
-                chunk_op = TensorZeros(dtype=op.dtype, gpu=op.gpu, sparse=op.sparse)
-                out_chunk = chunk_op.new_chunk(None, shape=chunk_shape,
-                                               index=out_idx, order=tensor.order)
+                chunk_op = TensorZeros(
+                    dtype=op.dtype,
+                    gpu=op.gpu,
+                    sparse=op.sparse,
+                    shape=chunk_shape,
+                    order=tensor.order.value,
+                )
+                out_chunk = chunk_op.new_chunk(
+                    None, shape=chunk_shape, index=out_idx, order=tensor.order
+                )
             else:
                 lu_pos = ru_pos[0], ld_pos[1]
                 chunk_k = fx(*lu_pos)
 
                 input_chunk = m.cix[out_idx]
                 chunk_op = op.to_chunk_op(chunk_k)
-                out_chunk = chunk_op.new_chunk([input_chunk], shape=chunk_shape,
-                                               index=out_idx, order=tensor.order)
+                out_chunk = chunk_op.new_chunk(
+                    [input_chunk], shape=chunk_shape, index=out_idx, order=tensor.order
+                )
 
             out_chunks.append(out_chunk)
 
         new_op = op.copy()
-        return new_op.new_tensors(op.inputs, tensor.shape, chunks=out_chunks, nsplits=m.nsplits)
+        params = tensor.params
+        params["chunks"] = out_chunks
+        params["nsplits"] = m.nsplits
+        return new_op.new_tensors(op.inputs, kws=[params])
 
     @classmethod
     def execute(cls, ctx, op):
         chunk = op.outputs[0]
-        f = 'triu' if isinstance(op, TensorTriu) else 'tril'
+        f = "triu" if isinstance(op, TensorTriu) else "tril"
         if op.sparse:
             ctx[chunk.key] = getattr(sparse, f)(ctx[op.inputs[0].key], k=op.k)
         else:
-            ctx[chunk.key] = create_array(op)(
-                f, ctx[op.inputs[0].key], op.k)
+            ctx[chunk.key] = create_array(op)(f, ctx[op.inputs[0].key], op.k)
 
 
 class TensorTriu(TensorTri):
     _op_type_ = OperandDef.TENSOR_TRIU
 
-    _input = KeyField('input')
-    _k = Int32Field('k')
+    _input = KeyField("input")
+    _k = Int32Field("k")
 
-    def __init__(self, k=None, dtype=None, sparse=False, gpu=None, **kw):
-        super().__init__(_k=k, _dtype=dtype, _sparse=sparse, _gpu=gpu, **kw)
+    def __init__(self, k=None, **kw):
+        super().__init__(_k=k, **kw)
 
     @property
     def k(self):
@@ -141,11 +153,11 @@ def triu(m, k=0, gpu=None):
 class TensorTril(TensorTri):
     _op_type_ = OperandDef.TENSOR_TRIL
 
-    _input = KeyField('input')
-    _k = Int32Field('k')
+    _input = KeyField("input")
+    _k = Int32Field("k")
 
-    def __init__(self, k=None, dtype=None, sparse=False, gpu=None, **kw):
-        super().__init__(_k=k, _dtype=dtype, _sparse=sparse, _gpu=gpu, **kw)
+    def __init__(self, k=None, **kw):
+        super().__init__(_k=k, **kw)
 
     @property
     def k(self):
