@@ -18,7 +18,11 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialization.serializables import KeyField, StringField
+from ...serialization.serializables import (
+    AnyField,
+    KeyField,
+    StringField,
+)
 from ...lib import sparse
 from ...lib.sparse.core import get_sparse_module, get_array_module, naked
 from ..array_utils import create_array
@@ -30,27 +34,28 @@ from .array import tensor
 class TensorZeros(TensorNoInput):
     _op_type_ = OperandDef.TENSOR_ZEROS
 
-    _order = StringField('order')
+    order = StringField("order")
+    shape = AnyField("shape")
+    chunk_size = AnyField("chunk_size")
 
-    def __init__(self, dtype=None, order=None, **kw):
-        dtype = np.dtype(dtype or 'f8')
-        super().__init__(dtype=dtype, _order=order, **kw)
-
-    @property
-    def order(self):
-        return self._order
+    def to_chunk_op(self, *args):
+        chunk_op = super().to_chunk_op(*args)
+        chunk_op.shape = args[0]
+        chunk_op.chunk_size = None
+        return chunk_op
 
     @classmethod
     def execute(cls, ctx, op):
         chunk = op.outputs[0]
         if op.sparse:
-            ctx[chunk.key] = sparse.zeros(chunk.shape, dtype=op.dtype, gpu=op.gpu)
+            ctx[chunk.key] = sparse.zeros(op.shape, dtype=op.dtype, gpu=op.gpu)
         else:
-            ctx[chunk.key] = create_array(op)('zeros', chunk.shape,
-                                              dtype=op.dtype, order=op.order)
+            ctx[chunk.key] = create_array(op)(
+                "zeros", op.shape, dtype=op.dtype, order=op.order
+            )
 
 
-def zeros(shape, dtype=None, chunk_size=None, gpu=False, sparse=False, order='C'):
+def zeros(shape, dtype=None, chunk_size=None, gpu=None, sparse=False, order="C"):
     """
     Return a new tensor of given shape and type, filled with zeros.
 
@@ -107,21 +112,33 @@ def zeros(shape, dtype=None, chunk_size=None, gpu=False, sparse=False, order='C'
     array([(0, 0), (0, 0)],
           dtype=[('x', '<i4'), ('y', '<i4')])
     """
-    tensor_order = get_order(order, None, available_options='CF',
-                             err_msg="only 'C' or 'F' order is permitted")
-    op = TensorZeros(dtype=dtype, gpu=gpu, sparse=sparse, order=order)
+    tensor_order = get_order(
+        order,
+        None,
+        available_options="CF",
+        err_msg="only 'C' or 'F' order is permitted",
+    )
+    dtype = np.dtype(dtype or "f8")
+    op = TensorZeros(
+        dtype=dtype,
+        shape=shape,
+        chunk_size=chunk_size,
+        gpu=gpu,
+        sparse=sparse,
+        order=order,
+    )
     return op(shape, chunk_size=chunk_size, order=tensor_order)
 
 
 class TensorZerosLike(TensorLike):
     _op_type_ = OperandDef.TENSOR_ZEROS_LIKE
 
-    _input = KeyField('input')
-    _order = StringField('order')
+    _input = KeyField("input")
+    _order = StringField("order")
 
     def __init__(self, dtype=None, gpu=None, sparse=False, order=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else None
-        super().__init__(_dtype=dtype, _gpu=gpu, _sparse=sparse, _order=order, **kw)
+        super().__init__(dtype=dtype, gpu=gpu, sparse=sparse, _order=order, **kw)
 
     @property
     def order(self):
@@ -134,16 +151,23 @@ class TensorZerosLike(TensorLike):
             in_data = naked(ctx[op.inputs[0].key])
             xps = get_sparse_module(in_data)
             xp = get_array_module(in_data)
-            ctx[chunk.key] = sparse.SparseNDArray(xps.csr_matrix(
-                (xp.zeros_like(in_data.data, dtype=op.dtype),
-                 in_data.indices, in_data.indptr), shape=in_data.shape
-            ))
+            ctx[chunk.key] = sparse.SparseNDArray(
+                xps.csr_matrix(
+                    (
+                        xp.zeros_like(in_data.data, dtype=op.dtype),
+                        in_data.indices,
+                        in_data.indptr,
+                    ),
+                    shape=in_data.shape,
+                )
+            )
         else:
             ctx[chunk.key] = create_array(op)(
-                'zeros_like', ctx[op.inputs[0].key], dtype=op.dtype, order=op.order)
+                "zeros_like", ctx[op.inputs[0].key], dtype=op.dtype, order=op.order
+            )
 
 
-def zeros_like(a, dtype=None, gpu=None, order='K'):
+def zeros_like(a, dtype=None, gpu=None, order="K"):
     """
     Return a tensor of zeros with the same shape and type as a given tensor.
 
