@@ -20,9 +20,9 @@ from numpy.compat import basestring
 
 from ..datasource.array import tensor as astensor
 
-__all__ = ['parse_einsum_input', 'einsum_path']
+__all__ = ["parse_einsum_input", "einsum_path"]
 
-einsum_symbols = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
+einsum_symbols = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
 einsum_symbols_set = set(einsum_symbols)
 
 
@@ -148,7 +148,7 @@ def _find_contraction(positions, input_sets, output_set):
             idx_remain |= value
 
     new_result = idx_remain & idx_contract
-    idx_removed = (idx_contract - new_result)
+    idx_removed = idx_contract - new_result
     remaining.append(new_result)
 
     return (new_result, remaining, idx_removed, idx_contract)
@@ -204,7 +204,9 @@ def _optimal_path(input_sets, output_set, idx_dict, memory_limit):
                     continue
 
                 # Build (total_cost, positions, indices_remaining)
-                total_cost = cost + _flop_count(idx_contract, idx_removed, len(con), idx_dict)
+                total_cost = cost + _flop_count(
+                    idx_contract, idx_removed, len(con), idx_dict
+                )
                 new_pos = positions + [con]
                 iter_results.append((total_cost, new_pos, new_input_sets))
 
@@ -225,7 +227,9 @@ def _optimal_path(input_sets, output_set, idx_dict, memory_limit):
     return path
 
 
-def _parse_possible_contraction(positions, input_sets, output_set, idx_dict, memory_limit, path_cost, naive_cost):
+def _parse_possible_contraction(
+    positions, input_sets, output_set, idx_dict, memory_limit, path_cost, naive_cost
+):
     """Compute the cost (removed size + flops) and resultant indices for
     performing the contraction specified by ``positions``.
 
@@ -385,8 +389,15 @@ def _greedy_path(input_sets, output_set, idx_dict, memory_limit):
             if input_sets[positions[0]].isdisjoint(input_sets[positions[1]]):
                 continue
 
-            result = _parse_possible_contraction(positions, input_sets, output_set, idx_dict, memory_limit, path_cost,
-                                                 naive_cost)
+            result = _parse_possible_contraction(
+                positions,
+                input_sets,
+                output_set,
+                idx_dict,
+                memory_limit,
+                path_cost,
+                naive_cost,
+            )
             if result is not None:
                 known_contractions.append(result)
 
@@ -395,8 +406,15 @@ def _greedy_path(input_sets, output_set, idx_dict, memory_limit):
 
             # Then check the outer products
             for positions in itertools.combinations(range(len(input_sets)), 2):
-                result = _parse_possible_contraction(positions, input_sets, output_set, idx_dict, memory_limit,
-                                                     path_cost, naive_cost)
+                result = _parse_possible_contraction(
+                    positions,
+                    input_sets,
+                    output_set,
+                    idx_dict,
+                    memory_limit,
+                    path_cost,
+                    naive_cost,
+                )
                 if result is not None:
                     known_contractions.append(result)
 
@@ -571,7 +589,7 @@ def parse_einsum_input(operands):
 
         # Ensure all characters are valid
         for s in subscripts:
-            if s in '.,->':
+            if s in ".,->":
                 continue
             if s not in einsum_symbols:
                 raise ValueError(f"Character {s} is not a valid symbol.")
@@ -595,8 +613,10 @@ def parse_einsum_input(operands):
                 elif isinstance(s, int):
                     subscripts += einsum_symbols[s]
                 else:
-                    raise TypeError("For this input type lists must contain "
-                                    "either int or Ellipsis")
+                    raise TypeError(
+                        "For this input type lists must contain "
+                        "either int or Ellipsis"
+                    )
             if num != last:
                 subscripts += ","
 
@@ -608,8 +628,10 @@ def parse_einsum_input(operands):
                 elif isinstance(s, int):
                     subscripts += einsum_symbols[s]
                 else:
-                    raise TypeError("For this input type lists must contain "
-                                    "either int or Ellipsis")
+                    raise TypeError(
+                        "For this input type lists must contain "
+                        "either int or Ellipsis"
+                    )
     # Check for proper "->"
     if ("-" in subscripts) or (">" in subscripts):
         invalid = (subscripts.count("-") > 1) or (subscripts.count(">") > 1)
@@ -628,7 +650,7 @@ def parse_einsum_input(operands):
             split_subscripts = input_tmp.split(",")
             out_sub = True
         else:
-            split_subscripts = subscripts.split(',')
+            split_subscripts = subscripts.split(",")
             out_sub = False
 
         for num, sub in enumerate(split_subscripts):
@@ -641,7 +663,7 @@ def parse_einsum_input(operands):
                     ellipse_count = 0
                 else:
                     ellipse_count = max(operands[num].ndim, 1)
-                    ellipse_count -= (len(sub) - 3)
+                    ellipse_count -= len(sub) - 3
 
                 if ellipse_count > longest:
                     longest = ellipse_count
@@ -649,10 +671,10 @@ def parse_einsum_input(operands):
                 if ellipse_count < 0:
                     raise ValueError("Ellipses lengths do not match.")
                 elif ellipse_count == 0:
-                    split_subscripts[num] = sub.replace('...', '')
+                    split_subscripts[num] = sub.replace("...", "")
                 else:
                     rep_inds = ellipse_inds[-ellipse_count:]
-                    split_subscripts[num] = sub.replace('...', rep_inds)
+                    split_subscripts[num] = sub.replace("...", rep_inds)
 
         subscripts = ",".join(split_subscripts)
         if longest == 0:
@@ -671,8 +693,7 @@ def parse_einsum_input(operands):
                     raise ValueError(f"Character {s} is not a valid symbol.")
                 if tmp_subscripts.count(s) == 1:
                     output_subscript += s
-            normal_inds = ''.join(sorted(set(output_subscript) -
-                                         set(out_ellipse)))
+            normal_inds = "".join(sorted(set(output_subscript) - set(out_ellipse)))
 
             subscripts += "->" + out_ellipse + normal_inds
 
@@ -696,9 +717,10 @@ def parse_einsum_input(operands):
             raise ValueError(f"Output character {char} did not appear in the input")
 
     # Make sure number operands is equivalent to the number of terms
-    if len(input_subscripts.split(',')) != len(operands):
-        raise ValueError("Number of einsum subscripts must be equal to the "
-                         "number of operands.")
+    if len(input_subscripts.split(",")) != len(operands):
+        raise ValueError(
+            "Number of einsum subscripts must be equal to the " "number of operands."
+        )
 
     return (input_subscripts, output_subscript, operands)
 
@@ -824,16 +846,15 @@ def einsum_path(*operands, **kwargs):
     """
 
     # Make sure all keywords are valid
-    valid_contract_kwargs = ['optimize', 'einsum_call']
-    unknown_kwargs = [k for (k, v) in kwargs.items() if k
-                      not in valid_contract_kwargs]
+    valid_contract_kwargs = ["optimize", "einsum_call"]
+    unknown_kwargs = [k for (k, v) in kwargs.items() if k not in valid_contract_kwargs]
     if len(unknown_kwargs):
         raise TypeError(f"Did not understand the following kwargs: {unknown_kwargs!r}")
 
     # Figure out what the path really is
-    path_type = kwargs.pop('optimize', True)
+    path_type = kwargs.pop("optimize", True)
     if path_type is True:
-        path_type = 'greedy'
+        path_type = "greedy"
     if path_type is None:
         path_type = False
 
@@ -844,12 +865,15 @@ def einsum_path(*operands, **kwargs):
         pass
 
     # Given an explicit path
-    elif len(path_type) and (path_type[0] == 'einsum_path'):  # pragma: no cover
+    elif len(path_type) and (path_type[0] == "einsum_path"):  # pragma: no cover
         pass
 
     # Path tuple with memory limit
-    elif ((len(path_type) == 2) and isinstance(path_type[0], basestring) and
-            isinstance(path_type[1], (int, float))):  # pragma: no cover
+    elif (
+        (len(path_type) == 2)
+        and isinstance(path_type[0], basestring)
+        and isinstance(path_type[1], (int, float))
+    ):  # pragma: no cover
         memory_limit = int(path_type[1])
         path_type = path_type[0]
 
@@ -863,10 +887,10 @@ def einsum_path(*operands, **kwargs):
     input_subscripts, output_subscript, operands = parse_einsum_input(operands)
 
     # Build a few useful list and sets
-    input_list = input_subscripts.split(',')
+    input_list = input_subscripts.split(",")
     input_sets = [set(x) for x in input_list]
     output_set = set(output_subscript)
-    indices = set(input_subscripts.replace(',', ''))
+    indices = set(input_subscripts.replace(",", ""))
 
     # Get length of each unique dimension and ensure all dimensions are correct
     dimension_dict = {}
@@ -874,9 +898,11 @@ def einsum_path(*operands, **kwargs):
     for tnum, term in enumerate(input_list):
         sh = operands[tnum].shape
         if len(sh) != len(term):
-            raise ValueError("Einstein sum subscript %s does not contain the "
-                             "correct number of indices for operand %d."
-                             % (input_subscripts[tnum], tnum))
+            raise ValueError(
+                "Einstein sum subscript %s does not contain the "
+                "correct number of indices for operand %d."
+                % (input_subscripts[tnum], tnum)
+            )
         for cnum, char in enumerate(term):
             dim = sh[cnum]
 
@@ -889,9 +915,11 @@ def einsum_path(*operands, **kwargs):
                 if dimension_dict[char] == 1:
                     dimension_dict[char] = dim
                 elif dim not in (1, dimension_dict[char]):
-                    raise ValueError("Size of label '%s' for operand %d (%d) "
-                                     "does not match previous terms (%d)."
-                                     % (char, tnum, dimension_dict[char], dim))
+                    raise ValueError(
+                        "Size of label '%s' for operand %d (%d) "
+                        "does not match previous terms (%d)."
+                        % (char, tnum, dimension_dict[char], dim)
+                    )
             else:
                 dimension_dict[char] = dim
 
@@ -899,8 +927,10 @@ def einsum_path(*operands, **kwargs):
     broadcast_indices = [set(x) for x in broadcast_indices]
 
     # Compute size of each input array plus the output array
-    size_list = [_compute_size_by_dict(term, dimension_dict)
-                 for term in input_list + [output_subscript]]
+    size_list = [
+        _compute_size_by_dict(term, dimension_dict)
+        for term in input_list + [output_subscript]
+    ]
     max_size = max(size_list)
 
     if memory_limit is None:
@@ -921,7 +951,7 @@ def einsum_path(*operands, **kwargs):
         path = _greedy_path(input_sets, output_set, dimension_dict, memory_arg)
     elif path_type == "optimal":
         path = _optimal_path(input_sets, output_set, dimension_dict, memory_arg)
-    elif path_type[0] == 'einsum_path':  # pragma: no cover
+    elif path_type[0] == "einsum_path":  # pragma: no cover
         path = path_type[1:]
     else:  # pragma: no cover
         raise KeyError("Path name %s not found", path_type)
@@ -936,7 +966,9 @@ def einsum_path(*operands, **kwargs):
         contract = _find_contraction(contract_inds, input_sets, output_set)
         out_inds, input_sets, idx_removed, idx_contract = contract
 
-        cost = _flop_count(idx_contract, idx_removed, len(contract_inds), dimension_dict)
+        cost = _flop_count(
+            idx_contract, idx_removed, len(contract_inds), dimension_dict
+        )
         cost_list.append(cost)
         scale_list.append(len(idx_contract))
         size_list.append(_compute_size_by_dict(out_inds, dimension_dict))
@@ -981,7 +1013,7 @@ def einsum_path(*operands, **kwargs):
     speedup = naive_cost / opt_cost
     max_i = max(size_list)
 
-    path_print  = "  Complete contraction:  %s\n" % overall_contraction  # noqa: E221
+    path_print = "  Complete contraction:  %s\n" % overall_contraction  # noqa: E221
     path_print += "         Naive scaling:  %d\n" % len(indices)
     path_print += "     Optimized scaling:  %d\n" % max(scale_list)
     path_print += "      Naive FLOP count:  %.3e\n" % naive_cost
@@ -998,5 +1030,5 @@ def einsum_path(*operands, **kwargs):
         path_run = (scale_list[n], einsum_str, remaining_str)
         path_print += "\n%4d    %24s %40s" % path_run
 
-    path = ['einsum_path'] + path
+    path = ["einsum_path"] + path
     return path, path_print
