@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,5 +15,5 @@
 # limitations under the License.
 
 from .core import TensorFuseChunk
-from .ne import TensorNeFuseChunk
-from .cp import TensorCpFuseChunk
+from .cupy import TensorCpFuseChunk
+from .numexpr import TensorNeFuseChunk
