@@ -122,8 +122,9 @@ def take(a, indices, axis=None, out=None):
         return t
 
     if out.shape != t.shape:
-        raise ValueError('output tensor has wrong shape, '
-                         f'expect: {t.shape}, got: {out.shape}')
-    check_out_param(out, t, 'unsafe')
+        raise ValueError(
+            "output tensor has wrong shape, " f"expect: {t.shape}, got: {out.shape}"
+        )
+    check_out_param(out, t, "unsafe")
     out.data = t.data
     return out
