@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,31 +17,34 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorExponential(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_scale', '_size'
-    _input_fields_ = ['_scale']
+    _input_fields_ = ["_scale"]
     _op_type_ = OperandDef.RAND_EXPONENTIAL
 
-    _scale = AnyField('scale')
-    _func_name = 'exponential'
+    _fields_ = "_scale", "_size"
+    _scale = AnyField("scale")
+    _func_name = "exponential"
 
     @property
     def scale(self):
         return self._scale
 
-    def __init__(self, state=None, size=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_state=state, _size=size, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     def __call__(self, scale, chunk_size=None):
         return self.new_tensor([scale], self._size, raw_chunk_size=chunk_size)
 
 
-def exponential(random_state, scale=1.0, size=None, chunk_size=None, gpu=None, dtype=None):
+def exponential(
+    random_state, scale=1.0, size=None, chunk_size=None, gpu=None, dtype=None
+):
     r"""
     Draw samples from an exponential distribution.
 
@@ -90,8 +93,10 @@ def exponential(random_state, scale=1.0, size=None, chunk_size=None, gpu=None, d
            http://en.wikipedia.org/wiki/Exponential_distribution
     """
     if dtype is None:
-        dtype = np.random.RandomState().exponential(
-            handle_array(scale), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState().exponential(handle_array(scale), size=(0,)).dtype
+        )
     size = random_state._handle_size(size)
-    op = TensorExponential(state=random_state.to_numpy(), size=size, gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorExponential(seed=seed, size=size, gpu=gpu, dtype=dtype)
     return op(scale, chunk_size=chunk_size)
