@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,25 +17,26 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorGeometric(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_p', '_size'
-    _input_fields_ = ['_p']
+    _input_fields_ = ["_p"]
     _op_type_ = OperandDef.RAND_GEOMETRIC
 
-    _p = AnyField('p')
-    _func_name = 'geometric'
+    _fields_ = "_p", "_size"
+    _p = AnyField("p")
+    _func_name = "geometric"
 
     @property
     def p(self):
         return self._p
 
-    def __init__(self, state=None, size=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_state=state, _size=size, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     def __call__(self, p, chunk_size=None):
         return self.new_tensor([p], None, raw_chunk_size=chunk_size)
@@ -93,8 +94,8 @@ def geometric(random_state, p, size=None, chunk_size=None, gpu=None, dtype=None)
     0.34889999999999999 #random
     """
     if dtype is None:
-        dtype = np.random.RandomState().geometric(
-            handle_array(p), size=(0,)).dtype
+        dtype = np.random.RandomState().geometric(handle_array(p), size=(0,)).dtype
     size = random_state._handle_size(size)
-    op = TensorGeometric(state=random_state.to_numpy(), size=size, gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorGeometric(seed=seed, size=size, gpu=gpu, dtype=dtype)
     return op(p, chunk_size=chunk_size)
