@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,23 +17,24 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorHypergeometric(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_ngood', '_nbad', '_nsample', '_size'
-    _input_fields_ = ['_ngood', '_nbad', '_nsample']
+    _input_fields_ = ["_ngood", "_nbad", "_nsample"]
     _op_type_ = OperandDef.RAND_HYPERGEOMETRIC
 
-    _ngood = AnyField('ngood')
-    _nbad = AnyField('nbad')
-    _nsample = AnyField('nsample')
-    _func_name = 'hypergeometric'
+    _fields_ = "_ngood", "_nbad", "_nsample", "_size"
+    _ngood = AnyField("ngood")
+    _nbad = AnyField("nbad")
+    _nsample = AnyField("nsample")
+    _func_name = "hypergeometric"
 
-    def __init__(self, state=None, size=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_state=state, _size=size, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     @property
     def ngood(self):
@@ -51,7 +52,9 @@ class TensorHypergeometric(TensorDistribution, TensorRandomOperandMixin):
         return self.new_tensor([ngood, nbad, nsample], None, raw_chunk_size=chunk_size)
 
 
-def hypergeometric(random_state, ngood, nbad, nsample, size=None, chunk_size=None, gpu=None, dtype=None):
+def hypergeometric(
+    random_state, ngood, nbad, nsample, size=None, chunk_size=None, gpu=None, dtype=None
+):
     r"""
     Draw samples from a Hypergeometric distribution.
 
@@ -145,8 +148,17 @@ def hypergeometric(random_state, ngood, nbad, nsample, size=None, chunk_size=Non
     #   answer = 0.003 ... pretty unlikely!
     """
     if dtype is None:
-        dtype = np.random.RandomState().hypergeometric(
-            handle_array(ngood), handle_array(nbad), handle_array(nsample), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .hypergeometric(
+                handle_array(ngood),
+                handle_array(nbad),
+                handle_array(nsample),
+                size=(0,),
+            )
+            .dtype
+        )
     size = random_state._handle_size(size)
-    op = TensorHypergeometric(state=random_state.to_numpy(), size=size, gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorHypergeometric(seed=seed, size=size, gpu=gpu, dtype=dtype)
     return op(ngood, nbad, nsample, chunk_size=chunk_size)
