@@ -23,14 +23,14 @@ from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorNoncentralF(TensorDistribution, TensorRandomOperandMixin):
-    _input_fields_ = ['_dfnum', '_dfden', '_nonc']
+    _input_fields_ = ["_dfnum", "_dfden", "_nonc"]
     _op_type_ = OperandDef.RAND_NONCENTRAL_F
 
-    _fields_ = '_dfnum', '_dfden', '_nonc', '_size'
-    _dfnum = AnyField('dfnum')
-    _dfden = AnyField('dfden')
-    _nonc = AnyField('nonc')
-    _func_name = 'noncentral_f'
+    _fields_ = "_dfnum", "_dfden", "_nonc", "_size"
+    _dfnum = AnyField("dfnum")
+    _dfden = AnyField("dfden")
+    _nonc = AnyField("nonc")
+    _func_name = "noncentral_f"
 
     def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
@@ -52,7 +52,9 @@ class TensorNoncentralF(TensorDistribution, TensorRandomOperandMixin):
         return self.new_tensor([dfnum, dfden, nonc], None, raw_chunk_size=chunk_size)
 
 
-def noncentral_f(random_state, dfnum, dfden, nonc, size=None, chunk_size=None, gpu=None, dtype=None):
+def noncentral_f(
+    random_state, dfnum, dfden, nonc, size=None, chunk_size=None, gpu=None, dtype=None
+):
     """
     Draw samples from the noncentral F distribution.
 
@@ -127,8 +129,13 @@ def noncentral_f(random_state, dfnum, dfden, nonc, size=None, chunk_size=None, g
     >>> plt.show()
     """
     if dtype is None:
-        dtype = np.random.RandomState().noncentral_f(
-            handle_array(dfnum), handle_array(dfden), handle_array(nonc), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .noncentral_f(
+                handle_array(dfnum), handle_array(dfden), handle_array(nonc), size=(0,)
+            )
+            .dtype
+        )
     size = random_state._handle_size(size)
     seed = gen_random_seeds(1, random_state.to_numpy())[0]
     op = TensorNoncentralF(size=size, seed=seed, gpu=gpu, dtype=dtype)
