@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,22 +17,23 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorNormal(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_loc', '_scale', '_size'
-    _input_fields_ = ['_loc', '_scale']
+    _input_fields_ = ["_loc", "_scale"]
     _op_type_ = OperandDef.RAND_NORMAL
 
-    _loc = AnyField('loc')
-    _scale = AnyField('scale')
-    _func_name = 'normal'
+    _fields_ = "_loc", "_scale", "_size"
+    _loc = AnyField("loc")
+    _scale = AnyField("scale")
+    _func_name = "normal"
 
-    def __init__(self, size=None, state=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_size=size, _state=state, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     @property
     def loc(self):
@@ -46,7 +47,9 @@ class TensorNormal(TensorDistribution, TensorRandomOperandMixin):
         return self.new_tensor([loc, scale], None, raw_chunk_size=chunk_size)
 
 
-def normal(random_state, loc=0.0, scale=1.0, size=None, chunk_size=None, gpu=None, dtype=None):
+def normal(
+    random_state, loc=0.0, scale=1.0, size=None, chunk_size=None, gpu=None, dtype=None
+):
     r"""
     Draw random samples from a normal (Gaussian) distribution.
 
@@ -141,8 +144,12 @@ def normal(random_state, loc=0.0, scale=1.0, size=None, chunk_size=None, gpu=Non
     >>> plt.show()
     """
     if dtype is None:
-        dtype = np.random.RandomState().normal(
-            handle_array(loc), handle_array(scale), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .normal(handle_array(loc), handle_array(scale), size=(0,))
+            .dtype
+        )
     size = random_state._handle_size(size)
-    op = TensorNormal(size=size, state=random_state.to_numpy(), gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorNormal(size=size, seed=seed, gpu=gpu, dtype=dtype)
     return op(loc, scale, chunk_size=chunk_size)
