@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,23 +17,26 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, TensorDistribution
 
 
 class TensorStandardExponential(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_size',
     _op_type_ = OperandDef.RAND_STANDARD_EXPONENTIAL
-    _func_name = 'standard_exponential'
+    _func_name = "standard_exponential"
+    _fields_ = ("_size",)
 
-    def __init__(self, size=None, state=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_size=size, _state=state, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     def __call__(self, chunk_size=None):
         return self.new_tensor(None, None, raw_chunk_size=chunk_size)
 
 
-def standard_exponential(random_state, size=None, chunk_size=None, gpu=None, dtype=None):
+def standard_exponential(
+    random_state, size=None, chunk_size=None, gpu=None, dtype=None
+):
     """
     Draw samples from the standard exponential distribution.
 
@@ -68,5 +71,6 @@ def standard_exponential(random_state, size=None, chunk_size=None, gpu=None, dty
     if dtype is None:
         dtype = np.random.RandomState().standard_exponential(size=(0,)).dtype
     size = random_state._handle_size(size)
-    op = TensorStandardExponential(size=size, state=random_state.to_numpy(), gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorStandardExponential(size=size, seed=seed, gpu=gpu, dtype=dtype)
     return op(chunk_size=chunk_size)
