@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,23 +17,24 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorTriangular(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_left', '_mode', '_right', '_size'
-    _input_fields_ = ['_left', '_mode', '_right']
+    _input_fields_ = ["_left", "_mode", "_right"]
     _op_type_ = OperandDef.RAND_TRIANGULAR
 
-    _left = AnyField('left')
-    _mode = AnyField('mode')
-    _right = AnyField('right')
-    _func_name = 'triangular'
+    _fields_ = "_left", "_mode", "_right", "_size"
+    _left = AnyField("left")
+    _mode = AnyField("mode")
+    _right = AnyField("right")
+    _func_name = "triangular"
 
-    def __init__(self, size=None, state=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_size=size, _state=state, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     @property
     def left(self):
@@ -51,7 +52,9 @@ class TensorTriangular(TensorDistribution, TensorRandomOperandMixin):
         return self.new_tensor([left, mode, right], None, raw_chunk_size=chunk_size)
 
 
-def triangular(random_state, left, mode, right, size=None, chunk_size=None, gpu=None, dtype=None):
+def triangular(
+    random_state, left, mode, right, size=None, chunk_size=None, gpu=None, dtype=None
+):
     r"""
     Draw samples from the triangular distribution over the
     interval ``[left, right]``.
@@ -119,8 +122,14 @@ def triangular(random_state, left, mode, right, size=None, chunk_size=None, gpu=
     >>> plt.show()
     """
     if dtype is None:
-        dtype = np.random.RandomState().triangular(
-            handle_array(left), handle_array(mode), handle_array(right), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .triangular(
+                handle_array(left), handle_array(mode), handle_array(right), size=(0,)
+            )
+            .dtype
+        )
     size = random_state._handle_size(size)
-    op = TensorTriangular(size=size, state=random_state.to_numpy(), gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorTriangular(size=size, seed=seed, gpu=gpu, dtype=dtype)
     return op(left, mode, right, chunk_size=chunk_size)
