@@ -23,13 +23,13 @@ from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorUniform(TensorDistribution, TensorRandomOperandMixin):
-    _input_fields_ = ['_low', '_high']
+    _input_fields_ = ["_low", "_high"]
     _op_type_ = OperandDef.RAND_UNIFORM
 
-    _fields_ = '_low', '_high', '_size'
-    _low = AnyField('low')
-    _high = AnyField('high')
-    _func_name = 'uniform'
+    _fields_ = "_low", "_high", "_size"
+    _low = AnyField("low")
+    _high = AnyField("high")
+    _func_name = "uniform"
 
     def __init__(self, size=None, state=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
@@ -47,7 +47,9 @@ class TensorUniform(TensorDistribution, TensorRandomOperandMixin):
         return self.new_tensor([low, high], None, raw_chunk_size=chunk_size)
 
 
-def uniform(random_state, low=0.0, high=1.0, size=None, chunk_size=None, gpu=None, dtype=None):
+def uniform(
+    random_state, low=0.0, high=1.0, size=None, chunk_size=None, gpu=None, dtype=None
+):
     r"""
     Draw samples from a uniform distribution.
 
@@ -130,8 +132,11 @@ def uniform(random_state, low=0.0, high=1.0, size=None, chunk_size=None, gpu=Non
     >>> plt.show()
     """
     if dtype is None:
-        dtype = np.random.RandomState().uniform(
-            handle_array(low), handle_array(high), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .uniform(handle_array(low), handle_array(high), size=(0,))
+            .dtype
+        )
     size = random_state._handle_size(size)
     seed = gen_random_seeds(1, random_state.to_numpy())[0]
     op = TensorUniform(size=size, seed=seed, gpu=gpu, dtype=dtype)
