@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,22 +17,23 @@
 import numpy as np
 
 from ... import opcodes as OperandDef
-from ...serialize import AnyField
+from ...serialization.serializables import AnyField
+from ..utils import gen_random_seeds
 from .core import TensorRandomOperandMixin, handle_array, TensorDistribution
 
 
 class TensorVonmises(TensorDistribution, TensorRandomOperandMixin):
-    __slots__ = '_mu', '_kappa', '_size'
-    _input_fields_ = ['_mu', '_kappa']
+    _input_fields_ = ["_mu", "_kappa"]
     _op_type_ = OperandDef.RAND_VONMISES
 
-    _mu = AnyField('mu')
-    _kappa = AnyField('kappa')
-    _func_name = 'vonmises'
+    _fields_ = "_mu", "_kappa", "_size"
+    _mu = AnyField("mu")
+    _kappa = AnyField("kappa")
+    _func_name = "vonmises"
 
-    def __init__(self, size=None, state=None, dtype=None, gpu=None, **kw):
+    def __init__(self, size=None, dtype=None, **kw):
         dtype = np.dtype(dtype) if dtype is not None else dtype
-        super().__init__(_size=size, _state=state, _dtype=dtype, _gpu=gpu, **kw)
+        super().__init__(_size=size, dtype=dtype, **kw)
 
     @property
     def mu(self):
@@ -130,9 +131,13 @@ def vonmises(random_state, mu, kappa, size=None, chunk_size=None, gpu=None, dtyp
     >>> plt.show()
     """
     if dtype is None:
-        dtype = np.random.RandomState().vonmises(
-            handle_array(mu), handle_array(kappa), size=(0,)).dtype
+        dtype = (
+            np.random.RandomState()
+            .vonmises(handle_array(mu), handle_array(kappa), size=(0,))
+            .dtype
+        )
 
     size = random_state._handle_size(size)
-    op = TensorVonmises(size=size, state=random_state.to_numpy(), gpu=gpu, dtype=dtype)
+    seed = gen_random_seeds(1, random_state.to_numpy())[0]
+    op = TensorVonmises(size=size, seed=seed, gpu=gpu, dtype=dtype)
     return op(mu, kappa, chunk_size=chunk_size)
