@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +18,8 @@ from .rechunk import rechunk
 def _install():
     from ..core import Tensor, TensorData
 
-    setattr(Tensor, 'rechunk', rechunk)
-    setattr(TensorData, 'rechunk', rechunk)
+    setattr(Tensor, "rechunk", rechunk)
+    setattr(TensorData, "rechunk", rechunk)
 
 
 _install()
