@@ -23,12 +23,17 @@ from .core import TensorReduction, TensorReductionMixin
 
 class TensorAny(TensorReduction, TensorReductionMixin):
     _op_type_ = OperandDef.ANY
-    _func_name = 'any'
+    _func_name = "any"
 
     def __init__(self, axis=None, keepdims=None, combine_size=None, stage=None, **kw):
         stage = self._rewrite_stage(stage)
-        super().__init__(_axis=axis, _keepdims=keepdims,
-                         _combine_size=combine_size, stage=stage, **kw)
+        super().__init__(
+            _axis=axis,
+            _keepdims=keepdims,
+            _combine_size=combine_size,
+            stage=stage,
+            **kw
+        )
 
 
 def any(a, axis=None, out=None, keepdims=None, combine_size=None):
@@ -104,7 +109,7 @@ def any(a, axis=None, out=None, keepdims=None, combine_size=None):
 
     """
     a = astensor(a)
-    if a.dtype == np.object_:
+    if a.dtype == object:
         dtype = a.dtype
     else:
         dtype = np.dtype(bool)
