@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,12 +21,17 @@ from .core import TensorReduction, TensorReductionMixin
 
 class TensorNanMax(TensorReduction, TensorReductionMixin):
     _op_type_ = OperandDef.NANMAX
-    _func_name = 'nanmax'
+    _func_name = "nanmax"
 
-    def __init__(self, axis=None, dtype=None, keepdims=None, combine_size=None, stage=None, **kw):
+    def __init__(self, axis=None, keepdims=None, combine_size=None, stage=None, **kw):
         stage = self._rewrite_stage(stage)
-        super().__init__(_axis=axis, _dtype=dtype, _keepdims=keepdims,
-                         _combine_size=combine_size, _stage=stage, **kw)
+        super().__init__(
+            _axis=axis,
+            _keepdims=keepdims,
+            _combine_size=combine_size,
+            stage=stage,
+            **kw
+        )
 
 
 def nanmax(a, axis=None, out=None, keepdims=None, combine_size=None):
@@ -114,5 +119,7 @@ def nanmax(a, axis=None, out=None, keepdims=None, combine_size=None):
 
     """
     a = astensor(a)
-    op = TensorNanMax(axis=axis, dtype=a.dtype, keepdims=keepdims, combine_size=combine_size)
+    op = TensorNanMax(
+        axis=axis, dtype=a.dtype, keepdims=keepdims, combine_size=combine_size
+    )
     return op(a, out=out)
