@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,16 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from... import opcodes
+import scipy.special as spspecial
+
 from ..arithmetic.utils import arithmetic_operand
 from ..utils import infer_dtype, implement_scipy
-from .core import spspecial, TensorSpecialUnaryOp
+from .core import TensorSpecialUnaryOp, _register_special_op
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorErf(TensorSpecialUnaryOp):
-    _op_code_ = opcodes.ERF
-    _func_name = 'erf'
+    _func_name = "erf"
 
 
 @implement_scipy(spspecial.erf)
