@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,9 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import scipy.special as spspecial
+
 from ..arithmetic.utils import arithmetic_operand
 from ..utils import infer_dtype, implement_scipy
-from .core import spspecial, TensorSpecialUnaryOp, TensorSpecialMultiOp, TensorSpecialBinOp
+from .core import (
+    TensorSpecialUnaryOp,
+    TensorSpecialMultiOp,
+    TensorSpecialBinOp,
+    _register_special_op,
+)
 
 
 class NoOrderSpecialMixin:
@@ -23,15 +30,16 @@ class NoOrderSpecialMixin:
         func = super()._get_func(xp)
 
         def _wrapped(*args, **kw):
-            kw.pop('order', None)
+            kw.pop("order", None)
             return func(*args, **kw)
 
         return _wrapped
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorGamma(TensorSpecialUnaryOp):
-    _func_name = 'gamma'
+    _func_name = "gamma"
 
 
 @implement_scipy(spspecial.gamma)
@@ -41,9 +49,10 @@ def gamma(x, **kwargs):
     return op(x)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorGammaln(TensorSpecialUnaryOp):
-    _func_name = 'gammaln'
+    _func_name = "gammaln"
 
 
 @implement_scipy(spspecial.gammaln)
@@ -88,9 +97,10 @@ def gammaln(x, out=None, where=None, **kwargs):
     return op(x, out=out, where=where)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorLogGamma(TensorSpecialUnaryOp):
-    _func_name = 'loggamma'
+    _func_name = "loggamma"
 
 
 @implement_scipy(spspecial.loggamma)
@@ -100,9 +110,10 @@ def loggamma(x, **kwargs):
     return op(x)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorGammaSgn(TensorSpecialUnaryOp):
-    _func_name = 'gammasgn'
+    _func_name = "gammasgn"
 
 
 @implement_scipy(spspecial.gammasgn)
@@ -112,9 +123,10 @@ def gammasgn(x, **kwargs):
     return op(x)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorGammaInc(TensorSpecialBinOp):
-    _func_name = 'gammainc'
+    _func_name = "gammainc"
 
 
 @implement_scipy(spspecial.gammainc)
@@ -124,9 +136,10 @@ def gammainc(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorGammaIncInv(TensorSpecialBinOp):
-    _func_name = 'gammaincinv'
+    _func_name = "gammaincinv"
 
 
 @implement_scipy(spspecial.gammaincinv)
@@ -136,9 +149,10 @@ def gammaincinv(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorGammaIncc(TensorSpecialBinOp):
-    _func_name = 'gammaincc'
+    _func_name = "gammaincc"
 
 
 @implement_scipy(spspecial.gammainc)
@@ -148,9 +162,10 @@ def gammaincc(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorGammaInccInv(TensorSpecialBinOp):
-    _func_name = 'gammainccinv'
+    _func_name = "gammainccinv"
 
 
 @implement_scipy(spspecial.gammainccinv)
@@ -160,9 +175,10 @@ def gammainccinv(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorBeta(TensorSpecialBinOp):
-    _func_name = 'beta'
+    _func_name = "beta"
 
 
 @implement_scipy(spspecial.beta)
@@ -172,9 +188,10 @@ def beta(a, b, out=None, **kwargs):
     return op(a, b, out=out)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorBetaLn(TensorSpecialBinOp):
-    _func_name = 'betaln'
+    _func_name = "betaln"
 
 
 @implement_scipy(spspecial.betaln)
@@ -184,9 +201,10 @@ def betaln(a, b, out=None, **kwargs):
     return op(a, b, out=out)
 
 
+@_register_special_op
 class TensorBetaInc(TensorSpecialMultiOp):
     _ARG_COUNT = 3
-    _func_name = 'betainc'
+    _func_name = "betainc"
 
 
 @implement_scipy(spspecial.betainc)
@@ -196,9 +214,10 @@ def betainc(a, b, x, out=None, **kwargs):
     return op(a, b, x, out=out)
 
 
+@_register_special_op
 class TensorBetaIncInv(TensorSpecialMultiOp):
     _ARG_COUNT = 3
-    _func_name = 'betaincinv'
+    _func_name = "betaincinv"
 
 
 @implement_scipy(spspecial.betaincinv)
@@ -208,9 +227,10 @@ def betaincinv(a, b, y, out=None, **kwargs):
     return op(a, b, y, out=out)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorPsi(TensorSpecialUnaryOp):
-    _func_name = 'psi'
+    _func_name = "psi"
 
 
 @implement_scipy(spspecial.psi)
@@ -220,9 +240,10 @@ def psi(x, out=None, **kwargs):
     return op(x, out=out)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorRGamma(TensorSpecialUnaryOp):
-    _func_name = 'rgamma'
+    _func_name = "rgamma"
 
 
 @implement_scipy(spspecial.rgamma)
@@ -232,9 +253,10 @@ def rgamma(x, out=None, **kwargs):
     return op(x, out=out)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorPolyGamma(NoOrderSpecialMixin, TensorSpecialBinOp):
-    _func_name = 'polygamma'
+    _func_name = "polygamma"
 
 
 @implement_scipy(spspecial.polygamma)
@@ -244,9 +266,10 @@ def polygamma(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorMultiGammaLn(NoOrderSpecialMixin, TensorSpecialBinOp):
-    _func_name = 'multigammaln'
+    _func_name = "multigammaln"
 
 
 @implement_scipy(spspecial.multigammaln)
@@ -256,9 +279,10 @@ def multigammaln(a, b, **kwargs):
     return op(a, b)
 
 
-@arithmetic_operand(sparse_mode='unary')
+@_register_special_op
+@arithmetic_operand(sparse_mode="unary")
 class TensorDiGamma(TensorSpecialUnaryOp):
-    _func_name = 'digamma'
+    _func_name = "digamma"
 
 
 @implement_scipy(spspecial.digamma)
@@ -268,9 +292,10 @@ def digamma(x, out=None, **kwargs):
     return op(x, out=out)
 
 
-@arithmetic_operand(sparse_mode='binary_and')
+@_register_special_op
+@arithmetic_operand(sparse_mode="binary_and")
 class TensorPoch(TensorSpecialBinOp):
-    _func_name = 'poch'
+    _func_name = "poch"
 
 
 @implement_scipy(spspecial.poch)
