@@ -110,7 +110,7 @@ def average(a, axis=None, weights=None, returned=False):
         wgt = astensor(weights)
 
         if issubclass(a.dtype.type, (np.integer, np.bool_)):
-            result_dtype = np.result_type(a.dtype, wgt.dtype, 'f8')
+            result_dtype = np.result_type(a.dtype, wgt.dtype, "f8")
         else:
             result_dtype = np.result_type(a.dtype, wgt.dtype)
 
@@ -118,21 +118,23 @@ def average(a, axis=None, weights=None, returned=False):
         if a.shape != wgt.shape:
             if axis is None:
                 raise TypeError(
-                    "Axis must be specified when shapes of a and weights "
-                    "differ.")
+                    "Axis must be specified when shapes of a and weights " "differ."
+                )
             if wgt.ndim != 1:
                 raise TypeError(
-                    "1D weights expected when shapes of a and weights differ.")
+                    "1D weights expected when shapes of a and weights differ."
+                )
             if wgt.shape[0] != a.shape[axis]:
                 raise ValueError(
-                    "Length of weights not compatible with specified axis.")
+                    "Length of weights not compatible with specified axis."
+                )
 
             # setup wgt to broadcast along axis
             wgt = broadcast_to(wgt, (a.ndim - 1) * (1,) + wgt.shape)
             wgt = swapaxes(wgt, -1, axis)
 
         scl = wgt.sum(axis=axis, dtype=result_dtype)
-        with np.errstate(divide='raise'):
+        with np.errstate(divide="raise"):
             avg = truediv(multiply(a, wgt, dtype=result_dtype).sum(axis), scl)
 
     if returned:
