@@ -1,4 +1,4 @@
-# Copyright 1999-2020 Alibaba Group Holding Ltd.
+# Copyright 1999-2021 Alibaba Group Holding Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,10 +19,10 @@ import numpy as np
 
 from ... import opcodes as OperandDef
 from ... import tensor as mt
-from ...serialize import AnyField, TupleField, KeyField, BoolField
-from ...tiles import TilesError
-from ...context import get_context
-from ...utils import check_chunks_unknown_shape, recursive_tile
+from ...core import recursive_tile
+from ...core.context import get_context
+from ...serialization.serializables import AnyField, TupleField, KeyField, BoolField
+from ...utils import has_unknown_shape
 from ..core import TENSOR_TYPE, TENSOR_CHUNK_TYPE, TensorOrder
 from ..operands import TensorOperand, TensorOperandMixin
 from ..datasource import tensor as astensor
@@ -49,27 +49,22 @@ class HistBinSelector:
         self._x = x
         self._range = range
         self._raw_range = raw_range
+        self._width = None
 
     def check(self):
-        if len(self._op._calc_bin_edges_dependencies) == 0:
-            # not checked before
-            width = self()
-            if width is None:
-                return
-            err = TilesError('bin edges calculation requires '
-                             'some dependencies executed first')
-            self._op._calc_bin_edges_dependencies = [width]
-            recursive_tile(width)
-            err.partial_tiled_chunks = [c.data for c in width.chunks]
-            raise err
+        # not checked before
+        width = self()
+        if width is None:
+            return
+        self._width = width = yield from recursive_tile(width)
+        yield [c.data for c in width.chunks]
 
     def __call__(self):
         return
 
     def get_result(self):
         ctx = get_context()
-        width = ctx.get_chunk_results(
-            [self._op._calc_bin_edges_dependencies[0].chunks[0].key])[0]
+        width = ctx.get_chunks_result([self._width.chunks[0].key])[0]
         return width
 
 
@@ -124,7 +119,7 @@ class HistBinScottSelector(HistBinSelector):
     """
 
     def __call__(self):
-        return (24.0 * np.pi**0.5 / self._x.size)**(1.0 / 3.0) * mt.std(self._x)
+        return (24.0 * np.pi**0.5 / self._x.size) ** (1.0 / 3.0) * mt.std(self._x)
 
 
 class HistBinStoneSelector(HistBinSelector):
@@ -180,9 +175,10 @@ class HistBinDoaneSelector(HistBinSelector):
 
         sg1 = np.sqrt(6.0 * (x.size - 2) / ((x.size + 1.0) * (x.size + 3)))
         sigma = mt.std(x)
-        g1 = mt.mean(((x - mt.mean(x)) / sigma)**3)
-        ret = _ptp(self._raw_range) / (1.0 + np.log2(x.size) +
-                                      mt.log2(1.0 + mt.absolute(g1) / sg1))
+        g1 = mt.mean(((x - mt.mean(x)) / sigma) ** 3)
+        ret = _ptp(self._raw_range) / (
+            1.0 + np.log2(x.size) + mt.log2(1.0 + mt.absolute(g1) / sg1)
+        )
         return mt.where(sigma > 0.0, ret, 0.0)
 
     def get_result(self):
@@ -235,10 +231,10 @@ class HistBinAutoSelector(HistBinSelector):
 
     def __init__(self, histogram_bin_edges_op, x, range, raw_range):
         super().__init__(histogram_bin_edges_op, x, range, raw_range)
-        self._bin_fd = HistBinFdSelector(
-            histogram_bin_edges_op, x, range, raw_range)
+        self._bin_fd = HistBinFdSelector(histogram_bin_edges_op, x, range, raw_range)
         self._bin_sturges = HistBinSturgesSelector(
-            histogram_bin_edges_op, x, range, raw_range)
+            histogram_bin_edges_op, x, range, raw_range
+        )
 
     def __call__(self):
         return self._bin_fd()
@@ -254,31 +250,35 @@ class HistBinAutoSelector(HistBinSelector):
 
 
 # Private dict initialized at module load time
-_hist_bin_selectors = {'stone': HistBinStoneSelector,
-                       'auto': HistBinAutoSelector,
-                       'doane': HistBinDoaneSelector,
-                       'fd': HistBinFdSelector,
-                       'rice': HistBinRiceSelector,
-                       'scott': HistBinScottSelector,
-                       'sqrt': HistBinSqrtSelector,
-                       'sturges': HistBinSturgesSelector}
+_hist_bin_selectors = {
+    "stone": HistBinStoneSelector,
+    "auto": HistBinAutoSelector,
+    "doane": HistBinDoaneSelector,
+    "fd": HistBinFdSelector,
+    "rice": HistBinRiceSelector,
+    "scott": HistBinScottSelector,
+    "sqrt": HistBinSqrtSelector,
+    "sturges": HistBinSturgesSelector,
+}
 
 
 def _ravel_and_check_weights(a, weights):
-    """ Check a and weights have matching shapes, and ravel both """
+    """Check a and weights have matching shapes, and ravel both"""
     a = astensor(a)
 
     # Ensure that the array is a "subtractable" dtype
     if a.dtype == np.bool_:
-        warnings.warn(f"Converting input from {a.dtype} to {np.uint8} for compatibility.",
-                      RuntimeWarning, stacklevel=3)
+        warnings.warn(
+            f"Converting input from {a.dtype} to {np.uint8} for compatibility.",
+            RuntimeWarning,
+            stacklevel=3,
+        )
         a = a.astype(np.uint8)
 
     if weights is not None:
         weights = astensor(weights)
         if weights.shape != a.shape:
-            raise ValueError(
-                'weights should have the same shape as a.')
+            raise ValueError("weights should have the same shape as a.")
         weights = weights.ravel()
     a = a.ravel()
     return a, weights
@@ -287,11 +287,9 @@ def _ravel_and_check_weights(a, weights):
 def _check_range(range):
     first_edge, last_edge = range
     if first_edge > last_edge:
-        raise ValueError(
-            'max must be larger than min in range parameter.')
+        raise ValueError("max must be larger than min in range parameter.")
     if not (np.isfinite(first_edge) and np.isfinite(last_edge)):
-        raise ValueError(
-            f"supplied range of [{first_edge}, {last_edge}] is not finite")
+        raise ValueError(f"supplied range of [{first_edge}, {last_edge}] is not finite")
     return first_edge, last_edge
 
 
@@ -328,7 +326,7 @@ def _unsigned_subtract(a, b):
         np.short: np.ushort,
         np.intc: np.uintc,
         np.int_: np.uint,
-        np.longlong: np.ulonglong
+        np.longlong: np.ulonglong,
     }
     dt = np.result_type(a, b)
     try:
@@ -338,7 +336,7 @@ def _unsigned_subtract(a, b):
     else:
         # we know the inputs are integers, and we are deliberately casting
         # signed to unsigned
-        return np.subtract(a, b, casting='unsafe', dtype=dt)
+        return np.subtract(a, b, casting="unsafe", dtype=dt)
 
 
 def _get_bin_edges(op, a, bins, range, weights):
@@ -362,11 +360,15 @@ def _get_bin_edges(op, a, bins, range, weights):
             n_equal_bins = 1
         else:
             # Do not call selectors on empty arrays
-            selector = _hist_bin_selectors[bin_name](op, a, (first_edge, last_edge), raw_range)
-            selector.check()
+            selector = _hist_bin_selectors[bin_name](
+                op, a, (first_edge, last_edge), raw_range
+            )
+            yield from selector.check()
             width = selector.get_result()
             if width:
-                n_equal_bins = int(np.ceil(_unsigned_subtract(last_edge, first_edge) / width))
+                n_equal_bins = int(
+                    np.ceil(_unsigned_subtract(last_edge, first_edge) / width)
+                )
             else:
                 # Width can be zero for some estimators, e.g. FD when
                 # the IQR of the data is zero.
@@ -381,8 +383,7 @@ def _get_bin_edges(op, a, bins, range, weights):
         assert mt.ndim(bins) == 1 and not isinstance(bins, TENSOR_TYPE)
         bin_edges = np.asarray(bins)
         if not is_asc_sorted(bin_edges):
-            raise ValueError(
-                '`bins` must increase monotonically, when an array')
+            raise ValueError("`bins` must increase monotonically, when an array")
 
     if n_equal_bins is not None:
         # numpy gh-10322 means that type resolution rules are dependent on array
@@ -394,31 +395,36 @@ def _get_bin_edges(op, a, bins, range, weights):
 
         # bin edges must be computed
         bin_edges = mt.linspace(
-            first_edge, last_edge, n_equal_bins + 1,
-            endpoint=True, dtype=bin_type, gpu=op.gpu)
+            first_edge,
+            last_edge,
+            n_equal_bins + 1,
+            endpoint=True,
+            dtype=bin_type,
+            gpu=op.gpu,
+        )
         return bin_edges, (first_edge, last_edge, n_equal_bins)
     else:
         return mt.tensor(bin_edges), None
 
 
 class TensorHistogramBinEdges(TensorOperand, TensorOperandMixin):
-    __slots__ = '_calc_bin_edges_dependencies',
     _op_type_ = OperandDef.HISTOGRAM_BIN_EDGES
 
-    _input = KeyField('input')
-    _bins = AnyField('bins')
-    _range = TupleField('range')
-    _weights = KeyField('weights')
-    _input_min = KeyField('input_min')
-    _input_max = KeyField('input_max')
-    _uniform_bins = TupleField('uniform_bins')
+    _input = KeyField("input")
+    _bins = AnyField("bins")
+    _range = TupleField("range")
+    _weights = KeyField("weights")
+    _uniform_bins = TupleField("uniform_bins")
 
-    def __init__(self, input=None, bins=None, range=None, weights=None,
-                 input_min=None, input_max=None, dtype=None, **kw):
-        super().__init__(_input=input, _bins=bins, _range=range, _weights=weights,
-                         _input_min=input_min, _input_max=input_max, _dtype=dtype, **kw)
-        if getattr(self, '_calc_bin_edges_dependencies', None) is None:
-            self._calc_bin_edges_dependencies = []
+    def __init__(
+        self,
+        input=None,
+        bins=None,
+        range=None,
+        weights=None,
+        **kw,
+    ):
+        super().__init__(_input=input, _bins=bins, _range=range, _weights=weights, **kw)
 
     @property
     def input(self):
@@ -436,14 +442,6 @@ class TensorHistogramBinEdges(TensorOperand, TensorOperandMixin):
     def weights(self):
         return self._weights
 
-    @property
-    def input_min(self):
-        return self._input_min
-
-    @property
-    def input_max(self):
-        return self._input_max
-
     def _set_inputs(self, inputs):
         super()._set_inputs(inputs)
         inputs_iter = iter(self._inputs)
@@ -452,10 +450,6 @@ class TensorHistogramBinEdges(TensorOperand, TensorOperandMixin):
             self._bins = next(inputs_iter)
         if self._weights is not None:
             self._weights = next(inputs_iter)
-        if self._input_min is not None:
-            self._input_min = next(inputs_iter)
-        if self._input_max is not None:
-            self._input_max = next(inputs_iter)
 
     def __call__(self, a, bins, range, weights):
         if range is not None:
@@ -467,11 +461,12 @@ class TensorHistogramBinEdges(TensorOperand, TensorOperandMixin):
             # if `bins` is a string for an automatic method,
             # this will replace it with the number of bins calculated
             if bin_name not in _hist_bin_selectors:
-                raise ValueError(
-                    f"{bin_name!r} is not a valid estimator for `bins`")
+                raise ValueError(f"{bin_name!r} is not a valid estimator for `bins`")
             if weights is not None:
-                raise TypeError("Automated estimation of the number of "
-                                "bins is not supported for weighted data")
+                raise TypeError(
+                    "Automated estimation of the number of "
+                    "bins is not supported for weighted data"
+                )
             if isinstance(range, tuple) and len(range) == 2:
                 # if `bins` is a string, e.g. 'auto', 'stone'...,
                 # and `range` provided as well,
@@ -483,67 +478,63 @@ class TensorHistogramBinEdges(TensorOperand, TensorOperandMixin):
             try:
                 n_equal_bins = operator.index(bins)
             except TypeError:  # pragma: no cover
-                raise TypeError(
-                    '`bins` must be an integer, a string, or an array')
+                raise TypeError("`bins` must be an integer, a string, or an array")
             if n_equal_bins < 1:
-                raise ValueError('`bins` must be positive, when an integer')
+                raise ValueError("`bins` must be positive, when an integer")
             shape = (bins + 1,)
         elif mt.ndim(bins) == 1:
             if not isinstance(bins, TENSOR_TYPE):
                 bins = np.asarray(bins)
                 if not is_asc_sorted(bins):
                     raise ValueError(
-                        '`bins` must increase monotonically, when an array')
+                        "`bins` must increase monotonically, when an array"
+                    )
             shape = astensor(bins).shape
         else:
-            raise ValueError('`bins` must be 1d, when an array')
+            raise ValueError("`bins` must be 1d, when an array")
 
         inputs = [a]
         if isinstance(bins, TENSOR_TYPE):
             inputs.append(bins)
         if weights is not None:
             inputs.append(weights)
-        if (a.size > 0 or np.isnan(a.size)) and \
-                (isinstance(bins, str) or mt.ndim(bins) == 0) and not range:
-            # for bins that is str or integer, requires min max calculated first
-            # dims need to be kept in case a is empty which causes errors in reduction
-            input_min = self._input_min = a.min(keepdims=True)
-            inputs.append(input_min)
-            input_max = self._input_max = a.max(keepdims=True)
-            inputs.append(input_max)
 
         return self.new_tensor(inputs, shape=shape, order=TensorOrder.C_ORDER)
 
     @classmethod
     def tile(cls, op):
         ctx = get_context()
+        a = op.input
         range_ = op.range
-        if isinstance(op.bins, str):
-            check_chunks_unknown_shape([op.input], TilesError)
-        if op.input_min is not None:
-            # check if input min and max are calculated
-            min_max_chunk_keys = \
-                [inp.chunks[0].key for inp in (op.input_min, op.input_max)]
-            metas = ctx.get_chunk_metas(min_max_chunk_keys)
-            if any(meta is None for meta in metas):
-                raise TilesError('`input_min` or `input_max` need be executed first')
-            range_results = ctx.get_chunk_results(min_max_chunk_keys)
+        bins = op.bins
+
+        if isinstance(bins, str):
+            if has_unknown_shape(op.input):
+                yield
+        if (
+            (a.size > 0 or np.isnan(a.size))
+            and (isinstance(bins, str) or mt.ndim(bins) == 0)
+            and not range_
+        ):
+            input_min = a.min(keepdims=True)
+            input_max = a.max(keepdims=True)
+            input_min, input_max = yield from recursive_tile(input_min, input_max)
+            chunks = [input_min.chunks[0], input_max.chunks[0]]
+            yield chunks
+            range_results = ctx.get_chunks_result([c.key for c in chunks])
             # make sure returned bounds are valid
             if all(x.size > 0 for x in range_results):
                 range_ = tuple(x[0] for x in range_results)
-        if isinstance(op.bins, TENSOR_TYPE):
+        if isinstance(bins, TENSOR_TYPE):
             # `bins` is a Tensor, needs to be calculated first
-            bins_chunk_keys = [c.key for c in op.bins.chunks]
-            metas = ctx.get_chunk_metas(bins_chunk_keys)
-            if any(meta is None for meta in metas):
-                raise TilesError('`bins` should be executed first if it\'s a tensor')
-            bin_datas = ctx.get_chunk_results(bins_chunk_keys)
+            yield
+            bin_datas = ctx.get_chunks_result([c.key for c in bins.chunks])
             bins = np.concatenate(bin_datas)
         else:
             bins = op.bins
 
-        bin_edges, _ = _get_bin_edges(op, op.input, bins, range_, op.weights)
-        bin_edges = bin_edges._inplace_tile()
+        bin_edges, _ = yield from _get_bin_edges(op, op.input, bins, range_, op.weights)
+        bin_edges = yield from recursive_tile(bin_edges)
         return [bin_edges]
 
 
@@ -751,26 +742,41 @@ def histogram_bin_edges(a, bins=10, range=None, weights=None):
 
     """
     a, weights = _ravel_and_check_weights(a, weights)
-    op = TensorHistogramBinEdges(input=a, bins=bins,
-                                 range=range, weights=weights,
-                                 dtype=a.dtype)
+    op = TensorHistogramBinEdges(
+        input=a, bins=bins, range=range, weights=weights, dtype=a.dtype
+    )
     return op(a, bins, range, weights)
 
 
 class TensorHistogram(TensorOperand, TensorOperandMixin):
     _op_type_ = OperandDef.HISTOGRAM
 
-    _input = KeyField('input')
-    _bins = AnyField('bins')
-    _range = TupleField('range')
-    _weights = KeyField('weights')
-    _density = BoolField('density')
-    _ret_bins = BoolField('ret_bins')
+    _input = KeyField("input")
+    _bins = AnyField("bins")
+    _range = TupleField("range")
+    _weights = KeyField("weights")
+    _density = BoolField("density")
+    _ret_bins = BoolField("ret_bins")
 
-    def __init__(self, input=None, bins=None, range=None, weights=None,
-                 density=None, ret_bins=None, **kw):
-        super().__init__(_input=input, _bins=bins, _range=range, _weights=weights,
-                         _density=density, _ret_bins=ret_bins, **kw)
+    def __init__(
+        self,
+        input=None,
+        bins=None,
+        range=None,
+        weights=None,
+        density=None,
+        ret_bins=None,
+        **kw,
+    ):
+        super().__init__(
+            _input=input,
+            _bins=bins,
+            _range=range,
+            _weights=weights,
+            _density=density,
+            _ret_bins=ret_bins,
+            **kw,
+        )
 
     @property
     def input(self):
@@ -812,8 +818,8 @@ class TensorHistogram(TensorOperand, TensorOperandMixin):
     def __call__(self, a, bins, range, weights):
         a, weights = _ravel_and_check_weights(a, weights)
         histogram_bin_edges_op = TensorHistogramBinEdges(
-            input=a, bins=bins, range=range, weights=weights,
-            dtype=np.dtype(np.float64))
+            input=a, bins=bins, range=range, weights=weights, dtype=np.dtype(np.float64)
+        )
         bins = self._bins = histogram_bin_edges_op(a, bins, range, weights)
 
         inputs = [histogram_bin_edges_op.input]
@@ -825,10 +831,11 @@ class TensorHistogram(TensorOperand, TensorOperandMixin):
         else:
             inputs.append(weights)
             dtype = weights.dtype
-        self._dtype = dtype
+        self.dtype = dtype
 
-        hist = self.new_tensor(inputs, shape=(bins.size - 1,),
-                               order=TensorOrder.C_ORDER)
+        hist = self.new_tensor(
+            inputs, shape=(bins.size - 1,), order=TensorOrder.C_ORDER
+        )
         return mt.ExecutableTuple([hist, bins])
 
     @classmethod
@@ -839,7 +846,7 @@ class TensorHistogram(TensorOperand, TensorOperandMixin):
         weights = None
         if op.weights is not None:
             # make input and weights have the same nsplits
-            weights = op.weights.rechunk(op.input.nsplits)._inplace_tile()
+            weights = yield from recursive_tile(op.weights.rechunk(op.input.nsplits))
 
         out_chunks = []
         for chunk in op.input.chunks:
@@ -851,19 +858,25 @@ class TensorHistogram(TensorOperand, TensorOperandMixin):
             if weights is not None:
                 weights_chunk = weights.cix[chunk.index]
                 chunk_inputs.append(weights_chunk)
-            out_chunk = chunk_op.new_chunk(chunk_inputs, shape=shape,
-                                           index=chunk.index, order=out.order)
+            out_chunk = chunk_op.new_chunk(
+                chunk_inputs, shape=shape, index=chunk.index, order=out.order
+            )
             out_chunks.append(out_chunk)
 
         # merge chunks together
         chunk = chunk_tree_add(out.dtype, out_chunks, (0,), shape)
         new_op = op.copy()
-        n = new_op.new_tensor(op.inputs, shape=shape, order=out.order,
-                              chunks=[chunk], nsplits=((shape[0],),))
+        n = new_op.new_tensor(
+            op.inputs,
+            shape=shape,
+            order=out.order,
+            chunks=[chunk],
+            nsplits=((shape[0],),),
+        )
         if op.density:
             db = mt.array(mt.diff(bins), float)
             hist = n / db / n.sum()
-            recursive_tile(hist)
+            hist = yield from recursive_tile(hist)
             return [hist]
         else:
             return [n]
@@ -871,15 +884,17 @@ class TensorHistogram(TensorOperand, TensorOperandMixin):
     @classmethod
     def execute(cls, ctx, op):
         inputs, device_id, xp = as_same_device(
-            [ctx[inp.key] for inp in op.inputs], device=op.device, ret_extra=True)
+            [ctx[inp.key] for inp in op.inputs], device=op.device, ret_extra=True
+        )
         a = inputs[0]
         bins = inputs[1] if isinstance(op.bins, TENSOR_CHUNK_TYPE) else op.bins
         weights = None
         if op.weights is not None:
             weights = inputs[-1]
         with device(device_id):
-            hist, bin_edges = xp.histogram(a, bins=bins, range=op.range,
-                                           weights=weights, density=op.density)
+            hist, bin_edges = xp.histogram(
+                a, bins=bins, range=op.range, weights=weights, density=op.density
+            )
             ctx[op.outputs[0].key] = hist
             if op.ret_bins:
                 ctx[op.outputs[1].key] = bin_edges
@@ -985,6 +1000,7 @@ def histogram(a, bins=10, range=None, weights=None, density=None):
 
     """
     a, weights = _ravel_and_check_weights(a, weights)
-    op = TensorHistogram(input=a, bins=bins, range=range,
-                         weights=weights, density=density)
+    op = TensorHistogram(
+        input=a, bins=bins, range=range, weights=weights, density=density
+    )
     return op(a, bins, range, weights)
